@@ -5,7 +5,7 @@
  * Project led by Terence Parr at http://www.jGuru.com
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: BaseAST.hpp 312 2008-07-05 17:40:12Z vadim $
+ * $Id: BaseAST.hpp 2969 2010-06-08 20:42:31Z vadim $
  */
 
 #include <antlr/config.hpp>
@@ -137,12 +137,12 @@ public:
 	}
 
 	/// Set the token text for this node
-	virtual void setText(const ANTLR_USE_NAMESPACE(std)string& txt)
+	virtual void setText(const ANTLR_USE_NAMESPACE(std)string& /*UNUSED txt */)
 	{
 	}
 
 	/// Set the token type for this node
-	virtual void setType(int type)
+	virtual void setType(int /*UNUSED type */)
 	{
 	}
 
