@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Helper.h 312 2008-07-05 17:40:12Z vadim $
+  $Id: Helper.h 1706 2009-11-10 05:14:04Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -65,19 +65,11 @@ namespace fwcompiler {
 
         /**
          * recursively expands object 'o' and places all its children
-         * objects in the list 'ol'. Uses cache in compiler.
+         * objects in the list 'ol'.
          */
         void expand_group_recursive(libfwbuilder::FWObject *o,
                                     std::list<libfwbuilder::FWObject*> &ol);
 
-        /**
-         * recursively expands object 'o' and places all its children
-         * objects in the list 'ol'. Does not use cache in compiler,
-         * therefore can be called even if compiler object has not
-         * been created yet.
-         */
-        void expand_group_recursive_no_cache(libfwbuilder::FWObject *o,
-                                             std::list<libfwbuilder::FWObject*> &ol);
 
     };
 
