@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_pix.cpp 2479 2010-02-01 06:39:24Z vadim $
+  $Id: NATCompiler_pix.cpp 2800 2010-04-09 02:29:27Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -81,7 +81,8 @@ NATCompiler_pix::NATCompiler_pix(FWObjectDatabase *_db,
 void NATCompiler_pix::_expand_addr_recursive_pix(Rule *rule,
                                                  FWObject *re,
                                                  FWObject *s,
-                                                 list<FWObject*> &ol)
+                                                 list<FWObject*> &ol,
+                                                 bool expand_cluster_interfaces_fully)
 {
     Interface *rule_iface = Interface::cast(dbcopy->findInIndex(rule->getInterfaceId()));
     bool odst_or_tsrc = (re->getTypeName() == RuleElementODst::TYPENAME ||
@@ -139,53 +140,29 @@ void NATCompiler_pix::_expand_addr_recursive_pix(Rule *rule,
                     continue;
                 }
 
-                _expand_interface(rule, i2itf, ol);
+                _expand_interface(rule, i2itf, ol, expand_cluster_interfaces_fully);
                 continue;
             }
-            _expand_addr_recursive_pix(rule, re, *i2, ol);
+            _expand_addr_recursive_pix(rule, re, *i2, ol, expand_cluster_interfaces_fully);
         }
     }
 }
 
 
 void NATCompiler_pix::_expand_addr_recursive(Rule *rule, FWObject *re,
-                                             list<FWObject*> &ol)
+                                             list<FWObject*> &ol,
+                                             bool expand_cluster_interfaces_fully)
 {
-    _expand_addr_recursive_pix(rule, re, re, ol);
+    _expand_addr_recursive_pix(rule, re, re, ol, expand_cluster_interfaces_fully);
 }
 
 
 void NATCompiler_pix::_expand_interface(Rule *rule,
                                         Interface *iface,
-                                        std::list<FWObject*> &ol)
+                                        std::list<FWObject*> &ol,
+                                        bool expand_cluster_interfaces_fully)
 {
-    FWObject *parent = iface->getParentHost();
-    if (Cluster::cast(parent) == NULL)
-    {
-        Compiler::_expand_interface(rule, iface, ol);
-        return;
-    }
-
-    FailoverClusterGroup *failover_group = FailoverClusterGroup::cast(
-        iface->getFirstByType(FailoverClusterGroup::TYPENAME));
-    if (failover_group)
-    {
-        Interface *member_iface =
-            failover_group->getInterfaceForMemberFirewall(fw);
-        if (member_iface)
-        {
-            Compiler::_expand_interface(rule, member_iface, ol);
-            return;
-        }
-        
-        QString err("Failover group of cluster interface '%1' (%2) "
-                    "does not include interface for the member '%3'");
-        abort(rule,
-              err.
-              arg(iface->getName().c_str()).
-              arg(iface->getLabel().c_str()).
-              arg(fw->getName().c_str()).toStdString());
-    }
+    Compiler::_expand_interface(rule, iface, ol, expand_cluster_interfaces_fully);
 }
 
 string NATCompiler_pix::getNATACLname(Rule *rule,int nat_id)
