@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_cisco.cpp 1152 2009-07-13 15:45:49Z vadim $
+  $Id: PolicyCompiler_cisco.cpp 2479 2010-02-01 06:39:24Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -41,13 +41,6 @@
 #include "fwbuilder/AddressTable.h"
 
 #include <iostream>
-#if __GNUC__ > 3 || \
-    (__GNUC__ == 3 && (__GNUC_MINOR__ > 2 || (__GNUC_MINOR__ == 2 ) ) ) || \
-     _MSC_VER
-#  include <streambuf>
-#else
-#  include <streambuf.h>
-#endif
 #include <iomanip>
 #include <algorithm>
 #include <functional>
@@ -61,11 +54,13 @@ using namespace std;
 string PolicyCompiler_cisco::myPlatformName() { return ""; }
 
 PolicyCompiler_cisco::PolicyCompiler_cisco(FWObjectDatabase *_db,
-                                           const std::string &fwname,
+                                           Firewall *fw,
                                            bool ipv6_policy,
                                            OSConfigurator *_oscnf) :
-    PolicyCompiler(_db, fwname, ipv6_policy, _oscnf) , helper(this)
+    PolicyCompiler(_db, fw, ipv6_policy, _oscnf) , helper(this)
 {
+    object_groups = new Group();
+    dbcopy->add( object_groups );
 }
 
 int PolicyCompiler_cisco::prolog()
@@ -88,13 +83,18 @@ string PolicyCompiler_cisco::createRuleLabel(const string &txt,
 
 string PolicyCompiler_cisco::debugPrintRule(Rule *r)
 {
-    PolicyRule *rule=PolicyRule::cast(r);
-    Interface  *rule_iface = getCachedFwInterface(rule->getInterfaceId());
-    string iname=(rule_iface!=NULL)?rule_iface->getName():"";
-    string dir= rule->getDirectionAsString();
+    ostringstream str;
+    PolicyRule *rule = PolicyRule::cast(r);
+    FWObject *rule_iface = dbcopy->findInIndex(rule->getInterfaceId());
+    string iname = (rule_iface!=NULL)?rule_iface->getName():"";
 
-    return PolicyCompiler::debugPrintRule(rule)+
-        " "+dir+" "+iname+" "+rule->getStr("acl");
+    string dir = rule->getDirectionAsString();
+
+    str << PolicyCompiler::debugPrintRule(rule) <<
+        " " << dir << " " << iname << " " << rule->getStr("acl") <<
+        " intfId=" << rule->getInterfaceId() <<
+        " intfstr=" << rule->getInterfaceStr();
+    return str.str();
 }
 
 
@@ -106,66 +106,27 @@ void PolicyCompiler_cisco::addDefaultPolicyRule()
     if ( getCachedFwOpt()->getBool("mgmt_ssh") &&
          !getCachedFwOpt()->getStr("mgmt_addr").empty() )
     {
-        PolicyRule *r;
         TCPService *ssh = dbcopy->createTCPService();
         ssh->setDstRangeStart(22);
         ssh->setDstRangeEnd(22);
-        dbcopy->add(ssh,false);
-        cacheObj(ssh); // to keep cache consistent
+        dbcopy->add(ssh, false);
+
+        TCPService *ssh_rev = dbcopy->createTCPService();
+        ssh_rev->setSrcRangeStart(22);
+        ssh_rev->setSrcRangeEnd(22);
+        dbcopy->add(ssh_rev, false);
 
         Network *mgmt_workstation = dbcopy->createNetwork();
         mgmt_workstation->setAddressNetmask(
             getCachedFwOpt()->getStr("mgmt_addr"));
 
         dbcopy->add(mgmt_workstation, false);
-        cacheObj(mgmt_workstation); // to keep cache consistent
 
-        r= dbcopy->createPolicyRule();
-        temp_ruleset->add(r);
-        r->setAction(PolicyRule::Accept);
-        r->setLogging(false);
-        r->setDirection(PolicyRule::Inbound);
-        r->setPosition(-1);
-//        r->setComment("   backup ssh access rule ");
-        r->setHidden(true);
-        r->setFallback(false);
-        r->setLabel("backup ssh access rule");
-
-        RuleElement *src=RuleElement::cast(
-            r->getFirstByType(RuleElementSrc::TYPENAME) );
-        src->addRef(mgmt_workstation);
-
-        RuleElement *dst=RuleElement::cast(
-            r->getFirstByType(RuleElementDst::TYPENAME) );
-        dst->addRef(fw);
-
-        RuleElement *srv=RuleElement::cast(
-            r->getFirstByType(RuleElementSrv::TYPENAME) );
-        srv->addRef(ssh);
-
-        combined_ruleset->push_front(r);
+        PolicyCompiler::addMgmtRule(
+            mgmt_workstation, fw, ssh,
+            NULL, PolicyRule::Inbound, PolicyRule::Accept,
+            "backup ssh access rule");
     }
-
-    // Ciscos provide built-in fallback rule so we do not need
-    // this. Besides, desired behavior is that if the user did not
-    // create any rules for a given interface (at all), then generated
-    // config file should have none. Adding fallback rule here creates
-    // 'deny any any' rule for such interfaces and screws things big
-    // time.
-#if 0
-    PolicyRule *r= dbcopy->createPolicyRule();
-
-    temp_ruleset->add(r);
-    r->setAction(PolicyRule::Deny);
-    r->setLogging(false);
-//    r->setDirection(PolicyRule::Both);
-    r->setPosition(10000);
-    r->setComment("   fallback rule ");
-    r->setLabel("fallback rule");
-    r->setFallback(true);
-    r->setHidden(true);
-    combined_ruleset->push_back(r);
-#endif
 }
 
 bool PolicyCompiler_cisco::splitIfSrcAny::processNext()
@@ -437,7 +398,7 @@ bool PolicyCompiler_cisco::specialCaseWithDynInterface::dropDynamicInterface(
     PolicyRule  *rule, PolicyRule::Direction cmp_dir, RuleElement *re)
 {
     PolicyRule::Direction dir=rule->getDirection();
-    Interface  *rule_iface = compiler->getCachedFwInterface(rule->getInterfaceId());
+    FWObject *rule_iface = compiler->dbcopy->findInIndex(rule->getInterfaceId());
 
     list<FWObject*> cl;
     for (list<FWObject*>::iterator i1=re->begin(); i1!=re->end(); ++i1) 
@@ -542,7 +503,10 @@ bool PolicyCompiler_cisco::tcpServiceToFW::processNext()
             RuleElementDst *ndst=r->getDst();
             ndst->clearChildren();
             ndst->setAnyElement();
-//            ndst->addRef( compiler->fw );
+
+            // Was commented out in r50
+            ndst->addRef( compiler->fw );
+
             RuleElementSrv *nsrv=r->getSrv();
             nsrv->clearChildren();
             nsrv->add( cl.front() );
@@ -570,7 +534,7 @@ bool PolicyCompiler_cisco::tcpServiceToFW::processNext()
 bool PolicyCompiler_cisco::replaceFWinSRCInterfacePolicy::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
-    Interface  *rule_iface = compiler->getCachedFwInterface(rule->getInterfaceId());
+    FWObject *rule_iface = compiler->dbcopy->findInIndex(rule->getInterfaceId());
 
     if (rule_iface!=NULL && rule->getDirection()==PolicyRule::Outbound)
     {
@@ -590,7 +554,7 @@ bool PolicyCompiler_cisco::replaceFWinSRCInterfacePolicy::processNext()
 bool PolicyCompiler_cisco::replaceFWinDSTInterfacePolicy::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
-    Interface  *rule_iface = compiler->getCachedFwInterface(rule->getInterfaceId());
+    FWObject *rule_iface = compiler->dbcopy->findInIndex(rule->getInterfaceId());
 
     if (rule_iface!=NULL && rule->getDirection()==PolicyRule::Inbound)
     {
@@ -615,7 +579,7 @@ bool PolicyCompiler_cisco::replaceFWinDSTPolicy::processNext()
 {
     Helper helper(compiler);
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
-    Interface  *rule_iface = compiler->getCachedFwInterface(rule->getInterfaceId());
+    FWObject *rule_iface = compiler->dbcopy->findInIndex(rule->getInterfaceId());
 
     if (rule_iface==NULL)
     {
@@ -628,7 +592,7 @@ bool PolicyCompiler_cisco::replaceFWinDSTPolicy::processNext()
             {
                 int iface_id = helper.findInterfaceByNetzone(
                     compiler->getFirstSrc(rule));
-                Interface *iface = compiler->getCachedFwInterface(iface_id);
+                FWObject *iface = compiler->dbcopy->findInIndex(iface_id);
 
                 dst->clearChildren();
                 dst->addRef(iface);
@@ -636,10 +600,9 @@ bool PolicyCompiler_cisco::replaceFWinDSTPolicy::processNext()
             {
                 ostringstream str;
                 str << "Address " << addr
-                    << " does not match address or network zone of any interface. Rule " 
-                    << rule->getLabel()
-                    << endl;
-                compiler->abort(str.str());
+                    << " does not match address or network zone of any interface." ;
+                compiler->abort(rule, str.str());
+                return true;
             }
         }
     }
@@ -710,7 +673,7 @@ bool PolicyCompiler_cisco::splitByNetworkZonesForRE::processNext()
                     compiler->fw->getStr("platform"), "network_zones");
 
             if (supports_network_zones)
-                compiler->warning(err + " Rule " + rule->getLabel());
+                compiler->warning(rule, err);
 
             FWObjectTypedChildIterator i =
                 compiler->fw->findByType(Interface::TYPENAME);
@@ -754,9 +717,7 @@ bool PolicyCompiler_cisco::removeRedundantAddresses::processNext()
     std::list<FWObject*> cl;
     for (list<FWObject*>::iterator i1=re->begin(); i1!=re->end(); ++i1) 
     {
-	FWObject *obj = *i1;
-	if (FWReference::cast(obj)!=NULL) obj=FWReference::cast(obj)->getPointer();
-        Address *a=Address::cast(obj);
+        Address *a = Address::cast(FWReference::getObject(*i1));
         assert(a!=NULL);   // assuming all objects are addresses.
         addrmap[a] = *i1;
     }
@@ -765,22 +726,23 @@ bool PolicyCompiler_cisco::removeRedundantAddresses::processNext()
          i1!=addrmap.end(); ++i1)
     {
         Address *a1 = i1->first;
-
+        const InetAddrMask* am1 = a1->getInetAddrMaskObjectPtr();
         for (std::map<Address*,FWObject*>::iterator i2=addrmap.begin();
              i2!=addrmap.end(); ++i2)
         {
             Address *a2 = i2->first;
-            if (a1==a2) continue;
+            const InetAddrMask* am2 = a2->getInetAddrMaskObjectPtr();
+            if (am1 && am2 && am1->toString() == am2->toString()) continue;
             if (compiler->checkForShadowing(*a1, *a2) ) cl.push_back(i1->second);
         }
     }
 
-    if (!cl.empty()) {
+    if (!cl.empty())
+    {
         for (list<FWObject*>::iterator i1=cl.begin(); i1!=cl.end(); ++i1)  
             re->remove( (*i1) );
     }
 
-
     tmp_queue.push_back(rule);
     return true;
 }
@@ -796,7 +758,12 @@ bool PolicyCompiler_cisco::processMultiAddressObjectsInRE::processNext()
         if (FWReference::cast(o)!=NULL) o = FWReference::cast(o)->getPointer();
         MultiAddress *atrt = MultiAddress::cast(o);
         if (atrt!=NULL && atrt->isRunTime())
-            compiler->abort("Run-time AddressTable and DNSName objects are not supported. Rule " + rule->getLabel());
+        {
+            compiler->abort(
+                    rule, 
+                    "Run-time AddressTable and DNSName objects are not supported.");
+            return true;
+        }
     }
 
     tmp_queue.push_back(rule);
