@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_iosacl.cpp 2569 2010-02-19 04:33:13Z vadim $
+  $Id: PolicyCompiler_iosacl.cpp 2899 2010-05-12 21:28:50Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -67,8 +67,9 @@ PolicyCompiler_iosacl::PolicyCompiler_iosacl(FWObjectDatabase *_db,
                                              OSConfigurator *_oscnf) :
     PolicyCompiler_cisco(_db, fw, ipv6_policy, _oscnf)
 {
-    resetinbound=false;
-    fragguard=false;
+    resetinbound = false;
+    fragguard = false;
+    comment_symbol = "!";
 }
 
 int PolicyCompiler_iosacl::prolog()
@@ -80,11 +81,13 @@ int PolicyCompiler_iosacl::prolog()
     if (platform!="iosacl")
 	abort("Unsupported platform " + platform );
 
+    fw->getOptionsObject()->setBool(
+        "use_acl_remarks",
+        fw->getOptionsObject()->getBool("iosacl_use_acl_remarks"));
+
     object_groups = new Group();
     dbcopy->add( object_groups );
 
-//    output << "!################"  << endl;
-
     return PolicyCompiler::prolog();
 }
 
@@ -375,6 +378,10 @@ void PolicyCompiler_iosacl::compile()
         add( new processMultiAddressObjectsInDst(
                  "process MultiAddress objects in Dst") );
 
+        add( new expandGroupsInItf("expand groups in Interface" ));
+        add( new replaceClusterInterfaceInItf(
+                 "replace cluster interfaces with member interfaces in the Interface rule element"));
+
         add( new ItfNegation( "process negation in Itf" ) );
         add( new InterfacePolicyRules(
                  "process interface policy rules and store interface ids") );
@@ -479,7 +486,7 @@ void PolicyCompiler_iosacl::compile()
     }
 }
 
-string PolicyCompiler_iosacl::printAccessGroupCmd(ciscoACL *acl)
+string PolicyCompiler_iosacl::printAccessGroupCmd(ciscoACL *acl, bool neg)
 {
     ostringstream str;
 
@@ -493,6 +500,7 @@ string PolicyCompiler_iosacl::printAccessGroupCmd(ciscoACL *acl)
         if (acl->direction()=="out" || acl->direction()=="Outbound") dir="out";
 
         str << "interface " << acl->getInterface()->getName() << endl;
+        if (neg) str << "  no";
         str << "  " << addr_family_prefix << " ";
         str << getAccessGroupCommandForAddressFamily(ipv6);
         str << " " << acl->workName() << " " << dir << endl;
@@ -508,7 +516,7 @@ void PolicyCompiler_iosacl::epilog()
     for (map<string,ciscoACL*>::iterator i=acls.begin(); i!=acls.end(); ++i) 
     {
         ciscoACL *acl=(*i).second;
-        if (acl->size()!=0) output << printAccessGroupCmd(acl);
+        if (acl->size()!=0) output << printAccessGroupCmd(acl, false);
     }
     output << endl;
 
