@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pix.cpp 2479 2010-02-01 06:39:24Z vadim $
+  $Id: PolicyCompiler_pix.cpp 2800 2010-04-09 02:29:27Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -183,39 +183,10 @@ int PolicyCompiler_pix::prolog()
 
 void PolicyCompiler_pix::_expand_interface(Rule *rule,
                                            Interface *iface,
-                                           std::list<FWObject*> &ol)
+                                           std::list<FWObject*> &ol,
+                                           bool expand_cluster_interfaces_fully)
 {
-    FWObject *parent = iface->getParentHost();
-    if (Cluster::cast(parent) == NULL)
-    {
-        Compiler::_expand_interface(rule, iface, ol);
-        return;
-    }
-
-    FWObject *failover_group = iface->getFirstByType(FailoverClusterGroup::TYPENAME);
-    if (failover_group)
-    {
-        for (FWObjectTypedChildIterator it =
-                 failover_group->findByType(FWObjectReference::TYPENAME);
-             it != it.end(); ++it)
-        {
-            Interface *member_iface =
-                Interface::cast(FWObjectReference::getObject(*it));
-            assert(member_iface);
-            if (member_iface->isChildOf(fw))
-            {
-                Compiler::_expand_interface(rule, member_iface, ol);
-                return;
-            }
-        }
-        QString err("Failover group of cluster interface '%1' (%2) "
-                    "does not include interface for the member '%3'");
-        abort(rule,
-              err.
-              arg(iface->getName().c_str()).
-              arg(iface->getLabel().c_str()).
-              arg(fw->getName().c_str()).toStdString());
-    }
+    Compiler::_expand_interface(rule, iface, ol, expand_cluster_interfaces_fully);
 }
 
 
@@ -658,6 +629,9 @@ void PolicyCompiler_pix::compile()
         add( new processMultiAddressObjectsInDst(
                  "process MultiAddress objects in Dst"));
 
+        add( new expandGroupsInItf("expand groups in Interface" ));
+        add( new replaceClusterInterfaceInItf(
+                 "replace cluster interfaces with member interfaces in the Interface rule element"));
         add( new ItfNegation( "process negation in Itf" ));
         add( new InterfacePolicyRules(
                  "process interface policy rules and store interface ids"));
