@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: CompilerDriver.cpp 2655 2010-03-04 06:09:02Z vadim $
+  $Id: CompilerDriver.cpp 3082 2010-07-14 23:22:49Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -108,7 +108,9 @@ CompilerDriver::~CompilerDriver()
 // create a copy of itself, including objdb
 CompilerDriver* CompilerDriver::clone()
 {
-    return new CompilerDriver(objdb);
+    CompilerDriver* new_cd = new CompilerDriver(objdb);
+    if (inEmbeddedMode()) new_cd->setEmbeddedMode();
+    return new_cd;
 }
 
 bool CompilerDriver::configure(const QStringList &args)
@@ -751,15 +753,8 @@ QTextStream& operator<< (QTextStream &text_stream, const string &str)
  */
 string CompilerDriver::indent(int n_spaces, const string &txt)
 {
-    ostringstream output;
-    istringstream str(txt);
-    char line[65536];
-    while (!str.eof())
-    {
-        str.getline(line, sizeof(line));
-        output << std::setw(n_spaces) << std::setfill(' ') << " " << line << endl;
-    }
-    return output.str();
+    QString res = indent(n_spaces, QString(txt.c_str()));
+    return res.toStdString();
 }
 
 QString CompilerDriver::indent(int n_spaces, const QString &txt)
@@ -768,12 +763,17 @@ QString CompilerDriver::indent(int n_spaces, const QString &txt)
     return prepend(fill, txt);
 }
 
+/*
+ * prepend each line in @txt with @prep, however there is no need to
+ * prepend empty lines
+ */
 QString CompilerDriver::prepend(const QString &prep, const QString &txt)
 {
     QStringList str;
     foreach (QString line, txt.split("\n"))
     {
-        str.append(line.prepend(prep));
+        if (line.isEmpty()) str.append(line);
+        else str.append(line.prepend(prep));
     }
     return str.join("\n");
 }
@@ -977,7 +977,7 @@ void CompilerDriver::populateClusterElements(Cluster *cluster, Firewall *fw)
  *   addresses of the firewalls (perhaps this restriction can be
  *   lifted? Was originally implemented by Secunet folks like this)
  */
-void CompilerDriver::copyFailoverInterface(Cluster *cluster,
+void CompilerDriver::copyFailoverInterface(Cluster * /*UNUSED cluster */,
                                            Firewall *fw,
                                            FailoverClusterGroup *cluster_group,
                                            Interface *iface)
@@ -1020,39 +1020,6 @@ void CompilerDriver::copyFailoverInterface(Cluster *cluster,
     new_cl_if->setUnprotected(iface->isUnprotected());
     
     fw->getOptionsObject()->setBool("cluster_member", true);
-
-    /* Add copy of firewall's real interface to the cluster to make sure
-     * compiler recognizes it when it encounters cluster object in rules.
-     * This fixes #15 (makes compiler choose correct chains)
-     *
-     * Update 01/31/2010:
-     *
-     * Example of rule where this is necessary is anti-spoofing
-     * rule. When cluster object is placed in rule element, it is
-     * assumed that it represents its own addresses, plus addresses of
-     * the members.
-     *
-     * A copy of the member interface does not have
-     * FailoverClusterGroup child object and is not recognized as
-     * failover interface. This is important when this interface is
-     * dynamic. When cluster object is used in the rule and then
-     * replaced with all its interfaces in one of the rule processors,
-     * this copy interface appears as having cluster as a parent, not
-     * the firewall that is being compiled. This creates problems with
-     * processing of dynamic interfaces. They look like they belong to
-     * some other object and trigger "can use dynamic interface
-     * because its address is unknown" error.
-     *
-     * However there is no need to add a copy of the interface of the
-     * member to the cluster if this interface is dynamic or
-     * unnumbered. Corresponding cluster interface inherits isDyn()
-     * property and is sufficient. This is for ticket #1184
-     */
-    if ( ! iface->isDyn() && ! iface->isUnnumbered())
-    {
-        FWObject *new_member_if = cluster->addCopyOf(iface, true);
-        new_member_if->setBool("member_interface_copy", true);
-    }
 }
 
 /**
@@ -1150,3 +1117,30 @@ QString CompilerDriver::formSingleRuleCompileOutput(const QString &generated_cod
     return res;
 }
 
+/*
+ * Replace ' ' with '\ ' in the string. 
+ *
+ * DO NOT CHANGE WITHOUT EXTENSIVE TESTING OF THE POLICY INSTALLER !
+ *
+ * This is used in different places to deal with generated files with
+ * spaces in the name. This can happen if firewall object name has
+ * spaces. This method of escaping the space is used when we generate
+ * manifest line in the .fw file to find other generated files. The
+ * same method is also used to generate command line arguments for scp
+ * where spaces cause all sorts of problems, for example scp can't
+ * find the file to copy or issues "ambiguous target" error when
+ * remote file name has a space. Finally, the same method is used to
+ * escape space in the file name before using it for the configlet
+ * variable because this name is used in the shell script that we run
+ * on the firewall.
+ */
+QString CompilerDriver::escapeFileName(QString fileName)
+{
+    return fileName.replace(' ', "\\ ");
+}
+
+QString CompilerDriver::unescapeFileName(QString fileName)
+{
+    return fileName.replace("\\ ", " ");
+}
+
