@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: interfaceProperties.cpp 2317 2010-01-07 00:17:32Z vadim $
+  $Id: interfaceProperties.cpp 2958 2010-06-07 22:40:54Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -63,6 +63,21 @@ bool interfaceProperties::looksLikeVlanInterface(const QString &int_name)
     return parseVlan(int_name, NULL, NULL);
 }
 
+// simple name validation: does not allow space and "-"
+// However some platform permit space (procurve).
+bool interfaceProperties::basicValidateInterfaceName(Interface *intf,
+                                                     const QString &obj_name,
+                                                     QString &err)
+{
+    if (obj_name.indexOf(' ') != -1 || obj_name.indexOf('-') != -1)
+    {
+        err = QObject::tr("Interface name '%1' can not contain white space and \"-\"").arg(obj_name);
+        return false;
+    }
+    return true;
+}
+    
+
 /*
  * While looksLikeVlanInterface only checks interface name format,
  * this method does more detailed check to determine if the interface
@@ -148,6 +163,7 @@ bool interfaceProperties::manageIpAddresses(Interface *intf,
     if (intf->isDyn()) return false;
     if (intf->isBridgePort()) return false;
     if (intf->isSlave()) return false;
+    if (intf->isUnnumbered()) return false;   // see #1506
 
     string intf_name = intf->getName();
 
