@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: linux24Interfaces.h 1778 2009-11-16 23:38:14Z vadim $
+  $Id: linux24Interfaces.h 2907 2010-05-16 03:09:14Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -33,7 +33,11 @@ class linux24Interfaces : public interfaceProperties
 {
 public:
     linux24Interfaces() : interfaceProperties() {}
-    
+    virtual ~linux24Interfaces() {}
+
+    virtual bool basicValidateInterfaceName(libfwbuilder::Interface *intf,
+                                            const QString &proposed_name,
+                                            QString &err);
     virtual bool parseVlan(const QString&, QString*, int*);
     virtual void rearrangeInterfaces(
         std::map<int,libfwbuilder::InterfaceData> &interfaces,
