@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: ActionsDialog.h 952 2009-05-20 21:54:45Z vadim $
+  $Id: ActionsDialog.h 1891 2009-11-24 03:40:50Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -29,6 +29,7 @@
 
 #include "../../config.h"
 #include <ui_actionsdialog_q.h>
+#include "BaseObjectDialog.h"
 #include "DialogData.h"
 #include <QWidget>
 
@@ -38,24 +39,27 @@
 
 namespace libfwbuilder
 {
-    class PolicyRule;
+    class Rule;
     class Firewall;
 }
 
 class QLineEdit;
 class QComboBox;
 class FWObjectDropArea;
-class ActionsDialog : public QWidget
+
+
+class ActionsDialog : public BaseObjectDialog
 {
-    Q_OBJECT
- private:
+    Q_OBJECT;
+
+private:
     libfwbuilder::Firewall *firewall; 
-    libfwbuilder::PolicyRule *rule; 
-    std::string               editor;
-    std::string               platform;
-    QLineEdit                *branchNameInput;
+    libfwbuilder::Rule *rule; 
+    std::string editor;
+    std::string platform;
+    QLineEdit *branchNameInput;
     
-    DialogData                data;
+    DialogData data;
     FWObjectDropArea * BranchChainArea ;
     FWObjectDropArea * BranchAnchorArea;
     FWObjectDropArea * TagIntArea ;
@@ -67,33 +71,21 @@ class ActionsDialog : public QWidget
     Ui::ActionsDialog_q *m_dialog;
      
     ActionsDialog(QWidget *parent);
-    
     ~ActionsDialog();
-    virtual void closeEvent(QCloseEvent *e);
+
     void fillInterfaces(QComboBox *);
 
 
 public slots:
-    virtual void changed();
     virtual void applyChanges();
-    virtual void discardChanges();
     virtual void tagvalueChanged(int);
     virtual void iptRouteContinueToggled();
     virtual void loadFWObject(libfwbuilder::FWObject *obj);
     virtual void validate(bool*);
-    virtual void isChanged(bool*);
     virtual void getHelpName(QString*);
-    void setRule(libfwbuilder::PolicyRule*);
-    
- signals:
-/**
- * This signal is emitted from closeEvent, ObjectEditor connects
- * to this signal to make checks before the object editor can be closed
- * and to store its position on the screen
- */
-    void close_sign(QCloseEvent *e);
-    void changed_sign();
+    void setRule(libfwbuilder::Rule*);
     
+
 };
 
 #endif 
