@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: AddressTableDialog.cpp 1932 2009-11-26 03:26:24Z vadim $
+  $Id: AddressTableDialog.cpp 3039 2010-06-28 23:48:34Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -157,7 +157,7 @@ void AddressTableDialog::browse()
     QString s = QFileDialog::getOpenFileName(this,
                     "Choose a file",
                     dir,
-                    "All files (*.*)");
+                    "All files (*)");
 
     if (!s.isEmpty())
     {
