@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: CommentEditorPanel.cpp 952 2009-05-20 21:54:45Z vadim $
+  $Id: CommentEditorPanel.cpp 2129 2009-12-13 20:59:05Z yalovoy $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -32,6 +32,9 @@
 #include "FWBSettings.h"
 #include "ObjectManipulator.h"
 #include "FWWindow.h"
+#include "FWCmdRule.h"
+
+#include <memory>
 
 #include <qmessagebox.h>
 #include <qfiledialog.h>
@@ -49,32 +52,29 @@ CommentEditorPanel::~CommentEditorPanel()
     delete m_widget;
 }
 
-CommentEditorPanel::CommentEditorPanel(QWidget *p,
-                                   bool enableLoadFromFile):QWidget(p)
+CommentEditorPanel::CommentEditorPanel(QWidget *p) : BaseObjectDialog(p)
 {
     m_widget = new Ui::CommentEditorPanel_q;
     m_widget->setupUi(this);
+    m_widget->inputFromFileButton->hide();
+    rule=NULL;
+}
 
+void CommentEditorPanel::setFileInput(bool enableLoadFromFile)
+{
     if (enableLoadFromFile) m_widget->inputFromFileButton->show();
     else                    m_widget->inputFromFileButton->hide();
-
-    //m_widget->editor->setTextFormat(QTextEdit::PlainText);
-    rule=NULL;
-    //editor->setText(txt);
 }
 
 QString CommentEditorPanel::text()
 {
     return m_widget->editor->toPlainText();
 }
+
 void CommentEditorPanel::setText(QString s)
 {
     m_widget->editor->setText(s);
 }
-void CommentEditorPanel::setTitle(QString s)
-{
-    m_widget->editorTitle->setText(s);
-}
 
 void CommentEditorPanel::loadFromFile()
 {
@@ -113,12 +113,16 @@ void CommentEditorPanel::changed()
 
 void CommentEditorPanel::applyChanges()
 {
-    if (fwbdebug) qDebug("CommentEditorPanel::applyChanges()");
+    std::auto_ptr<FWCmdRuleChange> cmd( new FWCmdRuleChangeComment(m_project, rule));
+    // new_state  is a copy of the rule object
+    FWObject* new_state = cmd->getNewState();
 
-    mw->updateLastModifiedTimestampForAllFirewalls(rule);
-    rule->setComment(
+    new_state->setComment(
         string(m_widget->editor->toPlainText().toUtf8().constData())
     );
+
+    if (!cmd->getOldState()->cmp(new_state, true))
+        m_project->undoStack->push(cmd.release());
 }
 
 void CommentEditorPanel::getHelpName(QString *str)
@@ -128,24 +132,9 @@ void CommentEditorPanel::getHelpName(QString *str)
 
 void CommentEditorPanel::loadFWObject(FWObject *obj)
 {
-    Rule *r=Rule::cast(obj);
-
-    rule=r;
-
-    FWObject *o = r;
-    while (o!=NULL && Firewall::cast(o)==NULL) o=o->getParent();
-    assert(o!=NULL);
-    Firewall *f=Firewall::cast(o);
-
+    Rule *r = Rule::cast(obj);
+    rule = r;
     setText(QString::fromUtf8(r->getComment().c_str()));
-    setTitle(QString("%1 / %2 / %3 ( Comment )")
-            .arg(QString::fromUtf8(f->getName().c_str()))
-            .arg(r->getTypeName().c_str())
-            .arg(r->getPosition()));
-}
-
-void CommentEditorPanel::discardChanges()
-{
 }
 
 void CommentEditorPanel::validate(bool* b)
@@ -153,12 +142,4 @@ void CommentEditorPanel::validate(bool* b)
     *b=true;
 }
 
-void CommentEditorPanel::isChanged(bool*)
-{
 
-}
-
-void CommentEditorPanel::closeEvent(QCloseEvent *e)
-{
-    emit close_sign(e);
-}
