@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: DNSNameDialog.cpp 952 2009-05-20 21:54:45Z vadim $
+  $Id: DNSNameDialog.cpp 2135 2009-12-14 21:07:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -29,12 +29,16 @@
 
 #include "DNSNameDialog.h"
 #include "ProjectPanel.h"
+#include "FWBSettings.h"
+#include "FWCmdChange.h"
 
 #include "fwbuilder/Library.h"
 #include "fwbuilder/DNSName.h"
 #include "fwbuilder/Interface.h"
 #include "fwbuilder/FWException.h"
 
+#include <memory>
+
 #include <qlineedit.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
@@ -46,7 +50,7 @@
 #include <qpushbutton.h>
 #include <qapplication.h>
 #include <qcursor.h>
-#include "FWBSettings.h"
+#include <QUndoStack>
 
 #include <iostream>
 
@@ -54,7 +58,7 @@
 using namespace std;
 using namespace libfwbuilder;
 
-DNSNameDialog::DNSNameDialog(ProjectPanel *project, QWidget *parent) : QWidget(parent), m_project(project)
+DNSNameDialog::DNSNameDialog(QWidget *parent) : BaseObjectDialog(parent)
 {
     m_dialog = new Ui::DNSNameDialog_q;
     m_dialog->setupUi(this);
@@ -98,65 +102,49 @@ void DNSNameDialog::loadFWObject(FWObject *o)
     m_dialog->comment->setReadOnly(o->isReadOnly());
     setDisabledPalette(m_dialog->comment);
 
+    if (st->getBool("Objects/DNSName/useNameForDNSRecord"))
+        m_dialog->dnsrec->setEnabled(false);
 
 
     init=false;
 }
 
-void DNSNameDialog::changed()
-{
-    //apply->setEnabled( true );
-    emit changed_sign();
-}
-
 void DNSNameDialog::validate(bool *res)
 {
     *res=true;
     DNSName *s = dynamic_cast<DNSName*>(obj);
     assert(s!=NULL);
 
-    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
     if (!validateName(this,obj,m_dialog->obj_name->text())) { *res=false; return; }
 }
 
-void DNSNameDialog::isChanged(bool*)
-{
-   // *res=(!init && apply->isEnabled());
-}
 
-void DNSNameDialog::libChanged()
-{
-    changed();
-}
 
 void DNSNameDialog::applyChanges()
 {
-    DNSName *s = dynamic_cast<DNSName*>(obj);
+    std::auto_ptr<FWCmdChange> cmd( new FWCmdChange(m_project, obj));
+    FWObject* new_state = cmd->getNewState();
+
+    DNSName *s = dynamic_cast<DNSName*>(new_state);
     assert(s!=NULL);
 
-    string oldname=obj->getName();
-    obj->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
-    obj->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
+    string oldname = obj->getName();
+    new_state->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
+    new_state->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
 
-    s->setSourceName( m_dialog->dnsrec->text().toLatin1().constData() );
     s->setRunTime(m_dialog->r_runtime->isChecked() );
 
-    mw->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
+    if (st->getBool("Objects/DNSName/useNameForDNSRecord") &&
+        m_dialog->obj_name->text() != m_dialog->dnsrec->text())
+        m_dialog->dnsrec->setText(m_dialog->obj_name->text());
 
-    //apply->setEnabled( false );
-    mw->updateLastModifiedTimestampForAllFirewalls(obj);
-}
+    s->setSourceName( m_dialog->dnsrec->text().toLatin1().constData() );
 
-void DNSNameDialog::discardChanges()
-{
-    loadFWObject(obj);
-}
-
-
-void DNSNameDialog::closeEvent(QCloseEvent *e)
-{
-    if (fwbdebug)
-        qDebug("DNSNameDialog::closeEvent  got close event: %p",e);
-    emit close_sign(e);
+    if (!cmd->getOldState()->cmp(new_state, true))
+    {
+        if (obj->isReadOnly()) return;
+        m_project->undoStack->push(cmd.release());
+    }
+    
 }
 
