@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: DNSNameDialog.h 952 2009-05-20 21:54:45Z vadim $
+  $Id: DNSNameDialog.h 2135 2009-12-14 21:07:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -29,45 +29,29 @@
 
 #include "../../config.h"
 #include <ui_dnsnamedialog_q.h>
+#include "BaseObjectDialog.h"
 #include <QWidget>
 
 #include "fwbuilder/FWObject.h"
 
 class ProjectPanel;
 
-class DNSNameDialog : public QWidget
+class DNSNameDialog : public BaseObjectDialog
 {
-    Q_OBJECT
+    Q_OBJECT;
 
-    libfwbuilder::FWObject *obj;
-    bool init;
     Ui::DNSNameDialog_q *m_dialog;
-    ProjectPanel *m_project;
 
  public:
-     DNSNameDialog(ProjectPanel *project, QWidget *parent);
+     DNSNameDialog(QWidget *parent);
      ~DNSNameDialog();
-    virtual void closeEvent(QCloseEvent *e);
     
 public slots:
-    virtual void changed();
-    virtual void libChanged();
     virtual void applyChanges();
-    virtual void discardChanges();
     virtual void loadFWObject(libfwbuilder::FWObject *obj);
     virtual void validate(bool*);
-    virtual void isChanged(bool*);
     virtual void getHelpName(QString*);
     
- signals:
-/**
- * This signal is emitted from closeEvent, ObjectEditor connects
- * to this signal to make checks before the object editor can be closed
- * and to store its position on the screen
- */
-    void close_sign(QCloseEvent *e);
-    void changed_sign();
-    
 };
 
 #endif 
