@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: DialogFactory.cpp 2373 2010-01-17 21:29:16Z vadim $
+  $Id: DialogFactory.cpp 2891 2010-05-11 17:01:08Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -64,8 +64,9 @@
 #include "pixAdvancedDialog.h"
 #include "iosaclAdvancedDialog.h"
 #include "ipcopAdvancedDialog.h"
-
 #include "secuwallAdvancedDialog.h"
+#include "procurveaclAdvancedDialog.h"
+
 #include "linux24IfaceOptsDialog.h"
 #include "secuwallIfaceOptsDialog.h"
 #include "vlanOnlyIfaceOptsDialog.h"
@@ -83,6 +84,7 @@
 #include "pixosAdvancedDialog.h"
 #include "iosAdvancedDialog.h"
 #include "ipcoposAdvancedDialog.h"
+#include "secuwallosAdvancedDialog.h"
 
 #include "RuleOptionsDialog.h"
 #include "RoutingRuleOptionsDialog.h"
@@ -230,6 +232,8 @@ QWidget *DialogFactory::createFWDialog(QWidget *parent, FWObject *o)
         "/FWBuilderResources/Target/dialog");
     if (platform == "iptables" && os_family == "ipcop")
         dlgname = "ipcop";
+    if (platform == "iptables" && os_family == "secuwall")
+        dlgname = "secuwall";
 
     if (dlgname=="iosacl")   return new iosaclAdvancedDialog(parent,o);
     if (dlgname=="ipcop")    return new ipcopAdvancedDialog(parent,o);
@@ -238,6 +242,8 @@ QWidget *DialogFactory::createFWDialog(QWidget *parent, FWObject *o)
     if (dlgname=="iptables") return new iptAdvancedDialog(parent,o);
     if (dlgname=="pf")       return new pfAdvancedDialog(parent,o);
     if (dlgname=="pix")      return new pixAdvancedDialog(parent,o);
+    if (dlgname=="secuwall") return new secuwallAdvancedDialog(parent,o);
+    if (dlgname=="procurveacl") return new procurveaclAdvancedDialog(parent,o);
 
     cerr << "Firewall settings dialog for " << dlgname
          << " is not implemented" << endl;
@@ -269,7 +275,7 @@ QWidget *DialogFactory::createOSDialog(QWidget *parent,FWObject *o)
     if (dlgname=="pix_os")    return new pixosAdvancedDialog(parent, o);
     if (dlgname=="ios")       return new iosAdvancedDialog(parent, o);
     if (dlgname=="ipcop")     return new ipcoposAdvancedDialog(parent, o);
-    if (dlgname=="secuwall")  return new secuwallAdvancedDialog(parent, o);
+    if (dlgname=="secuwall")  return new secuwallosAdvancedDialog(parent, o);
 
     cerr << "OS settings dialog for " << dlgname
          << " is not implemented" << endl;
@@ -289,7 +295,8 @@ QWidget *DialogFactory::createIfaceDialog(QWidget *parent,FWObject *o)
                               QObject::tr("Support module for %1 is not available").
                               arg(host_OS.c_str()).toLocal8Bit().constData()));
 
-    string dlgname = os->Resources::getResourceStr("/FWBuilderResources/Target/interface_dialog");
+    string dlgname = os->Resources::getResourceStr(
+        "/FWBuilderResources/Target/interface_dialog");
 
     // add further dlgname support here ...
 
