@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: DialogFactory.h 304 2008-07-03 02:19:16Z vadim $
+  $Id: DialogFactory.h 2153 2009-12-15 23:36:04Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -23,21 +23,43 @@
 
 */
 
-#include <qwidget.h>
+#ifndef _DIALOGFACTORY_HH_
+#define _DIALOGFACTORY_HH_
+
+#include "BaseObjectDialog.h"
+
+#include <QWidget>
 
 namespace libfwbuilder {
     class FWObject;
     class FWException;
+    class Firewall;
+    class Rule;
 };
-class ProjectPanel;
-class DialogFactory {
 
+
+class DialogFactory {
  public:
 
-    static QWidget *createDialog(ProjectPanel *project, QWidget *parent,const QString &objType);
+    static BaseObjectDialog *createDialog(QWidget *parent,const QString &objType);
+
     static QWidget *createFWDialog(QWidget *parent,libfwbuilder::FWObject *o)
         throw(libfwbuilder::FWException);
     static QWidget *createOSDialog(QWidget *parent,libfwbuilder::FWObject *o)
         throw(libfwbuilder::FWException);
-    
+    static QWidget *createIfaceDialog(QWidget *parent,libfwbuilder::FWObject *o)
+        throw(libfwbuilder::FWException);
+    static QWidget *createClusterConfDialog(QWidget *parent, libfwbuilder::FWObject *o)
+        throw(libfwbuilder::FWException);
+    static QString getClusterGroupOptionsDialogName(libfwbuilder::FWObject *o);
+    static QWidget *createClusterGroupOptionsDialog(QWidget *parent, libfwbuilder::FWObject *o)
+        throw(libfwbuilder::FWException);
+
+    static std::string getActionDialogPageName(libfwbuilder::Firewall *fw,
+                                               libfwbuilder::Rule *rule);
+
 };
+
+
+
+#endif
