@@ -7,7 +7,7 @@
   Author:  Vadim Kurland     vadim@fwbuilder.org
            Illiya Yalovoy    <yalovoy@gmail.com>
 
-  $Id: DiscoveryDruid.cpp 2441 2010-01-26 19:28:41Z vadim $
+  $Id: DiscoveryDruid.cpp 3081 2010-07-14 19:26:11Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -82,6 +82,7 @@
 #include "fwbuilder/Logger.h"
 
 #include "FWBSettings.h"
+#include "UserWorkflow.h"
 #include "ObjectManipulator.h"
 #include "FWWindow.h"
 
@@ -162,9 +163,7 @@ DiscoveryDruid::DiscoveryDruid(QWidget *parent, bool start_with_import) :
     m_dialog->dm_usesnmp->setEnabled(false);
 #endif
 
-#ifndef HAVE_ANTLR_RUNTIME
     m_dialog->dm_import_config->setEnabled(false);
-#endif
 
     restore();
 
@@ -173,7 +172,6 @@ DiscoveryDruid::DiscoveryDruid(QWidget *parent, bool start_with_import) :
     showPage(0);
     setNextEnabled(0, true);
 
-#ifdef HAVE_ANTLR_RUNTIME
     if (start_with_import)
     {
         m_dialog->dm_import_config->setDown(true);
@@ -184,7 +182,6 @@ DiscoveryDruid::DiscoveryDruid(QWidget *parent, bool start_with_import) :
         setNextEnabled(2, true);
         cancelButton->show();
     }
-#endif
 
     prg_timer->start(100);
 }
@@ -601,7 +598,7 @@ void DiscoveryDruid::browseHostsFile()
                     this,
                     "Choose a file",
                     dir,
-                    "All files (*.*)");
+                    "All files (*)");
     
     if (!s.isEmpty())
     {
@@ -621,7 +618,7 @@ void DiscoveryDruid::browseForImport()
                     this,
                     "Choose a file",
                     dir,
-                    "All files (*.*)");
+                    "All files (*)");
     
     if (!s.isEmpty())
     {
@@ -776,6 +773,9 @@ void DiscoveryDruid::startConfigImport()
         thread = new ConfigImport(buffer, platform);
         thread->setTargetWidget(this);
         thread->start();
+
+        wfl->registerFlag(UserWorkflow::IMPORT, true);
+
     } else
     {
         QMessageBox::critical(this, tr("Discovery error"),
@@ -1315,24 +1315,28 @@ void DiscoveryDruid::loadDataFromImporter()
     if (imp!=NULL)
     {
         Firewall *fw = imp->finalize();
-        ProjectPanel *pp = mw->activeProject();
-        QString filename = pp->getFileName();
-        //pp->m_panel->om->reload();
-        //pp->m_panel->om->autoRenameChildren(fw, "");
+        if (fw) // fw can be NULL if import was uncussessful
+        {
 
-        QCoreApplication::postEvent(mw, new reloadObjectTreeEvent(filename));
-        if (mw->isEditorVisible())
+            ProjectPanel *pp = mw->activeProject();
+            QString filename = pp->getFileName();
+            //pp->m_panel->om->reload();
+            //pp->m_panel->om->autoRenameChildren(fw, "");
+
+            QCoreApplication::postEvent(mw, new reloadObjectTreeEvent(filename));
+            if (mw->isEditorVisible())
+                QCoreApplication::postEvent(
+                    mw, new openObjectInEditorEvent(filename, fw->getId()));
             QCoreApplication::postEvent(
-                mw, new openObjectInEditorEvent(filename, fw->getId()));
-        QCoreApplication::postEvent(
-            mw, new showObjectInTreeEvent(filename, fw->getId()));
+                mw, new showObjectInTreeEvent(filename, fw->getId()));
 
-        // Open first created Policy ruleset object
-        FWObject *first_policy = fw->getFirstByType(Policy::TYPENAME);
-        if (first_policy)
-            QCoreApplication::postEvent(
-                mw, new openRulesetEvent(filename, first_policy->getId()));
+            // Open first created Policy ruleset object
+            FWObject *first_policy = fw->getFirstByType(Policy::TYPENAME);
+            if (first_policy)
+                QCoreApplication::postEvent(
+                    mw, new openRulesetEvent(filename, first_policy->getId()));
 
+        }
     }
 }
 
