@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWBSettings.cpp 2672 2010-03-07 06:28:49Z vadim $
+  $Id: FWBSettings.cpp 3065 2010-07-12 03:01:52Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -35,16 +35,19 @@
 #include <qtextbrowser.h>
 #include <qmessagebox.h>
 #include <qapplication.h>
+
 #include <QDir>
 #include <QDesktopWidget>
 #include <QUuid>
 #include <QRegExp>
 #include <QtDebug>
+#include <QCryptographicHash>
 
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
+#include <time.h>
 
 #ifdef _WIN32
 #  include <direct.h>
@@ -80,6 +83,8 @@ const char* groupColsSetpath = SETTINGS_PATH_PREFIX "/UI/GroupViewColumns";
 const char* objTooltips = SETTINGS_PATH_PREFIX "/UI/objTooltips";
 const char* tooltipDelay = SETTINGS_PATH_PREFIX "/UI/tooltipDelay";
 const char* showUndoPanel = SETTINGS_PATH_PREFIX "/UI/showUndoPanel";
+const char* userWorkflowFlags = SETTINGS_PATH_PREFIX "/UI/userWorkFlowFlags";
+const char* iconsWithText = SETTINGS_PATH_PREFIX "/UI/IconWithText";
 
 const char* emptyRCSLog = SETTINGS_PATH_PREFIX "/RCS/emptyLog";
 const char* rcsFilePreviewStyle = SETTINGS_PATH_PREFIX "/RCS/FilePreviewStyle";
@@ -89,8 +94,6 @@ const char* dontSaveStdLib = SETTINGS_PATH_PREFIX "/DataFormat/dontSaveStdLib";
 const char* WindowGeometrySetpath= SETTINGS_PATH_PREFIX "/Layout/";
 const char* screenPositionSetpath= SETTINGS_PATH_PREFIX "/ScreenPos/";
 
-const char* SSHPath = SETTINGS_PATH_PREFIX "/SSH/SSHPath";
-const char* SCPPath = SETTINGS_PATH_PREFIX "/SSH/SCPPath";
 const char* showIconsInRules = SETTINGS_PATH_PREFIX "/UI/Icons/ShowIconsInRules";
 const char* showDirectionText = SETTINGS_PATH_PREFIX "/UI/Icons/ShowDirectionTextInRules";
 const char* iconsInRulesSize = SETTINGS_PATH_PREFIX "/UI/Icons/IconsInRulesSize";
@@ -103,6 +106,7 @@ const char* clipComment = SETTINGS_PATH_PREFIX "/UI/ClipComment";
 
 const char* checkUpdates = SETTINGS_PATH_PREFIX "/UI/CheckUpdates";
 const char* updateAvailableWarningLastTime = SETTINGS_PATH_PREFIX "/UI/updateAvailableWarningLastTime";
+const char* announcementLastTime = SETTINGS_PATH_PREFIX "/UI/announcementLastTime/%1";
 const char* checkUpdatesProxy = SETTINGS_PATH_PREFIX "/UI/CheckUpdatesProxy";
 
 const char* newFirewallPlatform = SETTINGS_PATH_PREFIX "/Objects/NewFireallPlatform";
@@ -111,14 +115,49 @@ const char* appGUID = SETTINGS_PATH_PREFIX "/ApplicationGUID";
 
 const char* targetStatus = SETTINGS_PATH_PREFIX "/TargetStatus/";
 
+const char* SSHPath = SETTINGS_PATH_PREFIX "/SSH/SSHPath";
+const char* SCPPath = SETTINGS_PATH_PREFIX "/SSH/SCPPath";
+
+#ifdef _WIN32
+const char* SSHTimeout = "Sessions/fwb_session_with_keepalive/PingIntervalSecs";
+#else
+const char* SSHTimeout = SETTINGS_PATH_PREFIX "/SSH/SSHTimeout";
+#endif
+
+
 
 /**
  * Settings path defined here should match Windows registry paths used
  * in the Windows installer/uninstaller scripts.
+ *
+ * Path used for uuid_settings should not include version to ensure
+ * uuid persistence across upgrades. This means do not use getApplicationNameForSettings()
  */
-FWBSettings::FWBSettings() :
-    QSettings(QSettings::UserScope, "netcitadel.com", getApplicationNameForSettings())
+FWBSettings::FWBSettings(bool testData) :
+    QSettings(QSettings::UserScope,
+              "netcitadel.com",
+              testData?"fwb_test_data":getApplicationNameForSettings())
 {
+    if (testData)
+    {
+        this->clear();
+    }
+    uuid_settings = new QSettings(QSettings::IniFormat, QSettings::UserScope,
+                                  "netcitadel.com", "FirewallBuilder");
+#ifdef _WIN32
+    ssh_timeout_setings_object = new QSettings(QSettings::UserScope,
+                                                 "SimonTatham", "PuTTY");
+#else
+    ssh_timeout_setings_object = this;
+#endif
+}
+
+FWBSettings::~FWBSettings()
+{
+    delete uuid_settings;
+#ifdef _WIN32
+    delete ssh_timeout_setings_object;
+#endif
 }
 
 /**
@@ -132,8 +171,46 @@ void FWBSettings::init()
 {
     bool ok=false;
 
-    ok = contains(appGUID);
-    if (!ok) setValue(appGUID, QUuid::createUuid().toString() );
+    ok = uuid_settings->contains(appGUID);
+    if (!ok)
+    {
+        // migrate uuid from the old native format settings to uuid_settings
+        // See #1497
+        ok = contains(appGUID);
+        if (ok)
+        {
+            uuid_settings->setValue(appGUID, value(appGUID).toString());
+        } else
+        {
+            qsrand(time(NULL));
+            uuid_settings->setValue(appGUID, QUuid::createUuid().toString());
+        }
+    }
+
+    /*
+     * I am seeing two particular uuids a lot in the logs, both coming
+     * from thousands of different instances all over the world. I
+     * have no idea why so many different systems assigned themselves
+     * the same uuid which is supposed to be random and
+     * unique. Apparently QUuid::createUuid() returns predictable uuid
+     * in some cases.  Versions of the program before 4.0.2 did not
+     * call qsrand() to re-seed random generator because Qt
+     * documentation says that createUuid() does that. Interestingly,
+     * if I run google search for the first of the two uuids, I get
+     * some results which means exactly the same uuid was generated by
+     * an unrelated program in some completely unrelated case.
+     * Anyway, I am going to "flush" these two repeatable uuids to
+     * reduce systematic error in counting how many instances of
+     * fwbuilder are running out there.
+     */
+    QString my_uuid = getAppGUID();
+    if (my_uuid == "b7203c47-06bf-4878-9ff5-6afffb2db546" ||
+        my_uuid == "46759a87-7956-431f-a171-ccb754ef239e")
+    {
+        qsrand(time(NULL));
+        uuid_settings->setValue(appGUID, QUuid::createUuid().toString());
+    }
+
 
     // By default sort RCS File preview by date, which is column 1
     ok = contains(rcsFilePreviewSortColumn);
@@ -213,6 +290,9 @@ void FWBSettings::init()
         qDebug() << "Default application font:"
                  << QApplication::font();
 
+    ok = contains(iconsWithText);
+    if (!ok) setIconsWithText(true);
+
     ok = contains(clipComment);
     if (!ok) setClipComment(true);
 
@@ -227,9 +307,12 @@ void FWBSettings::init()
     if (!ok) setCompression(false);
 
 #ifndef _WIN32
-    if (getSSHPath().isEmpty())  setSSHPath("ssh");
-    if (getSCPPath().isEmpty())  setSCPPath("scp");
+    if (getSSHPath().isEmpty()) setSSHPath("ssh");
+    if (getSCPPath().isEmpty()) setSCPPath("scp");
 #endif
+    // default timeout is 30 sec (default value of ServerAliveCountMax is 3)
+    // do this for both Linux and windows !
+    if (!haveSSHTimeout()) setSSHTimeout(10);
 
     // Note: hasKey calls QSettings::contains using path given as
     // argument, prepended with SETTINGS_PATH_PREFIX
@@ -252,7 +335,7 @@ bool FWBSettings::hasKey(const QString &attribute)
 
 QString FWBSettings::getAppGUID()
 {
-    return value(appGUID).toString();
+    return uuid_settings->value(appGUID).toString();
 }
 
 QString FWBSettings::getStr(const QString &attribute)
@@ -396,6 +479,19 @@ void FWBSettings::setDontSaveStdLib( bool f) { setValue(dontSaveStdLib,f);}
 bool FWBSettings::getShowUndoPanel() {return value(showUndoPanel).toBool();}
 void FWBSettings::setShowUndoPanel(bool f) {setValue(showUndoPanel, f);}
 
+bool FWBSettings::getIconsWithText() { return value(iconsWithText).toBool(); }
+void FWBSettings::setIconsWithText(bool f) {setValue(iconsWithText, f);}
+
+QByteArray FWBSettings::getUserWorkflowFlags()
+{
+    return value(userWorkflowFlags).toByteArray();
+}
+
+void FWBSettings::setUserWorkflowFlags(const QByteArray &f)
+{
+    setValue(userWorkflowFlags, f);
+}
+
 bool FWBSettings::haveScreenPosition(const QString &wname)
 {
     QString val = value(QString(screenPositionSetpath)+wname ).toString();
@@ -602,6 +698,31 @@ void FWBSettings::setSCPPath(const QString &path)
     setValue(SCPPath,path);
 }
 
+// Putty uses different parameter name for the server alive interval
+// and keeps it as part of the session, stored in registry. Using
+// separate QSettings object on windows that controls putty session
+// "fwb_session_with_keepalive". On all other platforms
+// ssh_timeout_setings_object == this
+
+bool FWBSettings::haveSSHTimeout()
+{
+    return ssh_timeout_setings_object->contains(SSHTimeout);
+}
+
+int FWBSettings::getSSHTimeout()
+{
+    return ssh_timeout_setings_object->value(SSHTimeout).toInt();
+}
+
+void FWBSettings::setSSHTimeout(int value_sec)
+{
+    ssh_timeout_setings_object->setValue(SSHTimeout, value_sec);
+}
+
+
+
+
+
 void FWBSettings::getPrinterOptions(QPrinter *printer,
                                     int &pageWidth,
                                     int &pageHeight)
@@ -775,7 +896,19 @@ void FWBSettings::setTimeOfLastUpdateAvailableWarning(uint v)
     setValue(updateAvailableWarningLastTime, v);
 }
 
+uint FWBSettings::getTimeOfLastAnnouncement(const QString &announcement)
+{
+    QByteArray h = QCryptographicHash::hash(announcement.toAscii().constData(),
+                                            QCryptographicHash::Md5).toHex();
+    return value(QString(announcementLastTime).arg(h.constData())).toUInt();
+}
 
+void FWBSettings::setTimeOfLastAnnouncement(const QString &announcement, uint v)
+{
+    QByteArray h = QCryptographicHash::hash(announcement.toAscii().constData(),
+                                            QCryptographicHash::Md5).toHex();
+    setValue(QString(announcementLastTime).arg(h.constData()), v);
+}
 
 QString FWBSettings::getCheckUpdatesProxy()
 {
