@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWBSettings.h 2672 2010-03-07 06:28:49Z vadim $
+  $Id: FWBSettings.h 3064 2010-07-12 02:31:41Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -26,8 +26,6 @@
 #ifndef __FWBSETTINGS_H_
 #define __FWBSETTINGS_H_
 
-#include "fwbuilder/FWObject.h"
-
 
 #include <qsettings.h>
 #include <qrect.h>
@@ -38,6 +36,8 @@
 
 #define SETTINGS_PATH_PREFIX  "/4.0"
 
+#include <fwbuilder/FWObject.h>
+
 class QWidget;
 
 /*
@@ -56,11 +56,15 @@ class FWBSettings : public QSettings {
     enum IconSize{ SIZE25X25, SIZE16X16};
 
  private:
+    QSettings *uuid_settings;
+    QSettings *ssh_timeout_setings_object;
+    
     QString getLabelColorStr(enum LabelColors c);
-
+    
  public:
 
-    FWBSettings();
+    FWBSettings(bool testData = false);
+    ~FWBSettings();
 
     static QString getApplicationNameForSettings() { return "FirewallBuilder4.0"; }
 
@@ -158,6 +162,10 @@ class FWBSettings : public QSettings {
     QString getSCPPath();
     void    setSCPPath(const QString &path);
 
+    bool    haveSSHTimeout();
+    int     getSSHTimeout();
+    void    setSSHTimeout(int value_sec);
+
     void    getPrinterOptions(QPrinter *printer,int &pageWidth,int &pageHeight);
     void    setPrinterOptions(QPrinter *printer,int pageWidth,int pageHeight);
 
@@ -193,6 +201,9 @@ class FWBSettings : public QSettings {
     uint getTimeOfLastUpdateAvailableWarning();
     void setTimeOfLastUpdateAvailableWarning(uint v);
     
+    uint getTimeOfLastAnnouncement(const QString &announcement);
+    void setTimeOfLastAnnouncement(const QString &announcement, uint v);
+    
     QString getTargetStatus(const QString &platform, const QString &default_stat);
     void setTargetStatus(const QString &plaform, const QString &status);
 
@@ -241,7 +252,13 @@ class FWBSettings : public QSettings {
     bool getShowUndoPanel();
     void setShowUndoPanel(bool);
 
-
+    QByteArray getUserWorkflowFlags();
+    void setUserWorkflowFlags(const QByteArray &);
+    
+    bool getIconsWithText();
+    void setIconsWithText(bool f);
+    
+   
 private:
     QFont getFontByType(const char*type);
 };
