@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: FWCmdRule.cpp 2477 2010-01-31 22:46:05Z yalovoy $
+  $Id: FWCmdRule.cpp 2945 2010-06-02 06:44:37Z yalovoy $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,6 +28,7 @@
 #include "FWWindow.h"
 #include "FWCmdRule.h"
 #include "FindObjectWidget.h"
+#include "UserWorkflow.h"
 
 #include "events.h"
 
@@ -73,6 +74,7 @@ void FWCmdRule::notify()
 
 void FWCmdRule::redo()
 {
+    wfl->registerFlag(UserWorkflow::RULE_MOD, true);
     RuleSetModel* md = getRuleSetModel();
     redoOnModel(md);
     notify();
@@ -112,6 +114,7 @@ FWCmdRuleInsert::~FWCmdRuleInsert()
 
 void FWCmdRuleInsert::redoOnModel(RuleSetModel *md)
 {
+    wfl->registerFlag(UserWorkflow::RULE_MOD, true);
     if (insertedRule == 0) {
         if (ruleToInsert == 0)
         {
@@ -126,7 +129,7 @@ void FWCmdRuleInsert::redoOnModel(RuleSetModel *md)
         } else
         {
             QModelIndex index;
-            if (position) index = md->indexForPosition(position);
+            if (position!=0 || isAfter) index = md->indexForPosition(position);
             insertedRule = md->insertRule(ruleToInsert, index, isAfter);
         }
         insertedRule->ref();
@@ -212,6 +215,7 @@ FWCmdRuleDelete::~FWCmdRuleDelete()
 
 void FWCmdRuleDelete::redoOnModel(RuleSetModel *md)
 {
+    wfl->registerFlag(UserWorkflow::RULE_MOD, true);
     if (fwbdebug)
         qDebug() << "FWCmdRuleDelete::redoOnModel(RuleSetModel *md)";
     foreach(Rule* rule, rulesToDelete)
@@ -269,6 +273,8 @@ void FWCmdRuleColor::redoOnModel(RuleSetModel *md)
 {
     QModelIndexList indexes;
 
+    wfl->registerFlag(UserWorkflow::RULE_MOD, true);
+
     foreach(int ruleId, oldColors.keys())
     {
         Rule* rule = Rule::cast(getObject(ruleId));
@@ -309,6 +315,7 @@ FWCmdRuleMove::FWCmdRuleMove(ProjectPanel *project, libfwbuilder::RuleSet* rules
 
 void FWCmdRuleMove::redoOnModel(RuleSetModel *md)
 {
+    wfl->registerFlag(UserWorkflow::RULE_MOD, true);
     move(md, direction);
 }
 
@@ -356,6 +363,7 @@ FWCmdRuleRenameGroup::FWCmdRuleRenameGroup(ProjectPanel *project, RuleSet* rules
 
 void FWCmdRuleRenameGroup::redoOnModel(RuleSetModel *md)
 {
+    wfl->registerFlag(UserWorkflow::RULE_MOD, true);
     QModelIndex grp = md->index(oldName);
     md->renameGroup(grp, newName);
 }
@@ -378,6 +386,7 @@ FWCmdRuleRemoveFromGroup::FWCmdRuleRemoveFromGroup(ProjectPanel* project, RuleSe
 
 void FWCmdRuleRemoveFromGroup::redoOnModel(RuleSetModel *md)
 {
+    wfl->registerFlag(UserWorkflow::RULE_MOD, true);
     QModelIndex group = md->index(groupName);
     QModelIndex first = md->index(firstRule, 0);
     QModelIndex last = md->index(lastRule, 0);
@@ -421,6 +430,7 @@ FWCmdRuleNewGroup::FWCmdRuleNewGroup(ProjectPanel* project, RuleSet* ruleset, Ru
 
 void FWCmdRuleNewGroup::redoOnModel(RuleSetModel *md)
 {
+    wfl->registerFlag(UserWorkflow::RULE_MOD, true);
     QModelIndex first = md->index(firstRule, 0);
     QModelIndex last = md->index(lastRule, 0);
     QModelIndex index = md->createNewGroup(groupName, first.row(), last.row());
@@ -449,6 +459,7 @@ FWCmdRuleAddToGroup::FWCmdRuleAddToGroup(ProjectPanel* project, RuleSet* ruleset
 
 void FWCmdRuleAddToGroup::redoOnModel(RuleSetModel *md)
 {
+    wfl->registerFlag(UserWorkflow::RULE_MOD, true);
     QModelIndex first = md->index(firstRule, 0);
     QModelIndex last = md->index(lastRule, 0);
 
@@ -481,6 +492,7 @@ void FWCmdRuleChange::selectAffectedRule()
 
 void FWCmdRuleChange::redo()
 {
+    wfl->registerFlag(UserWorkflow::RULE_MOD, true);
     prepareRuleSetView();
     FWCmdChange::redo();
     selectAffectedRule();
@@ -618,6 +630,8 @@ FWCmdRuleNegateRE::FWCmdRuleNegateRE(ProjectPanel *project,
 
 void FWCmdRuleNegateRE::redo()
 {
+    wfl->registerFlag(UserWorkflow::RULE_MOD, true);
+
     prepareRuleSetView();
     RuleElement* ruleElement = RuleElement::cast(getObject());
     ruleElement->toggleNeg();
