@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: FWObjectClipboard.cpp 472 2008-08-18 01:28:00Z vadim $
+  $Id: FWObjectClipboard.cpp 1972 2009-11-29 17:53:31Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -94,6 +94,21 @@ void FWObjectClipboard::add(FWObject *obj, ProjectPanel * proj_p)
     ids.push_back( pair<int,ProjectPanel*>(obj->getId(), proj_p) );
 }
 
+void FWObjectClipboard::remove(FWObject* obj)
+{
+    int id = obj->getId();
+    for (vector<std::pair<int,ProjectPanel*> >::iterator i=ids.begin();
+         i!=ids.end(); ++i)
+    {
+        int obj_id = i->first;
+        if (obj_id == id)
+        {
+            ids.erase(i);
+            break;
+        }
+    }
+}
+
 FWObject* FWObjectClipboard::getObject()
 {
     if (ids.size()>0)
