@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: FWObjectDropArea.cpp 2074 2009-12-09 18:04:38Z vadim $
+  $Id: FWObjectDropArea.cpp 2905 2010-05-14 03:15:57Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -37,6 +37,7 @@
 #include "ProjectPanel.h"
 
 #include "fwbuilder/Resources.h"
+#include "fwbuilder/RuleSet.h"
 
 #include <qpainter.h>
 #include <qrect.h>
@@ -250,6 +251,10 @@ void FWObjectDropArea::editObject()
     ProjectPanel * pp = mw->activeProject();
     if (pp!=NULL)
     {
+        if (RuleSet::cast(object)!=NULL)
+            QCoreApplication::postEvent(
+                pp, new openRulesetEvent(pp->getFileName(), object->getId()));
+
         QCoreApplication::postEvent(
             mw, new openObjectInEditorEvent(pp->getFileName(), object->getId()));
         QCoreApplication::postEvent(
