@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWObjectPropertiesFactory.cpp 2639 2010-03-01 04:39:27Z vadim $
+  $Id: FWObjectPropertiesFactory.cpp 2919 2010-05-22 01:32:13Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -130,7 +130,7 @@ QString FWObjectPropertiesFactory::getObjectPropertiesBrief(FWObject *obj)
             str << ar->getRangeEnd().toString().c_str();
         } else if (Firewall::cast(obj))
         {
-            if (Firewall::cast(obj)->needsInstall()) str << " * ";
+            if (Firewall::cast(obj)->needsCompile()) str << " * ";
             QString platform = obj->getStr("platform").c_str();
             QString version  = obj->getStr("version").c_str();
             QString readableVersion = getVersionString(platform,version);
@@ -260,6 +260,7 @@ QString FWObjectPropertiesFactory::getObjectPropertiesBrief(FWObject *obj)
                 if (rs->isV4()) attrs.push_back("ipv4");
                 if (rs->isV6()) attrs.push_back("ipv6");
             }
+            attrs.push_back(QString("%1 rules").arg(rs->getRuleSetSize()));
             str << attrs.join(" ");
         } else if (Interval::isA(obj))
         {
@@ -273,7 +274,11 @@ QString FWObjectPropertiesFactory::getObjectPropertiesBrief(FWObject *obj)
     return QString::fromUtf8(res.toStdString().c_str());
 }
 
-
+/*
+ * More detailed list of properties, still one line, no fancy
+ * formatting and no HTML. This is used in object group list view and
+ * for printing.
+ */
 QString FWObjectPropertiesFactory::getObjectProperties(FWObject *obj)
 {
     QString res;
@@ -355,21 +360,22 @@ QString FWObjectPropertiesFactory::getObjectProperties(FWObject *obj)
         } else if (Network::isA(obj))
         {
             Network *n=Network::cast(obj);
-            str << n->getAddressPtr()->toString().c_str();
-            str << "/";
-            str << n->getNetmaskPtr()->toString().c_str();
+            str << QString("%1/%2")
+                .arg(n->getAddressPtr()->toString().c_str())
+                .arg(n->getNetmaskPtr()->toString().c_str());
 
         } else if (NetworkIPv6::isA(obj))
         {
             NetworkIPv6 *n=NetworkIPv6::cast(obj);
-            str << n->getAddressPtr()->toString().c_str();
-            str << "/";
-            str << QString("%1").arg(n->getNetmaskPtr()->getLength());
+            str << QString("%1/%2")
+                .arg(n->getAddressPtr()->toString().c_str())
+                .arg(n->getNetmaskPtr()->getLength());
 
         } else if (ClusterGroup::cast(obj)!=NULL)
         {
             ClusterGroup *g = ClusterGroup::cast(obj);
-            str << QObject::tr("type: ") << g->getStr("type").c_str() << "<br>";
+            str << QObject::tr("Type: ") << g->getStr("type").c_str() << " ";
+            QStringList members;
             FWObjectTypedChildIterator j = obj->findByType(FWObjectReference::TYPENAME);
             for ( ; j!=j.end(); ++j)
             {
@@ -377,16 +383,20 @@ QString FWObjectPropertiesFactory::getObjectProperties(FWObject *obj)
                 if (Interface::cast(obj))
                 {
                     FWObject *fw = obj->getParent();
-                    str << QObject::tr("Group member")
-                        << " " << fw->getName().c_str() 
-                        << ":" << obj->getName().c_str()
-                        << "<br>";
+                    members.push_back(
+                        QString("%1:%2")
+                        .arg(fw->getName().c_str()).arg(obj->getName().c_str()));
                 }
             }
+            if (members.size() != 0)
+            {
+                members.push_front(QObject::tr("Members:"));
+                str << members.join(" ");
+            }
         } else if (Group::cast(obj)!=NULL)   // just any group
         {
             Group *g=Group::cast(obj);
-            str << g->size() << " " << QObject::tr(" objects");
+            str << QObject::tr("%1 objects").arg(g->size());
 
         } else if (Firewall::cast(obj))
         {
@@ -394,21 +404,28 @@ QString FWObjectPropertiesFactory::getObjectProperties(FWObject *obj)
         } else if (Interface::isA(obj))
         {
             Interface *intf = Interface::cast(obj);
-            str << "Label: "
-                << QString::fromUtf8(intf->getLabel().c_str()) << "<br>";
+            QString label = QString::fromUtf8(intf->getLabel().c_str());
+            if (label != "")
+                str << QObject::tr("Label: %1").arg(label) << " ";
+
+            QString intf_type = intf->getOptionsObject()->getStr("type").c_str();
+            if (intf_type != "" && intf_type.toLower() != "ethernet")
+                str << QObject::tr("Type: ") << intf_type << " ";
+
+            QStringList addr;
             FWObjectTypedChildIterator j = obj->findByType(IPv4::TYPENAME);
             for ( ; j!=j.end(); ++j)
             {
-                str << getObjectProperties(*j);
-                str << "<br>";
+                addr << getObjectProperties(*j);
+            }
+            if (addr.size() != 0)
+            {
+                if (addr.size() > 1)
+                    addr.push_front(QObject::tr("Addresses:"));
+                else
+                    addr.push_front(QObject::tr("Address:"));
+                str << addr.join(" ");
             }
-            physAddress *paddr = intf->getPhysicalAddress();
-            if (paddr!=NULL) 
-                str << " MAC: " << paddr->getPhysAddress().c_str() << "<br>";
-            string intf_type = intf->getOptionsObject()->getStr("type");
-            if (!intf_type.empty())
-                str << " Interface Type: " << intf_type.c_str();
-
         } else if (IPService::isA(obj))
         {
             str << QObject::tr("protocol: %1").arg(obj->getStr("protocol_num").c_str());
@@ -432,11 +449,11 @@ QString FWObjectPropertiesFactory::getObjectProperties(FWObject *obj)
             str << dps << ":" << dpe;
         } else if (TagService::isA(obj)) 
         {
-            str << "Pattern: \"" << obj->getStr("tagcode").c_str() << "\"" ;
+            str << QObject::tr("Pattern: \"%1\"").arg(obj->getStr("tagcode").c_str());
         } else if (UserService::isA(obj)) 
         {
             const UserService* user_srv = UserService::constcast(obj);
-            str << "User id: \"" << user_srv->getUserId().c_str() << "\"" ;
+            str << QObject::tr("User id: \"%1\"").arg(user_srv->getUserId().c_str());
         } else if (Interval::isA(obj))
         {
 
@@ -466,7 +483,10 @@ QString FWObjectPropertiesFactory::stripHTML(const QString &str)
     return res;
 }
 
-
+/*
+ * Nicely formatted list of properties, HTML. This one is used for the
+ * tree tooltips.
+ */
 QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
                                                                bool showPath,
                                                                bool tooltip,
@@ -957,194 +977,200 @@ QString FWObjectPropertiesFactory::getRuleActionPropertiesRich(Rule *rule)
 
 QString FWObjectPropertiesFactory::getPolicyRuleOptions(Rule *rule)
 {
-    QString res;
-    
+    QList<QPair<QString,QString> > options;
+
     if (rule!=NULL)
     {
-        res="";
         FWObject *o = rule;
-        while (o!=NULL && Firewall::cast(o)==NULL) o=o->getParent();
+        while (o!=NULL && Firewall::cast(o)==NULL) o = o->getParent();
         assert(o!=NULL);
-        Firewall *f=Firewall::cast(o);
-        string platform=f->getStr("platform");
+        Firewall *f = Firewall::cast(o);
+        string platform = f->getStr("platform");
         FWOptions *ropt = rule->getOptionsObject();
-        
+
+        if (platform!="iosacl" && platform!="procurve_acl")
+        {
+            if (ropt->getBool("stateless"))
+            {
+                options << qMakePair(QObject::tr("Stateless"), QString(""));
+            } else
+            {
+                options << qMakePair(QObject::tr("Stateful"), QString(""));
+            }
+        }
+
         if (platform=="iptables")
         {
             if (!ropt->getStr("log_prefix").empty())
             {
-                res+=QObject::tr("<b>Log prefix    :</b> ");
-                res+=QString(ropt->getStr("log_prefix").c_str())+"<br>\n";
+                options << qMakePair(QObject::tr("Log prefix:"),
+                                     QString(ropt->getStr("log_prefix").c_str()));
             }
 
             if (!ropt->getStr("log_level").empty())
             {
-                res+=QObject::tr("<b>Log Level     :</b> ");
-                res+=getScreenName(ropt->getStr("log_level").c_str(),
-                        getLogLevels(platform.c_str()))+"<br>\n";
+                options << qMakePair(QObject::tr("Log Level:"),
+                                     QString(getScreenName(ropt->getStr("log_level").c_str(),
+                                                           getLogLevels(platform.c_str()))));
             }
 
             if (ropt->getInt("ulog_nlgroup")>1)
             {
-                res+=QObject::tr("<b>Netlink group :</b> ");
-                res+=QString(ropt->getStr("ulog_nlgroup").c_str())+"<br>\n";
+                options << qMakePair(QObject::tr("Netlink group:"),
+                                     QString(ropt->getStr("ulog_nlgroup").c_str()));
             }
             
             if (ropt->getInt("limit_value")>0)
             {
-                res += QObject::tr("<b>Limit value   :</b> ");
-                if (ropt->getBool("limit_value_not")) res += " ! ";
-                res += QString(ropt->getStr("limit_value").c_str())+" ";
-           
+                QString arg;
+                if (ropt->getBool("limit_value_not")) arg = " ! ";
+                arg += QString(ropt->getStr("limit_value").c_str());
                 if (!ropt->getStr("limit_suffix").empty())
                 {
-                    res+=getScreenName(ropt->getStr("limit_suffix").c_str(),
-                                       getLimitSuffixes(platform.c_str()))+"<br>\n";
+                    arg += getScreenName(ropt->getStr("limit_suffix").c_str(),
+                                         getLimitSuffixes(platform.c_str()));
                 }
+                options << qMakePair(QString("Limit value:"), arg);
             }
 
             if (ropt->getInt("limit_burst")>0)
             {
-                res+=QObject::tr("<b>Limit burst   :</b> ");
-                res+=QString(ropt->getStr("limit_burst").c_str())+"<br>\n";
+                options << qMakePair(QString("Limit burst:"),
+                                     QString(ropt->getStr("limit_burst").c_str()));
             }
 
             if (ropt->getInt("connlimit_value")>0)
             {
-                res+=QObject::tr("<b>connlimit value   :</b> ");
-                if (ropt->getBool("connlimit_above_not")) res += " ! ";
-                res+=QString(ropt->getStr("connlimit_value").c_str())+"<br>\n";
+                QString arg;
+
+                if (ropt->getBool("connlimit_above_not")) arg = " ! ";
+                arg += QString(ropt->getStr("connlimit_value").c_str());
+
+                options << qMakePair(QObject::tr("connlimit value:"), arg);
+            }
+
+            if (ropt->getInt("hashlimit_value")>0)
+            {
+                QString arg;
+                if (ropt->getBool("hashlimit_value_not")) arg = " ! ";
+                arg += QString(ropt->getStr("hashlimit_value").c_str());
+                if (!ropt->getStr("hashlimit_suffix").empty())
+                {
+                    arg += getScreenName(ropt->getStr("limit_suffix").c_str(),
+                                         getLimitSuffixes(platform.c_str()));
+                }
+
+                options << qMakePair(QString("hashlimit name:"),
+                                     QString(ropt->getStr("hashlimit_name").c_str()));
+                options << qMakePair(QString("hashlimit value:"), arg);
+
+                if (ropt->getInt("hashlimit_burst")>0)
+                {
+                    options << qMakePair(QString("haslimit burst:"),
+                                         QString(ropt->getStr("hashlimit_burst").c_str()));
+                }
             }
             
             if (ropt->getBool("firewall_is_part_of_any_and_networks"))
             {
-                res+=QObject::tr("<b>Part of Any</b>");
-                res+="<br>\n";
+                options << qMakePair(QObject::tr("Part of Any"), QString(""));
             }
 
-            if (ropt->getBool("stateless"))
-            {
-                res+=QObject::tr("<b>Stateless</b>");
-                res+="<br>\n";
-            }
             
-        }else if (platform=="ipf") 
+        } else if (platform=="ipf") 
         {
             if (!ropt->getStr("ipf_log_facility").empty())
             {
-                res+=QObject::tr("<b>Log facility:</b> ");
-                res+=getScreenName(ropt->getStr("ipf_log_facility").c_str(),
-                    getLogFacilities(platform.c_str()))+"<br>\n";
+                options << qMakePair(QObject::tr("Log facility:"),
+                                     QString(getScreenName(ropt->getStr("ipf_log_facility").c_str(),
+                                                           getLogFacilities(platform.c_str()))));
             }
             
             if (!ropt->getStr("log_level").empty())
             {
-                res+=QObject::tr("<b>Log level   :</b> ");
-                res+=getScreenName(ropt->getStr("log_level").c_str(),
-                    getLogLevels(platform.c_str()))+"<br>\n";
+                options << qMakePair(QObject::tr("Log level:"),
+                                     QString(getScreenName(ropt->getStr("log_level").c_str(),
+                                                           getLogLevels(platform.c_str()))));
             }
             
-            res+="<ul>";
             if (ropt->getBool("ipf_return_icmp_as_dest"))
             {
-                res+=QObject::tr("<li><b>Send 'unreachable'</b></li>");
-                res+="<br>\n";
-            }
-
-            if (ropt->getBool("stateless"))
-            {
-                res+=QObject::tr("<li><b>Stateless</b></li> ");
-                res+="<br>\n";
+                options << qMakePair(QObject::tr("Send 'unreachable'"), QString(""));
             }
 
             if (ropt->getBool("ipf_keep_frags"))
             {
-                res+=QObject::tr("<li><b>Keep information on fragmented packets</b></li> ");
-                res+="<br>\n";
+                options << qMakePair(QObject::tr("Keep information on fragmented packets"), QString(""));
             }
-            res+="</ul>";
             
         }else if (platform=="pf")
         {
             
             if (!ropt->getStr("log_prefix").empty())
             {
-                res+=QObject::tr("<b>Log prefix :</b> ");
-                res+=QString(ropt->getStr("log_prefix").c_str())+"<br>\n";
+                options << qMakePair(QObject::tr("Log prefix:"), 
+                                     QString(ropt->getStr("log_prefix").c_str()));
             }
             
             if (ropt->getInt("pf_rule_max_state")>0)
             {
-                res+=QObject::tr("<b>Max state  :</b> ");
-                res+=QString(ropt->getStr("pf_rule_max_state").c_str())+"<br>\n";
+                options << qMakePair(QObject::tr("Max state:"),
+                                     QString(ropt->getStr("pf_rule_max_state").c_str()));
             }
             
-            res+="<ul>";
-            if (ropt->getBool("stateless"))
-            {
-                res+=QObject::tr("<li><b>Stateless</b></li> ");
-                //res+="<br>\n";
-            }
             if (ropt->getBool("pf_keep_state"))
             {
-                res+=QObject::tr("<li><b>Force 'keep-state'</b></li> ");
-                //res+="<br>\n";
+                options << qMakePair(QObject::tr("Force 'keep-state'"), QString(""));
             }
             if (ropt->getBool("pf_no_sync"))
             {
-                res+=QObject::tr("<li><b>no-sync</b></li> ");
-                //res+="<br>\n";
+                options << qMakePair(QString("no-sync"), QString(""));
             }
             if (ropt->getBool("pf_pflow"))
             {
-                res+=QObject::tr("<li><b>pflow</b></li> ");
-                //res+="<br>\n";
+                options << qMakePair(QString("pflow"), QString(""));
             }
             if (ropt->getBool("pf_sloppy_tracker"))
             {
-                res+=QObject::tr("<li><b>sloppy-tracker</b></li> ");
-                //res+="<br>\n";
+                options << qMakePair(QString("sloppy-tracker"), QString(""));
             }
             
             if (ropt->getBool("pf_source_tracking"))
             {
-                res+=QObject::tr("<li><b>Source tracking</b></li> ");
-                //res+="<br>\n";
+                options << qMakePair(QObject::tr("Source tracking"), QString(""));
                 
-                res+=QObject::tr("<b>Max src nodes :</b> ");
-                res+=QString(ropt->getStr("pf_max_src_nodes").c_str())+"<br>\n";
-                
-                res+=QObject::tr("<b>Max src states:</b> ");
-                res+=QString(ropt->getStr("pf_max_src_states").c_str())+"<br>\n";
+                options << qMakePair(QObject::tr("Max src nodes:"),
+                                     QString(ropt->getStr("pf_max_src_nodes").c_str()));
                 
+                options << qMakePair(QObject::tr("Max src states:"),
+                                     QString(ropt->getStr("pf_max_src_states").c_str()));
+            }
+
+            if (ropt->getBool("pf_synproxy"))
+            {
+                options << qMakePair(QString("synproxy"), QString(""));
+            }
+
+            if (ropt->getBool("pf_modulate_state"))
+            {
+                options << qMakePair(QString("modulate_state"), QString(""));
             }
-            res+="</ul>";
             
         }else if (platform=="ipfw")
         {
-            res+="<ul>";
-            if (ropt->getBool("stateless"))
-            {
-                res+=QObject::tr("<li><b>Stateless</b></li> ");
-                res+="<br>\n";
-            }
-            res+="</ul>";
-
-        }else if (platform=="iosacl")
+            ;
+        }else if (platform == "iosacl" || platform == "procurve_acl")
         {
-            res+="<ul>";
             if (ropt->getBool("iosacl_add_mirror_rule"))
             {
-                res+=QObject::tr("<li><b>Add mirrored rule</b></li> ");
-                res+="<br>\n";
+                options << qMakePair(QObject::tr("Add mirrored rule"), QString(""));
             }
-            res+="</ul>";
             
         }else if (platform=="pix" || platform=="fwsm")
         {
-            string vers="version_"+f->getStr("version");
+            string vers = "version_"+f->getStr("version");
             
-            res+=QObject::tr("<u><b>Ver:%1</b></u><br>\n").arg(vers.c_str());
+            options << qMakePair(QObject::tr("Version:"), QString(vers.c_str()));
             
             if ( Resources::platform_res[platform]->getResourceBool(
                   "/FWBuilderResources/Target/options/"+vers+"/pix_rule_syslog_settings"))
@@ -1152,30 +1178,39 @@ QString FWObjectPropertiesFactory::getPolicyRuleOptions(Rule *rule)
                 
                 if (!ropt->getStr("log_level").empty())
                 {
-                    res+=QObject::tr("<b>Log level   :</b> ");
-                    res+=getScreenName(ropt->getStr("log_level").c_str(),
-                        getLogLevels(platform.c_str()))+"<br>\n";
+                    options << qMakePair(QObject::tr("Log level:"),
+                                         QString(getScreenName(ropt->getStr("log_level").c_str(),
+                                                               getLogLevels(platform.c_str()))));
                 }
                 if (ropt->getInt("log_interval")>0)
                 {
-                    res+=QObject::tr("<b>Log interval  :</b> ");
-                    res+=QString(ropt->getStr("log_interval").c_str())+"<br>\n";
+                    options << qMakePair(QObject::tr("Log interval:"),
+                                         QString(ropt->getStr("log_interval").c_str()));
                 }
                 
-                res+="<ul>";
                 if (ropt->getBool("disable_logging_for_this_rule"))
                 {
-                    res+=QObject::tr("<li><b>Disable logging for this rule</b></li> ");
-                    res+="<br>\n";
+                    options << qMakePair(QObject::tr("Disable logging for this rule"), QString(""));
                 }
-                res+="</ul>";
                 
             } 
         }
         
     }
-    
-    return res;
+
+    QStringList res;
+    res << "<table>";
+    QList<QPair<QString,QString> >::iterator it;
+    for (it=options.begin(); it!=options.end(); ++it)
+    {
+        QPair<QString,QString> p = *it;
+        res << "<tr><th align='left'>" + p.first + "</th><td>" + p.second + "</td></tr>";
+    }
+    res << "</table>";
+    QString html = res.join("\n");
+    if (fwbdebug)
+        qDebug() << html;
+    return html;
 }
 
 QString FWObjectPropertiesFactory::getNATRuleOptions(Rule *rule)
