@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWObjectPropertiesFactory.h 304 2008-07-03 02:19:16Z vadim $
+  $Id: FWObjectPropertiesFactory.h 1626 2009-10-21 00:51:10Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -42,6 +42,8 @@ class FWObjectPropertiesFactory {
  * returns a one line property of the object for the second column of
  * the tree view
  */
+    static QString getObjectPropertiesBrief(libfwbuilder::FWObject *obj);
+
     static QString getObjectProperties(libfwbuilder::FWObject *obj);
 
     static QString getObjectPropertiesDetailed(libfwbuilder::FWObject *obj,
@@ -49,8 +51,8 @@ class FWObjectPropertiesFactory {
                                                bool tooltip=false,
                                                bool accentName=true,
                                                bool richText=true);
-    static QString getRuleActionProperties(libfwbuilder::PolicyRule *rule); 
-    static QString getRuleActionPropertiesRich(libfwbuilder::PolicyRule *rule); 
+    static QString getRuleActionProperties(libfwbuilder::Rule *rule); 
+    static QString getRuleActionPropertiesRich(libfwbuilder::Rule *rule); 
     static QString getPolicyRuleOptions(libfwbuilder::Rule *rule);
     static QString getNATRuleOptions(libfwbuilder::Rule *rule);
 
