@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindow.cpp 2704 2010-03-09 16:48:42Z vadim $
+  $Id: FWWindow.cpp 3030 2010-06-27 04:29:48Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -34,6 +34,7 @@
 #include <ui_FWBMainWindow_q.h>
 #include <ui_pagesetupdialog_q.h>
 
+#include "FWBApplication.h"
 #include "FWWindow.h"
 #include "ProjectPanel.h"
 #include "ObjectTreeView.h"
@@ -41,6 +42,7 @@
 #include "FWObjectClipboard.h"
 #include "FWBTree.h"
 #include "FWBSettings.h"
+#include "UserWorkflow.h"
 #include "FWObjectPropertiesFactory.h"
 #include "upgradePredicate.h"
 #include "ObjConflictResolutionDialog.h"
@@ -171,24 +173,25 @@ FWWindow::FWWindow() : QMainWindow(),   // QMainWindow(NULL, Qt::Desktop),
                        m_space(0),
                        previous_subwindow(0),
                        instd(0),
-                       instDialogOnScreenTimer(
-                           new QTimer(static_cast<QObject*>(this))),
                        editorOwner(0),
                        printer(0), searchObject(0), replaceObject(0),
                        auto_load_from_rcs_head_revision(0),
                        oe(0), findObjectWidget(0), findWhereUsedWidget(0),
                        undoGroup(0)
 {
-    setUnifiedTitleAndToolBarOnMac(true);
+    instd = new instDialog(this);
+
 
     m_mainWindow = new Ui::FWBMainWindow_q();
     m_mainWindow->setupUi(dynamic_cast<QMainWindow*>(this));
+    this->setupGlobalToolbar();
 
     //setCentralWidget(m_space);
 
     psd = NULL;
 
     prepareFileOpenRecentMenu();
+    setCompileAndInstallActionsEnabled(false);
 
     // ProjectPanel *proj = newProjectPanel();
     // showSub(proj);
@@ -253,12 +256,6 @@ FWWindow::FWWindow() : QMainWindow(),   // QMainWindow(NULL, Qt::Desktop),
     connect(current_version_http_getter, SIGNAL(done(const QString&)),
             this, SLOT(checkForUpgrade(const QString&)));
 
-    connect(instDialogOnScreenTimer, SIGNAL(timeout()),
-            this, SLOT(killInstDialog()));
-
-    instDialogOnScreenTimer->start(1000);
-
-
     // connect( m_mainWindow->newObjectAction, SIGNAL( triggered() ),
     //          this, SLOT(newObject() ) );
 
@@ -307,6 +304,7 @@ FWWindow::FWWindow() : QMainWindow(),   // QMainWindow(NULL, Qt::Desktop),
     QWidget *tabbar= m_mainWindow->m_space->findChild<QTabBar*>();
     if (tabbar)
         tabbar->installEventFilter(new MDIEventFilter());
+
 }
 
 FWWindow::~FWWindow()
@@ -485,16 +483,6 @@ ProjectPanel* FWWindow::activeProject()
     return NULL;
 }
 
-void FWWindow::killInstDialog()
-{
-    if (instd!=NULL && !instd->isVisible())
-    {
-        if (fwbdebug) qDebug("killing instDialog...");
-        delete instd;
-        instd = NULL;
-    }
-}
-
 void FWWindow::updateWindowTitle()
 {
     if (activeProject())
@@ -543,6 +531,8 @@ void FWWindow::startupLoad()
         updateOpenRecentMenu(file);
     }
 
+    QCoreApplication::postEvent(this, new updateSubWindowTitlesEvent());
+
     if (! st->getBool("UI/NoStartTip"))
     {
         StartTipDialog *stdlg = new StartTipDialog(this);
@@ -550,6 +540,8 @@ void FWWindow::startupLoad()
     }
 
     prepareFileMenu();
+    updateGlobalToolbar();
+    //prepareRulesMenu();
 }
 
 void FWWindow::helpAbout()
@@ -579,6 +571,8 @@ void FWWindow::fileNew()
         {
             showSub(proj.get());
             prepareFileMenu();
+            updateGlobalToolbar();
+            //prepareRulesMenu();
             proj.release();
         }
     }
@@ -622,38 +616,61 @@ void FWWindow::fileOpen()
         return ;
     }
 
+    // Using absoluteFilePath(), see #1334
     QFileInfo fi(file_name);
-    QString file_path = fi.canonicalFilePath();
-    QMdiSubWindow* sw = alreadyOpened(file_path);
+    QString file_path = fi.absoluteFilePath();
+
+    if (fwbdebug) qDebug() << "FWWindow::fileOpen():"
+                           << "File name: " << file_name
+                           << "Absolute file path: " << file_path;
+
+    QMdiSubWindow* sw = alreadyOpened(file_name);
     if (sw != NULL)
     {
+        if (fwbdebug) qDebug() << "This file is already opened";
         // activate window with this file
         m_mainWindow->m_space->setActiveSubWindow(sw);
         return;
     }
 
+    QFileInfo file_path_info(file_path);
+    if (!file_path_info.exists() || !file_path_info.isReadable())
+    {
+        QMessageBox::warning(
+            this,"Firewall Builder",
+            tr("File '%1' does not exist or is not readable").arg(file_path));
+        return;
+    }
+
     if (loadFile(file_path, false))
     {
         updateOpenRecentMenu(file_name);
         // reset actions, including Save() which should now
         // be inactive
         prepareFileMenu();
+        //prepareRulesMenu();
+        updateGlobalToolbar();
+
         QCoreApplication::postEvent(this, new updateSubWindowTitlesEvent());
     } else
         m_mainWindow->m_space->setActiveSubWindow(last_active_window);
-
 }
 
 QMdiSubWindow* FWWindow::alreadyOpened(const QString &file_name)
 {
     QFileInfo fi(file_name);
-    QString file_path = fi.canonicalFilePath();
+    QString file_path = fi.absoluteFilePath();
+
+    if (fwbdebug) qDebug() << "FWWindow::alreadyOpened():"
+                           << "File name: " << file_name
+                           << "Absolute file path: " << file_path;
+
     foreach(QMdiSubWindow* sw, m_mainWindow->m_space->subWindowList())
     {
         ProjectPanel * pp = dynamic_cast<ProjectPanel *>(sw->widget());
         if (pp!=NULL)
         {
-            if (fwbdebug) qDebug() << "Opened file  " << pp->getFileName();
+            if (fwbdebug) qDebug() << "Opened file" << pp->getFileName();
             if (pp->getFileName() == file_path) return sw;
         }
     }
@@ -697,11 +714,16 @@ void FWWindow::fileClose()
         if (!project->saveIfModified()) return;  // abort operation
         project->saveState();
         project->fileClose();
+
+        // reset actions, including Save() which should now
+        // be inactive
+        prepareFileMenu();
+        //prepareRulesMenu();
+        updateGlobalToolbar();
     }
 
     if (fwbdebug) qDebug("subWindowList().size()=%d",
                          m_mainWindow->m_space->subWindowList().size());
-
 }
 
 void FWWindow::fileExit()
@@ -731,7 +753,7 @@ void FWWindow::fileExit()
 
     st->setInt("Window/maximized", window_maximized_state);
 
-    qApp->quit();
+    app->quit();
 }
 
 void FWWindow::toolsDiscoveryDruid()
@@ -752,91 +774,6 @@ void FWWindow::importPolicy()
     }
 }
 
-void FWWindow::setActionsEnabled(bool en)
-{
-    m_mainWindow->compileAction->setEnabled(en );
-    m_mainWindow->installAction->setEnabled(en );
-}
-
-void FWWindow::setEnabledAfterRF()
-{
-    m_mainWindow->compileAction->setEnabled( true );
-    m_mainWindow->installAction->setEnabled( true );
-}
-
-void FWWindow::selectRules()
-{
-    m_mainWindow ->compileAction->setEnabled( true );
-    m_mainWindow ->installAction->setEnabled( true );
-
-    if (activeProject()) activeProject()->selectRules();
-}
-
-void FWWindow::disableActions(bool havePolicies)
-{
-    m_mainWindow ->compileAction->setEnabled( true );
-    m_mainWindow ->installAction->setEnabled( true );
-}
-
-void FWWindow::compile()
-{
-    std::set<Firewall*> emp;
-
-    instd = new instDialog(this, false, false, emp);
-    instd->show();
-
-//    id->exec();
-//    delete id;
-}
-
-void FWWindow::compile(set<Firewall*> vf)
-{
-    if (fwbdebug)
-        qDebug("FWWindow::compile preselected %d firewalls", int(vf.size()));
-
-
-    instDialog *id = new instDialog(this, false, true, vf);
-    instd = id;
-    instd->show();
-
-//    id->exec();
-//    delete id;
-}
-
-void FWWindow::install(set<Firewall*> vf)
-{
-    instDialog *id = new instDialog(this, true, true, vf);
-
-    instd = id;
-    instd->show();
-
-//    id->exec();
-//    delete id;
-}
-
-void FWWindow::install()
-{
-    std::set<Firewall*> emp;
-    instd = new instDialog(this, true, false, emp);
-    instd->show();
-
-//    id->exec();
-//    delete id;
-}
-
-void FWWindow::transferfw(set<Firewall*> vf)
-{
-    transferDialog *ed = new transferDialog(NULL, vf);
-    ed->show();
-}
-
-void FWWindow::transferfw()
-{
-    std::set<Firewall*> emp;
-    transferDialog *ed = new transferDialog(NULL, emp);
-    ed->show();
-}
-
 void FWWindow::showEvent(QShowEvent *ev)
 {
     st->restoreGeometry(this, QRect(100,100,750,600) );
@@ -928,6 +865,7 @@ void FWWindow::prepareFileMenu()
         m_mainWindow->fileCommitAction->setEnabled(false);
         m_mainWindow->fileDiscardAction->setEnabled(false);
         m_mainWindow->filePropAction->setEnabled(false);
+        m_mainWindow->libExportAction->setEnabled(false);
         m_mainWindow->libImportAction->setEnabled(false);
         m_mainWindow->policyImportAction->setEnabled(false);
         return;
@@ -943,6 +881,8 @@ void FWWindow::prepareFileMenu()
     m_mainWindow->filePropAction->setEnabled(real_file_opened);
     m_mainWindow->filePrintAction->setEnabled(real_file_opened);
     m_mainWindow->libExportAction->setEnabled(real_file_opened);
+    m_mainWindow->libImportAction->setEnabled(true);
+    m_mainWindow->policyImportAction->setEnabled(true);
 
     m_mainWindow->addToRCSAction->setEnabled(real_file_opened && !in_rcs);
     m_mainWindow->fileCommitAction->setEnabled(real_file_opened && in_rcs && needs_saving);
@@ -1086,6 +1026,9 @@ void FWWindow::subWindowActivated(QMdiSubWindow *subwindow)
     if (pp)
     {
         prepareFileMenu();
+        //prepareRulesMenu();
+        updateGlobalToolbar();
+
         pp->setActive();
         if (isEditorVisible()) openEditor(pp->getSelectedObject());
     }
@@ -1352,16 +1295,45 @@ void FWWindow::checkForUpgrade(const QString& server_response)
             st->getTimeOfLastUpdateAvailableWarning();
         bool update_available = (server_response.trimmed() == "update = 1");
 
-        if (update_available &&
-            (now - last_update_available_warning_time > 24*3600))
+        if (update_available
+            && (now - last_update_available_warning_time > 24*3600)
+        )
         {
             QMessageBox::warning(
                 this,"Firewall Builder",
                 tr("A new version of Firewall Builder is available at"
                    " http://www.fwbuilder.org"));
             st->setTimeOfLastUpdateAvailableWarning(now);
-        }
+        } else
+        {
+            // format of the announcement string is very simple: it is just
+            // announcement = URL
+            // All on one line.
+            QRegExp announcement_re = QRegExp("announcement\\s*=\\s*(\\S+)");
+            if (announcement_re.indexIn(server_response.trimmed()) != -1)
+            {
+                QStringList list = announcement_re.capturedTexts();
+                if (list.size() > 1)
+                {
+                    QString announcement_url = list[1];
+                    uint last_annluncement_time = st->getTimeOfLastAnnouncement(
+                        announcement_url);
 
+                    if (fwbdebug)
+                        qDebug() << "announcement_url=" << announcement_url
+                                 << "last_annluncement_time=" << last_annluncement_time;
+
+                    if (last_annluncement_time == 0)
+                    {
+                        // We have an announcement to make and this user has not
+                        // seen it yet.
+                        st->setTimeOfLastAnnouncement(announcement_url, now);
+                        Help *h = Help::getHelpWindow(this);
+                        h->setSource(QUrl(announcement_url));
+                    }
+                }
+            }
+        }
     } else
     {
         if (fwbdebug)
@@ -1418,6 +1390,9 @@ void FWWindow::showSummary()
  */
 void FWWindow::showTutorial(QString tutorial)
 {
+    if (fwbdebug)
+        qDebug() << "FWWindow::showTutorial:" << tutorial;
+
     TutorialDialog *dialog;
     if (tutorial.isEmpty())
         dialog= new TutorialDialog(
@@ -1499,13 +1474,39 @@ void FWWindow::undoViewVisibilityChanged(bool visible)
        st->setShowUndoPanel(visible);
 }
 
-void FWWindow::prepareRulesMenu ()
+void FWWindow::updateGlobalToolbar()
 {
-    qDebug("FWWindow::ruleMenuAboutToShow ()");
+    ProjectPanel* pp = activeProject();
+    if (pp)
+    {
+        list<Firewall *> fws;
+	if (pp->db() != NULL) pp->findAllFirewalls(fws);
+        setCompileAndInstallActionsEnabled(fws.size() != 0);
+    } else
+        setCompileAndInstallActionsEnabled(false);
+}
 
+void FWWindow::setupGlobalToolbar()
+{
+    setUnifiedTitleAndToolBarOnMac(false);
+    if (st->getBool("/UI/IconWithText"))
+        m_mainWindow->toolBar->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
+    else
+        m_mainWindow->toolBar->setToolButtonStyle(Qt::ToolButtonIconOnly);
+    setUnifiedTitleAndToolBarOnMac(true);
+}
+
+
+/*
+ * This method constructs main menu "Rules" and enables or disables items
+ * as appropriate.
+ */
+void FWWindow::prepareRulesMenu()
+{
     cleanRulesMenu();
 
-    if (activeProject())
+    ProjectPanel* pp = activeProject();
+    if (pp)
     {
         RuleSetView* rsv = activeProject()->getCurrentRuleSetView();
 
@@ -1515,12 +1516,15 @@ void FWWindow::prepareRulesMenu ()
         }
         m_mainWindow->RulesMenu->addSeparator();
         m_mainWindow->RulesMenu->addActions(ruleStaticActions);
+
+        list<Firewall *> fws;
+        pp->findAllFirewalls(fws);
+        setCompileAndInstallActionsEnabled(fws.size() != 0);
     }
 }
 
 void FWWindow::cleanRulesMenu ()
 {
-    qDebug("FWWindow::cleanRulesMenu ()");
     m_mainWindow->RulesMenu->actions().clear();
     m_mainWindow->RulesMenu->clear();
 }
@@ -1534,3 +1538,94 @@ void FWWindow::showStatusBarMessage(const QString &txt)
     QApplication::processEvents(QEventLoop::ExcludeUserInputEvents, 100);
 }
 
+void FWWindow::setCompileAndInstallActionsEnabled(bool en)
+{
+    if (fwbdebug) qDebug() << "FWWindow::setCompileAndInstallActionsEnabled en="
+                           << en;
+    m_mainWindow->compileAction->setEnabled(en );
+    m_mainWindow->installAction->setEnabled(en );
+    m_mainWindow->inspectAction->setEnabled(en );
+}
+
+void FWWindow::setEnabledAfterRF()
+{
+    if (fwbdebug) qDebug() << "FWWindow::setEnabledAfterRF()";
+    m_mainWindow->compileAction->setEnabled( true );
+    m_mainWindow->installAction->setEnabled( true );
+    m_mainWindow->inspectAction->setEnabled( true );
+}
+
+void FWWindow::selectRules()
+{
+    if (fwbdebug) qDebug() << "FWWindow::selectRules()";
+
+    m_mainWindow ->compileAction->setEnabled( true );
+    m_mainWindow ->installAction->setEnabled( true );
+    m_mainWindow ->inspectAction->setEnabled( true );
+
+    if (activeProject()) activeProject()->selectRules();
+}
+
+void FWWindow::disableActions(bool havePolicies)
+{
+    if (fwbdebug) qDebug() << "FWWindow::disableActions()";
+
+    m_mainWindow ->compileAction->setEnabled(havePolicies);
+    m_mainWindow ->installAction->setEnabled(havePolicies);
+    m_mainWindow ->inspectAction->setEnabled(havePolicies);
+}
+
+void FWWindow::compile()
+{
+    if (activeProject())
+    {
+        std::set<Firewall*> emp;
+        instd->show(this->activeProject(), false, false, emp);
+    }
+}
+
+void FWWindow::install()
+{
+    if (activeProject())
+    {
+        std::set<Firewall*> emp;
+        instd->show(this->activeProject(), true, false, emp);
+    }
+}
+
+void FWWindow::compile(set<Firewall*> vf)
+{
+    if (fwbdebug)
+        qDebug("FWWindow::compile preselected %d firewalls", int(vf.size()));
+    if (activeProject())
+    {
+        instd->show(this->activeProject(), false, true, vf);
+    }
+}
+
+void FWWindow::install(set<Firewall*> vf)
+{
+    if (activeProject())
+    {
+        instd->show(this->activeProject(), true, true, vf);
+    }
+}
+
+void FWWindow::inspect()
+{
+    this->activeProject()->inspectAll();
+}
+
+void FWWindow::transferfw(set<Firewall*> vf)
+{
+    transferDialog *ed = new transferDialog(NULL, vf);
+    ed->show();
+}
+
+void FWWindow::transferfw()
+{
+    std::set<Firewall*> emp;
+    transferDialog *ed = new transferDialog(NULL, emp);
+    ed->show();
+}
+
