@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindow.h 2686 2010-03-08 01:13:19Z vadim $
+  $Id: FWWindow.h 3030 2010-06-27 04:29:48Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -34,6 +34,7 @@
 #include "HttpGet.h"
 #include "printerStream.h"
 #include "ObjectEditor.h"
+#include "instDialog.h"
 
 #include <QString>
 #include <QShowEvent>
@@ -94,10 +95,9 @@ class FWWindow : public QMainWindow {
         
     QMdiArea *m_space;
     QMdiSubWindow *previous_subwindow;
-    QWidget *instd;
+    instDialog *instd;
     HttpGet *current_version_http_getter;
-    
-    QTimer *instDialogOnScreenTimer;
+
     QString noFirewalls;
 
     QWidget *editorOwner;
@@ -139,7 +139,9 @@ public:
     void updateTreeFont();
     void updateRecentFileActions();
     void updateOpenRecentMenu(const QString &fileName);
-
+    void updateGlobalToolbar();
+    void setupGlobalToolbar();
+    
     void enableBackAction();
     
 public slots:
@@ -200,6 +202,7 @@ public slots:
     virtual void compile();
     virtual void install(std::set<libfwbuilder::Firewall * > vf);
     virtual void install();
+    virtual void inspect();
     virtual void transferfw(std::set<libfwbuilder::Firewall * > vf);
     virtual void transferfw();
 
@@ -232,8 +235,6 @@ public slots:
 
     virtual void toolsDiscoveryDruid();
 
-    virtual void killInstDialog();
-
     virtual void checkForUpgrade(const QString&);
 
     virtual void projectWindowClosed();
@@ -279,7 +280,7 @@ public slots:
      */
     void selectRules();
     void disableActions(bool havePolicies);
-    void setActionsEnabled(bool en);
+    void setCompileAndInstallActionsEnabled(bool en);
     void setEnabledAfterRF();
 
     QString getCurrentFileName();
