@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: FilterDialog.h 353 2008-07-13 01:26:39Z vadim $
+  $Id: FilterDialog.h 1554 2009-10-05 16:21:03Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -108,7 +108,6 @@ class FilterDialog : public QDialog
     ~FilterDialog();
     void setFilter(Filter *);
     
-    //virtual void closeEvent(QCloseEvent *e);
 
 
 public slots:
@@ -121,13 +120,6 @@ public slots:
     virtual void updateData();
 
     
- signals:
-/**
- * This signal is emitted from closeEvent, ObjectEditor connects
- * to this signal to make checks before the object editor can be closed
- * and to store its position on the screen
- */
-   // void close_sign(QCloseEvent *e);
     
 };
 
