@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: FindObjectWidget.cpp 991 2009-06-01 06:04:35Z vadim $
+  $Id: FindObjectWidget.cpp 2583 2010-02-19 18:43:18Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -29,7 +29,6 @@
 #include "utils.h"
 #include "platforms.h"
 
-#include <QLineEdit>
 #include "FindObjectWidget.h"
 #include "FWWindow.h"
 #include "FWObjectDropArea.h"
@@ -39,6 +38,8 @@
 #include "RuleSetView.h"
 #include "ObjectEditor.h"
 #include "ProjectPanel.h"
+#include "FWCmdChange.h"
+#include "events.h"
 
 #include "fwbuilder/FWObjectDatabase.h"
 #include "fwbuilder/FWReference.h"
@@ -49,8 +50,11 @@
 #include "fwbuilder/ICMPService.h"
 #include "fwbuilder/TCPService.h"
 #include "fwbuilder/UDPService.h"
+#include "fwbuilder/MultiAddress.h"
 
+#include <QLineEdit>
 #include <QStackedWidget>
+#include <QtDebug>
 #include <qradiobutton.h>
 #include <qcheckbox.h>
 #include <qcombobox.h>
@@ -62,14 +66,18 @@
 
 #include <iostream>
 #include <stdlib.h>
+#include <memory>
+
 
 using namespace std;
 using namespace libfwbuilder;
 
 #define MAX_SEARCH_ITEMS_COUNT 10
 
-FindObjectWidget::FindObjectWidget(QWidget*p, const char * n, Qt::WindowFlags f) : QWidget(p,f)
+FindObjectWidget::FindObjectWidget(QWidget*p, ProjectPanel *pp,
+                                   const char * n, Qt::WindowFlags f) : QWidget(p,f)
 {
+    project_panel = pp;
     m_widget = new Ui::findObjectWidget_q;
     m_widget->setupUi(this);
 
@@ -121,9 +129,9 @@ void FindObjectWidget::objectInserted()
 
 void FindObjectWidget::reset()
 {
-    lastFound=NULL;
-    lastAttrSearch="";
-    treeSeeker = mw->db()->tree_begin();
+    lastFound = NULL;
+    lastAttrSearch = "";
+    found_objects.clear();
 }
 
 
@@ -272,9 +280,63 @@ bool FindObjectWidget::matchAttr(libfwbuilder::FWObject *obj)
     return res;
 }
 
+/*
+ * Walks the whole tree and fills found_objects list
+ */
+void FindObjectWidget::_findAll()
+{
+    treeSeeker = project_panel->db()->tree_begin();
+    for (; treeSeeker != project_panel->db()->tree_end(); ++treeSeeker)
+    {
+        FWObject *o = *treeSeeker;
+
+        if( RuleElement::cast(o->getParent())!=NULL)
+        {
+            if (m_widget->srScope->currentIndex()==3) // scope == selected firewalls
+            {
+                if ( !inSelectedFirewall(RuleElement::cast(o->getParent())) )
+                {
+                    continue;
+                }
+            } else
+                if (m_widget->srScope->currentIndex()==0) continue ; // scope == tree only
+        } else
+        {
+/* if not in rules, then in the tree. */
+            if (m_widget->srScope->currentIndex()>1) continue; // scope in (firewalls only , selected firewalls)
+        }
+
+        FWObject *obj = o;
+        if (FWReference::cast(o)!=NULL)
+        {
+            FWReference *r = FWReference::cast(o);
+            obj = r->getPointer();
+        }
+
+        if (matchAttr(obj) && matchID(obj->getId()))
+        {
+            // If object we have found belongs to the deleted objects lib
+            // but this library is hidden, don't show it.
+            if (obj->getLibrary()->getId() == FWObjectDatabase::DELETED_OBJECTS_ID &&
+                !st->getBool("UI/ShowDeletedObjects")) continue;
+            // Note that if o is a reference, we should add reference
+            // to found_objects
+            found_objects.push_back(o);
+        }
+    }
+}
+
+/*
+ * Group::duplicateForUndo(), which is used in FWCmdChange::redo() and
+ * undo() breaks FWObject::tree_iterator because it adds or removes
+ * objects to groups. To work around this problem, we fill list
+ * found_objects on the first call to findNext() and then just iterate
+ * over items in this list later.
+ */
 void FindObjectWidget::findNext()
 {
     if (fwbdebug) qDebug("FindObjectWidget::findNext");
+
     if (
         m_widget->findAttr->currentText().isEmpty() &&
         m_widget->findDropArea->isEmpty()) return;
@@ -286,58 +348,26 @@ void FindObjectWidget::findNext()
 
     // if scope is "policies of opened firewall" then we need to get 
     // pointer to the currently opened firewall object
-    RuleSet* current_rule_set = mw->activeProject()->getCurrentRuleSet();
+    RuleSet* current_rule_set = project_panel->getCurrentRuleSet();
     if (current_rule_set)
         selectedFirewall = Firewall::cast(current_rule_set->getParent());
     else
         selectedFirewall = NULL;
 
-    if (fwbdebug)
-        qDebug("selectedFirewall: %p", selectedFirewall);
+    if (fwbdebug) qDebug() << "selectedFirewall: " << selectedFirewall;
 
 loop:
 
-    QApplication::setOverrideCursor( QCursor( Qt::WaitCursor) );
-
-    for (; treeSeeker!=mw->db()->tree_end(); ++treeSeeker)
+    if (found_objects.size() == 0)
     {
-        o = *treeSeeker;
+        QApplication::setOverrideCursor( QCursor( Qt::WaitCursor) );
+        _findAll();
+        QApplication::restoreOverrideCursor();
 
-//        if (fwbdebug)
-//            qDebug("Found object %s (%s)", o->getName().c_str(), o->getTypeName().c_str());
-
-        if( RuleElement::cast(o->getParent())!=NULL)
-        {
-            if (m_widget->srScope->currentIndex()==3) // scope == selected firewalls
-            {
-                if ( !inSelectedFirewall(RuleElement::cast(o->getParent())) )
-                {
-                    continue;
-
-                }
-            } else
-                if (m_widget->srScope->currentIndex()==0) continue ; // scope == tree only
-        } else
-        {
-/* if not in rules, then in the tree. */
-            if (m_widget->srScope->currentIndex()>1) continue; // scope in (firewalls only , selected firewalls)
-        }
-
-        if (FWReference::cast(o)!=NULL)
-        {
-            FWReference *r=FWReference::cast(o);
-            if (matchAttr( r->getPointer() ) &&
-                matchID( r->getPointer()->getId() )) break;
-        } else
-        {
-            if (matchAttr( o ) &&
-                matchID( o->getId() )) break;
-        }
+        found_objects_iter = found_objects.begin();
     }
 
-    QApplication::restoreOverrideCursor();
-
-    if (treeSeeker==mw->db()->tree_end())
+    if (found_objects_iter == found_objects.end())
     {
         reset();
         if (m_widget->srScope->currentIndex()==3) // scope ==selected firewalls
@@ -359,58 +389,76 @@ loop:
         }
         return;
     }
-    assert(o!=NULL);
-    lastFound=o;
-/* found object. Shift iterator so it does not return the same object
- * when user hits 'find next'
- */
 
-    ++treeSeeker;
+    o = *found_objects_iter;
+    ++found_objects_iter;
+
+    assert(o!=NULL);
+    lastFound = o;
 
     if (fwbdebug)
     {
-        qDebug("Found object: o=%p  id=%s  name=%s  type=%s",
-               o,
-               FWObjectDatabase::getStringId(o->getId()).c_str(),
-               o->getName().c_str(),o->getTypeName().c_str());
+        qDebug() << "Found object: o=" << o
+                 << "id=" << FWObjectDatabase::getStringId(o->getId()).c_str()
+                 << "name=" << o->getName().c_str()
+                 << "type=" << o->getTypeName().c_str();
     }
     showObject(o);
 }
 
 bool FindObjectWidget::validateReplaceObject()
 {
-    if (m_widget->findDropArea->isEmpty() || m_widget->replaceDropArea->isEmpty())
+    if (m_widget->findDropArea->isEmpty())
     {
         QMessageBox::warning(
-              this,"Firewall Builder",
-              tr("Search or Replace object ind't specified."));
+              this, "Firewall Builder", tr("Search object is missing."));
         return false;
     }
-    FWObject *findObj, *replObj;
-    findObj=m_widget->findDropArea->getObject();
-    replObj=m_widget->replaceDropArea->getObject();
+
+    if (m_widget->replaceDropArea->isEmpty())
+    {
+        QMessageBox::warning(
+              this, "Firewall Builder", tr("Replace object is missing."));
+        return false;
+    }
+
+    FWObject* findObj = m_widget->findDropArea->getObject();
+    FWObject* replObj = m_widget->replaceDropArea->getObject();
+
     if (findObj==replObj || findObj->getId() == replObj->getId())
     {
         QMessageBox::warning(
               this,"Firewall Builder",
-              tr("Cannot replace object by itself."));
+              tr("Cannot replace object with itself."));
         return false;
     }
-    if (!((Address::cast(findObj)!=NULL && Address::cast(replObj)) ||
-            (Service::cast(findObj)!=NULL && Service::cast(replObj))))
-    {
-        QMessageBox::warning(
-              this,"Firewall Builder",
-              tr("Search and Replace objects are incompatible."));
 
-        return false;
-    }
-    return true;
+    bool obj_1_address = 
+        Address::cast(findObj)!=NULL ||
+        MultiAddress::cast(findObj)!=NULL ||
+        ObjectGroup::cast(findObj)!=NULL;
+
+    bool obj_2_address =
+        Address::cast(replObj)!=NULL ||
+        MultiAddress::cast(replObj)!=NULL ||
+        ObjectGroup::cast(replObj)!=NULL;
+
+    bool obj_1_service = Service::cast(findObj)!=NULL || ServiceGroup::cast(findObj);
+    bool obj_2_service = Service::cast(replObj)!=NULL || ServiceGroup::cast(replObj);
+
+    if ((obj_1_address && obj_2_address) || (obj_1_service && obj_2_service))
+        return true;
+
+    QMessageBox::warning(
+        this,"Firewall Builder",
+        tr("Search and Replace objects are incompatible."));
+    
+    return false;
 }
+
 void FindObjectWidget::replace()
 {
-    if(!validateReplaceObject())  return;
-
+    if (!validateReplaceObject()) return;
 
     if (lastFound==NULL)
     {
@@ -418,136 +466,88 @@ void FindObjectWidget::replace()
         return;
     }
 
-    QApplication::setOverrideCursor( QCursor( Qt::WaitCursor) );
-    FWObject *res=_replaceCurrent();
-    mw->updateRuleSetView();
-    mw->info();
-    if (res)
-    {
-        showObject(res);
-    }
-    else
-    {
-        // object isn't inserted
-        qDebug("object isn't inserted");
-    }
-
-    QApplication::restoreOverrideCursor();
+    _replaceCurrent();
 }
 
 void FindObjectWidget::replaceAll()
 {
     if(!validateReplaceObject()) return;
     reset();
-    FWObject *o=NULL;
+
+    findNext();  // fill found_objects and position to the first found one
+
     int count=0;
-    bool f=true;
-
-    QApplication::setOverrideCursor( QCursor( Qt::WaitCursor) );
-    while (f)
+    for (found_objects_iter=found_objects.begin(); found_objects_iter!=found_objects.end();
+         ++found_objects_iter)
     {
-        for (; treeSeeker!=mw->db()->tree_end(); ++treeSeeker)
-        {
-            o = *treeSeeker;
-            if( RuleElement::cast(o->getParent())!=NULL)
-            {
-                if (m_widget->srScope->currentIndex()==3) // scope == selected firewalls
-                {
-                    if ( !inSelectedFirewall(RuleElement::cast(o->getParent())) )
-                    {
-                        continue;
-
-                    }
-                } else if (m_widget->srScope->currentIndex()==0) continue ; // scope == tree only
-            } else
-            {
-    /* if not in rules, then in the tree. */
-                if (m_widget->srScope->currentIndex()>1) continue; // scope in (firewalls only , selected firewalls)
-            }
-
-            if (FWReference::cast(o)!=NULL)
-            {
-                FWReference *r=FWReference::cast(o);
-                if (matchAttr( r->getPointer() ) &&
-                    matchID( r->getPointer()->getId() )) break;
-            } else
-            {
-                if (matchAttr( o ) &&
-                    matchID( o->getId() )) break;
-            }
-        }
-        if (treeSeeker==mw->db()->tree_end())
-        {
-            f=false;
-
-        } else
-        {
-            lastFound=o;
-            ++treeSeeker;
-            count++;
-            _replaceCurrent();
-        }
+        lastFound = *found_objects_iter;
+        _replaceCurrent();
+        count++;
     }
-    mw->updateRuleSetView();
-    mw->info();
-    QApplication::restoreOverrideCursor();
+
     QMessageBox::information(
-              this,"Firewall Builder",
+              this, "Firewall Builder",
               tr("Replaced %1 objects.").arg(count));
-
 }
-FWObject* FindObjectWidget::_replaceCurrent()
+
+void FindObjectWidget::_replaceCurrent()
 {
-    FWObject *o=lastFound;
-    FWObject *p=lastFound->getParent();
+    FWObject *o = lastFound;
+    FWObject *p = lastFound->getParent();
 
-    if (p==NULL || o==NULL) return NULL;
-    if (FWReference::cast(o)==NULL) return NULL;
+    if (p==NULL || o==NULL) return;
+    if (FWReference::cast(o)==NULL) return;
 
-    p->removeRef(FWReference::cast(o)->getPointer());
-    //chack for duplicates --------
+    FWObject *replace_object = m_widget->replaceDropArea->getObject();
 
-    FWObject *ro=m_widget->replaceDropArea->getObject();
-    if (RuleElement::cast(p)==NULL || !RuleElement::cast(p)->isAny())
+    std::auto_ptr<FWCmdChange> cmd(
+        new FWCmdChange(project_panel, p, QObject::tr("Replace object")));
+    FWObject *new_state = cmd->getNewState();
+
+    new_state->removeRef(FWReference::cast(o)->getPointer());
+
+    // check for duplicates --------
+
+    if (RuleElement::cast(new_state)==NULL ||
+        !RuleElement::cast(new_state)->isAny())
     {
-/* avoid duplicates */
-        int cp_id = ro->getId();
+        // avoid duplicates
+        int cp_id = replace_object->getId();
         FWObject *oo;
         FWReference *ref;
 
         list<FWObject*>::iterator j;
-        for(j=p->begin(); j!=p->end(); ++j)
+        for(j=new_state->begin(); j!=new_state->end(); ++j)
         {
-            oo=*j;
-            if(cp_id==oo->getId()) return NULL;
-
-            if( (ref=FWReference::cast(oo))!=NULL &&
-                cp_id==ref->getPointerId()) return NULL;
+            oo = *j;
+            if (cp_id==oo->getId() ||
+                ((ref=FWReference::cast(oo))!=NULL &&
+                 cp_id==ref->getPointerId()))
+            {
+                // replacement object is already a member of this
+                // group or rule element. Do not insert it again to
+                // avoid duplicates. Also check if new_state is
+                // different from old_state. It can be the same if
+                // original object was not a member of the group so
+                // the call to removeRef() above did nothing. This
+                // happens when user hits Replace, then hits it
+                // again without finding next.
+                if (!cmd->getOldState()->cmp(new_state, true))
+                    project_panel->undoStack->push(cmd.release());
+                return;
+            }
         }
     }
 
-    p->addRef(ro);
-    FWObject *to;
-    FWReference *ref;
-    list<FWObject*>::iterator i;
-    int id = m_widget->replaceDropArea->getObject()->getId();
-    for (i=p->begin();i!=p->end();++i)
-    {
-        to=*i;
-        ref=FWReference::cast(to);
-        if(ref && ref->getPointerId()==id)
-        {
-            return to;
-        }
-
-    }
-    return NULL;
-
+    new_state->addRef(replace_object);
+    if (!cmd->getOldState()->cmp(new_state, true))
+        project_panel->undoStack->push(cmd.release());
 }
+
 bool FindObjectWidget::inSelectedFirewall( RuleElement* r)
 {
     FWObject *f=r;
-    while (f!=NULL && !Firewall::isA(f)) f=f->getParent();
+    while (f!=NULL && Firewall::cast(f)==NULL) f=f->getParent();
     if (f==NULL) return false;
 
     return selectedFirewall==(Firewall::cast(f));
@@ -571,38 +571,41 @@ void FindObjectWidget::replaceDisable()
 
 void FindObjectWidget::showObject(FWObject* o)
 {
-    if (fwbdebug) qDebug("FindObjectWidget::showObject");
+    if (fwbdebug)
+        qDebug("FindObjectWidget::showObject  o: %s parent: %s",
+               o->getName().c_str(), o->getParent()->getName().c_str());
 
-    FWReference* ref=FWReference::cast(o);
+    FWReference* ref = FWReference::cast(o);
     if (ref!=NULL && RuleElement::cast(o->getParent())!=NULL)
     {
-        mw->closeEditor();
-        mw->clearManipulatorFocus();
-        mw->ensureObjectVisibleInRules( ref );
+
+        // found object in rules
+        QCoreApplication::postEvent(
+            project_panel, new showObjectInRulesetEvent(
+                project_panel->getFileName(), ref->getId()));
         return;
     }
 
-    mw->unselectRules();
-
-    if (Group::cast(o->getParent())!=NULL &&
-        !mw->isSystem(o->getParent()))
+    if (!FWBTree().isStandardFolder(o) &&
+        Group::cast(o->getParent())!=NULL &&
+        !FWBTree().isStandardFolder(o->getParent()))
     {
-        mw->openObject( o->getParent() );
-        mw->editObject( o->getParent() );
-        mw->selectObjectInEditor( (ref) ? ref->getPointer() : o );
+        QCoreApplication::postEvent(
+            mw, new showObjectInTreeEvent(project_panel->getFileName(),
+                                          o->getParent()->getId()));
         return;
     }
 
-    mw->closeEditor();
-    mw->openObject( o );
-    mw->select();  // selects an item in the tree and assigns kbd focus to it
+    QCoreApplication::postEvent(
+        mw, new showObjectInTreeEvent(project_panel->getFileName(), o->getId()));
+
+    //project_panel->select();  // selects an item in the tree and assigns kbd focus to it
 }
 
 void FindObjectWidget::init()
 {
     m_widget->findDropArea->deleteObject();
     m_widget->replaceDropArea->deleteObject();
-    hidePanel();
 }
 
 void FindObjectWidget::firewallOpened(Firewall *f)
