@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: FindObjectWidget.h 353 2008-07-13 01:26:39Z vadim $
+  $Id: FindObjectWidget.h 1985 2009-11-30 23:22:07Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -29,6 +29,7 @@
 
 #include "../../config.h"
 #include <ui_findobjectwidget_q.h>
+#include "ProjectPanel.h"
 
 #include "fwbuilder/FWObject.h"
 #include "fwbuilder/RuleElement.h"
@@ -40,30 +41,35 @@ class QWidget;
 
 class FindObjectWidget : public QWidget
 {
-    Q_OBJECT
- private:
+    Q_OBJECT;
 
-    QString                   lastAttrSearch;
-    libfwbuilder::FWObject   *lastFound;
-    libfwbuilder::FWObject::tree_iterator   treeSeeker;
+private:
+
+    QString lastAttrSearch;
+    libfwbuilder::FWObject *lastFound;
+    libfwbuilder::FWObject::tree_iterator  treeSeeker;
+    std::list<libfwbuilder::FWObject*> found_objects;
+    std::list<libfwbuilder::FWObject*>::iterator found_objects_iter;
     libfwbuilder::Firewall* selectedFirewall;
+    ProjectPanel *project_panel;
 
+    void _findAll();
+    void _replaceCurrent();
+    
     bool matchName(const QString &name);
     bool matchID(int id);
     bool matchAttr(libfwbuilder::FWObject* obj);
     bool validateReplaceObject();
-    libfwbuilder::FWObject* _replaceCurrent();
     bool inSelectedFirewall( libfwbuilder::RuleElement* r);
     
  public:
     Ui::findObjectWidget_q *m_widget;
-    FindObjectWidget(QWidget*p, const char * n = 0, Qt::WindowFlags f = 0);
+    FindObjectWidget(QWidget*p, ProjectPanel *pp, const char * n = 0, Qt::WindowFlags f = 0);
     ~FindObjectWidget() { delete m_widget; };
     void findObject (libfwbuilder::FWObject *o);
-    
+    void attachToProjectWindow(ProjectPanel *pp) { project_panel = pp; }
 
 public slots:
-    virtual void hidePanel() {reset();emit close();}; 
     virtual void enableAll();
     virtual void disableAll();
     virtual void objectInserted();
