@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: FindWhereUsedWidget.cpp 799 2009-04-10 22:44:00Z vadim $
+  $Id: FindWhereUsedWidget.cpp 2106 2009-12-12 18:11:20Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -29,6 +29,7 @@
 #include "utils.h"
 #include "utils_no_qt.h"
 #include "platforms.h"
+#include "events.h"
 
 #include "FindWhereUsedWidget.h"
 #include "FWWindow.h"
@@ -39,6 +40,7 @@
 #include "ObjectTreeView.h"
 #include "RuleSetView.h"
 #include "ProjectPanel.h"
+#include "ColDesc.h"
 
 #include "fwbuilder/FWObjectDatabase.h"
 #include "fwbuilder/FWReference.h"
@@ -68,6 +70,7 @@
 #include <qlineedit.h>
 #include <qgroupbox.h>
 #include <qpixmapcache.h>
+#include <QtDebug>
 
 #include <iostream>
 #include <stdlib.h>
@@ -77,10 +80,12 @@ using namespace libfwbuilder;
 
 
 FindWhereUsedWidget::FindWhereUsedWidget(QWidget *p,
+                                         ProjectPanel *pp,
                                          const char * n,
                                          Qt::WindowFlags f,
                                          bool f_mini) : QWidget(p)
 {
+    project_panel = pp;
     m_widget = new Ui::findWhereUsedWidget_q;
     m_widget->setupUi(this);
 
@@ -90,7 +95,7 @@ FindWhereUsedWidget::FindWhereUsedWidget(QWidget *p,
     flShowObject=true;
     if (f_mini)
     {
-        m_widget->buttonsBox->hide();
+        m_widget->pushButton2->hide();
         m_widget->dropBox->hide();
     }
     else
@@ -109,7 +114,31 @@ void FindWhereUsedWidget::setShowObject(bool fl)
     flShowObject=fl;
 }
 
-void FindWhereUsedWidget::itemActivated(QTreeWidgetItem* item)
+/**
+ * This signal is emitted when the user activates an item by single-
+ * or double-clicking (depending on the platform, i.e. on the
+ * QStyle::SH_ItemView_ActivateItemOnSingleClick style hint) or
+ * pressing a special key (e.g., Enter).
+ */
+void FindWhereUsedWidget::itemActivated(QTreeWidgetItem* item, int)
+{
+    FWObject *container = (FWObject*)(qVariantValue<void*>(item->data(1, Qt::UserRole)));
+
+    if (flShowObject && container!=NULL)
+    {
+        showObject(container);
+    }
+}
+
+/**
+ * This signal is emitted when the user clicks inside the widget.
+ *
+ * The specified item is the item that was clicked, or 0 if no item
+ * was clicked. The column is the item's column that was clicked. If
+ * no item was clicked, no signal will be emitted.
+ *
+ */
+void FindWhereUsedWidget::itemClicked(QTreeWidgetItem* item, int)
 {
     FWObject *container = (FWObject*)(qVariantValue<void*>(item->data(1, Qt::UserRole)));
 
@@ -136,33 +165,40 @@ void FindWhereUsedWidget::_find(FWObject *obj)
     m_widget->resListView->clear();
     resset.clear();
 
-    if (fwbdebug) qDebug("FindWhereUsedWidget: initiate search for %s",
-                         obj->getName().c_str());
+    if (fwbdebug)
+        qDebug() << "FindWhereUsedWidget "
+                 << this
+                 << ": initiate search for "
+                 << obj->getName().c_str()
+                 << "  project_panel "
+                 << project_panel;
 
-    mw->db()->findWhereObjectIsUsed(obj, mw->db(), resset);
-    humanizeSearchResults(resset);
+    if (project_panel==NULL) return;
 
-    set<FWObject*>::iterator i=resset.begin();
+    map<int, set<FWObject*> > reference_holders;
+    UsageResolver::findAllReferenceHolders(obj, obj->getRoot(), reference_holders);
 
-    for (;i!=resset.end();++i)
+    map<int, set<FWObject*> >::iterator it;
+    for (it=reference_holders.begin(); it!=reference_holders.end(); ++it)
     {
-        FWObject *o = *i;
+        FWObject *c_obj = project_panel->db()->findInIndex(it->first);
 
-        if (fwbdebug) qDebug("Search result object id=%d type=%s name=%s",
-                             o->getId(),
-                             o->getTypeName().c_str(),
-                             o->getName().c_str());
+        if (!m_widget->includeChildren->isChecked() && c_obj != obj) continue;
 
-        QTreeWidgetItem *item = createQTWidgetItem(obj, o);
-        if (item==NULL) continue;
-        m_widget->resListView->addTopLevelItem(item);
+        foreach(FWObject *container, it->second)
+        {
+            QTreeWidgetItem *item;
+            item = createQTWidgetItem(c_obj, container);
+            if (item==NULL) continue;
+            m_widget->resListView->addTopLevelItem(item);
+        }
     }
+
     m_widget->resListView->resizeColumnToContents(0);
     m_widget->resListView->resizeColumnToContents(1);
     show();
 }
 
-
 void FindWhereUsedWidget::init()
 {
     object=NULL;
@@ -182,89 +218,67 @@ void FindWhereUsedWidget::showObject(FWObject* o)
 
     if (object==NULL || o==NULL) return;
 
-    if (RuleElement::cast(o)!=NULL)
+    if (RuleElement::cast(o)!=NULL || RuleElement::cast(o->getParent())!=NULL)
     {
-        mw->activeProject()->openRuleSet(o->getParent()->getParent());
-        mw->clearManipulatorFocus();
-        RuleSetView *rsv = mw->activeProject()->getCurrentRuleSetView();
-        rsv->selectRE(RuleElement::cast(o), object);
-        rsv->setFocus(Qt::MouseFocusReason);
+        QCoreApplication::postEvent(
+            project_panel,
+            new showObjectInRulesetEvent(project_panel->getFileName(), o->getId()));
+        return;
+    }
 
-        if (mw->isEditorVisible()) mw->editObject( object );
+    if (Rule::cast(o)!=NULL)
+    {
+        QCoreApplication::postEvent(
+            project_panel,
+            new openRulesetImmediatelyEvent(project_panel->getFileName(),
+                                            o->getParent()->getId()));
+        QCoreApplication::postEvent(
+            project_panel,
+            new selectRuleElementEvent(project_panel->getFileName(),
+                                       o->getId(), ColDesc::Action));
+        return;
+    }
+
+    project_panel->unselectRules();
+
+    if (Group::cast(o)!=NULL)
+    {
+        QCoreApplication::postEvent(
+            project_panel,
+            new showObjectInTreeEvent(project_panel->getFileName(), o->getId()));
+        project_panel->unselectRules();
     } else
     {
-        if (Rule::cast(o)!=NULL)
-        {
-            mw->activeProject()->openRuleSet(o->getParent());
-            mw->clearManipulatorFocus();
-            RuleSetView *rsv = mw->activeProject()->getCurrentRuleSetView();
-            rsv->selectRE(Rule::cast(o),rsv->getColByType(RuleSetView::Action));
-
-            if (mw->isEditorVisible()) mw->editObject( object );
-        } else
-        {
-            mw->unselectRules();
-
-            if (Group::cast(o)!=NULL)
-            {
-                mw->openObject( o );
-                mw->unselectRules();
-
-                if (mw->isEditorVisible())
-                {
-                    mw->editObject( o );
-                    mw->selectObjectInEditor( object);
-                }
-            } else
-            {
-                mw->openObject( object );
-                mw->unselectRules();
-
-                if (mw->isEditorVisible()) mw->editObject( object );
-            }
-        }
+        QCoreApplication::postEvent(
+            project_panel,
+            new showObjectInTreeEvent(project_panel->getFileName(), o->getId()));
+        project_panel->unselectRules();
     }
-    //mw->closeEditor();
-    //mw->openObject( o );
-}
-
-void FindWhereUsedWidget::humanizeSearchResults(std::set<FWObject *> &resset)
-{
-    set<FWObject*> tmp_res;  // set deduplicates items automatically
-    set<FWObject*>::iterator i = resset.begin();
-    for (;i!=resset.end();++i)
-    {
-        FWReference  *ref = FWReference::cast(*i);
-        if (ref)
-        {
-            FWObject *o = ref->getParent();  // NB! We need parent of this ref.
-            tmp_res.insert(o);
-            if (fwbdebug)
-                qDebug("humanizeSearchResults: adding %s (%s)",
-                       o->getName().c_str(), o->getTypeName().c_str());
-        } else
-            tmp_res.insert(*i);
-    }
-    resset.clear();
-    resset = tmp_res;
 }
 
 QTreeWidgetItem* FindWhereUsedWidget::createQTWidgetItem(FWObject* o,
                                                          FWObject *container)
 {
+    if (fwbdebug)
+        qDebug() << "FindWhereUsedWidget::createQTWidgetItem"
+                 << "container:" << container->getName().c_str()
+                 << "(" << container->getTypeName().c_str() << ")";
+
     QString c1, c2;
     FWObject *fw = NULL;
     Rule *r = NULL;
     RuleSet *rs = NULL;
     QPixmap object_icon;
     QPixmap parent_icon;
+    FWBTree tree_format;
 
-    if (mw->isSystem(container) || Library::cast(container)) return NULL;
+    if (tree_format.isSystem(container) || Library::cast(container)) return NULL;
 
+    // container can be a Rule if user searched for an object used in action
     if (RuleElement::cast(container)!=NULL || Rule::cast(container)!=NULL)
     {
         fw = container;
-        while (fw!=NULL && !Firewall::isA(fw))
+        while (fw!=NULL && Firewall::cast(fw)==NULL) // Firewall::cast matches also Cluster
         {
             if (Rule::cast(fw)) r = Rule::cast(fw);
             if (RuleSet::cast(fw)) rs = RuleSet::cast(fw);
@@ -290,9 +304,11 @@ QTreeWidgetItem* FindWhereUsedWidget::createQTWidgetItem(FWObject* o,
         }
 
         QString rule_element_name;
+
         if (RuleElement::cast(container)!=NULL)
-            rule_element_name = 
-                getReadableRuleElementName(container->getTypeName());
+            rule_element_name =
+                getReadableRuleElementName(container->getParent()->getTypeName());
+
         if (Rule::cast(container)!=NULL)
             rule_element_name = "Action";
 
@@ -310,7 +326,7 @@ QTreeWidgetItem* FindWhereUsedWidget::createQTWidgetItem(FWObject* o,
 
         loadIcon(parent_icon, container);
     }
-    
+
     loadIcon(object_icon, o);
 
     QStringList qsl;
