@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FirewallDialog.h 952 2009-05-20 21:54:45Z vadim $
+  $Id: FirewallDialog.h 1891 2009-11-24 03:40:50Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -29,53 +29,37 @@
 
 #include "../../config.h"
 #include <ui_firewalldialog_q.h>
+#include "BaseObjectDialog.h"
 #include <QWidget>
 
 #include "fwbuilder/FWObject.h"
 
 
 class ProjectPanel;
-class FirewallDialog : public QWidget
+class FirewallDialog : public BaseObjectDialog
 {
-    Q_OBJECT
+    Q_OBJECT;
 
-    libfwbuilder::FWObject *obj;
     Ui::FirewallDialog_q   *m_dialog;
-    bool init;
-    bool modified;
     
     void fillVersion();
-    void saveVersion();
-    ProjectPanel *m_project;
-
+    void saveVersion(libfwbuilder::FWObject *o);
+    void updateTimeStamps();
     
  public:
-     FirewallDialog(ProjectPanel *project, QWidget *parent);
+     FirewallDialog(QWidget *parent);
      ~FirewallDialog();
      
 public slots:
-    virtual void changed();
-    virtual void libChanged();
     virtual void applyChanges();
-    virtual void discardChanges();
     virtual void platformChanged();
     virtual void hostOSChanged();
     virtual void loadFWObject(libfwbuilder::FWObject *obj);
     virtual void validate(bool*);
-    virtual void isChanged(bool*);
     virtual void openFWDialog();
     virtual void openOSDialog();
-    virtual void closeEvent(QCloseEvent *e);
     virtual void getHelpName(QString*);
     
- signals:
-/**
- * This signal is emitted from closeEvent, ObjectEditor connects
- * to this signal to make checks before the object editor can be closed
- * and to store its position on the screen
- */
-    void close_sign(QCloseEvent *e);
-    void changed_sign();
     
 };
 
