@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FirewallInstaller.cpp 2348 2010-01-15 02:25:25Z vadim $
+  $Id: FirewallInstaller.cpp 3084 2010-07-15 15:29:17Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,6 +28,7 @@
 #include "utils.h"
 #include "utils_no_qt.h"
 
+#include "compiler_lib/CompilerDriver.h"
 #include "FirewallInstaller.h"
 #include "instDialog.h"
 #include "FWBSettings.h"
@@ -35,6 +36,7 @@
 #include "SSHSession.h"
 #include "SSHUnx.h"
 #include "Configlet.h"
+#include "UserWorkflow.h"
 
 #include "fwbuilder/Resources.h"
 #include "fwbuilder/FWObjectDatabase.h"
@@ -78,18 +80,30 @@ bool FirewallInstaller::parseManifestLine(const QString &line,
         qDebug("Manifest line: '%s'", line.toAscii().constData());
 
     int n = QString(MANIFEST_MARKER).length();
-    QStringList parts = line.mid(n).split(" ", QString::SkipEmptyParts);
-    if (parts.size() == 0) return false;
-    if (parts[0] == "*") { *main_script = true; parts.pop_front(); }
-    if (parts.size() == 0) return false;
-    *local_file_name = parts[0];
-    if (parts.size() == 1)
+    QString workline = line.split(MANIFEST_MARKER)[1].trimmed();
+    if (workline.startsWith("*"))
     {
-        *remote_file_name = "";
-    } else
-    {
-        *remote_file_name = parts[1];
+        *main_script = true;
+        workline = workline.remove(0, 1).trimmed();
     }
+    QString local, remote;
+    int i = 0;
+    for(i=0; i<workline.size(); i++)
+    {
+        if (workline.at(i) == ' ' && workline.at(i-1) != '\\')
+            break;
+        else
+            local.append(workline.at(i));
+    }
+    for(; i<workline.size(); i++)
+    {
+        if (workline.at(i) == ' ' && workline.at(i-1) != '\\')
+            break;
+        else
+            remote.append(workline.at(i));
+    }
+    *local_file_name = fwcompiler::CompilerDriver::unescapeFileName(local);
+    *remote_file_name = fwcompiler::CompilerDriver::unescapeFileName(remote);
 
     if (fwbdebug)
         qDebug("local_name: '%s'  remote_name: '%s'  main_script: %d",
@@ -163,6 +177,7 @@ not root.
 
 */
 
+#include "CompilerDriver.h"
 
 bool FirewallInstaller::readManifest(const QString &script, 
                                      QMap<QString, QString> *all_files)
@@ -284,8 +299,12 @@ void FirewallInstaller::packSSHArgs(QStringList &args)
 {
     QString ssh = st->getSSHPath();
 
+    QStringList ssh_argv;
+    parseCommandLine(ssh, ssh_argv);
+
 #ifdef _WIN32
-    args.push_back(ssh);
+    args += ssh_argv;
+
 /*
  * putty ignores protocol and port specified in the session file if
  * command line option -ssh is given.
@@ -297,6 +316,8 @@ void FirewallInstaller::packSSHArgs(QStringList &args)
  */
     if (!cnf->user.isEmpty() && ssh.toLower().indexOf("plink.exe")!=-1)
     {
+        args.push_back("-load");
+        args.push_back("fwb_session_with_keepalive");
         args.push_back("-ssh");
         args.push_back("-pw");
         args.push_back(cnf->pwd);
@@ -306,9 +327,14 @@ void FirewallInstaller::packSSHArgs(QStringList &args)
 #else
 
     args.push_back(argv0.c_str());
+
     args.push_back("-X");   // fwbuilder works as ssh wrapper
-    //if (fwbdebug)
-    //    args.push_back("-d");
+
+    args += ssh_argv;
+
+    args.push_back("-o");
+    args.push_back(QString("ServerAliveInterval=%1").arg(st->getSSHTimeout()));
+
     args.push_back("-t");
     args.push_back("-t");
 
@@ -333,11 +359,17 @@ void FirewallInstaller::packSCPArgs(const QString &local_name,
     QString file_with_path = getFullPath(local_name);
     QString scp = st->getSCPPath();
 
+    QStringList scp_argv;
+    parseCommandLine(scp, scp_argv);
+
+
 #ifdef _WIN32
-    args.push_back(scp);
+    args += scp_argv;
 
     if (!cnf->user.isEmpty() && scp.toLower().indexOf("pscp.exe")!=-1)
     {
+        args.push_back("-load");
+        args.push_back("fwb_session_with_keepalive");
 //        args.push_back("-ssh");
         args.push_back("-pw");
         args.push_back(cnf->pwd);
@@ -346,6 +378,14 @@ void FirewallInstaller::packSCPArgs(const QString &local_name,
 #else
     args.push_back(argv0.c_str());
     args.push_back("-Y");   // fwbuilder works as scp wrapper
+
+    args += scp_argv;
+
+    args.push_back("-o");
+    // "3" here is the default value of ServerAliveCountMax parameter
+    // This way, overall timeout will be the same for ssh and scp
+    args.push_back(QString("ConnectTimeout=%1").arg(st->getSSHTimeout() * 3));
+
 #endif
 
     if (!cnf->scpArgs.isEmpty())
@@ -390,9 +430,11 @@ void FirewallInstaller::packSCPArgs(const QString &local_name,
     // is read and processed by getDestinationDir()
 
     if (!cnf->user.isEmpty())
-        args.push_back(cnf->user + "@" + mgmt_addr + ":" + remote_name);
+        args.push_back(cnf->user + "@" + mgmt_addr + ":" +
+                       fwcompiler::CompilerDriver::escapeFileName(remote_name));
     else
-        args.push_back(mgmt_addr + ":" + remote_name);
+        args.push_back(mgmt_addr + ":" +
+                       fwcompiler::CompilerDriver::escapeFileName(remote_name));
 }
 
 /*
@@ -421,6 +463,8 @@ void FirewallInstaller::runJobs()
     instJob current_job = job_list.front();
     job_list.pop_front();
 
+    wfl->registerFlag(UserWorkflow::INSTALL_RAN, true);
+
     switch (current_job.job) 
     {
     case COPY_FILE:
@@ -569,6 +613,7 @@ QString FirewallInstaller::getFullPath(const QString &file )
     else return file;
 }
 
+
 /*
  * This method builds and returns activation command
  * This method is used for all firewall platforms but PIX
@@ -597,6 +642,7 @@ QString FirewallInstaller::getActivationCmd()
     // family as "linux24")
     Configlet configlet(host_os, os_family, configlet_name);
     configlet.removeComments();
+    configlet.collapseEmptyStrings(true);
     configlet.setVariable("test",  cnf->testRun);
     configlet.setVariable("run", ! cnf->testRun);
     configlet.setVariable("with_rollback",   cnf->rollback);
@@ -604,11 +650,60 @@ QString FirewallInstaller::getActivationCmd()
     configlet.setVariable("with_compression",  cnf->compressScript);
     configlet.setVariable("no_compression",  ! cnf->compressScript);
 
-    inst_dlg->replaceMacrosInCommand(&configlet);
+    replaceMacrosInCommand(&configlet);
 
-    return configlet.expand();
+    return configlet.expand().trimmed();
 }
 
+void FirewallInstaller::replaceMacrosInCommand(Configlet *conf)
+{
+/* replace macros in activation commands:
+ *
+ * {{$fwbpromp}}   -- "magic" prompt that installer uses to detect when it is logged in
+ * {{$fwdir}}      -- directory on the firewall
+ * {{$fwscript}}   -- script name on the firewall
+ * {{$rbtimeout}}  -- rollbak timeout
+ */
+
+/*
+ * TODO: it does not make sense to split remote_script and then
+ * reassemble it again from the file name and cnf.fwdir. We should set
+ * variable $remote_script and use it in the configlets instead, but
+ * keep $fwbscript and $fwdir for backwards compatibility
+ */
+
+/*
+ * remote_script is a full path, which in case of Cisco can be
+ * something like "flash:file.fw". This means we have a problem with
+ * QFileInfo that interprets it as path:filename on Window or just
+ * file name with no directory path on Unix. As the result, fwbscript
+ * becomes just "file.fw" on Windows and stays "flash:file.fw" on
+ * Unix.
+ */
+
+    QString fwbscript = fwcompiler::CompilerDriver::escapeFileName(
+        QFileInfo(cnf->remote_script).fileName());
+
+    if (fwbscript.indexOf(":")!=-1) fwbscript = fwbscript.section(':', 1, 1);
+
+    if (fwbdebug)
+    {
+        qDebug() << "Macro substitutions:";
+        qDebug() << "  $fwdir=" << cnf->fwdir;
+        qDebug() << "  cnf->script=" << cnf->script;
+        qDebug() << "  cnf->remote_script=" << cnf->remote_script;
+        qDebug() << "  $fwscript=" << fwbscript;
+    }
+
+    conf->setVariable("fwbprompt", fwb_prompt);
+    conf->setVariable("fwdir", cnf->fwdir);
+    conf->setVariable("fwscript", fwbscript);
+
+    conf->setVariable("rbtimeout", cnf->rollbackTime);
+    conf->setVariable("rbtimeout_sec", cnf->rollbackTime * 60);
+}
+
+
 /*
  * Takes destination directory defined in the configlet (or XML
  * resource file) and substitutes {{$fwbdir}} macro with
