@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FirewallInstaller.h 2249 2009-12-23 01:02:51Z vadim $
+  $Id: FirewallInstaller.h 3082 2010-07-14 23:22:49Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -32,6 +32,7 @@
 
 #include "instConf.h"
 #include "instDialog.h"
+#include "Configlet.h"
 
 #include <qstring.h>
 #include <qstringlist.h>
@@ -88,9 +89,6 @@ protected:
 
     void executeExternalInstallScript(const QString &script,
                                       const QString &script_args);
-    
-    virtual bool readManifest(const QString &conffie,
-                              QMap<QString, QString> *all_files);
 
 public:
 
@@ -105,6 +103,7 @@ public:
     void packSSHArgs(QStringList &args);
     void packSCPArgs(const QString &local_name, const QString &remote_name, QStringList &args);
     QString getActivationCmd();
+    void replaceMacrosInCommand(Configlet *configlet);
     virtual QString getDestinationDir(const QString &dir);
 
     void terminate();
@@ -115,6 +114,8 @@ public:
     virtual void activatePolicy(const QString &script, const QString &args);
 
     static QString getGeneratedFileFullPath(libfwbuilder::Firewall *fw);
+    virtual bool readManifest(const QString &conffie,
+                              QMap<QString, QString> *all_files);
 
     
 public slots:
