@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FirewallInstallerUnx.h 888 2009-05-06 16:42:42Z vadim $
+  $Id: FirewallInstallerUnx.h 2249 2009-12-23 01:02:51Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -46,16 +46,14 @@ class FirewallInstallerUnx : public FirewallInstaller
     Q_OBJECT
 
     void executeSession(const QString &cmd);
-        
+
 public:
 
     FirewallInstallerUnx(instDialog *_dlg, instConf *_cnf, const QString &_p) :
     FirewallInstaller(_dlg, _cnf, _p) {}
 
     virtual bool packInstallJobsList(libfwbuilder::Firewall*);
-    virtual void copyFile(const QString &file_name);
-    virtual void activatePolicy();
-
+    virtual void activatePolicy(const QString &script,  const QString &args);
     
 };
 
