@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: HostDialog.cpp 952 2009-05-20 21:54:45Z vadim $
+  $Id: HostDialog.cpp 2460 2010-01-30 18:26:54Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -30,6 +30,7 @@
 #include "FWBTree.h"
 #include "HostDialog.h"
 #include "ProjectPanel.h"
+#include "FWCmdChange.h"
 
 #include "fwbuilder/Library.h"
 #include "fwbuilder/Host.h"
@@ -37,6 +38,8 @@
 #include "fwbuilder/Management.h"
 #include "fwbuilder/FWException.h"
 
+#include <memory>
+
 #include <qlineedit.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
@@ -44,14 +47,14 @@
 #include <qcombobox.h>
 #include <qmessagebox.h>
 #include <qpushbutton.h>
-#include "FWBSettings.h"
+#include <QUndoStack>
 
 #include "FWWindow.h"
 
 using namespace std;
 using namespace libfwbuilder;
 
-HostDialog::HostDialog(ProjectPanel *project, QWidget *parent) : QWidget(parent), m_project(project)
+HostDialog::HostDialog(QWidget *parent) : BaseObjectDialog(parent)
 {
     m_dialog = new Ui::HostDialog_q;
     m_dialog->setupUi(this);
@@ -75,7 +78,6 @@ void HostDialog::loadFWObject(FWObject *o)
     assert(s!=NULL);
 
     init = true;
-    modified = false;
 
     Management *mgmt=s->getManagementObject();
     assert(mgmt!=NULL);
@@ -106,20 +108,9 @@ void HostDialog::loadFWObject(FWObject *o)
     init=false;
 }
 
-void HostDialog::changed()
-{
-    if (!init) modified = true;
-    emit changed_sign();
-}
-
 void HostDialog::validate(bool *res)
 {
     *res = true;
-    if (!isTreeReadWrite(this,obj))
-    {
-        *res=false;
-        return;
-    }
     if (!validateName(this,obj,m_dialog->obj_name->text()))
     {
         *res=false;
@@ -127,52 +118,57 @@ void HostDialog::validate(bool *res)
     }
 }
 
-void HostDialog::isChanged(bool *m)
-{
-    *m = modified;
-}
 
-void HostDialog::libChanged()
-{
-    changed();
-}
 
 void HostDialog::applyChanges()
 {
-    Host *s = dynamic_cast<Host*>(obj);
+    bool autorename_chidren = false;
+    QString dialog_txt = tr(
+        "The name of the object '%1' has changed. The program can also "
+        "rename IP address objects that belong to this object, "
+        "using standard naming scheme 'host_name:interface_name:ip'. "
+        "This makes it easier to distinguish what host or a firewall "
+        "given IP address object belongs to when it is used in "
+        "the policy or NAT rule. The program also renames MAC address "
+        "objects using scheme 'host_name:interface_name:mac'. "
+        "Do you want to rename child IP and MAC address objects now? "
+        "(If you click 'No', names of all address objects that belong to "
+        "%2 will stay the same.)")
+        .arg(QString::fromUtf8(obj->getName().c_str()))
+        .arg(QString::fromUtf8(obj->getName().c_str()));
+
+    if (obj->getName() != m_dialog->obj_name->text().toUtf8().constData())
+    {
+        /* see comment about this in FirewallDialog */
+        blockSignals(true);
+        autorename_chidren = (QMessageBox::warning(
+                                  this,"Firewall Builder", dialog_txt,
+                                  tr("&Yes"), tr("&No"), QString::null,
+                                  0, 1 )==0 );
+        blockSignals(false);
+    }
+
+    std::auto_ptr<FWCmdChange> cmd(
+        new FWCmdChange(m_project, obj, "", autorename_chidren));
+    FWObject* new_state = cmd->getNewState();
+
+    Host *s = dynamic_cast<Host*>(new_state);
     assert(s!=NULL);
 
-    Management *mgmt=s->getManagementObject();
+    Management *mgmt = s->getManagementObject();
     assert(mgmt!=NULL);
 
     FWOptions  *opt =s->getOptionsObject();
 
     string oldname=obj->getName();
-    obj->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
-    obj->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
-//    mgmt->getSNMPManagement()->setReadCommunity( snmpCommunity->text().latin1() );
-    opt->setBool("use_mac_addr_filter", m_dialog->MACmatching->isChecked() );
-
-    mw->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
-
-    //apply->setEnabled( false );
-    mw->updateLastModifiedTimestampForAllFirewalls(obj);
-    modified = false;
-}
-
-void HostDialog::discardChanges()
-{
-    loadFWObject(obj);
-}
-
-
-/* ObjectEditor class connects its slot to this signal and does all
- * the verification for us, then accepts (or not) the event. So we do
- * nothing here and defer all the processing to ObjectEditor
- */
-void HostDialog::closeEvent(QCloseEvent *e)
-{
-    emit close_sign(e);
+    new_state->setName(string(m_dialog->obj_name->text().toUtf8().constData()));
+    new_state->setComment(string(m_dialog->comment->toPlainText().toUtf8().constData()) );
+    opt->setBool("use_mac_addr_filter", m_dialog->MACmatching->isChecked());
 
+    if (!cmd->getOldState()->cmp(new_state, true))
+    {
+        if (obj->isReadOnly()) return;
+        m_project->undoStack->push(cmd.release());
+    }
 }
 
