@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IOSImporter.cpp 2650 2010-03-04 03:56:46Z vadim $
+  $Id: IOSImporter.cpp 3061 2010-07-10 19:36:10Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -388,15 +388,15 @@ Firewall* IOSImporter::finalize()
     // UnidirectionalRuleSet into one RuleSet object. Attach this
     // object to the firewall.
 
-    if (fwbdebug) qDebug("IPTImporter::finalize()");
+    if (fwbdebug) qDebug("IOSImporter::finalize()");
 
     if (haveFirewallObject())
     {
-        FWObject *fw = getFirewallObject();
+        Firewall *fw = Firewall::cast(getFirewallObject());
         fw->setStr("host_OS", "ios");
+        Resources::setDefaultTargetOptions("ios" , fw);
 
-        FWObject *policy =
-            getFirewallObject()->getFirstByType(Policy::TYPENAME);
+        FWObject *policy = getFirewallObject()->getFirstByType(Policy::TYPENAME);
         assert( policy!=NULL );
 
         if (all_rulesets.size()!=0)
