@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IOSImporter.h 362 2008-07-15 17:37:58Z svn $
+  $Id: IOSImporter.h 2902 2010-05-13 19:39:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -38,9 +38,8 @@
 #include "fwbuilder/libfwbuilder-config.h"
 #include "fwbuilder/Logger.h"
 
-class IOSImporter : public Importer {
-
-    libfwbuilder::Logger *logger;
+class IOSImporter : public Importer
+{
 
     std::map<std::string, std::pair<int,int> > ios_icmp_specs;
     std::map<std::string, int>                 ios_proto_specs;
