@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPv6Dialog.cpp 952 2009-05-20 21:54:45Z vadim $
+  $Id: IPv6Dialog.cpp 2512 2010-02-10 23:46:54Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,8 +28,8 @@
 #include "utils.h"
 
 #include "IPv6Dialog.h"
-
-//#include "ProjectPanel.h"
+#include "ProjectPanel.h"
+#include "FWCmdChange.h"
 
 #include "fwbuilder/Library.h"
 #include "fwbuilder/IPv6.h"
@@ -37,6 +37,8 @@
 #include "fwbuilder/Interface.h"
 #include "fwbuilder/FWException.h"
 
+#include <memory>
+
 #include <qlineedit.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
@@ -48,7 +50,8 @@
 #include <qhostinfo.h>
 #include <qapplication.h>
 #include <qcursor.h>
-#include "FWBSettings.h"
+#include <QUndoStack>
+#include <QApplication>
 
 #include <iostream>
 
@@ -57,7 +60,7 @@
 using namespace std;
 using namespace libfwbuilder;
 
-IPv6Dialog::IPv6Dialog(ProjectPanel *project, QWidget *parent) : QWidget(parent), m_project(project)
+IPv6Dialog::IPv6Dialog(QWidget *parent) : BaseObjectDialog(parent)
 {
     m_dialog = new Ui::IPv6Dialog_q;
     m_dialog->setupUi(this);
@@ -139,17 +142,10 @@ void IPv6Dialog::loadFWObject(FWObject *o)
     init=false;
 }
 
-void IPv6Dialog::changed()
-{
-    //apply->setEnabled( true );
-    emit changed_sign();
-}
-
 void IPv6Dialog::validate(bool *res)
 {
     *res=true;
 
-    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
     if (!validateName(this,obj,m_dialog->obj_name->text())) { *res=false; return; }
 
     IPv6 *s = dynamic_cast<IPv6*>(obj);
@@ -159,11 +155,16 @@ void IPv6Dialog::validate(bool *res)
         InetAddr(AF_INET6, m_dialog->address->text().toLatin1().constData() );
     } catch (FWException &ex)
     {
-        *res=false;
-        QMessageBox::critical(this, "Firewall Builder",
-                              tr("Illegal IP address '%1'").arg(m_dialog->address->text()),
-                              tr("&Continue"), 0, 0,
-                              0 );
+        *res = false;
+        if (QApplication::focusWidget() != NULL)
+        {
+            blockSignals(true);
+            QMessageBox::critical(this, "Firewall Builder",
+                                  tr("Illegal IP address '%1'").arg(m_dialog->address->text()),
+                                  tr("&Continue"), 0, 0,
+                                  0 );
+            blockSignals(false);
+        }
     }
 
     if ( showNetmask )
@@ -175,34 +176,33 @@ void IPv6Dialog::validate(bool *res)
             if (!ok) throw FWException("");
         } catch (FWException &ex)
         {
-            *res=false;
-            QMessageBox::critical(this, "Firewall Builder",
-                                  tr("Illegal netmask '%1'").arg(m_dialog->netmask->text()),
-                                  tr("&Continue"), 0, 0,
-                                  0 );
+            *res = false;
+            if (QApplication::focusWidget() != NULL)
+            {
+                blockSignals(true);
+                QMessageBox::critical(this, "Firewall Builder",
+                                      tr("Illegal netmask '%1'").arg(m_dialog->netmask->text()),
+                                      tr("&Continue"), 0, 0,
+                                      0 );
+                blockSignals(false);
+            }
         }
     }
 }
 
-void IPv6Dialog::isChanged(bool*)
-{
-    //*res=(!init && apply->isEnabled());
 
-}
-
-void IPv6Dialog::libChanged()
-{
-    changed();
-}
 
 void IPv6Dialog::applyChanges()
 {
-    IPv6 *s = dynamic_cast<IPv6*>(obj);
+    std::auto_ptr<FWCmdChange> cmd( new FWCmdChange(m_project, obj));
+    FWObject* new_state = cmd->getNewState();
+
+    IPv6 *s = dynamic_cast<IPv6*>(new_state);
     assert(s!=NULL);
 
     string oldname=obj->getName();
-    obj->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
-    obj->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
+    new_state->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
+    new_state->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
 
     try
     {
@@ -222,15 +222,11 @@ void IPv6Dialog::applyChanges()
     } else
         s->setNetmask(InetAddr(AF_INET6, 0));
 
-    mw->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
-
-    //apply->setEnabled( false );
-    mw->updateLastModifiedTimestampForAllFirewalls(obj);
-}
-
-void IPv6Dialog::discardChanges()
-{
-    loadFWObject(obj);
+    if (!cmd->getOldState()->cmp(new_state, true))
+    {
+        if (obj->isReadOnly()) return;
+        m_project->undoStack->push(cmd.release());
+    }
 }
 
 void IPv6Dialog::DNSlookup()
@@ -258,6 +254,7 @@ void IPv6Dialog::DNSlookup()
         if (! addr.isEmpty())
         {
             m_dialog->address->setText( addr );
+            changed();
             return;
         }
 
@@ -280,6 +277,7 @@ void IPv6Dialog::DNSlookup()
             if ( ! addr.isEmpty())
             {
                 m_dialog->address->setText( addr );
+                changed();
                 return;
             }
             QMessageBox::warning(
@@ -297,11 +295,3 @@ void IPv6Dialog::DNSlookup()
         return;
     }
 }
-
-void IPv6Dialog::closeEvent(QCloseEvent *e)
-{
-    if (fwbdebug)
-        qDebug("IPv6Dialog::closeEvent  got close event: %p",e);
-    emit close_sign(e);
-}
-
