@@ -4,9 +4,9 @@
 
                  Copyright (C) 2010 NetCitadel, LLC
 
-  Author:  Roman Bovsunivkiy     a2k0001@gmail.com
+  Author:  Roman Bovsunivskiy     a2k0001@gmail.com
 
-  $Id: IconSetter.h 2567 2010-02-19 03:38:56Z vadim $
+  $Id: IconSetter.h 2707 2010-03-10 18:22:19Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
