@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Importer.cpp 2654 2010-03-04 05:32:41Z vadim $
+  $Id: Importer.cpp 3061 2010-07-10 19:36:10Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -221,18 +221,16 @@ Firewall* Importer::getFirewallObject()
     fw = Firewall::cast(nobj);
 
     fw->setStr("platform", platform);
+    Resources::setDefaultTargetOptions(platform , fw);
 
-    std::map<std::string,std::string> platforms = Resources::getPlatforms();
-    std::map<std::string,std::string>::iterator i;
-    for (i=platforms.begin(); i!=platforms.end(); i++)
-        Resources::setDefaultTargetOptions( i->first , fw );
+//     std::map<std::string,std::string> platforms = Resources::getPlatforms();
+//     std::map<std::string,std::string>::iterator i;
+//     for (i=platforms.begin(); i!=platforms.end(); i++)
+//         Resources::setDefaultTargetOptions( i->first , fw );
 
-    std::map<std::string,std::string> OSs = Resources::getOS();
-    for (i=OSs.begin(); i!=OSs.end(); i++)
-        Resources::setDefaultTargetOptions( i->first  , fw );
-
-    //o->setStr("platform", readPlatform(platform).latin1() );
-    //o->setStr("host_OS",  readHostOS(hostOS).latin1() );
+//     std::map<std::string,std::string> OSs = Resources::getOS();
+//     for (i=OSs.begin(); i!=OSs.end(); i++)
+//         Resources::setDefaultTargetOptions( i->first  , fw );
 
     return fw;
 }
@@ -372,6 +370,23 @@ void Importer::newUnidirRuleSet(const std::string &ruleset_name)
     *logger << "Ruleset: " << ruleset_name << "\n";
 }
 
+/*
+ * Grammar must ensure the call to setDefaultAction() happens
+ * after the call to newUnidirRuleSet()
+ * 
+ */
+void Importer::setDefaultAction(const std::string &iptables_action_name)
+{
+    string default_action_str = "Deny";
+    if (iptables_action_name == "ACCEPT")
+    {
+        current_ruleset->default_action = PolicyRule::Accept;
+        default_action_str = "Accept";
+    } else current_ruleset->default_action = PolicyRule::Deny;
+
+    *logger << "Default action: " << default_action_str << "\n";
+}
+
 
 void Importer::newPolicyRule()
 {
@@ -547,7 +562,12 @@ FWObject* Importer::getCustomService(const std::string &platform,
     s->setComment(cstr.str());
     all_objects[sstr.str()] = s;
 
-    *logger << "Custom Service object: " << nstr.str() << "\n";
+    *logger << "Custom Service object: " << nstr.str()
+            << ": "
+            << platform
+            << ": "
+            << code
+            << "\n";
     return s;
 }
 
@@ -711,10 +731,12 @@ FWObject* Importer::getUDPService(int srs, int sre, int drs, int dre)
          << srs << "-" << sre << ":" << drs << "-" << dre;
 
     std::ostringstream nstr;
-    nstr << "udp "
-         << srs << "-" << sre << ":" << drs << "-" << dre;
+    nstr << "udp " ;
+    if (srs!=0 || sre!=0)  nstr << srs << "-" << sre << ":";
+    if (drs!=0 || dre!=0)  nstr << drs << "-" << dre;
 
-    UDPService* s = UDPService::cast(createObject(UDPService::TYPENAME, nstr.str()));
+    UDPService* s = UDPService::cast(
+        createObject(UDPService::TYPENAME, nstr.str()));
     s->setSrcRangeStart(srs);
     s->setSrcRangeEnd(sre);
     s->setDstRangeStart(drs);
@@ -1019,9 +1041,7 @@ void Importer::markCurrentRuleBad(const std::string &comment)
     FWOptions  *ropt = current_rule->getOptionsObject();
     assert(ropt!=NULL);
 
-    QString color = getBadRuleColor().c_str();
-
-    ropt->setStr("color", color.toLatin1().constData());
+    ropt->setStr("color", getBadRuleColor());
 
     if (!rule_comment.empty()) rule_comment += "\n";
     rule_comment += comment;
