@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Importer.h 1039 2009-06-05 17:15:59Z vadim $
+  $Id: Importer.h 2973 2010-06-11 22:14:05Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -52,11 +52,13 @@ class Importer;
 class UnidirectionalRuleSet {
 
 public:
-    UnidirectionalRuleSet() {}
     libfwbuilder::RuleSet* ruleset;
     std::string name;
     // interface names and directions
     std::map<std::string,std::string> intf_dir;
+    libfwbuilder::PolicyRule::Action default_action;
+
+    UnidirectionalRuleSet() { default_action = libfwbuilder::PolicyRule::Deny; }
 };
 
 class ImporterException : public std::exception
@@ -85,7 +87,6 @@ protected:
     int  error_counter;
 
     libfwbuilder::FWObject *library;
-    libfwbuilder::Logger *logger;
 
     std::istringstream &input;
     
@@ -110,7 +111,7 @@ protected:
     std::map<const std::string, int> custom_service_codes;
 
     UnidirectionalRuleSet* current_ruleset;
-
+    
     libfwbuilder::Rule* current_rule;
 
     libfwbuilder::FWObject* createObject(const std::string &objType,
@@ -137,11 +138,11 @@ protected:
 
     // checks if ruleset "rsname" exists. Returns pointer if yes,
     // otherwise returns NULL
-    UnidirectionalRuleSet* checkUnidirRuleSet(const std::string &rsname);
+    virtual UnidirectionalRuleSet* checkUnidirRuleSet(const std::string &rsname);
 
     // finds and rturns pointer to ruleset "rsname". If it does not
     // exists, it is created
-    UnidirectionalRuleSet* getUnidirRuleSet(const std::string &rsname);
+    virtual UnidirectionalRuleSet* getUnidirRuleSet(const std::string &rsname);
     
     virtual libfwbuilder::FWObject* getCustomService(const std::string &platform,
                                                      const std::string &code,
@@ -193,6 +194,9 @@ protected:
     
 public:
 
+    // making logger public so I can access it from the code in the grammar
+    libfwbuilder::Logger *logger;
+    
     // temporary variables used by parser to store values
     // Importer converts these into a proper rule using method
     // pushRule()
@@ -269,6 +273,11 @@ public:
      */
     virtual void newUnidirRuleSet(const std::string &name);
 
+    /**
+     * Sets default action for the current rule set.
+     */
+    virtual void setDefaultAction(const std::string &iptables_action_name);
+
     /**
      * add interface and direction setting to a ruleset. Note that the
      * same ruleset may be associated with multiple interfaces and 
