@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: LibExportDialog.cpp 711 2008-12-25 20:48:19Z vadim $
+  $Id: LibExportDialog.cpp 1487 2009-09-23 17:00:48Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -31,6 +31,7 @@
 #include "LibExportDialog.h"
 #include "FWBSettings.h"
 #include "longTextDialog.h"
+#include "ProjectPanel.h"
 
 #include "fwbuilder/FWObject.h"
 #include "fwbuilder/FWObjectDatabase.h"
@@ -87,7 +88,7 @@ void LibExportDialog::init()
     m_dialog->exportRO->setChecked(true);
 
     m_dialog->libs->clear();
-    list<FWObject*> ll = mw->db()->getRoot()->getByType( Library::TYPENAME );
+    list<FWObject*> ll = mw->activeProject()->db()->getByType(Library::TYPENAME);
     int n=0;
     string libicn;
 
