@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectManipulator.cpp 2657 2010-03-04 20:02:54Z vadim $
+  $Id: ObjectManipulator.cpp 3046 2010-06-30 16:43:43Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -712,6 +712,7 @@ void ObjectManipulator::contextMenuRequested(const QPoint &pos)
         popup_menu->addSeparator();
         popup_menu->addAction( tr("Compile"), this, SLOT( compile()));
         popup_menu->addAction( tr("Install"), this, SLOT( install()));
+        popup_menu->addAction( tr("Inspect"), this, SLOT( inspect()));
 
         if (Firewall::cast(currentObj)!=NULL)
         {
@@ -852,7 +853,7 @@ void ObjectManipulator::getMenuState(bool haveMoveTargets,
             FWBTree().getPasteMenuState(object_path) &&
             (FWObjectClipboard::obj_clipboard->size()!=0);
         delMenuItem = delMenuItem && getDeleteMenuState(obj);
-        delMenuItem = delMenuItem &&
+        delMenuItem = delMenuItem && current_library != NULL &&
             current_library->getId() != FWObjectDatabase::STANDARD_LIB_ID;
 
 #if DISABLE_PASTE_MENU_ITEM_IF_PASTE_IS_ILLEGAL
@@ -1022,12 +1023,33 @@ void ObjectManipulator::editSelectedObject()
     FWObject *obj = getCurrentObjectTree()->getSelectedObjects().front();
     if (obj==NULL) return;
 
-    if (RuleSet::cast(obj)!=NULL && m_project->getCurrentRuleSet()!=obj)
-        QCoreApplication::postEvent(
-            m_project, new openRulesetEvent(m_project->getFileName(), obj->getId()));
+    if (RuleSet::cast(obj)!=NULL)
+    {
+        // Open rule set object in the editor if it is already opened
+        // in RuleSetView. If we just opened it in RuleSetView, check
+        // if the editor is visible and if yes, open the object in the
+        // editor right away. See #1331
 
-    QCoreApplication::postEvent(
-        mw, new openObjectInEditorEvent(m_project->getFileName(), obj->getId()));
+        if (m_project->getCurrentRuleSet() == obj)
+        {
+            QCoreApplication::postEvent(
+                mw, new openObjectInEditorEvent(
+                    m_project->getFileName(), obj->getId()));
+        } else
+        {
+            QCoreApplication::postEvent(
+                m_project, new openRulesetEvent(
+                    m_project->getFileName(), obj->getId()));
+            if (mw->isEditorVisible())
+                QCoreApplication::postEvent(
+                    mw, new openObjectInEditorEvent(
+                        m_project->getFileName(), obj->getId()));
+        }
+
+    } else
+        QCoreApplication::postEvent(
+            mw, new openObjectInEditorEvent(
+                m_project->getFileName(), obj->getId()));
 }
 
 void ObjectManipulator::openSelectedRuleSet()
