@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectTreeView.cpp 986 2009-05-31 21:22:59Z vadim $
+  $Id: ObjectTreeView.cpp 2639 2010-03-01 04:39:27Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,18 +28,21 @@
 #include "global.h"
 #include "utils.h"
 
+#include "FWWindow.h"
 #include "FWBTree.h"
 #include "ObjectTreeView.h"
 #include "ObjectTreeViewItem.h"
 #include "ObjectManipulator.h"
 #include "FWObjectDrag.h"
 #include "FWBSettings.h"
-
+#include "IconSetter.h"
 #include "FWObjectPropertiesFactory.h"
+
 #include "fwbuilder/FWObject.h"
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Resources.h"
 #include "fwbuilder/Group.h"
+#include "fwbuilder/Interface.h"
 
 #include <QAbstractItemView>
 #include <QHeaderView>
@@ -55,6 +58,7 @@
 #include <QMouseEvent>
 #include <QKeyEvent>
 #include <QDragEnterEvent>
+#include <QtDebug>
 
 #include <iostream>
 #include <algorithm>
@@ -63,11 +67,6 @@
 using namespace std;
 using namespace libfwbuilder;
 
-ObjectTreeView* ObjectTreeViewItem::getTree()
-{
-    return dynamic_cast<ObjectTreeView*>(treeWidget());
-}
-
 /****************************************************************************
  *
  *    class ObjectTreeView
@@ -83,7 +82,7 @@ ObjectTreeView::ObjectTreeView(ProjectPanel* project,
 {
     setObjectName(name);
     this->setParent(parent, f);
-    setFont (st->getTreeFont());
+    setFont(st->getTreeFont());
 //    setAcceptDrops( TRUE );
     item_before_drag_started=NULL;
     lastSelected = NULL;
@@ -123,13 +122,17 @@ ObjectTreeView::ObjectTreeView(ProjectPanel* project,
     connect(this, SIGNAL(itemExpanded(QTreeWidgetItem*)),
             this, SLOT(itemExpanded(QTreeWidgetItem*)));
 
-    setColumnCount(1);
-
     QStringList qsl;
     qsl.push_back(tr("Object"));
+    qsl.push_back(tr("Attributes"));
     setHeaderLabels(qsl);
 
-    header()->hide();
+    //header()->hide();
+
+    header()->setDefaultAlignment(Qt::AlignHCenter);
+    header()->setResizeMode(QHeaderView::Interactive);
+
+    showOrHideAttributesColumn();
 
     setMinimumSize( QSize( 100, 0 ) );
 
@@ -140,6 +143,9 @@ ObjectTreeView::ObjectTreeView(ProjectPanel* project,
     setDragDropMode( QAbstractItemView::DragDrop );
     setRootIsDecorated( TRUE );
 
+    connect(this, SIGNAL(itemChanged(QTreeWidgetItem*,int)), this,
+            SLOT(updateFilter()));
+
 // disable sorting, otherwise gui crashes when built with
 // QT 4.3.4 (discovered on Ubuntu Hardy). Crash happened when
 // second object was added to any branch of the tree.
@@ -192,15 +198,9 @@ bool ObjectTreeView::event( QEvent *event )
     return QTreeWidget::event(event);
 }
 
-
-void ObjectTreeView::currentItemChanged(QTreeWidgetItem *cur)
+void ObjectTreeView::currentItemChanged(QTreeWidgetItem*)
 {
-    if (fwbdebug) qDebug("ObjectTreeView::currentChanged  itm=%s",
-                         cur->text(0).toAscii().constData());
     expandOrCollapse = false;
-
-//    lastSelected = ovi;
-//    lastSelected = currentItem();
 }
 
 void ObjectTreeView::itemCollapsed(QTreeWidgetItem* itm)
@@ -214,7 +214,6 @@ void ObjectTreeView::itemCollapsed(QTreeWidgetItem* itm)
     {
         int id = o->getId();
         expanded_objects.erase(id);
-        if (fwbdebug) qDebug("Tree item for object id=%d collapsed", id);
     }
 }
 
@@ -229,7 +228,6 @@ void ObjectTreeView::itemExpanded(QTreeWidgetItem* itm)
     {
         int id = o->getId();
         expanded_objects.insert(id);
-        if (fwbdebug) qDebug("Tree item for object id=%d expanded", id);
     }
 }
 
@@ -261,20 +259,10 @@ FWObject* ObjectTreeView::getCurrentObject()
 {
     QTreeWidgetItem *ovi = currentItem();
     ObjectTreeViewItem *otvi=dynamic_cast<ObjectTreeViewItem*>(ovi);
-    assert(otvi!=NULL);
+    if (otvi==NULL) return NULL;
     return otvi->getFWObject();
 }
 
-bool ObjectTreeView::isLockable()
-{
-    return Lockable;
-}
-
-bool ObjectTreeView::isUnlockable()
-{
-    return Unlockable;
-}
-
 void ObjectTreeView::focusInEvent(QFocusEvent* ev)
 {
     QTreeWidget::focusInEvent(ev);
@@ -289,56 +277,24 @@ void ObjectTreeView::focusOutEvent(QFocusEvent* ev)
     if (ci) repaint();
 }
 
-void ObjectTreeView::updateTreeItems()
+void ObjectTreeView::updateTreeIcons()
 {
-    if (fwbdebug) qDebug("ObjectTreeView::updateTreeItems 1");
+    if (fwbdebug) qDebug("ObjectTreeView::updateTreeIcons ");
+
     QTreeWidgetItemIterator it(this);
-    QTreeWidgetItem *itm;
-    ObjectTreeViewItem *otvi;
-    FWObject *obj;
-    QString icn;
-
-    QPixmap pm_lock;
-    if ( ! QPixmapCache::find( ":/Icons/lock.png", pm_lock) )
-    {
-        pm_lock.load( ":/Icons/lock.png" );
-        QPixmapCache::insert( ":/Icons/lock.png", pm_lock);
-    }
-
     while ( *it )
     {
-        itm= *it;
-        otvi=dynamic_cast<ObjectTreeViewItem*>(itm);
-        obj=otvi->getFWObject();
-
-        if (m_project->isSystem(obj))
-            icn=":/Icons/folder1.png";
-        else
-            icn=(":/Icons/"+obj->getTypeName()+"/icon-tree").c_str();
+        QTreeWidgetItem *itm = *it;
+        ObjectTreeViewItem *otvi = dynamic_cast<ObjectTreeViewItem*>(itm);
+        FWObject *obj = otvi->getFWObject();
 
         QPixmap pm_obj;
-        if ( ! QPixmapCache::find( icn, pm_obj) )
-        {
-            pm_obj.load( icn );
-            QPixmapCache::insert( icn, pm_obj);
-        }
-
-        if (obj->getRO())  itm->setIcon(0, pm_lock);//setPixmap(0, pm_lock );
-        else               itm->setIcon(0, pm_obj );
-
-        Firewall *fw=Firewall::cast(obj);
-        if (fw!=NULL)
-        {
-            itm->setText(0,(fw->needsInstall())?
-                    QString::fromUtf8(fw->getName().c_str())+" *":
-                    QString::fromUtf8(fw->getName().c_str()));
-        }
+        IconSetter::setObjectIcon(obj, &pm_obj, 0);
+        itm->setIcon(0, pm_obj );
 
         ++it;
     }
-
-    update(); //for replacement as previous string
-    if (fwbdebug) qDebug("ObjectTreeView::updateTreeItems 2");
+    update();
 }
 
 void ObjectTreeView::startDrag(Qt::DropActions supportedActions)
@@ -362,7 +318,7 @@ void ObjectTreeView::startDrag(Qt::DropActions supportedActions)
     the end of void QListView::mouseMoveEvent( QMouseEvent * e)
     (See code after they decided that they do not need to call startDrag())
 
-    if (m_project->isSystem(obj)) return NULL;
+    if (FWBTree().isSystem(obj)) return NULL;
 */
     QString icn = (":/Icons/"+current_obj->getTypeName()+"/icon-ref").c_str();
 
@@ -377,6 +333,14 @@ void ObjectTreeView::startDrag(Qt::DropActions supportedActions)
             qDebug("ObjectTreeView::startDrag: adding object to drag list: %s",
                    (*v)->getName().c_str());
 
+        // while obj is still part of the tree, do some clean up
+        // to avoid problems in the future.  Create
+        // InterfaceOptions objects for interfaces because we'll
+        // need them for various validations during paste/drop
+        // operation.
+        Interface *intf = Interface::cast(*v);
+        if (intf) intf->getOptionsObject();
+
         dragobj.push_back( *v );
     }
     FWObjectDrag *drag = new FWObjectDrag(dragobj, this);
@@ -439,9 +403,9 @@ void ObjectTreeView::startDrag(Qt::DropActions supportedActions)
     if (fwbdebug) qDebug("ObjectTreeView::dragObject()  this=%p visible=%d",
                          this,visible);
 
-    FWObject *edit_obj = m_project->getOpenedEditor();
+    FWObject *edit_obj = mw->getOpenedEditor();
 
-    if (m_project->isEditorVisible() &&
+    if (mw->isEditorVisible() &&
         dragobj.size()==1 &&
         edit_obj!=NULL &&
         current_obj->getLibrary()==edit_obj->getLibrary() )
@@ -451,20 +415,6 @@ void ObjectTreeView::startDrag(Qt::DropActions supportedActions)
         resetSelection();
     }
 
-#if 0
-    /*
-     * need to reset selection if:
-     *
-     * object editor is opened, and
-     * we are dragging one object, and
-     * object opened in editor is not the same as the one we are dragging
-     */
-    if (m_project->isEditorVisible() && dragobj.size()==1 && m_project->getOpenedEditor()!=obj)
-    {
-        setSelected(otvi,false);
-        resetSelection();
-    }
-#endif
     if (fwbdebug) qDebug("ObjectTreeView::dragObject()  returns !NULL");
 
     drag->start(supportedActions);
@@ -514,7 +464,7 @@ void ObjectTreeView::dragMoveEvent( QDragMoveEvent *ev)
         FWObject *dragobj = *i;
         assert(dragobj!=NULL);
 
-        if (m_project->isSystem(dragobj))
+        if (FWBTree().isSystem(dragobj))
         {
 // can not drop system folder anywhere 
             ev->setAccepted(false);
@@ -525,54 +475,13 @@ void ObjectTreeView::dragMoveEvent( QDragMoveEvent *ev)
     ev->setAccepted(true);
 }
 
+/*
+ * See ticket #483: d&d of objects inside the tree should not be allowed
+ */
 void ObjectTreeView::dropEvent(QDropEvent *ev)
 {
-    if (fwbdebug) qDebug("ObjectTreeView::dropEvent");
-    QWidget *fromWidget = ev->source();
-
-    // The source of DnD object must be the same instance of fwbuilder
-    if (!fromWidget)
-    {
-        ev->setAccepted(false);
-        return;
-    }
-   
-    list<FWObject*> dragol;
-    if (FWObjectDrag::decode(ev, dragol))
-    {
-        for (list<FWObject*>::iterator i=dragol.begin(); i!=dragol.end(); ++i)
-        {
-            FWObject *dragobj = *i;
-            assert(dragobj);
-
-            ObjectTreeView * otvsource =
-                dynamic_cast<ObjectTreeView *>(ev->source());
-            if (otvsource!=NULL)
-            {
-                FWObjectDatabase* root =
-                    otvsource->getCurrentObject()->getRoot();
-
-                int id = dragobj->getId();
-                FWObject * item = root->getById(id, true);
-                if (fwbdebug)
-                {
-                    qDebug("%d", item->getId());
-                    qDebug(item->getTypeName().c_str());
-                    qDebug("%d", dragobj->getId());
-                    qDebug(dragobj->getTypeName().c_str());
-                }
-                //ProjectPanel * ppsource =  otvsource->m_project ;
-            }
-
-            FWObject *target = getDropTarget(ev, dragobj);
-            if (fwbdebug)
-                qDebug("ObjectTreeView::dropEvent  paste %s -> %s",
-                       dragobj->getName().c_str(), target->getName().c_str());
-
-            m_project->pasteTo(target, dragobj);
-        }
-    }
-    if (fwbdebug) qDebug("ObjectTreeView::dropEvent done");
+    ev->setAccepted(false);
+    return;
 }
 
 FWObject *ObjectTreeView::getDropTarget(QDropEvent *ev, FWObject*)
@@ -580,7 +489,8 @@ FWObject *ObjectTreeView::getDropTarget(QDropEvent *ev, FWObject*)
     QTreeWidgetItem *ovi = itemAt(ev->pos());
 
     ObjectTreeViewItem *otvi = dynamic_cast<ObjectTreeViewItem*>(ovi);
-    return otvi->getFWObject();
+    if (otvi) return otvi->getFWObject();
+    else return NULL;
 }
 
 void ObjectTreeView::dragLeaveEvent( QDragLeaveEvent *ev)
@@ -605,12 +515,10 @@ void ObjectTreeView::mousePressEvent( QMouseEvent *e )
 
     if (fwbdebug)
     {
-        qDebug(QString("ObjectTreeView::mousePressEvent :: currentItem=%1")
-               .arg((currentItem())?currentItem()->text(0):"nil").toAscii().constData()
-        );
-        qDebug(QString("ObjectTreeView::mousePressEvent :: lastSelected=%2")
-                .arg((lastSelected)?lastSelected->text(0):"nil").toAscii().constData()
-        );
+        qDebug() << "ObjectTreeView::mousePressEvent :: currentItem="
+                 << ((currentItem())?currentItem()->text(0):"nil");
+        qDebug() << "ObjectTreeView::mousePressEvent :: lastSelected="
+                 << ((lastSelected)?lastSelected->text(0):"nil");
     }
 
     lastSelected = currentItem();
@@ -678,6 +586,9 @@ void ObjectTreeView::mouseReleaseEvent( QMouseEvent *e )
     if (expandOrCollapse) return;  // user expanded or collapsed subtree,
                                    // no need to change object in the editor
 
+// Experiment: single click on the object in the tree should not open
+// it in the editor
+#if 0
     if (selectedObjects.size()==1)
         emit switchObjectInEditor_sign( getCurrentObject() );
     else
@@ -685,11 +596,12 @@ void ObjectTreeView::mouseReleaseEvent( QMouseEvent *e )
         // user selected multiple objects
         // do not let them if editor has unsaved changes
         //
-        if (m_project->isEditorVisible() && m_project->isEditorModified())
+        if (mw->isEditorVisible() && mw->isEditorModified())
             emit switchObjectInEditor_sign( getCurrentObject() );
         else
-            m_project->blankEditor();
+            mw->blankEditor();
     }
+#endif
 }
 
 /*
@@ -725,56 +637,29 @@ void ObjectTreeView::editCurrentObject()
 void ObjectTreeView::keyPressEvent( QKeyEvent* ev )
 {
     FWObject *obj = getCurrentObject();
-
-    if (ev->key()==Qt::Key_Enter || ev->key()==Qt::Key_Return)
+    if (obj)
     {
-        editCurrentObject();
-        ev->accept();
-        return;
-    }
-    if (ev->key()==Qt::Key_Delete)
-    {
-        emit deleteObject_sign(obj);
-        ev->accept();
-        return;
+        if (ev->key()==Qt::Key_Enter || ev->key()==Qt::Key_Return)
+        {
+            editCurrentObject();
+            ev->accept();
+            return;
+        }
+        if (ev->key()==Qt::Key_Delete)
+        {
+            emit deleteObject_sign(obj);
+            ev->accept();
+            return;
+        }
     }
     QTreeWidget::keyPressEvent(ev);
 }
 
 void ObjectTreeView::keyReleaseEvent( QKeyEvent* ev )
 {
-    if (fwbdebug)
-        qDebug("ObjectTreeView::keyReleaseEvent");
-
     QTreeWidget::keyReleaseEvent(ev);
-
-    if (selectedObjects.size()==1)
-        emit switchObjectInEditor_sign( getCurrentObject() );
-    else
-    {
-        // user selected multiple objects
-        // do not let them if editor has unsaved changes
-        //
-        if (m_project->isEditorVisible() && m_project->isEditorModified())
-            emit switchObjectInEditor_sign( getCurrentObject() );
-        else
-            m_project->blankEditor();
-    }
 }
 
-/*void ObjectTreeView::keyPressEvent(QKeyEvent *ke)
-{
-    if (ke->key() == Qt::Key_Enter)
-    {
-        if (fwbdebug)
-            qDebug("ObjectTreeView::keyPressed");
-
-        editCurrentObject();
-    }
-
-    QTreeWidget::returnPressed(ke);
-}*/
-
 void ObjectTreeView::itemOpened ()
 {
     if (fwbdebug) qDebug("ObjectTreeView::itemOpened");
@@ -789,11 +674,15 @@ void ObjectTreeView::clearLastSelected()
 
 void ObjectTreeView::resetSelection()
 {
-    if (fwbdebug)
-        qDebug(QString("ObjectTreeView::resetSelection :: lastSelected=%1").arg(lastSelected->text(0)).toAscii().constData());
+    if (lastSelected)
+    {
+        if (fwbdebug)
+            qDebug() << "ObjectTreeView::resetSelection :: lastSelected="
+                     << lastSelected->text(0);
 
-    setCurrentItem(lastSelected);
-    lastSelected->setSelected(true);
+        setCurrentItem(lastSelected);
+        lastSelected->setSelected(true);
+    }
 }
 
 void ObjectTreeView::itemSelectionChanged()
@@ -810,56 +699,23 @@ void ObjectTreeView::itemSelectionChanged()
 
     QList<QTreeWidgetItem*> selected = selectedItems();
     QList<QTreeWidgetItem*>::Iterator it;
-//    QTreeWidgetItemIterator it(this);
-//    while ( *it )
     for (it=selected.begin(); it!=selected.end(); it++)
     {
-//        if ((*it)->isSelected())
-//        {
-            QTreeWidgetItem *itm = (*it);
-            ObjectTreeViewItem *otvi = dynamic_cast<ObjectTreeViewItem*>(itm);
+        QTreeWidgetItem *itm = (*it);
+        ObjectTreeViewItem *otvi = dynamic_cast<ObjectTreeViewItem*>(itm);
 
-            selectedObjects.push_back(otvi->getFWObject());
+        selectedObjects.push_back(otvi->getFWObject());
 
-            if (fwbdebug) qDebug(
-                "ObjectTreeView::selectionChanged: selected otvi=%p object %s",
-                otvi, otvi->getFWObject()->getName().c_str());
-//        }
-//        ++it;
+        if (fwbdebug) qDebug(
+            "ObjectTreeView::selectionChanged: selected otvi=%p object %s",
+            otvi, otvi->getFWObject()->getName().c_str());
     }
-    setLockFlags();
 
     if (fwbdebug)
         qDebug("ObjectTreeView::itemSelectionChanged completed");
 /* now list  selectedObjects   holds all selected items */
 }
 
-void ObjectTreeView::setLockFlags()
-{
-    QTreeWidgetItemIterator it(this);
-    Lockable=false;
-    Unlockable=false;
-    while ( *it )
-    {
-        if ((*it)->isSelected())
-        {
-            QTreeWidgetItem *itm = *it;
-            ObjectTreeViewItem *otvi=dynamic_cast<ObjectTreeViewItem*>(itm);
-
-            FWObject *lib = otvi->getFWObject()->getLibrary();
-            // these lbraries are locked anyway, do not let the user
-            // lock objects inside because they won't be able to unlock them.
-            if (lib->getId()!=FWObjectDatabase::STANDARD_LIB_ID &&
-                lib->getId()!=FWObjectDatabase::TEMPLATE_LIB_ID)
-            {
-                if (otvi->getFWObject()->getRO())  Unlockable = true;
-                else                               Lockable = true;
-            }
-        }
-        ++it;
-    }
-}
-
 bool ObjectTreeView::isSelected(FWObject* obj)
 {
     for (vector<FWObject*>::iterator i=selectedObjects.begin();
@@ -894,3 +750,63 @@ void ObjectTreeView::ExpandTreeItems(const set<int> &ids)
     }
 }
 
+void ObjectTreeView::showOrHideAttributesColumn()
+{
+    if (st->getBool("UI/ShowObjectsAttributesInTree"))
+        setColumnCount(2);
+    else
+        setColumnCount(1);
+}
+
+QSet<QTreeWidgetItem*> ObjectTreeView::resolveChildren(QTreeWidgetItem *parent)
+{
+    QSet<QTreeWidgetItem*> children;
+    children.insert(parent);
+    if (parent->childCount() == 0) return children;
+    for (int i=0; i<parent->childCount(); i++)
+        children.unite(resolveChildren(parent->child(i)));
+    return children;
+}
+
+QSet<QTreeWidgetItem*> ObjectTreeView::resolveParents(QTreeWidgetItem *child)
+{
+    QSet<QTreeWidgetItem*> parents;
+    parents.insert(child);
+    if (child->parent() == NULL) return parents;
+    parents.unite(resolveParents(child->parent()));
+    return parents;
+}
+
+void ObjectTreeView::updateFilter()
+{
+    if (filter.isEmpty()) return;
+    setFilter(filter);
+}
+
+void ObjectTreeView::setFilter(QString text)
+{
+    if (fwbdebug)
+        qDebug() << "ObjectTreeView::setFilter " << text;
+
+    if (filter.isEmpty() && text.isEmpty()) return;
+    filter = text;
+    QSet<QTreeWidgetItem *> items = this->findItems(text, Qt::MatchContains|Qt::MatchRecursive, 0).toSet();
+    QSet<QTreeWidgetItem *> children, parents;
+    QSet<QTreeWidgetItem *>::iterator iter;
+    for(iter=items.begin(); iter!=items.end(); iter++)
+    {
+        children.unite(resolveChildren((*iter)));
+        parents.unite(resolveParents((*iter)));
+    }
+    items.unite(children);
+    items.unite(parents);
+    QTreeWidgetItemIterator witer(this);
+    while (*witer)
+    {
+        if (items.contains((*witer))) (*witer)->setHidden(false);
+        else (*witer)->setHidden(true);
+        witer++;
+    }
+    if (!text.isEmpty()) this->expandAll();
+}
+
