@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectTreeView.h 521 2008-09-10 06:15:27Z vadim $
+  $Id: ObjectTreeView.h 2566 2010-02-19 03:06:25Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -72,6 +72,12 @@ class ObjectTreeView : public QTreeWidget {
     libfwbuilder::FWObject *getDropTarget(
         QDropEvent *ev, libfwbuilder::FWObject* dragobj);
 
+    QSet<QTreeWidgetItem*> resolveChildren(QTreeWidgetItem*);
+
+    QSet<QTreeWidgetItem*> resolveParents(QTreeWidgetItem*);
+
+    QString filter;
+
 protected:
 
     bool event( QEvent *event );
@@ -111,9 +117,6 @@ protected:
 
     bool isSelected(libfwbuilder::FWObject* obj);
     int  getNumSelected();
-    bool isLockable();
-    bool isUnlockable();
-    void setLockFlags();
 
     libfwbuilder::FWObject* getCurrentObject();
 
@@ -140,6 +143,8 @@ protected:
     void ExpandTreeItems(const std::set<int> &ids);
     const std::set<int>& getListOfExpandedObjectIds() { return expanded_objects; }
 
+    void showOrHideAttributesColumn();
+
  public slots:
 
     void itemSelectionChanged();
@@ -148,7 +153,9 @@ protected:
     void itemCollapsed(QTreeWidgetItem *itm);
     void itemExpanded(QTreeWidgetItem *itm);
     void itemOpened ();
-    virtual void updateTreeItems();
+    virtual void updateTreeIcons();
+    void setFilter(QString);
+    void updateFilter();
 
  signals:
 
