@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectTreeViewItem.cpp 2568 2010-02-19 04:05:40Z vadim $
+  $Id: ObjectTreeViewItem.cpp 2804 2010-04-09 16:53:27Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -66,7 +66,7 @@ QVariant ObjectTreeViewItem::data(int column, int role) const
 
         if (o!=NULL)
         {
-            bool mf = !o->getInactive() && (o->needsInstall()) ;
+            bool mf = !o->getInactive() && (o->needsCompile()) ;
             usual.setBold (mf);
             usual.setStrikeOut(o->getInactive());
             return QVariant(usual);
