@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: PrefsDialog.cpp 2466 2010-01-30 23:55:51Z yalovoy $
+  $Id: PrefsDialog.cpp 3064 2010-07-12 02:31:41Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -38,6 +38,7 @@
 #include "ProjectPanel.h"
 #include "HttpGet.h"
 #include "RuleSetView.h"
+#include "UserWorkflow.h"
 
 #include "fwbuilder/Resources.h"
 
@@ -131,6 +132,7 @@ PrefsDialog::PrefsDialog(QWidget *parent) : QDialog(parent)
     m_dialog->new_addr_tbl_run_tm->setChecked(
         ! st->getBool("Objects/AddressTable/useCompileTimeForNewObjects"));
 
+    m_dialog->toolbarIconsText->setChecked(st->getIconsWithText());
 
     m_dialog->emptyRCSLog->setChecked( st->getRCSLogState() );
 
@@ -143,6 +145,8 @@ PrefsDialog::PrefsDialog(QWidget *parent) : QDialog(parent)
 
     m_dialog->sshPath->setText( st->getSSHPath() );
     m_dialog->scpPath->setText( st->getSCPPath() );
+    m_dialog->sshTimeout->setValue( st->getSSHTimeout() );
+
     m_dialog->rememberSshPass->setChecked( st->getBool("Environment/RememberSshPassEnabled") );
 
     m_dialog->showTips->setChecked( st->getBool("UI/NoStartTip") );
@@ -410,6 +414,8 @@ void PrefsDialog::accept()
     st->setBool("UI/ShowDeletedObjects", m_dialog->deletedObj->isChecked());
     st->setBool("UI/ShowObjectsAttributesInTree", m_dialog->attributesInTree->isChecked());
 
+    st->setIconsWithText(m_dialog->toolbarIconsText->isChecked());
+
     ProjectPanel *pp = mw->activeProject();
     if (pp)
     {
@@ -466,13 +472,49 @@ void PrefsDialog::accept()
     st->setCompilerOutputFont(compilerOutputFont);
 
     st->setClipComment(m_dialog->chClipComment->isChecked());
-    st->setCheckUpdates(m_dialog->checkUpdates->isChecked());
+
     st->setCheckUpdatesProxy(m_dialog->checkUpdatesProxy->text());
 
+    wfl->registerFlag(UserWorkflow::USING_HTTP_PROXY,
+                      !st->getCheckUpdatesProxy().isEmpty());
+
+    // annoyingly, widget shotTip has the name opposite to its meaning.
+    // When it is checked, we do not show tip of the day.
+
+    wfl->registerFlag(UserWorkflow::TIP_OF_THE_DAY_DISABLED,
+                      m_dialog->showTips->isChecked());
+    st->setBool("UI/NoStartTip", m_dialog->showTips->isChecked());
+
     st->setSSHPath( m_dialog->sshPath->text() );
     st->setSCPPath( m_dialog->scpPath->text() );
+    st->setSSHTimeout(m_dialog->sshTimeout->value());
+
     st->setBool("Environment/RememberSshPassEnabled", m_dialog->rememberSshPass->isChecked());
     
+    wfl->registerFlag(UserWorkflow::SSH_CONFIGURED, 
+                      !m_dialog->sshPath->text().isEmpty() &&
+                      !m_dialog->scpPath->text().isEmpty());
+
+
+    if (m_dialog->checkUpdates->isChecked())
+    {
+        wfl->registerFlag(UserWorkflow::UPDATE_CHECKS_DISABLED, false);
+    } else
+    {
+        wfl->registerFlag(UserWorkflow::UPDATE_CHECKS_DISABLED, true);
+
+        if (st->getCheckUpdates())
+        {
+            // update checking was enabled but the user disabled it in
+            // this preferences dialog session. Run last closing
+            // report before disabling both update check and closing
+            // report.
+            wfl->report();
+        }
+    }
+
+    st->setCheckUpdates(m_dialog->checkUpdates->isChecked());
+
     for (int row=0; row < m_dialog->enabled_platforms->rowCount(); ++row)
     {
         QTableWidgetItem *itm = m_dialog->enabled_platforms->item(row, 0);
@@ -506,8 +548,10 @@ void PrefsDialog::accept()
     mw->setupAutoSave();
     mw->showDeletedObjects(st->getBool("UI/ShowDeletedObjects"));
     mw->updateTreeFont();
+    mw->setupGlobalToolbar();
 //    app->setFont(st->getTreeFont());
-    st->setBool("UI/NoStartTip", m_dialog->showTips->isChecked());
+
+
     QDialog::accept();
 }
 
