@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: PrintingController.cpp 1151 2009-07-12 19:52:11Z vadim $
+  $Id: PrintingController.cpp 1487 2009-09-23 17:00:48Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -70,6 +70,7 @@
 
 #include <qstring.h>
 #include <QPixmapCache>
+#include <QHeaderView>
 
 using namespace libfwbuilder;
 using namespace std;
@@ -145,7 +146,7 @@ list<FWObject*> PrintingController::findAllUsedByType(list<FWObject*> &result,
         }
     }
 
-    if (Firewall::isA(obj))
+    if (Firewall::cast(obj))  // cast matches Firewall and Cluster
     {
         FWObject *ruleSet;
         const char* const child_types[] =
@@ -286,7 +287,7 @@ void PrintingController::printRuleSet(FWObject *fw,
         pr->printText("\n");
         pr->printText(name);
 
-        RuleSetView *ruleView = RuleSetViewFactory::getRuleSetViewByType(
+        RuleSetView *ruleView = RuleSetView::getRuleSetViewByType(
             project, ruleset, NULL);
         ruleView->setSizePolicy( QSizePolicy( (QSizePolicy::Policy)7,
                                               (QSizePolicy::Policy)7) );
@@ -303,7 +304,7 @@ void PrintingController::printRuleSet(FWObject *fw,
 
         if (fwbdebug) qDebug("Size: %dx%d",ruleView->width(),ruleView->height());
 
-        pr->printQTable(ruleView);
+        pr->printRuleSetView(ruleView);
 
         delete ruleView;
     }
