@@ -7,7 +7,7 @@
   Author:  alek@codeminders.com
            refactoring and bugfixes: vadim@fwbuilder.org
 
-  $Id: ProjectPanel.cpp 2588 2010-02-19 19:29:04Z vadim $
+  $Id: ProjectPanel.cpp 3051 2010-07-05 15:25:16Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -39,6 +39,7 @@
 #include "fwbuilder/RuleElement.h"
 
 #include "FWBSettings.h"
+#include "UserWorkflow.h"
 #include "FWBTree.h"
 #include "FWObjectPropertiesFactory.h"
 #include "FWWindow.h"
@@ -49,6 +50,8 @@
 #include "events.h"
 #include "ObjectTreeView.h"
 #include "FWObjectClipboard.h"
+#include "WorkflowIcons.h"
+#include "FirewallCodeViewer.h"
 
 #include <QtDebug>
 #include <QMdiSubWindow>
@@ -60,6 +63,7 @@
 #include <QUndoStack>
 #include <QUndoGroup>
 #include <QScrollBar>
+#include <QMessageBox>
 
 #include <iostream>
 
@@ -110,6 +114,8 @@ void ProjectPanel::initMain(FWWindow *main)
 
     fd  = new findDialog(this, this);
     fd->hide();
+
+    m_panel->icons->setUpSignals(this);
 }
 
 void ProjectPanel::reset()
@@ -150,6 +156,8 @@ ProjectPanel::ProjectPanel(QWidget *parent):
     m_panel->setupUi(this);
     m_panel->om->setupProject(this);
 
+    m_panel->toolbar->hide();
+
     undoStack = new QUndoStack(this);
 
     setWindowTitle(getPageTitle());
@@ -208,7 +216,7 @@ void ProjectPanel::restoreRuleSetTab()
 {
     if (fwbdebug) qDebug("ProjectPanel::()");
     m_panel->ruleSets->setCurrentIndex(ruleSetTabIndex);
-
+    m_panel->toolbar->show();
 }
 
 void ProjectPanel::loadObjects()
@@ -337,11 +345,13 @@ void ProjectPanel::reopenFirewall()
                    db()->isDirty(), ctime(&last_modified));
 
         m_panel->ruleSets->setCurrentIndex(currentPage);
+        m_panel->toolbar->show();
         rv = dynamic_cast<RuleSetView*>(m_panel->ruleSets->currentWidget());
         rv->restoreCurrentRowColumn(memento);
 
         changingTabs = false;
-        mainW->setEnabledAfterRF();
+
+        mainW->updateGlobalToolbar();
 
         m_panel->ruleSets->setUpdatesEnabled(true);
         m_panel->ruleSets->show();
@@ -721,9 +731,22 @@ RCS * ProjectPanel::getRCS()
     return rcs;
 }
 
+/*
+ * This slot is connected to the "add rule" button in the mini-toolbar
+ * at the top of the rule set view
+ */
+void ProjectPanel::addRule()
+{
+    if (visibleRuleSet==NULL) return ;
+    getCurrentRuleSetView()->insertRule();
+}
+
 void ProjectPanel::compileThis()
 {
     if (visibleRuleSet==NULL) return ;
+
+    wfl->registerFlag(UserWorkflow::COMPILE, true);
+
     set<Firewall*> fw;
     Firewall *f = Firewall::cast(visibleRuleSet->getParent());
     if (f)
@@ -736,6 +759,9 @@ void ProjectPanel::compileThis()
 void ProjectPanel::installThis()
 {
     if (visibleRuleSet==NULL) return ;
+
+    wfl->registerFlag(UserWorkflow::INSTALL, true);
+
     set<Firewall*> fw;
     Firewall *f = Firewall::cast(visibleRuleSet->getParent());
     if (f)
@@ -745,6 +771,160 @@ void ProjectPanel::installThis()
     }
 }
 
+void ProjectPanel::inspectThis()
+{
+    if (visibleRuleSet==NULL) return;
+    Firewall *f = Firewall::cast(visibleRuleSet->getParent());
+    set<Firewall*> fwlist;
+    if (Cluster::isA(f))
+    {
+        std::list<Firewall*> cfws;
+        Cluster::cast(f)->getMembersList(cfws);
+        foreach(Firewall *fw, cfws)
+            fwlist.insert(fw);
+    }
+    else
+    {
+        fwlist.insert(f);
+    }
+
+    this->inspect(fwlist);
+}
+
+void ProjectPanel::inspectAll()
+{
+    ObjectManipulator *om = this->findChild<ObjectManipulator*>();
+    list<Firewall*> fws;
+    om->findAllFirewalls(fws);
+    set<Firewall*> fwset;
+    foreach(Firewall *fw, fws)
+    {
+        if (Cluster::isA(fw))
+        {
+            std::list<Firewall*> cfws;
+            Cluster::cast(fw)->getMembersList(cfws);
+            foreach(Firewall *f, cfws)
+                fwset.insert(f);
+        }
+        else
+        {
+            fwset.insert(fw);
+        }
+    }
+
+    this->inspect(fwset);
+}
+
+void ProjectPanel::inspect(std::set<libfwbuilder::Firewall *> fws)
+{
+    if (fws.empty())
+        return;
+
+    QMessageBox messageBox(this);
+    messageBox.addButton(tr("Cancel"), QMessageBox::RejectRole);
+    messageBox.addButton(tr("Compile and Inspect files"), QMessageBox::AcceptRole);
+    messageBox.setIcon(QMessageBox::Critical);
+
+    set<Firewall*> needCompile;
+    foreach(Firewall *fw, fws)
+        if (fw->needsCompile())
+            needCompile.insert(fw);
+
+    if (!needCompile.empty())
+    {
+        QString text;
+        QStringList names;
+        foreach(Firewall *fw, needCompile)
+            names.append(fw->getName().c_str());
+
+        if (needCompile.size() > 1 && needCompile.size() < 5)
+        {
+            QString last = names.last();
+            names.pop_back();
+            QString firewalls = "\"" + names.join("\", \"") + "\" " + tr("and") + " \"" + last + "\"";
+            text = tr("Firewall objects %1 have been modified and need to be recompiled.").arg(firewalls);
+        }
+        else
+            if (needCompile.size() == 1)
+                text = tr("Firewall object \"%1\" has been modified and needs to be recompiled.").arg(names.first());
+            else
+            {
+                text = tr("%1 firewall objects have been modified and need to be recompiled.").arg(needCompile.size());
+            }
+
+        messageBox.setText(text);
+        messageBox.exec();
+        if (messageBox.result() == QMessageBox::Accepted)
+        {
+            this->compile(needCompile);
+        }
+        return;
+    }
+
+    QStringList files;
+
+    QSet<Firewall*> filesMissing;
+    foreach(Firewall *fw, fws)
+    {
+        bool canShowCode = true;
+        QString mainFile = FirewallInstaller::getGeneratedFileFullPath(fw);
+        if (QFile::exists(mainFile))
+        {
+            instConf cnf;
+            cnf.fwobj = fw;
+            cnf.script = mainFile;
+            QMap<QString, QString> res;
+            FirewallInstaller(NULL, &cnf, "").readManifest(mainFile, &res);
+            QStringList current_files = res.keys();
+            foreach(QString file, current_files)
+            {
+                if (!QFile::exists(file))
+                    filesMissing.insert(fw);
+                else
+                    files.append(file);
+            }
+        }
+        else
+            filesMissing.insert(fw);
+    }
+
+    if (!filesMissing.isEmpty())
+    {
+        QString text;
+        QStringList names;
+        foreach(Firewall *fw, filesMissing)
+            names.append(fw->getName().c_str());
+
+        if (filesMissing.size() > 1 && filesMissing.size() < 5)
+        {
+            QString last = names.last();
+            names.pop_back();
+            QString firewalls = "\"" + names.join("\", \"") + "\" " + tr("and") + " \"" + last + "\"";
+            text = tr("Can not read generated files for the firewall objects %1. You need to compile them to create the files.").arg(firewalls);
+        }
+        else
+            if (filesMissing.size() == 1)
+                text = tr("Can not read generated files for the firewall objects %1. You need to compile it to create the files.").arg(names.first());
+            else
+            {
+                text = tr("Can not read generated files for the %1 firewall objects. You need to compile then to create the files.").arg(filesMissing.size());
+            }
+        messageBox.setText(text);
+        messageBox.exec();
+        if (messageBox.result() == QMessageBox::Accepted)
+        {
+            this->compile(fws);
+        }
+        return;
+    }
+
+    if (files.empty())
+        return;
+
+    FirewallCodeViewer *viewer = new FirewallCodeViewer(files, tr("<b>Multiple firewalls</b>"), this);
+    viewer->show();
+}
+
 void ProjectPanel::compile()
 {
     if (mw->isEditorVisible() &&
@@ -752,6 +932,7 @@ void ProjectPanel::compile()
         return;
 
     fileSave();
+    wfl->registerFlag(UserWorkflow::COMPILE, true);
     mainW->compile();
 }
 
@@ -762,16 +943,19 @@ void ProjectPanel::compile(set<Firewall*> vf)
         return;
 
     fileSave();
+    wfl->registerFlag(UserWorkflow::COMPILE, true);
     mainW->compile(vf);
 }
 
 void ProjectPanel::install(set<Firewall*> vf)
 {
+    wfl->registerFlag(UserWorkflow::INSTALL, true);
     mainW->install(vf);
 }
 
 void ProjectPanel::install()
 {
+    wfl->registerFlag(UserWorkflow::INSTALL, true);
     mainW->install();
 }
 
@@ -1018,7 +1202,11 @@ void ProjectPanel::topLevelChangedForTreePanel(bool f)
 
     if (f)  // window becomes detached
     {
+        QString file_name = getFileName(); // full path
+        QFileInfo fi(file_name);
+        QString short_name = fi.fileName();
         m_panel->treeDockWidget->setParent(mw);
+        m_panel->treeDockWidget->setWindowTitle(short_name);
         mw->addDockWidget(Qt::LeftDockWidgetArea, m_panel->treeDockWidget);
         m_panel->treeDockWidget->show();
         m_panel->treeDockWidget->blockSignals(false);
@@ -1030,6 +1218,7 @@ void ProjectPanel::topLevelChangedForTreePanel(bool f)
 #else
 // Setting widget position here causes crash on Qt < 4.5.
         mw->removeDockWidget(m_panel->treeDockWidget);
+        m_panel->treeDockWidget->setWindowTitle("");
         m_panel->treeDockWidget->setParent(m_panel->treeDockWidgetParentFrame);
         m_panel->treeDockWidgetParentFrame->layout()->addWidget(m_panel->treeDockWidget);
         m_panel->treeDockWidget->show();
