@@ -6,7 +6,7 @@
 
   Author:  alek@codeminders.com
 
-  $Id: ProjectPanel.h 2588 2010-02-19 19:29:04Z vadim $
+  $Id: ProjectPanel.h 3046 2010-06-30 16:43:43Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -169,7 +169,7 @@ public:
 
     ObjectTreeView* getCurrentObjectTree();
 
-    void findAllFirewalls (std::list<libfwbuilder::Firewall *> &fws);
+    void findAllFirewalls(std::list<libfwbuilder::Firewall *> &fws);
 
     void showDeletedObjects(bool f);
     void select();
@@ -277,6 +277,7 @@ public:
     virtual void compile();
     virtual void install(std::set<libfwbuilder::Firewall*> vf);
     virtual void install();
+    virtual void inspect(std::set<libfwbuilder::Firewall*> vf);
     virtual void transferfw(std::set<libfwbuilder::Firewall*> vf);
     virtual void transferfw();
 
@@ -285,6 +286,9 @@ public:
     virtual void autoSave();
     virtual void compileThis();
     virtual void installThis();
+    virtual void inspectThis();
+    virtual void inspectAll();
+    virtual void addRule();
 
     void updateLastModifiedTimestampForAllFirewalls();
     void updateObjectInTree();
