@@ -7,7 +7,7 @@
   Author:  alek@codeminders.com
            refactoring and bugfixes: vadim@fwbuilder.org
 
-  $Id: ProjectPanel_file_ops.cpp 2644 2010-03-03 01:04:24Z vadim $
+  $Id: ProjectPanel_file_ops.cpp 2799 2010-04-08 22:53:47Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -191,10 +191,6 @@ bool ProjectPanel::fileNew()
         qDebug("ProjectPanel::fileNew()  rcs=%p  rcs->getFileName()='%s'",
                rcs, rcs->getFileName().toAscii().constData());
 
-    // reset actions, including Save() which should now
-    // be inactive
-    mw->prepareFileMenu();
-
     return (rcs!=NULL);
 }
 
@@ -264,9 +260,7 @@ void ProjectPanel::fileClose()
     if (!saveIfModified() || !checkin(true))  return;
     reset();
     mdiWindow->close();
-    // reset actions, including Save() which should now
-    // be inactive
-    mw->prepareFileMenu();
+    mw->setCompileAndInstallActionsEnabled(false);
     if (fwbdebug) qDebug("ProjectPanel::fileClose(): done");
 }
 
@@ -325,10 +319,6 @@ void ProjectPanel::fileCommit()
     save();
     if (!checkin(true))  return;
     rcs->co();
-
-    // reset actions, including Save() which should now
-    // be inactive
-    mw->prepareFileMenu();
 }
 
 /*
@@ -376,10 +366,6 @@ void ProjectPanel::fileDiscard()
          * open, which it isn't because we reset rcs to NULL
          */
         loadFile(fname, false);
-
-        // reset actions, including Save() which should now
-        // be inactive
-        mw->prepareFileMenu();
     }
 }
 
@@ -410,13 +396,7 @@ void ProjectPanel::fileAddToRCS()
             0, 1 );
     }
 
-    // reset actions, including Save() which should now
-    // be inactive
-    mw->prepareFileMenu();
-
-    //setWindowTitle(getPageTitle());
     QCoreApplication::postEvent(mw, new updateSubWindowTitlesEvent());
-
 }
 
 void ProjectPanel::fileImport()
@@ -435,13 +415,6 @@ void ProjectPanel::fileImport()
 
     loadObjects();
 
-    // reset actions, including Save() which should now
-    // be inactive
-    mw->prepareFileMenu();
-
-    //QCoreApplication::postEvent(this, new openLibraryForObjectEvent(
-    //                                getFileName(), new_lib->getId()));
-
     m_panel->om->openLib(new_lib);
 }
 
@@ -695,7 +668,8 @@ bool ProjectPanel::exportLibraryTest(list<FWObject*> &selectedLibs)
         QString objlist = "";
         QString s       = "";
 
-        for (list<FWReference*>::iterator i=externalRefs2.begin(); i!=externalRefs2.end(); ++i)
+        for (list<FWReference*>::iterator i=externalRefs2.begin();
+             i!=externalRefs2.end(); ++i)
         {
             FWReference *robj   = *i;
             FWObject *selLib = robj->getLibrary();
@@ -729,31 +703,19 @@ bool ProjectPanel::exportLibraryTest(list<FWObject*> &selectedLibs)
                 while (fw!=NULL && Firewall::cast(fw)==NULL)
                     fw=fw->getParent();
 
-                QString rsname;
-                if (Policy::cast(ruleset)!=NULL)
-                {
-                    s =
-   QObject::tr("Library %1: Firewall '%2' (global policy rule #%3) uses object '%4' from library '%5'")
-                        .arg(selLib->getName().c_str())
-                        .arg(fw->getName().c_str())
-                        .arg(Rule::cast(rule)->getPosition())
-                        .arg(tgt->getName().c_str())
-                        .arg(tgtlib->getName().c_str());
-                }
-                if (NAT::cast(ruleset)!=NULL)
-                {
-                    s =
-   QObject::tr("Library %1: Firewall '%2' (NAT rule #%3) uses object '%4' from library '%5'")
-                        .arg(selLib->getName().c_str())
-                        .arg(fw->getName().c_str())
-                        .arg(Rule::cast(rule)->getPosition())
-                        .arg(tgt->getName().c_str())
-                        .arg(tgtlib->getName().c_str());
-                }
+                s = QObject::tr("Library %1: Firewall '%2' (%3 rule #%4) uses "
+                                "object '%5' from library '%6'")
+                    .arg(selLib->getName().c_str())
+                    .arg(fw->getName().c_str())
+                    .arg(ruleset->getTypeName().c_str())
+                    .arg(Rule::cast(rule)->getPosition())
+                    .arg(tgt->getName().c_str())
+                    .arg(tgtlib->getName().c_str());
+
             } else
             {
-                    s =
-   QObject::tr("Library %1: Group '%2' uses object '%3' from library '%4'")
+                s =
+                    QObject::tr("Library %1: Group '%2' uses object '%3' from library '%4'")
                         .arg(selLib->getName().c_str())
                         .arg(pp->getName().c_str())
                         .arg(tgt->getName().c_str())
@@ -766,13 +728,13 @@ bool ProjectPanel::exportLibraryTest(list<FWObject*> &selectedLibs)
             objlist = objlist + s;
         }
 
-        longTextDialog ltd( this,
-
+        longTextDialog ltd(
+            this,
             tr("A library that you are trying to export contains references\n"
                "to objects in the other libraries and can not be exported.\n"
                "The following objects need to be moved outside of it or\n"
                "objects that they refer to moved in it:"),
-                            objlist );
+            objlist );
 
         ltd.exec();
         return false;
@@ -1118,7 +1080,7 @@ bool ProjectPanel::loadFromRCS(RCS *_rcs)
         /* if the file name has an old extension .xml, change it to .fwb and
          * warn the user
          */
-        QString   fn = rcs->getFileName();
+        QString fn = rcs->getFileName();
         QFileInfo ofinfo(fn);
 
         if ( ofinfo.suffix()=="xml")
@@ -1256,6 +1218,9 @@ bool ProjectPanel::loadFromRCS(RCS *_rcs)
                 0, 1 );
         } else
         {
+            // this was not XML error, perhaps permissions or other
+            // filesystem problem
+
             QString error_txt = QString::fromUtf8(ex.toString().c_str());
             if (error_txt.length() > LONG_ERROR_CUTOFF) 
             {
