@@ -7,7 +7,7 @@
   Author:  alek@codeminders.com
            refactoring and bugfixes: vadim@fwbuilder.org
 
-  $Id: ProjectPanel_state_ops.cpp 2588 2010-02-19 19:29:04Z vadim $
+  $Id: ProjectPanel_state_ops.cpp 2805 2010-04-09 17:11:37Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -69,8 +69,14 @@ void ProjectPanel::saveState()
     m_panel->om->saveExpandedTreeItems();
     m_panel->om->saveSectionSizes();
 
+    if (fwbdebug)
+        qDebug() << "ProjectPanel::saveState "
+                 << "rcs=" << rcs
+                 << "getCurrentRuleSetView()=" << getCurrentRuleSetView();
+
     saveLastOpenedLib();
-    saveOpenedRuleSet();
+
+    if (getCurrentRuleSetView()) saveOpenedRuleSet();
 
     if (fwbdebug) qDebug("ProjectPanel::saveState() done");
 }
