@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland vadim@fwbuilder.org
 
-  $Id: RCS.cpp 2644 2010-03-03 01:04:24Z vadim $
+  $Id: RCS.cpp 2930 2010-05-25 05:20:25Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,6 +28,7 @@
 #include "utils.h"
 #include "utils_no_qt.h"
 
+#include "FWBApplication.h"
 #include "RCS.h"
 
 // need this for FS_SEPARATOR
@@ -301,9 +302,15 @@ RCS::RCS(const QString &file)
 {
     if (rcsenvfix==NULL) rcsenvfix = new RCSEnvFix();
 
+    if (fwbdebug) qDebug() << "RCS::RCS(" << file << ")";
+
+    // Using absoluteFilePath() rather than canonicalFilePath, see #1334
     QFileInfo fi(file);
-    if (fi.exists()) filename = fi.canonicalFilePath();
+    if (fi.exists()) filename = fi.absoluteFilePath();
     else filename = file;
+
+    if (fwbdebug) qDebug() << "filename=" << filename;
+
     checked_out   = false;
     locked        = false;
     inrcs         = false;
@@ -464,7 +471,7 @@ void RCS::readFromStderr()
 void RCS::setFileName(const QString &fn)
 {
     QFileInfo fi(fn);
-    if (fi.exists()) filename = fi.canonicalFilePath();
+    if (fi.exists()) filename = fi.absoluteFilePath();
     else filename = fn;
     if (fwbdebug)
         qDebug() << "RCS::setFileName fn =" << fn << "filename =" << filename;
