@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: RuleOptionsDialog.cpp 2558 2010-02-18 04:59:47Z vadim $
+  $Id: RuleOptionsDialog.cpp 2919 2010-05-22 01:32:13Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -105,7 +105,7 @@ void RuleOptionsDialog::loadFWObject(FWObject *o)
     if (platform=="pf")       wid=2;
     if (platform=="ipfw")     wid=3;
     if (platform=="pix" || platform=="fwsm")      wid=4;
-    if (platform=="iosacl")   wid=5;
+    if (platform=="iosacl" || platform=="procurve_acl")   wid=5;
 
     m_dialog->wStack->widget(wid)->raise();
     m_dialog->wStack->setCurrentWidget(m_dialog->wStack->widget(wid));
@@ -261,7 +261,7 @@ void RuleOptionsDialog::loadFWObject(FWObject *o)
         data.registerOption(m_dialog->ipfw_stateless, ropt,"stateless");
     }
 
-    if (platform=="iosacl")
+    if (platform=="iosacl" || platform=="procurve_acl")
     {
         data.registerOption(m_dialog->iosacl_add_mirror_rule,
                             ropt, "iosacl_add_mirror_rule");
