@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: RuleSetView.cpp 2693 2010-03-08 18:44:55Z yalovoy $
+  $Id: RuleSetView.cpp 3050 2010-07-03 16:02:24Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -79,7 +79,7 @@ RuleSetView::RuleSetView(ProjectPanel *project, QWidget *parent):QTreeView(paren
     this->project = project;
     fwosm = new FWObjectSelectionModel();
     setContextMenuPolicy(Qt::CustomContextMenu);
-    setSelectionMode(QAbstractItemView::ExtendedSelection);
+    setSelectionMode(QAbstractItemView::ContiguousSelection);
     setSelectionBehavior(QAbstractItemView::SelectRows);
 
     setDragEnabled(true);
@@ -106,6 +106,10 @@ RuleSetView::RuleSetView(ProjectPanel *project, QWidget *parent):QTreeView(paren
     initActions();
 
     popup_menu = new QMenu(this);
+
+    this->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
+    this->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
+    this->header()->setStretchLastSection(false);
 }
 
 RuleSetView::~RuleSetView()
@@ -1408,7 +1412,6 @@ void RuleSetView::pasteRuleBelow()
     RuleSetModel* md = ((RuleSetModel*)model());
     if (!canChange(md)) return;
 
-    QModelIndexList selection = getSelectedRows();
     QModelIndex index = currentIndex();
 
     vector<std::pair<int,ProjectPanel*> >::reverse_iterator i;
@@ -2172,17 +2175,19 @@ bool RuleSetView::validateForInsertion(RuleElement *re, FWObject *obj, bool quie
             {
                 QMessageBox::information(
                     NULL , "Firewall Builder",
-                    "A single interface belonging to this firewall is "
-                    "expected in this field.",
+                    QObject::tr(
+                        "A single interface belonging to this firewall is "
+                        "expected in this field."),
                     QString::null,QString::null);
             }
             else if (RuleElementRGtw::cast(re))
             {
                 QMessageBox::information(
                     NULL , "Firewall Builder",
-                    "A single ip adress is expected here. You may also "
-                    "insert a host or a network adapter leading to a single "
-                    "ip adress.",
+                    QObject::tr(
+                        "A single ip adress is expected here. You may also "
+                        "insert a host or a network adapter leading to a single "
+                        "ip adress."),
                     QString::null,QString::null);
             }
         }
@@ -2350,65 +2355,84 @@ void RuleSetView::updateCurrentCell()
     updateColumnSizeForIndex(fwosm->index);
 }
 
+/*
+ * looks like this method can be called when we print from the command
+ * line. Variable project==NULL at that time.
+ */
 void RuleSetView::saveCollapsedGroups()
 {
-    QStringList collapsed_groups;
-    QString filename = project->getRCS()->getFileName();
-    RuleSetModel* md = ((RuleSetModel*)model());
-    QList<QModelIndex> groups;
-    md->getGroups(groups);
-    foreach (QModelIndex index, groups)
+    if (project)
     {
-        if (!isExpanded(index))
+        QStringList collapsed_groups;
+        QString filename = project->getRCS()->getFileName();
+        RuleSetModel* md = ((RuleSetModel*)model());
+        QList<QModelIndex> groups;
+        md->getGroups(groups);
+        foreach (QModelIndex index, groups)
         {
-            RuleNode* node = static_cast<RuleNode *>(index.internalPointer());
-            collapsed_groups.push_back(node->name);
+            if (!isExpanded(index))
+            {
+                RuleNode* node = static_cast<RuleNode *>(index.internalPointer());
+                collapsed_groups.push_back(node->name);
+            }
         }
+        Firewall *f = md->getFirewall();
+        if (f)
+            st->setCollapsedRuleGroups(
+                filename,
+                f->getName().c_str(),
+                md->getRuleSet()->getName().c_str(),
+                collapsed_groups);
     }
-    Firewall *f = md->getFirewall();
-    if (f)
-        st->setCollapsedRuleGroups(
-            filename,
-            f->getName().c_str(),
-            md->getRuleSet()->getName().c_str(),
-            collapsed_groups);
 }
 
+/*
+ * looks like this method can be called when we print from the command
+ * line. Variable project==NULL at that time.
+ */
 void RuleSetView::restoreCollapsedGroups()
 {
-    QTime t;
-    t.start();
-    RuleSetModel* md = ((RuleSetModel*)model());
-    QStringList collapsed_groups;
-    QString filename = project->getRCS()->getFileName();
-    if (fwbdebug)
-        qDebug("restoreCollapsedGroups begin: %d ms", t.restart());
-    Firewall *f = md->getFirewall();
-    if (f)
-        st->getCollapsedRuleGroups(
-            filename,
-            f->getName().c_str(),
-            md->getRuleSet()->getName().c_str(),
-            collapsed_groups);
-    if (fwbdebug)
-        qDebug("restoreCollapsedGroups getCollapsedRuleGroups: %d ms", t.restart());
-    QList<QModelIndex> groups;
-    md->getGroups(groups);
-
-    if (fwbdebug)
+    if (project)
     {
-        qDebug("restoreCollapsedGroups getGroups: %d ms", t.restart());
-        qDebug() << "Groups:" << groups.size();
-    }
+        QTime t;
+        t.start();
+        RuleSetModel* md = ((RuleSetModel*)model());
+        QStringList collapsed_groups;
+        QString filename;
+        filename = project->getRCS()->getFileName();
 
-    foreach (QModelIndex index, groups)
-    {
-        RuleNode* node = static_cast<RuleNode *>(index.internalPointer());
-        setExpanded(index,  !collapsed_groups.contains(node->name) );
-    }
+        if (fwbdebug)
+            qDebug("restoreCollapsedGroups begin: %d ms", t.restart());
 
-    if (fwbdebug)
-        qDebug("restoreCollapsedGroups foreach setExpanded: %d ms", t.restart());
+        Firewall *f = md->getFirewall();
+        if (f)
+            st->getCollapsedRuleGroups(
+                filename,
+                f->getName().c_str(),
+                md->getRuleSet()->getName().c_str(),
+                collapsed_groups);
+
+        if (fwbdebug)
+            qDebug("restoreCollapsedGroups getCollapsedRuleGroups: %d ms", t.restart());
+
+        QList<QModelIndex> groups;
+        md->getGroups(groups);
+
+        if (fwbdebug)
+        {
+            qDebug("restoreCollapsedGroups getGroups: %d ms", t.restart());
+            qDebug() << "Groups:" << groups.size();
+        }
+
+        foreach (QModelIndex index, groups)
+        {
+            RuleNode* node = static_cast<RuleNode *>(index.internalPointer());
+            setExpanded(index,  !collapsed_groups.contains(node->name) );
+        }
+
+        if (fwbdebug)
+            qDebug("restoreCollapsedGroups foreach setExpanded: %d ms", t.restart());
+    }
 }
 
 int RuleSetView::rowHeight(const QModelIndex& index) const
@@ -2430,7 +2454,11 @@ bool RuleSetView::showToolTip(QEvent *event)
     QPoint pos = viewport()->mapFromGlobal(he->globalPos());
 
     QModelIndex index = indexAt(pos);
-    if (!index.isValid()) return false;
+    if (!index.isValid())
+    {
+        QToolTip::hideText();
+        return false;
+    }
 
     RuleSetModel* md = ((RuleSetModel*)model());
     RuleNode *node = md->nodeFromIndex(index);
@@ -2454,8 +2482,9 @@ bool RuleSetView::showToolTip(QEvent *event)
                     Rule* rule = node->rule;
                     if (PolicyRule::cast(rule)!=NULL )
                     {
-                        if (!isDefaultPolicyRuleOptions(rule->getOptionsObject()))
+                        if (!isDefaultPolicyRuleOptions(rule->getOptionsObject())) {
                             toolTip = FWObjectPropertiesFactory::getPolicyRuleOptions(rule);
+                        }
                     }
                     if (NATRule::cast(rule)!=NULL )
                     {
@@ -2484,7 +2513,11 @@ bool RuleSetView::showToolTip(QEvent *event)
         toolTip = node->name;
     }
 
-    if (toolTip.isEmpty()) return true;
+    if (toolTip.isEmpty())
+    {
+        QToolTip::hideText();
+        return true;
+    }
 
     QRect   cr = visualRect(index);
 
@@ -2827,12 +2860,15 @@ void RuleSetView::updateSelectionSensitiveActions()
             if (index.isValid())
             {
                 RuleNode* node = md->nodeFromIndex(index);
+
+                topLevelOnly = topLevelOnly && (node->type == RuleNode::Rule);
+
                 if (node!=0 && node->type == RuleNode::Rule && node->rule != 0)
                 {
                     bool isInGroup = node->isInGroup();
                     inGroup = inGroup && isInGroup;
                     topLevelOnly = topLevelOnly && !isInGroup;
-                    outermost = outermost || node->isOutermost();
+                    outermost = outermost || (node->isOutermost() && isInGroup);
 
                     Rule *r =  node->rule;
 
