@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: RuleSetViewDelegate.cpp 2475 2010-01-31 21:09:25Z yalovoy $
+  $Id: RuleSetViewDelegate.cpp 3012 2010-06-18 19:02:42Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -33,7 +33,6 @@
 #include "RuleNode.h"
 #include "ColDesc.h"
 #include "FWObjectSelectionModel.h"
-#include "RuleSetModel.h"
 
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Resources.h"
@@ -120,22 +119,16 @@ void RuleSetViewDelegate::drawIcons(QPainter *painter, QRect rect,
 {
     int x = rect.left();
     int y = rect.top();
+    int iconWidth = 0;
 
-    if (st->getShowIconsInRules())
+    for (int i=0; i<icons.size(); i++)
     {
         QPixmap pm;
-        QString icon;
-        for (int i=0; i<icons.size(); i++)
-        {
-            icon = calculateIconName(icons[i], false);
-            LoadPixmap(icon, pm);
-            painter->drawPixmap(x,y,pm);
-            x += pm.width() + ICON_TEXT_GAP;
-        }
-    }
-    else
-    {
-        //TODO we should show something in this case!
+        QString icon = calculateIconName(icons[i], false);
+        LoadPixmap(icon, pm);
+        painter->drawPixmap(x, y, pm);
+        iconWidth = pm.width();
+        x += iconWidth + ICON_TEXT_GAP;
     }
 }
 
@@ -147,7 +140,6 @@ void RuleSetViewDelegate::drawIconAndText(QPainter *painter,
 {
     int x = rect.left();
     int y = rect.top();
-
     int iconWidth = 0;
 
     if (!icon.isEmpty() && st->getShowIconsInRules())
@@ -178,12 +170,17 @@ void RuleSetViewDelegate::drawSelectedFocus(QPainter *painter, const QStyleOptio
     }
 }
 
-void RuleSetViewDelegate::paintRule(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index, RuleNode * node) const
+void RuleSetViewDelegate::paintRule(QPainter *painter,
+                                    const QStyleOptionViewItem &option,
+                                    const QModelIndex &index,
+                                    RuleNode * node) const
 {
-    //if (fwbdebug) qDebug() << "RuleSetViewDelegate::paintRule";
     QVariant v = index.data(Qt::DisplayRole);
     if (!v.isValid()) return;
 
+    // if (fwbdebug) qDebug() << "RuleSetViewDelegate::paintRule"
+    //                        << v;
+
     if (node != 0)
     {
         FWOptions *ropt = node->rule->getOptionsObject();
@@ -238,17 +235,31 @@ void RuleSetViewDelegate::paintAction(QPainter *painter, const QStyleOptionViewI
     DrawingContext ctx = initContext(option.rect);
     ActionDesc actionDesc = v.value<ActionDesc>();
     drawSelectedFocus(painter, option, ctx.objectRect);
-    QString text = (st->getShowDirectionText())?actionDesc.displayName:"";
-    drawIconAndText(painter, ctx.drawRect,actionDesc.name,text);
+    QString text = constructActionText(actionDesc);
+    drawIconAndText(painter, ctx.drawRect, actionDesc.name, text);
 }
 
 void RuleSetViewDelegate::paintOptions(QPainter *painter, const QStyleOptionViewItem &option, const QVariant &v) const
 {
     //if (fwbdebug) qDebug() << "RuleSetViewDelegate::paintOptions";
     DrawingContext ctx = initContext(option.rect);
-    QStringList options = v.value<QStringList>();
     drawSelectedFocus(painter, option, ctx.objectRect);
-    drawIcons(painter, ctx.drawRect, options);
+    QStringList icons;
+    icons = v.value<QStringList>();
+    QStringList text;
+
+    if (st->getShowIconsInRules())
+    {
+        drawIcons(painter, ctx.drawRect, icons);
+    } else
+    {
+        for (int i=0; i<icons.size(); i++)
+        {
+            if (icons[i].contains("Log")) text.push_back(tr("log"));
+            if (icons[i].contains("Options")) text.push_back(tr("(options)"));
+        }
+        drawIconAndText(painter, ctx.drawRect, "", text.join(", "), false);
+    }
 }
 
 
@@ -462,7 +473,6 @@ QSize RuleSetViewDelegate::calculateCellSizeForRule(const QStyleOptionViewItem &
     }
 
     result = result.expandedTo(calculated);
-
     return result;
 }
 
@@ -470,10 +480,9 @@ QSize RuleSetViewDelegate::calculateCellSizeForComment(const QModelIndex & index
 {
     QString text = index.data(Qt::DisplayRole).value<QString>();
     if (text.isNull() && text.isEmpty()) return QSize(0,0);
-
-    if (st->getClipComment()) return QSize(0,0);
-
     QSize res = getTextSize(text,0);
+    if (st->getClipComment())
+        res.setHeight(0);
     return res;
 }
 
@@ -513,11 +522,28 @@ QSize RuleSetViewDelegate::calculateCellSizeForObject(const QModelIndex & index)
     return res;
 }
 
+QString RuleSetViewDelegate::constructActionText(ActionDesc &actionDesc) const
+{
+    QString text;
+    if (st->getShowDirectionText())
+    {
+        text = actionDesc.displayName + (actionDesc.argument.isEmpty()?"":(":"+actionDesc.argument));
+    } else if (!actionDesc.argument.isEmpty())
+    {
+        text = actionDesc.argument;
+    }
+
+    if (text.length() > 20)
+        text = text.left(17) + "...";
+
+    return text;
+}
+
 QSize RuleSetViewDelegate::calculateCellSizeForIconAndText(const QModelIndex & index) const
 {
     QVariant v = index.data(Qt::DisplayRole);
     ActionDesc actionDesc = v.value<ActionDesc>();
-    QString text = (st->getShowDirectionText())?actionDesc.displayName:"";
+    QString text = constructActionText(actionDesc);
 
     if (text == "Undefined") text = "Both";
 
