@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHPIX.h 585 2008-10-09 05:08:41Z vadim $
+  $Id: SSHPIX.h 2251 2009-12-23 01:44:15Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -30,7 +30,7 @@
 #include "../../config.h"
 #include "global.h"
 
-#include "SSHSession.h"
+#include "SSHCisco.h"
 
 #include <qstring.h>
 #include <qstringlist.h>
@@ -38,29 +38,10 @@
 #include <list>
 #include <string>
 
-class QEventLoop;
+class SSHPIX : public SSHCisco {
 
-class SSHPIX : public SSHSession {
+    Q_OBJECT;
 
-    Q_OBJECT
-
-    QEventLoop *local_event_loop;
-    int         nLines;
-    int         ncmd;
-    QStringList allConfig;
-
-    QStringList newAcls;
-    QStringList currentAcls;
-        
-    QStringList newObjectGroups;
-    QStringList currentObjectGroups;
-    
-    std::ifstream   *config_file;
-
-protected:
-    QStringList      pre_config_commands;
-    QStringList      post_config_commands;
-    
 public:
     
     SSHPIX(QWidget *parent,
@@ -71,21 +52,14 @@ public:
            const std::list<std::string> &in);
     virtual ~SSHPIX();
 
-    virtual bool checkForErrors();
     virtual void stateMachine();
 
-    QString cmd(QProcess *proc,const QString &cmd);
-
-    void loadPreConfigCommands(const QStringList &cl);
-    void loadPostConfigCommands(const QStringList &cl);
-    
 public slots:
- void PIXbackup();
- void getACLs();
- void clearACLs();
- void getObjectGroups();
- void clearObjectGroups();
- void PIXincrementalInstall();
+    void PIXbackup();
+    void getACLs();
+    void clearACLs();
+    void getObjectGroups();
+    void clearObjectGroups();
      
 };
 
