@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHSession.cpp 2261 2009-12-23 22:56:52Z vadim $
+  $Id: SSHSession.cpp 2861 2010-04-29 22:07:11Z svn $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -38,11 +38,11 @@
 #include <qmessagebox.h>
 #include <qapplication.h>
 #include <qeventloop.h>
-//#include <qcstring.h>
 #include <qtextcodec.h>
 #include <qapplication.h>
 #include <qdatetime.h>
 #include <QtDebug>
+#include <QTime>
 
 #include <iostream>
 
@@ -137,7 +137,7 @@ void SSHSession::startSession()
 
     if (fwbdebug)
         qDebug("SSHSession::startSession  this=%p  proc=%p   heartBeatTimer=%p",
-               this,proc,heartBeatTimer);
+               this, proc, heartBeatTimer);
 
     connect(proc,SIGNAL(readyReadStandardOutput()),
             this,  SLOT(readFromStdout() ) );
@@ -254,15 +254,48 @@ void SSHSession::terminate()
                  << "proc=" << proc
                  << "heartBeatTimer=" << heartBeatTimer;
 
+    // Ticket #1426, SF bug 2990333. If installation process generates
+    // a lot of output and keeps the GUI busy updating buffers and
+    // progress log display, it becomes possible for the user to hit
+    // Cancel and place corresponding event in the queue after the
+    // process has actually finished but before its signal "finished"
+    // could be processed by the slot SSHSession::terminated(). This
+    // causes problems because we disconnect this signal here so we
+    // never process it anymore. Also, it looks like QProcess does not
+    // change its own state to indicate it is no longer running if its
+    // signal processExited has not been processed. This means that
+    // even though the background process has finished and exited,
+    // QProcess still thinks it is running. We try to send terminate
+    // and then kill signals to it in this function, to no avail. In
+    // the end, the program crashes trying to destroy QProcess object
+    // which still thinks it is running.
+
+    //qApp->processEvents();
+
     stopHeartBeat();
 
-    if (proc!=NULL)
+    if (proc != NULL)
     {
-        disconnect(proc,SIGNAL(finished(int, QProcess::ExitStatus)),
-                   this,SLOT(finished(int) ) );
+        if (proc->state() == QProcess::Running)
+        {
+            if (fwbdebug)
+                qDebug() << "SSHSession::terminate   "
+                         << "waiting for pending signal 'finished()', if any";
+            // this processes events and lets QProcess send signal finished()
+            // in case user hit Cancel at just right time when background process
+            // already exited but QProcess has not noticed this yet.
+            proc->waitForFinished(100);
+        }
 
-        if (fwbdebug)
-            qDebug() << "SSHSession::terminate   terminating child process";
+        // If QProcess sent signal finished() while we were waiting in
+        // waitForFinished(), the signal has been processed in
+        // SSHSession::finished and proc has already been deleted.
+
+        if (proc == NULL)
+        {
+            if (fwbdebug) qDebug("SSHSession::terminate   proc==NULL");
+            return;
+        }
 
 #ifdef _WIN32
         if (proc->pid() != NULL)
@@ -273,8 +306,11 @@ void SSHSession::terminate()
             if (proc->state() == QProcess::Running)
             {
                 Q_PID pid = proc->pid();
-                if (fwbdebug) qDebug() << "Process is running pid=" << pid;
-                emit printStdout_sign(QString("Stopping background process"));
+                if (fwbdebug)
+                    qDebug() << "SSHSession::terminate   "
+                             << "terminating child process pid="  << pid;
+
+                emit printStdout_sign(tr("Stopping background process"));
 
                 /*
                  * on windows proc->terminate() posts a WM_CLOSE
@@ -291,16 +327,19 @@ void SSHSession::terminate()
 #endif
 
                 if (fwbdebug)
-                    qDebug() << "Terminate signal sent, waiting for it to finish";
+                    qDebug() << "SSHSession::terminate   terminate signal sent,"
+                             << "waiting for it to finish";
 
                 int time_to_wait = 20;
-                for (int timeout = 0; timeout < time_to_wait; timeout++)
+                for (int timeout = 0; proc != NULL &&
+                         proc->state() == QProcess::Running &&
+                         timeout < time_to_wait;
+                     timeout++)
                 {
-                    if (proc->state() != QProcess::Running) break;
                     // print countdown only if we've been waiting more than 3 sec
                     if (timeout > 3)
                         emit printStdout_sign(
-                            QString(
+                            tr(
                                 "Background process is still running. "
                                 "Will wait %1 sec").arg(time_to_wait - timeout));
 
@@ -310,15 +349,25 @@ void SSHSession::terminate()
                         s.replace('\r',"");
                         emit printStdout_sign(s);
                     }
-                    QCoreApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
-#ifdef _WIN32
-                    Sleep(1000);
-#else
-                    sleep(1);
-#endif
+
+                    QApplication::processEvents(
+                        QEventLoop::ExcludeUserInputEvents,1);
+
+                    // check if proc is still running after we processed events
+                    if (proc != NULL) proc->waitForFinished(1000);
                 }
 
-                if (fwbdebug) qDebug() << "Reading last output buffers";
+                // proc can be NULL at this point if it had sent signal finished()
+                // which we processed in the call to waitForFinished() above
+                if (proc == NULL)
+                {
+                    if (fwbdebug) qDebug("SSHSession::terminate   proc==NULL");
+                    return;
+                }
+
+                if (fwbdebug)
+                    qDebug() << "SSHSession::terminate   "
+                             << "Reading last output buffers";
 
                 QString s = QString(proc->readAllStandardOutput());
                 if (!quiet)
@@ -327,13 +376,23 @@ void SSHSession::terminate()
                     emit printStdout_sign(s);
                 }
 
-                if (fwbdebug) qDebug() << "done reading I/O buffers";
+                if (fwbdebug)
+                    qDebug() << "SSHSession::terminate   done reading I/O buffers. Disconnecting signals";
+
+                disconnect(proc, SIGNAL(readyReadStandardOutput()),
+                           this, SLOT(readFromStdout() ) );
+                disconnect(proc, SIGNAL(readyReadStandardError()),
+                           this, SLOT(readFromStderr() ) );
+                disconnect(proc, SIGNAL(finished(int, QProcess::ExitStatus)),
+                           this, SLOT(finished(int) ) );
 
                 if (proc->state() == QProcess::Running)
                 {
-                    if (fwbdebug) qDebug() << "Still running, killing";
+                    if (fwbdebug)
+                        qDebug() << "SSHSession::terminate   Still running, killing";
                     proc->kill();
                 }
+
             }
 
             delete proc;
@@ -433,20 +492,23 @@ void SSHSession::allDataSent()
 
 void SSHSession::startHeartBeat()
 {
-    if (fwbdebug) qDebug("SSHSession::startHeartBeat");
-    heartBeatTimer->start(1000);
+    if (fwbdebug)
+        qDebug() << "SSHSession::startHeartBeat" << QTime::currentTime().toString();
+    heartBeatTimer->start(100);
 }
 
 void SSHSession::stopHeartBeat()
 {
-    if (fwbdebug) qDebug("SSHSession::stopHeartBeat");
+    if (fwbdebug)
+        qDebug() << "SSHSession::stopHeartBeat" << QTime::currentTime().toString();
     heartBeatTimer->stop();
     send_keepalive = false;
 }
 
 void SSHSession::heartBeat()
 {
-    if (fwbdebug) qDebug("SSHSession::heartBeat");
+    if (fwbdebug)
+        qDebug() << "SSHSession::heartBeat begin" << QTime::currentTime().toString();
     if (send_keepalive) proc->write("\n");
     readFromStderr();
     readFromStdout();
@@ -455,10 +517,17 @@ void SSHSession::heartBeat()
         allDataSent();
         endOfCopy = false;
     }
+    if (fwbdebug)
+        qDebug() << "SSHSession::heartBeat end  " << QTime::currentTime().toString();
 }
 
 void SSHSession::readFromStdout()
 {
+    if (fwbdebug)
+        qDebug() << "SSHSession::readFromStdout"
+                 << QTime::currentTime().toString()
+                 << "################ proc=" << proc;
+
     if (proc)
     {
         QByteArray ba = proc->readAllStandardOutput();
@@ -469,8 +538,7 @@ void SSHSession::readFromStdout()
 
         stdoutBuffer.append(buf);
 
-        if (fwbdebug)
-            qDebug("SSHSession::readFromStdout: '%s'", buf.toAscii().constData());
+        if (fwbdebug) qDebug() << buf;
 
         bool endsWithLF = buf.endsWith("\n");
         QString lastLine = "";
@@ -515,8 +583,16 @@ void SSHSession::readFromStdout()
 
         pendingLogLine += lastLine;
 
+        if (fwbdebug)
+            qDebug() << "SSHSession::readFromStdout"
+                     << QTime::currentTime().toString()
+                     << "calling stateMachine()";
         stateMachine();
     }
+    if (fwbdebug)
+        qDebug() << "SSHSession::readFromStdout"
+                 << QTime::currentTime().toString()
+                 << "---------------- end";
 }
 
 /*
@@ -552,6 +628,7 @@ void SSHSession::sessionComplete(bool err)
         emit sessionFatalError_sign();
     else
         emit sessionFinished_sign();
+    if (fwbdebug) qDebug("SSHSession::sessionComplete  done");
 }
 
 void SSHSession::finished(int retcode)
@@ -561,14 +638,24 @@ void SSHSession::finished(int retcode)
                          proc, retcode);
 
     // background process has exited now, we do not need proc object anymore
+
+    disconnect(proc, SIGNAL(readyReadStandardOutput()),
+               this, SLOT(readFromStdout() ) );
+    disconnect(proc, SIGNAL(readyReadStandardError()),
+               this, SLOT(readFromStderr() ) );
+    disconnect(proc, SIGNAL(finished(int, QProcess::ExitStatus)),
+               this, SLOT(finished(int) ) );
+
     delete proc;
-    proc=NULL;
+    proc = NULL;
 
     QString exitStatus = (retcode)?QObject::tr("ERROR"):QObject::tr("OK");
 
     emit printStdout_sign(tr("SSH session terminated, exit status: %1").arg(
                               retcode) + "\n");
     sessionComplete( retcode!=0 );
+
+    if (fwbdebug) qDebug("SSHSession::processExited done");
 //    if (retcode) error=true;
 //    emit sessionFinished_sign();
 }
