@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SimpleTextEditor.cpp,v 1.6 2007/01/07 01:00:30 vkurland Exp $
+  $Id: SimpleTextEditor.cpp 332 2008-07-06 20:11:03Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,7 +17,7 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
@@ -25,7 +25,7 @@
 
 
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 
 #include "SimpleTextEditor.h"
@@ -43,49 +43,57 @@ using namespace std;
 SimpleTextEditor::SimpleTextEditor(QWidget *parent,
                                    const QString &txt,
                                    bool enableLoadFromFile,
-                                   const QString &title) : SimpleTextEditor_q(parent)
+                                   const QString &title) : QDialog(parent)
 {
-    if (enableLoadFromFile) inputFromFileButton->show();
-    else                    inputFromFileButton->hide();
+    m_dialog = new Ui::SimpleTextEditor_q;
+    m_dialog->setupUi(static_cast<QDialog*>(this));
 
-    if (!title.isEmpty()) setCaption(title);
-    editor->setTextFormat(QTextEdit::PlainText);
-    editor->setText(txt);
+    if (enableLoadFromFile) m_dialog->inputFromFileButton->show();
+    else                    m_dialog->inputFromFileButton->hide();
+
+    if (!title.isEmpty()) setWindowTitle(title);
+    //editor->setTextFormat(QTextEdit::PlainText);
+    m_dialog->editor->setPlainText(txt);
+}
+
+SimpleTextEditor::~SimpleTextEditor()
+{
+    delete m_dialog;
 }
 
 QString SimpleTextEditor::text()
 {
-    return editor->text();
+    return m_dialog->editor->toPlainText();
 }
 
 
 void SimpleTextEditor::loadFromFile()
 {
     if ( QMessageBox::warning(
-       this,"Firewall Builder", 
+       this,"Firewall Builder",
        tr("Warning: loading from file discards current contents of the script."),
        "&Load", "&Cancel", QString::null, 0, 1 )==0)
     {
-        QString filename = QFileDialog::getOpenFileName( st->getWDir(),
-                                                         NULL,  this, NULL,
-                                                         tr("Choose file") );
+        QString filename = QFileDialog::getOpenFileName( this, tr("Choose file"),
+                                                         st->getWDir());
+
         if (filename!="")
         {
-           ifstream ifile(filename.latin1());
+           ifstream ifile(filename.toLatin1().constData());
            if (!ifile)
            {
                QMessageBox::warning(
-                   this,"Firewall Builder", 
+                   this,"Firewall Builder",
                    tr("Could not open file %1").arg(filename),
                    "&Continue", QString::null, QString::null, 0, 1 );
                return;
            }
 
-           editor->clear();
+           m_dialog->editor->clear();
            char buf[1024];
            while (ifile.getline(buf,1024))
            {
-               editor->append( buf );
+               m_dialog->editor->append( buf );
            }
         }
     }
