@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: SimpleTextView.h,v 1.1 2005/12/17 20:59:45 vkurland Exp $
+  $Id: SimpleTextView.h 438 2008-08-02 20:33:06Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,18 +27,27 @@
 #ifndef __SIMPLETEXTVIEW_H_
 #define __SIMPLETEXTVIEW_H_
 
-#include "config.h"
-#include <simpletextview_q.h>
+#include "../../config.h"
+#include <ui_simpletextview_q.h>
+#include <QDialog>
 
 
 
-class SimpleTextView : public SimpleTextView_q
+class SimpleTextView : public QDialog
 {
     Q_OBJECT
  private:
  
  public:
-    SimpleTextView(QWidget *parent) : SimpleTextView_q(parent){};
+    Ui::SimpleTextView_q *m_dialog;
+     
+    SimpleTextView(QWidget *parent) : QDialog(parent)
+    {
+        m_dialog = new Ui::SimpleTextView_q;
+        m_dialog->setupUi(this);
+    };
+    
+    virtual ~SimpleTextView() { delete m_dialog; };
     virtual void setText(QString s);
     virtual void setName(QString s);
 
