@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland <vadim@fwbuilder.org>
 
-  $Id: StartTipDialog.cpp 2686 2010-03-08 01:13:19Z vadim $
+  $Id: StartTipDialog.cpp 2937 2010-05-26 19:10:07Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -32,6 +32,7 @@
 #include "FWBSettings.h"
 #include "FWWindow.h"
 #include "Help.h"
+#include "UserWorkflow.h"
 
 #include <QCheckBox>
 #include <QLocale>
@@ -103,6 +104,17 @@ StartTipDialog::~StartTipDialog()
     delete http_getter;
 };
 
+/*
+ * disconnect signal in case dialog is closed before http query completes.
+ * This does happen in unit tests and might happen on slow machines or
+ * slow internet connections
+ */
+void StartTipDialog::closeEvent(QCloseEvent*)
+{
+    disconnect(http_getter, SIGNAL(done(const QString&)),
+               this, SLOT(downloadComplete(const QString&)));
+}
+
 /*
  * Returns file name for a random tip
  */
