@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: TCPServiceDialog.cpp 952 2009-05-20 21:54:45Z vadim $
+  $Id: TCPServiceDialog.cpp 2341 2010-01-13 01:27:59Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -30,11 +30,14 @@
 
 #include "FWBTree.h"
 #include "TCPServiceDialog.h"
+#include "FWCmdChange.h"
 
 #include "ProjectPanel.h"
 #include "fwbuilder/Library.h"
 #include "fwbuilder/TCPService.h"
 
+#include <memory>
+
 #include <qlineedit.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
@@ -43,13 +46,13 @@
 #include <qpushbutton.h>
 #include <qmessagebox.h>
 #include <qlabel.h>
-#include "FWBSettings.h"
+#include <QUndoStack>
+
 
-#include "FWWindow.h"
 using namespace std;
 using namespace libfwbuilder;
 
-TCPServiceDialog::TCPServiceDialog(ProjectPanel *project, QWidget *parent) : QWidget(parent), m_project(project)
+TCPServiceDialog::TCPServiceDialog(QWidget *parent) : BaseObjectDialog(parent)
 {
     m_dialog = new Ui::TCPServiceDialog_q;
     m_dialog->setupUi(this);
@@ -164,106 +167,70 @@ void TCPServiceDialog::loadFWObject(FWObject *o)
     init=false;
 }
 
-void TCPServiceDialog::changed()
-{
-    //apply->setEnabled( true );
-    emit changed_sign();
-}
-
 void TCPServiceDialog::validate(bool *res)
 {
-    if (fwbdebug) qDebug("TCPServiceDialog::validate");
+    *res = true;
+    if (!validateName(this,obj,m_dialog->obj_name->text()))
+    {
+        *res = false;
+        return;
+    }
+}
 
-    *res=true;
 
-    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
-    if (!validateName(this,obj,m_dialog->obj_name->text())) { *res=false; return; }
+
+void TCPServiceDialog::applyChanges()
+{
+    std::auto_ptr<FWCmdChange> cmd( new FWCmdChange(m_project, obj));
+    FWObject* new_state = cmd->getNewState();
+
+    string oldname = obj->getName();
+    new_state->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
+    new_state->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
 
     // check port ranges (bug #1695481, range start must be <= range end)
+    // See #981  Do this check in applyChanges() rather than validate so we
+    // can update end of range input fields instead of signalling invalid
+    // configuration.
+
     int sps = m_dialog->ss->value();
     int spe = m_dialog->se->value();
     int dps = m_dialog->ds->value();
     int dpe = m_dialog->de->value();
 
-    if (sps > spe)
+    if (sps > spe) m_dialog->se->setValue( m_dialog->ss->value() );
+    if (dps > dpe) m_dialog->de->setValue( m_dialog->ds->value() );
+
+    spe = m_dialog->se->value();
+    dpe = m_dialog->de->value();
+
+    TCPUDPService::cast(new_state)->setSrcRangeStart(m_dialog->ss->value());
+    TCPUDPService::cast(new_state)->setSrcRangeEnd(m_dialog->se->value());
+    TCPUDPService::cast(new_state)->setDstRangeStart(m_dialog->ds->value());
+    TCPUDPService::cast(new_state)->setDstRangeEnd(m_dialog->de->value());
+
+    new_state->setBool("urg_flag_mask", m_dialog->urg_m->isChecked() );
+    new_state->setBool("ack_flag_mask", m_dialog->ack_m->isChecked() );
+    new_state->setBool("psh_flag_mask", m_dialog->psh_m->isChecked() );
+    new_state->setBool("rst_flag_mask", m_dialog->rst_m->isChecked() );
+    new_state->setBool("syn_flag_mask", m_dialog->syn_m->isChecked() );
+    new_state->setBool("fin_flag_mask", m_dialog->fin_m->isChecked() );
+
+    new_state->setBool("urg_flag",      m_dialog->urg_s->isChecked() );
+    new_state->setBool("ack_flag",      m_dialog->ack_s->isChecked() );
+    new_state->setBool("psh_flag",      m_dialog->psh_s->isChecked() );
+    new_state->setBool("rst_flag",      m_dialog->rst_s->isChecked() );
+    new_state->setBool("syn_flag",      m_dialog->syn_s->isChecked() );
+    new_state->setBool("fin_flag",      m_dialog->fin_s->isChecked() );
+
+    new_state->setBool("established",  m_dialog->established->isChecked());
+
+    if (!cmd->getOldState()->cmp(new_state, true))
     {
-        QMessageBox::warning(this, "Firewall Builder",
-          QObject::tr("Invalid range defined for the source port."),
-          QObject::tr("&Continue editing"), NULL, NULL, 0, 2 );
-        *res = false;
-        return;
+        if (obj->isReadOnly()) return;
+        m_project->undoStack->push(cmd.release());
     }
-    if (dps > dpe)
-    {
-        QMessageBox::warning(this, "Firewall Builder",
-          QObject::tr("Invalid range defined for the destination port."),
-          QObject::tr("&Continue editing"), NULL, NULL, 0, 2 );
-        *res = false;
-        return;
-    }
-}
-
-void TCPServiceDialog::isChanged(bool*)
-{
-    //*res=(!init && apply->isEnabled());
-}
-
-void TCPServiceDialog::libChanged()
-{
-    changed();
-}
-
-void TCPServiceDialog::applyChanges()
-{
-    string oldname=obj->getName();
-    obj->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
-    obj->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
-
-    if (m_dialog->ss->value()!=0 && m_dialog->se->value()==0) m_dialog->se->setValue( m_dialog->ss->value() );
-    if (m_dialog->ds->value()!=0 && m_dialog->de->value()==0) m_dialog->de->setValue( m_dialog->ds->value() );
-
-
-    TCPUDPService::cast(obj)->setSrcRangeStart(m_dialog->ss->value());
-    TCPUDPService::cast(obj)->setSrcRangeEnd(m_dialog->se->value());
-    TCPUDPService::cast(obj)->setDstRangeStart(m_dialog->ds->value());
-    TCPUDPService::cast(obj)->setDstRangeEnd(m_dialog->de->value());
-
-    obj->setBool("urg_flag_mask", m_dialog->urg_m->isChecked() );
-    obj->setBool("ack_flag_mask", m_dialog->ack_m->isChecked() );
-    obj->setBool("psh_flag_mask", m_dialog->psh_m->isChecked() );
-    obj->setBool("rst_flag_mask", m_dialog->rst_m->isChecked() );
-    obj->setBool("syn_flag_mask", m_dialog->syn_m->isChecked() );
-    obj->setBool("fin_flag_mask", m_dialog->fin_m->isChecked() );
-
-    obj->setBool("urg_flag",      m_dialog->urg_s->isChecked() );
-    obj->setBool("ack_flag",      m_dialog->ack_s->isChecked() );
-    obj->setBool("psh_flag",      m_dialog->psh_s->isChecked() );
-    obj->setBool("rst_flag",      m_dialog->rst_s->isChecked() );
-    obj->setBool("syn_flag",      m_dialog->syn_s->isChecked() );
-    obj->setBool("fin_flag",      m_dialog->fin_s->isChecked() );
-
-    obj->setBool("established",  m_dialog->established->isChecked());
-
-    mw->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
-
-    //apply->setEnabled( false );
-    mw->updateLastModifiedTimestampForAllFirewalls(obj);
-}
-
-void TCPServiceDialog::discardChanges()
-{
-    loadFWObject(obj);
-}
-
-
-/* ObjectEditor class connects its slot to this signal and does all
- * the verification for us, then accepts (or not) the event. So we do
- * nothing here and defer all the processing to ObjectEditor
- */
-void TCPServiceDialog::closeEvent(QCloseEvent *e)
-{
-    emit close_sign(e);
-
+    
 }
 
 void TCPServiceDialog::toggleEstablished()
