@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: TagServiceDialog.cpp 952 2009-05-20 21:54:45Z vadim $
+  $Id: TagServiceDialog.cpp 1932 2009-11-26 03:26:24Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -29,13 +29,15 @@
 
 #include "TagServiceDialog.h"
 #include "ProjectPanel.h"
-#include "FWWindow.h"
+#include "FWCmdChange.h"
 
 #include "fwbuilder/Library.h"
 #include "fwbuilder/TagService.h"
 #include "fwbuilder/Interface.h"
 #include "fwbuilder/FWException.h"
 
+#include <memory>
+
 #include <qlineedit.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
@@ -47,9 +49,9 @@
 #include <qpushbutton.h>
 #include <qapplication.h>
 #include <qcursor.h>
+#include <QUndoStack>
 
 #include <iostream>
-#include "FWBSettings.h"
 
 using namespace std;
 using namespace libfwbuilder;
@@ -59,7 +61,7 @@ TagServiceDialog::~TagServiceDialog()
     delete m_dialog;
 }
 
-TagServiceDialog::TagServiceDialog(ProjectPanel *project, QWidget *parent) : QWidget(parent), m_project(project)
+TagServiceDialog::TagServiceDialog(QWidget *parent) : BaseObjectDialog(parent)
 {
     m_dialog = new Ui::TagServiceDialog_q;
     m_dialog->setupUi(this);
@@ -101,59 +103,36 @@ void TagServiceDialog::loadFWObject(FWObject *o)
     init=false;
 }
 
-void TagServiceDialog::changed()
-{
-    //apply->setEnabled( true );
-    emit changed_sign();
-}
-
 void TagServiceDialog::validate(bool *res)
 {
     *res=true;
     TagService *s = dynamic_cast<TagService*>(obj);
     assert(s!=NULL);
 
-    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
     if (!validateName(this,obj,m_dialog->obj_name->text())) { *res=false; return; }
 }
 
-void TagServiceDialog::isChanged(bool*)
-{
-    //*res=(!init && apply->isEnabled());
-}
 
-void TagServiceDialog::libChanged()
-{
-    changed();
-}
 
 void TagServiceDialog::applyChanges()
 {
-    TagService *s = dynamic_cast<TagService*>(obj);
+    std::auto_ptr<FWCmdChange> cmd( new FWCmdChange(m_project, obj));
+    FWObject* new_state = cmd->getNewState();
+
+    TagService *s = dynamic_cast<TagService*>(new_state);
     assert(s!=NULL);
 
-    string oldname=obj->getName();
-    obj->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
-    obj->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
+    string oldname = obj->getName();
+    new_state->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
+    new_state->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
 
     s->setCode( m_dialog->tagcode->text().toLatin1().constData() );
 
-    mw->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
-
-    //apply->setEnabled( false );
-    mw->updateLastModifiedTimestampForAllFirewalls(obj);
-}
-
-void TagServiceDialog::discardChanges()
-{
-    loadFWObject(obj);
-}
-
-
-void TagServiceDialog::closeEvent(QCloseEvent *e)
-{
-    if (fwbdebug)
-        qDebug("TagServiceDialog::closeEvent  got close event: %p",e);
-    emit close_sign(e);
+    if (!cmd->getOldState()->cmp(new_state, true))
+    {
+        if (obj->isReadOnly()) return;
+        m_project->undoStack->push(cmd.release());
+    }
+    
 }
 
