@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: TimeDialog.cpp 952 2009-05-20 21:54:45Z vadim $
+  $Id: TimeDialog.cpp 2148 2009-12-15 21:02:48Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -33,10 +33,13 @@
 #include "ProjectPanel.h"
 
 #include "FWWindow.h"
+#include "FWCmdChange.h"
 
 #include "fwbuilder/Library.h"
 #include "fwbuilder/Interval.h"
 
+#include <memory>
+
 #include <qlineedit.h>
 #include <qtextedit.h>
 #include <qcombobox.h>
@@ -45,6 +48,8 @@
 #include <qlabel.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
+#include <QUndoStack>
+#include <QDebug>
 
 #include <iostream>
 #include "FWBSettings.h"
@@ -52,7 +57,7 @@
 using namespace libfwbuilder;
 using namespace std;
 
-TimeDialog::TimeDialog(ProjectPanel *project, QWidget *parent) : QWidget(parent), m_project(project)
+TimeDialog::TimeDialog(QWidget *parent) : BaseObjectDialog(parent)
 {
     m_dialog = new Ui::TimeDialog_q;
     m_dialog->setupUi(this);
@@ -89,30 +94,6 @@ void TimeDialog::loadFWObject(FWObject *o)
     m_dialog->obj_name->setText( QString::fromUtf8(s->getName().c_str()) );
     m_dialog->comment->setPlainText( QString::fromUtf8(s->getComment().c_str()) );
 
-    /*switch (m_dialog->startDate->order())
-    {
-    case QDateEdit::MDY:
-        m_dialog->startDateLabel->setText( tr("(M/D/Y)") );
-        m_dialog->endDateLabel->setText(   tr("(M/D/Y)") );
-        break;
-
-    case QDateEdit::DMY:
-        m_dialog->startDateLabel->setText( tr("(D/M/Y)") );
-        m_dialog->endDateLabel->setText(   tr("(D/M/Y)") );
-        break;
-
-    case QDateEdit::YMD:
-        m_dialog->startDateLabel->setText( tr("(Y/M/D)") );
-        m_dialog->endDateLabel->setText(   tr("(Y/M/D)") );
-        break;
-
-    case QDateEdit::YDM:
-        m_dialog->startDateLabel->setText( tr("(Y/D/M)") );
-        m_dialog->endDateLabel->setText(   tr("(Y/D/M)") );
-        break;
-
-    }*/
-
     int fromH = obj->getInt("from_hour");
     int fromM = obj->getInt("from_minute");
     if (fromH<0) fromH=0;
@@ -161,6 +142,17 @@ void TimeDialog::loadFWObject(FWObject *o)
     m_dialog->endDate->setDate( (using_end_date)?QDate( y, m, d ):QDate() );
     m_dialog->useEndDate->setChecked(using_end_date);
 
+    // See #893 No need to show object attributes if the object is "Any"
+    if (obj->getId() == FWObjectDatabase::ANY_INTERVAL_ID)
+    {
+        m_dialog->object_attributes_1->hide();
+        m_dialog->object_attributes_2->hide();
+    } else
+    {
+        m_dialog->object_attributes_1->show();
+        m_dialog->object_attributes_2->show();
+    }
+
     setDisabledPalette(m_dialog->obj_name);
     setDisabledPalette(m_dialog->comment);
     setDisabledPalette(m_dialog->startTime);
@@ -196,12 +188,6 @@ void TimeDialog::enableAllWidgets()
 
 }
 
-void TimeDialog::changed()
-{
-    //apply->setEnabled( true );
-    emit changed_sign();
-}
-
 void TimeDialog::useStartOrEndDate()
 {
     enableAllWidgets();
@@ -213,53 +199,45 @@ void TimeDialog::validate(bool *res)
     *res=true;
 }
 
-void TimeDialog::isChanged(bool*)
-{
-    //*res=(!init && apply->isEnabled());
-}
-
-void TimeDialog::libChanged()
-{
-    changed();
-}
-
 void TimeDialog::applyChanges()
 {
-    if (!isTreeReadWrite(this,obj)) return;
-    Interval *s = dynamic_cast<Interval*>(obj);
-    assert(s!=NULL);
 
-    string oldname=obj->getName();
-    obj->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
-    obj->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
+    std::auto_ptr<FWCmdChange> cmd( new FWCmdChange(m_project, obj));
+    FWObject* new_state = cmd->getNewState();
+
+    Interval *interval = dynamic_cast<Interval*>(new_state);
+    assert(interval!=NULL);
+
+    new_state->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
+    new_state->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
 
     if (m_dialog->useStartDate->isChecked())
     {
-        obj->setInt( "from_day"   ,      m_dialog->startDate->date().day()   );
-        obj->setInt( "from_month" ,      m_dialog->startDate->date().month() );
-        obj->setInt( "from_year"  ,      m_dialog->startDate->date().year()  );
+        new_state->setInt( "from_day"   ,      m_dialog->startDate->date().day()   );
+        new_state->setInt( "from_month" ,      m_dialog->startDate->date().month() );
+        new_state->setInt( "from_year"  ,      m_dialog->startDate->date().year()  );
     } else
     {
-        obj->setInt( "from_day"   ,      -1 );
-        obj->setInt( "from_month" ,      -1 );
-        obj->setInt( "from_year"  ,      -1 );
+        new_state->setInt( "from_day"   ,      -1 );
+        new_state->setInt( "from_month" ,      -1 );
+        new_state->setInt( "from_year"  ,      -1 );
     }
-    obj->setInt( "from_minute"   ,   m_dialog->startTime->time().minute());
-    obj->setInt( "from_hour"  ,      m_dialog->startTime->time().hour()  );
+    new_state->setInt( "from_minute"   ,   m_dialog->startTime->time().minute());
+    new_state->setInt( "from_hour"  ,      m_dialog->startTime->time().hour()  );
 
     if (m_dialog->useEndDate->isChecked())
     {
-        obj->setInt( "to_day"   ,        m_dialog->endDate->date().day()     );
-        obj->setInt( "to_month" ,        m_dialog->endDate->date().month()   );
-        obj->setInt( "to_year"  ,        m_dialog->endDate->date().year()    );
+        new_state->setInt( "to_day"   ,        m_dialog->endDate->date().day()     );
+        new_state->setInt( "to_month" ,        m_dialog->endDate->date().month()   );
+        new_state->setInt( "to_year"  ,        m_dialog->endDate->date().year()    );
     } else
     {
-        obj->setInt( "to_day"   ,      -1 );
-        obj->setInt( "to_month" ,      -1 );
-        obj->setInt( "to_year"  ,      -1 );
+        new_state->setInt( "to_day"   ,      -1 );
+        new_state->setInt( "to_month" ,      -1 );
+        new_state->setInt( "to_year"  ,      -1 );
     }
-    obj->setInt( "to_minute"   ,     m_dialog->endTime->time().minute()  );
-    obj->setInt( "to_hour"  ,        m_dialog->endTime->time().hour()    );
+    new_state->setInt( "to_minute"   ,     m_dialog->endTime->time().minute()  );
+    new_state->setInt( "to_hour"  ,        m_dialog->endTime->time().hour()    );
 
     QStringList weekDays ;
     if (m_dialog->cbStart7_2->checkState ()==Qt::Checked)
@@ -277,26 +255,12 @@ void TimeDialog::applyChanges()
     if (m_dialog->cbStart6_2->checkState ()==Qt::Checked)
         weekDays.append("6");
 
-    s->setDaysOfWeek(weekDays.join(",").toAscii().data());
-
-    mw->updateObjName(obj, QString::fromUtf8(oldname.c_str()));
-
-    //apply->setEnabled( false );
-    mw->updateLastModifiedTimestampForAllFirewalls(obj);
-}
-
-void TimeDialog::discardChanges()
-{
-    loadFWObject(obj);
-}
-
-/* ObjectEditor class connects its slot to this signal and does all
- * the verification for us, then accepts (or not) the event. So we do
- * nothing here and defer all the processing to ObjectEditor
- */
-void TimeDialog::closeEvent(QCloseEvent *e)
-{
-    emit close_sign(e);
+    interval->setDaysOfWeek(weekDays.join(",").toAscii().data());
 
+    if (!cmd->getOldState()->cmp(new_state, true))
+    {
+        if (obj->isReadOnly()) return;
+        m_project->undoStack->push(cmd.release());
+    }
 }
 
