@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: debugDialog.cpp 540 2008-09-15 06:04:55Z vadim $
+  $Id: debugDialog.cpp 2175 2009-12-17 01:26:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -25,13 +25,14 @@
 
 
 #include "../../config.h"
+
 #include "global.h"
 #include "utils.h"
 #include "VERSION.h"
-#include "build_num"
 
 #include "debugDialog.h"
 #include "RCS.h"
+#include "ProjectPanel.h"
 #include "FWWindow.h"
 
 #include <qtextbrowser.h>
@@ -48,8 +49,7 @@
 using namespace std;
 
 
-debugDialog::debugDialog(QWidget *parent) :
-    QDialog(parent, Qt::CustomizeWindowHint|Qt::WindowSystemMenuHint)
+debugDialog::debugDialog(QWidget *parent) : QDialog(parent)
 {
     m_dialog = new Ui::debugDialog_q;
     m_dialog->setupUi(this);
@@ -70,19 +70,15 @@ debugDialog::debugDialog(QWidget *parent) :
     m_dialog->debugText->append( QString("appRootDir: %1")
         .arg(appRootDir.c_str()) );
     m_dialog->debugText->append( "\n" );
-    m_dialog->debugText->append( QString("sysfname: %1")
-        .arg(sysfname.c_str()) );
-    m_dialog->debugText->append( QString("tempfname: %1")
-        .arg(tempfname.c_str()) );
+    m_dialog->debugText->append( QString("sysfname: %1").arg(sysfname.c_str()));
+    m_dialog->debugText->append( QString("tempfname: %1").arg(tempfname.c_str()));
+    m_dialog->debugText->append( QString("user name: %1").arg(user_name) );
     m_dialog->debugText->append( "\n" );
-    m_dialog->debugText->append( QString("Path to rcs: %1")
-        .arg(RCS_FILE_NAME) );
-    m_dialog->debugText->append( QString("Path to rcsdiff: %1")
-        .arg(RCSDIFF_FILE_NAME) );
-    m_dialog->debugText->append( QString("Path to rlog: %1")
-        .arg(RLOG_FILE_NAME) );
-    m_dialog->debugText->append( QString("Path to ci: %1").arg(CI_FILE_NAME) );
-    m_dialog->debugText->append( QString("Path to co: %1").arg(CO_FILE_NAME) );
+    m_dialog->debugText->append( QString("Path to rcs: %1").arg(RCS_FILE_NAME));
+    m_dialog->debugText->append( QString("Path to rcsdiff: %1").arg(RCSDIFF_FILE_NAME));
+    m_dialog->debugText->append( QString("Path to rlog: %1").arg(RLOG_FILE_NAME));
+    m_dialog->debugText->append( QString("Path to ci: %1").arg(CI_FILE_NAME));
+    m_dialog->debugText->append( QString("Path to co: %1").arg(CO_FILE_NAME));
     m_dialog->debugText->append( "\n" );
 
     m_dialog->debugText->append( "RCS timezone setting:" );
@@ -98,8 +94,7 @@ debugDialog::debugDialog(QWidget *parent) :
     m_dialog->debugText->append( QString("Versions:") );
     m_dialog->debugText->append( QString("  Firewall Builder %1")
         .arg(VERSION) );
-    m_dialog->debugText->append( QString("  Revision %1  Build %2")
-        .arg(RELEASE_NUM).arg(BUILD_NUM) );
+    m_dialog->debugText->append( QString("  Build %2").arg(build_num));
     m_dialog->debugText->append( QString("  Using libfwbuilder %1")
         .arg( libfwbuilder::Constants::getLibraryVersion().c_str() ) );
 
@@ -107,25 +102,26 @@ debugDialog::debugDialog(QWidget *parent) :
         .arg(libfwbuilder::Constants::getDataFormatVersion().c_str() ) );
 
 
-    m_dialog->debugText->append( QString("  Built with QT %1")
-        .arg(QT_VERSION_STR) );
+    m_dialog->debugText->append( QString("  Built with QT %1").arg(QT_VERSION_STR));
     m_dialog->debugText->append( QString("  Using QT %1").arg( qVersion() ) );
     m_dialog->debugText->append( QString("  Built with libxml2 %1")
         .arg(LIBXML_DOTTED_VERSION) );
 #if !defined(Q_OS_MACX)
-    m_dialog->debugText->append( QString("  Using libxml2 %1")
-        .arg(xmlParserVersion) );
+    m_dialog->debugText->append( QString("  Using libxml2 %1").arg(xmlParserVersion));
 #endif
     m_dialog->debugText->append( "\n" );
 
     m_dialog->debugText->append( QString("FWObjectDatabase index statistics:"));
 
-    int s,h,m;
-    mw->db()->getIndexStats(s,h,m);
-    m_dialog->debugText->append( QString("  index size: %1 records").arg(s) );
-    m_dialog->debugText->append( QString("  hits: %1").arg(h) );
-    m_dialog->debugText->append( QString("  misses: %1").arg(m) );
-    m_dialog->debugText->append( "\n" );
+    if (mw->activeProject())
+    {
+        int s,h,m;
+        mw->activeProject()->db()->getIndexStats(s,h,m);
+        m_dialog->debugText->append( QString("  index size: %1 records").arg(s) );
+        m_dialog->debugText->append( QString("  hits: %1").arg(h) );
+        m_dialog->debugText->append( QString("  misses: %1").arg(m) );
+        m_dialog->debugText->append( "\n" );
+    }
 
     m_dialog->debugText->append( QString("QPixmapCache limit: %1 kb")
         .arg(QPixmapCache::cacheLimit()));
