@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: filePropDialog.cpp 653 2008-11-20 06:22:06Z vadim $
+  $Id: filePropDialog.cpp 1487 2009-09-23 17:00:48Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -32,6 +32,7 @@
 
 #include "filePropDialog.h"
 #include "FWWindow.h"
+#include "ProjectPanel.h"
 #include "PrintingProgressDialog.h"
 #include "printerStream.h"
 
@@ -70,7 +71,7 @@ filePropDialog::filePropDialog(QWidget *parent, RCS *rcs) :
     if (rcs->isRO()) m_dialog->fileRO->setText( tr("Opened read-only") );
     else             m_dialog->fileRO->setText("");
 
-    time_t lm = mw->db()->getTimeLastModified();
+    time_t lm = mw->activeProject()->db()->getTimeLastModified();
     QString s = ctime( &lm );
     s.truncate( s.length()-1 );   // chop newline
 
