@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: findDialog.cpp 353 2008-07-13 01:26:39Z vadim $
+  $Id: findDialog.cpp 1845 2009-11-20 23:29:37Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -32,6 +32,8 @@
 #include "ProjectPanel.h"
 #include "FWBTree.h"
 #include "FWBSettings.h"
+#include "FWWindow.h"
+#include "events.h"
 
 #include "fwbuilder/FWObjectDatabase.h"
 #include "fwbuilder/FWReference.h"
@@ -289,10 +291,14 @@ loop:
     }
 
     if (Group::cast(o->getParent())!=NULL &&
-        !m_project->isSystem(o->getParent()))
+        !FWBTree().isSystem(o->getParent()))
     {
-        m_project->openObject( o->getParent() );
-        m_project->editObject( o->getParent() );
+        QCoreApplication::postEvent(
+            mw, new showObjectInTreeEvent(m_project->getFileName(),
+                                          o->getParent()->getId()));
+        QCoreApplication::postEvent(
+            mw, new openObjectInEditorEvent(m_project->getFileName(),
+                                            o->getParent()->getId()));
         QTimer::singleShot(200, this, SLOT(makeActive()) );
         return;
     }
@@ -306,9 +312,12 @@ loop:
                o->getTypeName().c_str());
     }
 
-    m_project->openObject( o );
-    m_project->editObject( o );
-
+    QCoreApplication::postEvent(
+        mw, new showObjectInTreeEvent(m_project->getFileName(),
+                                      o->getId()));
+    QCoreApplication::postEvent(
+        mw, new openObjectInEditorEvent(m_project->getFileName(),
+                                        o->getId()));
     QTimer::singleShot(200, this, SLOT(makeActive()) );
 }
 
