@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: freebsdAdvancedDialog.cpp 390 2008-07-18 22:56:50Z vadim $
+  $Id: freebsdAdvancedDialog.cpp 1932 2009-11-26 03:26:24Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,10 +28,13 @@
 #include "platforms.h"
 
 #include "freebsdAdvancedDialog.h"
+#include "FWCmdChange.h"
 
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Management.h"
 
+#include <memory>
+
 #include <qcheckbox.h>
 #include <qspinbox.h>
 #include <qcombobox.h>
@@ -93,9 +96,12 @@ freebsdAdvancedDialog::freebsdAdvancedDialog(QWidget *parent,FWObject *o)
                         fwopt, "freebsd_path_ipf");
     data.registerOption(m_dialog->freebsd_path_ipfw,
                         fwopt, "freebsd_path_ipfw");
-
+    data.registerOption(m_dialog->freebsd_path_pfctl,
+                        fwopt, "freebsd_path_pfctl");
 
     data.loadAll();
+
+    m_dialog->tabWidget->setCurrentIndex(0);
 }
 
 /*
@@ -103,15 +109,19 @@ freebsdAdvancedDialog::freebsdAdvancedDialog(QWidget *parent,FWObject *o)
  */
 void freebsdAdvancedDialog::accept()
 {
-    FWOptions *fwopt=(Firewall::cast(obj))->getOptionsObject();
+    ProjectPanel *project = mw->activeProject();
+    std::auto_ptr<FWCmdChange> cmd( new FWCmdChange(project, obj));
+
+    // new_state  is a copy of the fw object
+    FWObject* new_state = cmd->getNewState();
+    FWOptions *fwopt=(Firewall::cast(new_state))->getOptionsObject();
     assert(fwopt!=NULL);
 
-    Management *mgmt=(Firewall::cast(obj))->getManagementObject();
-    assert(mgmt!=NULL);
-
-    data.saveAll();
-    mw->updateLastModifiedTimestampForAllFirewalls(obj);
+    data.saveAll(fwopt);
 
+    if (!cmd->getOldState()->cmp(new_state, true))
+        project->undoStack->push(cmd.release());
+    
     QDialog::accept();
 }
 
