@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instConf.h 585 2008-10-09 05:08:41Z vadim $
+  $Id: instConf.h 2249 2009-12-23 01:02:51Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -53,7 +53,8 @@ class instConf {
     bool      cancelRollbackIfSuccess;
     bool      saveStandby;
     bool      batchInstall;
-    
+    bool      useSCPForCisco;
+
     QString   pgm;
     QString   wdir;
     QString   diff_pgm;
@@ -71,7 +72,8 @@ class instConf {
     libfwbuilder::Firewall  *fwobj;
 
     QString   fwbfile;
-    QString   conffile;
+    QString   script;
+    QString   remote_script;
     QString   backup_file;
     QString   diff_file;
 
