@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog.cpp 2669 2010-03-05 20:18:22Z vadim $
+  $Id: instDialog.cpp 3082 2010-07-14 23:22:49Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -38,6 +38,7 @@
 #include "FWWindow.h"
 #include "instOptionsDialog.h"
 #include "instBatchOptionsDialog.h"
+#include "FirewallCodeViewer.h"
 
 #include <qcheckbox.h>
 #include <qlineedit.h>
@@ -63,6 +64,7 @@
 #include <QDateTime>
 #include <QtDebug>
 #include <QTime>
+#include <QWidget>
 
 #include "fwbuilder/Resources.h"
 #include "fwbuilder/FWObjectDatabase.h"
@@ -86,75 +88,7 @@ using namespace libfwbuilder;
 using namespace fwcompiler;
 
 
-instDialog::instDialog(QWidget *p,
-                       bool install,
-                       bool showOnlySelected,
-                       set<Firewall*> fws) : QDialog(p)
-{
-    init(p);
-
-    reqFirewalls = fws;
-    onlySelected = showOnlySelected;
-    compile_only = ! install;
-
-    if (!onlySelected)
-        findFirewalls();
-    else
-    {
-        firewalls.clear();
-        clusters.clear();
-        foreach(Firewall* fw, fws)
-        {
-            if (Cluster::isA(fw))
-                clusters.push_back(Cluster::cast(fw));
-            else
-                firewalls.push_back(fw);
-        }
-        firewalls.sort(FWObjectNameCmpPredicate());
-        clusters.sort(FWObjectNameCmpPredicate());
-        m_dialog->saveMCLogButton->setEnabled(true);
-    }
-
-    if (fwbdebug)
-        qDebug() << "instDialog::instDialog"
-                 << "firewalls.size()=" << firewalls.size()
-                 << "clusters.size()=" << clusters.size();
-
-    if (firewalls.size()==0 && clusters.size()==0)
-    {
-        setTitle( pageCount()-1, tr("There are no firewalls to process.") );
-        for (int i=0;i<pageCount()-1;i++)
-        {
-            setAppropriate(i, false);
-        }
-        showPage(pageCount()-1);
-        return;
-    }
-
-    if ((firewalls.size() + clusters.size()) == 1)
-        m_dialog->batchInstall->setEnabled(false);
-
-    creatingTable = false;
-
-    m_dialog->warning_space->hide();
-
-    m_dialog->selectTable->setFocus();
-
-    m_dialog->selectInfoLabel->setText(
-        tr("<p align=\"center\"><b><font size=\"+2\">Select firewalls to compile.</font></b></p>"));
-
-    if (compile_only)
-    {
-        m_dialog->batchInstFlagFrame->hide();
-        setAppropriate(2, false);
-        m_dialog->selectTable->hideColumn(INSTALL_CHECKBOX_COLUMN);
-    }
-    showPage(0);
-
-    m_dialog->detailMCframe->show();
-}
-
-void instDialog::init(QWidget* p)
+instDialog::instDialog(QWidget *p) : QDialog(p)
 {
     connect(this, SIGNAL(activateRule(ProjectPanel*, QString, QString, int)),
             p, SLOT(activateRule(ProjectPanel*, QString, QString, int)));
@@ -164,7 +98,7 @@ void instDialog::init(QWidget* p)
 
     batch_inst_opt_dlg = NULL;
 
-    project = mw->activeProject();
+    //project = mw->activeProject();
 
     setControlWidgets(this,
                       m_dialog->stackedWidget,
@@ -176,14 +110,6 @@ void instDialog::init(QWidget* p)
 
     setWindowFlags(Qt::Dialog | Qt::WindowSystemMenuHint);
 
-    installer = NULL;
-    finished = false;
-
-    page_1_op = INST_DLG_COMPILE;
-    state = NONE;
-
-    rejectDialogFlag = false;
-
     list<string> err_re;
     BaseCompiler::errorRegExp(&err_re);
     err_re.push_back("(Abnormal[^\n]*)");
@@ -201,8 +127,7 @@ void instDialog::init(QWidget* p)
     }
 
 
-    currentLog = m_dialog->procLogDisplay;
-    QTextCursor cursor(currentLog->textCursor());
+    QTextCursor cursor(m_dialog->procLogDisplay->textCursor());
     normal_format = cursor.charFormat();
     error_format = normal_format;
     error_format.setForeground(QBrush(Qt::red));
@@ -221,7 +146,7 @@ void instDialog::init(QWidget* p)
 
     currentSaveButton = m_dialog->saveMCLogButton;
     currentSaveButton->setEnabled(true);
-    currentStopButton = m_dialog->controlMCButton;
+    currentStopButton = m_dialog->stopButton;
     currentProgressBar = m_dialog->compProgress;
     currentFirewallsBar = m_dialog->compFirewallProgress;
     currentLabel = m_dialog->infoMCLabel;
@@ -236,11 +161,127 @@ void instDialog::init(QWidget* p)
     proc.setProcessChannelMode(QProcess::MergedChannels);
 
     m_dialog->fwWorkList->setSortingEnabled(true);
+}
+
+/*
+ * list fws is empty when user hits main toolbar button Compile or
+ * Install or uses main menu Rules/Compile or Rules/Install. This list
+ * has firewall objects to be compiled/installed when user uses
+ * "compile-this" or "install-this" button or context menu items
+ * "Compile" or "Install".
+ */
+void instDialog::show(ProjectPanel *proj,
+                      bool install,
+                      bool onlySelected,
+                      std::set<Firewall*> fws)
+{
+    canceledAll = false;
+    if (isVisible()) return;
+    lastPage = -1;
+    installer = NULL;
+    finished = false;
+    page_1_op = INST_DLG_COMPILE;
+    compile_complete = false;
+    rejectDialogFlag = false;
+
+    m_dialog->selectTable->clear();
+    this->project = proj;
+
+    compile_only = ! install;
+
+    m_dialog->warning_space->hide();
+    m_dialog->procLogDisplay->clear();
+
+    firewalls.clear();
+    clusters.clear();
+    compile_fw_list.clear();
+    install_fw_list.clear();
 
     for (int page=0; page < pageCount(); page++)
         setFinishEnabled(page, false);
 
-    lastPage=-1;
+    disableStopButton();
+
+    if (!onlySelected)
+    {
+        findFirewalls();
+    }
+    else
+    {
+        firewalls.clear();
+        clusters.clear();
+        foreach(Firewall* fw, fws)
+        {
+            if (Cluster::isA(fw))
+                clusters.push_back(Cluster::cast(fw));
+            else
+                firewalls.push_back(fw);
+        }
+        firewalls.sort(FWObjectNameCmpPredicate());
+        clusters.sort(FWObjectNameCmpPredicate());
+        m_dialog->saveMCLogButton->setEnabled(true);
+    }
+
+    if (fwbdebug)
+        qDebug() << "instDialog::show"
+                 << "firewalls.size()=" << firewalls.size()
+                 << "clusters.size()=" << clusters.size()
+                 << "install=" << install;
+
+    if (firewalls.size()==0 && clusters.size()==0)
+    {
+        setTitle(0, tr("There are no firewalls to process."));
+        for (int i=0; i<pageCount(); i++)
+        {
+            setAppropriate(i, false);
+        }
+        showPage(CHOOSE_OBJECTS);
+        return;
+    }
+
+    m_dialog->batchInstall->setEnabled(false);
+
+    if (firewalls.size() > 1)
+        m_dialog->batchInstall->setEnabled(true);
+
+    if (clusters.size() >= 1)  // even one cluster enables batch install btn
+        m_dialog->batchInstall->setEnabled(true);
+
+    if (firewalls.size() == 1 && clusters.size() == 0)
+        m_dialog->selectAllNoneFrame->hide();
+    else
+        m_dialog->selectAllNoneFrame->show();
+
+    m_dialog->batchInstall->setChecked(false);
+
+    creatingTable = false;
+
+    m_dialog->selectTable->setFocus();
+
+    m_dialog->selectInfoLabel->setText(
+        QString("<p align=\"center\"><b><font size=\"+2\">%1</font></b></p>")
+        .arg(tr("Select firewalls to compile.")));
+
+    if (compile_only)
+    {
+        m_dialog->batchInstFlagFrame->hide();
+        setAppropriate(2, false);
+        m_dialog->selectTable->hideColumn(INSTALL_CHECKBOX_COLUMN);
+    } else
+    {
+        m_dialog->batchInstFlagFrame->show();
+        setAppropriate(2, true);
+        m_dialog->selectTable->showColumn(INSTALL_CHECKBOX_COLUMN);
+    }
+
+    m_dialog->detailMCframe->show();
+    this->setVisible(true);
+
+    // we just started, there is nothing to inspect in the workflow of
+    // this wizard yet. This button will be enabled when compile phase is complete
+    m_dialog->inspectGeneratedFiles->setEnabled(compile_complete);
+
+    showPage(CHOOSE_OBJECTS);
 }
 
 instDialog::~instDialog()
@@ -259,6 +300,8 @@ void instDialog::mainLoopCompile()
 {
     if (finished) return;
 
+    enableStopButton();
+
     // first compile all
     if (compile_fw_list.size())
     {
@@ -274,18 +317,25 @@ void instDialog::mainLoopCompile()
         // that we "uncheck" "install" checkboxes in the first page of
         // the wizard on compile failure, so we need to rebuild install_fw_list
         // here.
-        state = COMPILE_DONE;
         fillInstallOpList();
+        disableStopButton();
 
         if (compile_only)
         {
+            compile_complete = true;
             finished = true;
             setFinishEnabled(currentPage(), true);
+
+            QStringList files;
+            int n = findFilesToInspect(files);
+            m_dialog->inspectGeneratedFiles->setEnabled(n != 0);
         } else
         {
-            page_1_op = INST_DLG_INSTALL;
-            setNextEnabled(1, true);
-            setFinishEnabled(currentPage(), false);
+            compile_complete = true;
+            showPage(COMPILE_INSTALL);
+//             setNextEnabled(currentPage(), true);
+//             setFinishEnabled(currentPage(), false);
+//             m_dialog->inspectGeneratedFiles->setEnabled(compile_complete);
         }
     }
 }
@@ -298,7 +348,9 @@ void instDialog::mainLoopInstall()
 
     if (finished) return;
 
-    if (install_fw_list.size())
+    enableStopButton();
+
+    if (install_fw_list.size() && !canceledAll)
     {
         Firewall *fw = install_fw_list.front();
 
@@ -312,13 +364,21 @@ void instDialog::mainLoopInstall()
         }
 
         install_fw_list.pop_front();
-        runInstaller(fw);
+        runInstaller(fw, install_fw_list.size()>0);
         return;
     }
+    if (canceledAll)
+    {
+        foreach(Firewall *fw, install_fw_list)
+        {
+            this->opCancelled(fw);
+        }
+        install_fw_list.clear();
+    }
 
-    state = INSTALL_DONE;
     finished = true;
     setFinishEnabled(currentPage(), true);
+    disableStopButton();
 }
 
 // ========================================================================
@@ -333,69 +393,86 @@ void instDialog::showPage(const int page)
         m_dialog->batchInstFlagFrame->hide();
     }
 
-    FakeWizard::showPage(page);
+    QStringList tmp;
+    m_dialog->inspectGeneratedFiles->setEnabled(
+        compile_complete && page_1_op == INST_DLG_COMPILE && findFilesToInspect(tmp));
 
-    if (fwbdebug && reqFirewalls.empty())
-        qDebug() << "instDialog::showPage reqFirewalls is empty";
+    if (fwbdebug)
+        qDebug() << "instDialog::showPage  page "
+                 << lastPage << "--->" << page << "page_1_op=" << page_1_op;
+
+    FakeWizard::showPage(page);
 
     int p = page;
 
-    if (fwbdebug)
-        qDebug() << QString("State %1  page_1_op %2  page %3 ---> %4")
-            .arg(state).arg(page_1_op).arg(lastPage).arg(page);
-
-    if (p==2)
+    switch (page)
     {
-        showPage(1);
-        return;
-    }
-
-    switch (p)
-    {
-    case 0: // select firewalls for compiling and installing
+    case CHOOSE_OBJECTS: // select firewalls for compiling and installing
     {
+        // if user returned to this page from "compile" page, assume they
+        // want to recompile
+        finished = false;
+        compile_complete = false;
+        fillCompileSelectList();
+        setAppropriate(1, tableHasCheckedItems());
+        setNextEnabled(page, tableHasCheckedItems());
         m_dialog->selectTable->setFocus();
-        if (lastPage<0) fillCompileSelectList();
-        setNextEnabled(0, tableHasCheckedItems());
         break;
     }
 
-    case 1: // compile and install firewalls
+    case COMPILE_INSTALL:
     {
-        setBackEnabled(1, false);
-        setNextEnabled(1, false);
+        // compile, install firewalls and inspect files, depending on
+        // the value of page_1_op
+
+        setNextEnabled(page, false);
+        setBackEnabled(page, false);
 
         fillCompileOpList();
-        
-        fillInstallOpList(); // fill install_fw_list 
+        fillInstallOpList(); // fill install_fw_list
+
+        if (compile_fw_list.size()==0 && install_fw_list.size()==0)
+        {
+            showPage(CHOOSE_OBJECTS);
+            return;
+        }
+
+        if (compile_fw_list.size()==0) page_1_op = INST_DLG_INSTALL;
+
+        m_dialog->stackedWidget->widget(1)->layout()->removeWidget(m_dialog->logFrame);
+        m_dialog->stackedWidget->widget(1)->layout()->addWidget(m_dialog->firewallListFrame);
+        m_dialog->stackedWidget->widget(1)->layout()->addWidget(m_dialog->logFrame);
 
         // Page 1 of the wizard does both compile and install
-        // controlled by flag page_1_op
+        // controlled by flag page_1_op. May be it would be less hacky if we
+        // used sepaarte page for installs, but that page would look exactly
+        // like the page for compile
         switch (page_1_op)
         {
         case INST_DLG_COMPILE:
         {
-            if (fwbdebug) qDebug("Page 1 compile");
-            if (compile_fw_list.size()==0)
+            if (fwbdebug) qDebug() << "Page 1 compile"
+                                   << "compile_complete=" << compile_complete;
+
+            // run full compile cycle only if we haven't done it before
+            // User may click Back on the "Inspect" page, this should return
+            // them to the "compile" page but not trigger full recompile.
+            // Flag compile_complete is set in instDialog::mainLoopCompile()
+            if (compile_complete)
             {
-                if (install_fw_list.size()==0)
-                {
-                    showPage(0);
-                    return;
-                }
-                page_1_op = INST_DLG_INSTALL;
-                showPage(1);
-                return;
+                setNextEnabled(page, true);
+                setBackEnabled(page, true);
+            } else
+            {
+                mw->fileSave();
+                currentFirewallsBar->reset();
+                currentFirewallsBar->setMaximum(compile_list_initial_size);
+                m_dialog->procLogDisplay->clear();
+                fillCompileUIList();
+                qApp->processEvents();
+                mainLoopCompile();
             }
-
-            mw->fileSave();
-
-            currentFirewallsBar->reset();
-            currentFirewallsBar->setMaximum(compile_list_initial_size);
-            currentLog->clear();
-            fillCompileUIList();
-            qApp->processEvents();
-            mainLoopCompile();
+            setBackEnabled(page, true);
             break;
         }
 
@@ -406,16 +483,70 @@ void instDialog::showPage(const int page)
             {
                 currentFirewallsBar->reset();
                 currentFirewallsBar->setMaximum(install_list_initial_size);
-                currentLog->clear();
+                m_dialog->procLogDisplay->clear();
                 fillInstallUIList();
                 qApp->processEvents();
                 mainLoopInstall();
-                break;
             }
+            setBackEnabled(page, false);
+            break;
         }
+
+        case INST_DLG_INSPECT:
+        {
+            QStringList files;
+            int no_files = findFilesToInspect(files);
+
+            if (no_files == 0)
+            {
+                QMessageBox::critical(this, tr("Error"), tr("No files were generated, there is nothing to show."));
+                return;
+            }
+
+            if (m_dialog->stackedWidget->count() == 3 )
+                m_dialog->stackedWidget->removeWidget(m_dialog->stackedWidget->widget(2));
+
+            FirewallCodeViewer *viewer;
+            if (firewalls.size() == 1)
+                viewer = new FirewallCodeViewer(
+                    files,
+                    QString("<b>") + firewalls.front()->getName().c_str() + "</b>",
+                    this);
+            else
+                viewer = new FirewallCodeViewer(
+                    files, tr("<b>Multiple firewalls</b>"), this);
+            viewer->hideCloseButton();
+
+            viewer->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding);
+            QWidget *container = new QWidget(this);
+            container->setObjectName("codeViewer");
+            QHBoxLayout *layout = new QHBoxLayout(container);
+            layout->setContentsMargins(0,0,0,0);
+            layout->setSpacing(6);
+            QFrame *frame = new QFrame(container);
+            frame->setLayout(new QHBoxLayout());
+            frame->layout()->addWidget(viewer);
+            frame->setFrameShape(QFrame::Box);
+            frame->setFrameShadow(QFrame::Plain);
+            frame->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+            m_dialog->firewallListFrame->setSizePolicy(QSizePolicy::Maximum,QSizePolicy::Minimum);
+            m_dialog->progress_page->layout()->removeWidget(m_dialog->firewallListFrame);
+            layout->addWidget(m_dialog->firewallListFrame);
+            layout->addWidget(frame);
+            frame->layout()->setContentsMargins(0,0,0,0);
+
+            m_dialog->stackedWidget->addWidget(container);
+            m_dialog->stackedWidget->setCurrentIndex(m_dialog->stackedWidget->count()-1);
+
+            setNextEnabled(page, !compile_only);
+            setBackEnabled(page, true);
+
+            break;
         }
+        } // end switch(page_1_op)
+
         break;
-    }
+    } // end case 1:
 
     default: { }
     }
@@ -424,56 +555,54 @@ void instDialog::showPage(const int page)
     setCurrentPage(page);
 }
 
-void instDialog::replaceMacrosInCommand(Configlet *conf)
-{
-/* replace macros in activation commands:
+/**
+ * Finds files that were generated for the firewalls scheduled for
+ * compile and fills the list. Returns number of files found.
  *
- * {{$fwbpromp}}   -- "magic" prompt that installer uses to detect when it is logged in
- * {{$fwdir}}      -- directory on the firewall
- * {{$fwscript}}   -- script name on the firewall
- * {{$rbtimeout}}  -- rollbak timeout
  */
+int instDialog::findFilesToInspect(QStringList &files)
+{
 
-/*
- * TODO: it does not make sense to split remote_script and then
- * reassemble it again from the file name and cnf.fwdir. We should set
- * variable $remote_script and use it in the configlets instead, but
- * keep $fwbscript and $fwdir for backwards compatibility
- */
-
-/*
- * remote_script is a full path, which in case of Cisco can be
- * something like "flash:file.fw". This means we have a problem with
- * QFileInfo that interprets it as path:filename on Window or just
- * file name with no directory path on Unix. As the result, fwbscript
- * becomes just "file.fw" on Windows and stays "flash:file.fw" on
- * Unix.
- */
-
-    QString fwbscript = QFileInfo(cnf.remote_script).fileName();
-    if (fwbscript.indexOf(":")!=-1) fwbscript = fwbscript.section(':', 1, 1);
-
-    if (fwbdebug)
+    QList<Firewall*> fwlist;
+    foreach(Firewall *f, firewalls)
+        fwlist.append(f);
+    foreach(Cluster *c, clusters)
     {
-        qDebug() << "Macro substitutions:";
-        qDebug() << "  $fwdir=" << cnf.fwdir;
-        qDebug() << "  cnf.script=" << cnf.script;
-        qDebug() << "  cnf.remote_script=" << cnf.remote_script;
-        qDebug() << "  $fwscript=" << fwbscript;
+        std::list<Firewall*> cfws;
+        c->getMembersList(cfws);
+        foreach(Firewall *f, cfws)
+            fwlist.append(f);
     }
 
-    conf->setVariable("fwbprompt", fwb_prompt);
-    conf->setVariable("fwdir", cnf.fwdir);
-    conf->setVariable("fwscript", fwbscript);
-
-    conf->setVariable("rbtimeout", cnf.rollbackTime);
-    conf->setVariable("rbtimeout_sec", cnf.rollbackTime * 60);
+    foreach(Firewall *f, fwlist)
+    {
+        QString mainFile = FirewallInstaller::getGeneratedFileFullPath(f);
+        if (!QFile::exists(mainFile)) continue;
+        instConf cnf;
+        cnf.fwobj = f;
+        cnf.script = mainFile;
+        QMap<QString, QString> res;
+        FirewallInstaller(NULL, &cnf, "").readManifest(mainFile, &res);
+        foreach(QString item, res.keys())
+            if (QFile::exists(item))
+                files.append(item);
+    }
+    return files.size();
 }
-
+ 
 void instDialog::testRunRequested()
 {
 }
 
+struct CaseInsensitiveComparison :
+    public std::binary_function<libfwbuilder::FWObject*, libfwbuilder::FWObject*, bool>
+{
+    bool operator()(libfwbuilder::FWObject *a,libfwbuilder::FWObject *b)
+    {
+        return QString(a->getName().c_str()).toLower() < QString(b->getName().c_str()).toLower();
+    }
+};
+
 void instDialog::findFirewalls()
 {
     firewalls.clear();
@@ -485,8 +614,8 @@ void instDialog::findFirewalls()
         project->m_panel->om->findAllClusters(clusters);
     }
 
-    firewalls.sort(FWObjectNameCmpPredicate());
-    clusters.sort(FWObjectNameCmpPredicate());
+    firewalls.sort(CaseInsensitiveComparison());
+    clusters.sort(CaseInsensitiveComparison());
 
     m_dialog->saveMCLogButton->setEnabled(true);
 }
@@ -523,7 +652,10 @@ bool instDialog::checkSSHPathConfiguration(Firewall *fw)
 bool instDialog::isCiscoFamily()
 {
     string platform = cnf.fwobj->getStr("platform");
-    return (platform=="pix" || platform=="fwsm" || platform=="iosacl");
+    return (platform=="pix" ||
+            platform=="fwsm" ||
+            platform=="iosacl" ||
+            platform=="procurve_acl");
 }
 
 /*
