@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog.h 2377 2010-01-17 23:09:51Z vadim $
+  $Id: instDialog.h 3082 2010-07-14 23:22:49Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -37,7 +37,6 @@
 #include "instOptionsDialog.h"
 #include "FirewallInstaller.h"
 #include "ProjectPanel.h"
-#include "Configlet.h"
 
 #include <qstring.h>
 #include <qstringlist.h>
@@ -72,10 +71,8 @@ namespace libfwbuilder
 }
 
 enum BatchOperation {BATCH_INSTALL, BATCH_COMPILE} ;
-enum Page1Operation {INST_DLG_COMPILE, INST_DLG_INSTALL};
-enum InstDialogState {NONE, COMPILE_DONE, INSTALL_DONE };
-
-typedef std::pair<QString,QString> t_procMess; // first - compilation result, second - installation result;
+enum Page1Operation {INST_DLG_COMPILE, INST_DLG_INSTALL, INST_DLG_INSPECT};
+enum WizardPageNumber {CHOOSE_OBJECTS=0, COMPILE_INSTALL=1 };
 
 #define FIREWALL_NAME_COLUMN 0
 #define COMPILE_CHECKBOX_COLUMN 1
@@ -90,25 +87,21 @@ class instDialog : public QDialog, public FakeWizard
 
     Q_OBJECT;
 
-    void init(QWidget*);
-
     Ui::instDialog_q *m_dialog;
     instConf cnf;
     Page1Operation page_1_op;
-    InstDialogState state;
     FirewallInstaller *installer;
     ProjectPanel *project;
     instBatchOptionsDialog *batch_inst_opt_dlg;
     bool compile_only;
-
+    bool compile_complete;
+    
     // proc is used to launch external oprocess, such as compiler or
     // user-defined installer script
     QProcess       proc;
 
     QString fwb_prompt;
     
-    std::set<libfwbuilder::Firewall*> reqFirewalls;
-
     std::list<libfwbuilder::Firewall*> firewalls;
     std::list<libfwbuilder::Cluster*> clusters;
     
@@ -137,8 +130,9 @@ class instDialog : public QDialog, public FakeWizard
     bool showSelectedFlag;
     bool finished;
     bool onlySelected;
+    bool secondPageVisited;
+    bool canceledAll;
 
-    QTextBrowser *currentLog;
     QTextCharFormat normal_format;
     QTextCharFormat error_format;
     QTextCharFormat warning_format;
@@ -177,12 +171,14 @@ class instDialog : public QDialog, public FakeWizard
     void setFlags(QTreeWidgetItem* item);
 
     virtual void closeEvent(QCloseEvent *event);
+
+    int findFilesToInspect(QStringList &files);
  
  public:
    
-    instDialog(QWidget *p, bool install, bool onlySelected, std::set<libfwbuilder::Firewall*> fws);
+    instDialog(QWidget *p);
     virtual ~instDialog();
-    
+
     void summary();
     void opSuccess(libfwbuilder::Firewall *fw);
     void opError(libfwbuilder::Firewall *fw);
@@ -192,13 +188,10 @@ class instDialog : public QDialog, public FakeWizard
     
     void displayCommand(const QStringList &args);
     bool runCompiler(libfwbuilder::Firewall *fw);
-    bool runInstaller(libfwbuilder::Firewall *fw);
+    bool runInstaller(libfwbuilder::Firewall *fw, bool cancelAllVisible = true);
 
     QStringList prepareArgForCompiler(libfwbuilder::Firewall *fw);
     bool tableHasCheckedItems();
-    void clearReqFirewalls();
-    void addReqFirewall(libfwbuilder::Firewall *f);
-    void replaceMacrosInCommand(Configlet *configlet);
     QString getActivationCmd();
     
     void enableStopButton();
@@ -215,7 +208,7 @@ protected:
     virtual void showEvent( QShowEvent *ev);
     virtual void hideEvent( QHideEvent *ev);
 
-    bool getInstOptions(libfwbuilder::Firewall *fw);
+    bool getInstOptions(libfwbuilder::Firewall *fw, bool cancelAllVisible = true);
     bool getBatchInstOptions(libfwbuilder::Firewall *first_fw);
     
     void prepareInstConf(libfwbuilder::Firewall *fw);
@@ -237,6 +230,7 @@ protected:
     
 public slots:
 
+    void show(ProjectPanel *project, bool install, bool onlySelected, std::set<libfwbuilder::Firewall*> fws);
     void compilerFinished(int ret_code, QProcess::ExitStatus);
     void installerFinished(int ret_code, QProcess::ExitStatus);
     void installerSuccess();
@@ -253,6 +247,7 @@ public slots:
     void updateProgressBar(int n,bool setsize);
 
     void saveLog();
+    void inspectFiles();
 
     void readFromStdout();
     void selectAllFirewalls();
