@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog_installer.cpp 2159 2009-12-16 10:33:58Z a2k $
+  $Id: instDialog_installer.cpp 3074 2010-07-14 13:43:18Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -56,7 +56,7 @@
 using namespace std;
 using namespace libfwbuilder;
 
-bool instDialog::runInstaller(Firewall *fw)
+bool instDialog::runInstaller(Firewall *fw, bool cancelAllVisible)
 {
     cnf.fwobj = fw;
     cnf.maddr = "";
@@ -66,7 +66,7 @@ bool instDialog::runInstaller(Firewall *fw)
                  << fw->getName().c_str()
                  << " cnf.user=" << cnf.user;
 
-    if (!getInstOptions(fw))
+    if (!getInstOptions(fw, cancelAllVisible))
     {
         QTimer::singleShot( 0, this, SLOT(mainLoopInstall()));
         this->opCancelled(fw);
@@ -146,13 +146,21 @@ bool instDialog::runInstaller(Firewall *fw)
 void instDialog::stopInstall()
 {
     currentStopButton->setEnabled(false);
-    stopProcessFlag=true;
 
-    disconnect(currentStopButton, SIGNAL(clicked()) );
-    currentStopButton->setEnabled(false);
+    disconnect(currentStopButton, SIGNAL(clicked()));
 
-    proc.terminate();                                  //try to close proc.
-    QTimer::singleShot( 1000, &proc, SLOT( kill() ) ); //if it doesn't respond, kill it
+    stopProcessFlag = true; // likely unused
+    proc.terminate(); // try to close proc.
+    QTimer::singleShot(1000, &proc, SLOT(kill())); //if it doesn't respond, kill it
+
+    if (installer != NULL)
+    {
+        if (fwbdebug)
+            qDebug() << "instDialog::stopInstall  killing installer";
+        installer->terminate();
+        delete installer;
+        installer = NULL;
+    }
 
     // to terminate whole install sequence rather than just current
     // process, clear the list.
