@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog_ui_ops.cpp 2697 2010-03-09 10:11:53Z buerki $
+  $Id: instDialog_ui_ops.cpp 3074 2010-07-14 13:43:18Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -35,6 +35,8 @@
 #include "InstallFirewallViewItem.h"
 #include "instOptionsDialog.h"
 #include "instBatchOptionsDialog.h"
+#include "UserWorkflow.h"
+#include "FirewallCodeViewer.h"
 
 #include <qcheckbox.h>
 #include <qlineedit.h>
@@ -68,6 +70,7 @@
 #include <QBrush>
 #include <QTextFormat>
 #include <QtDebug>
+#include <QTime>
 
 #include "fwbuilder/Resources.h"
 #include "fwbuilder/FWObjectDatabase.h"
@@ -104,15 +107,12 @@ void instDialog::disableStopButton()
 
 bool instDialog::checkIfNeedToCompile(Firewall *fw)
 {
-    return (fw->needsCompile() && reqFirewalls.empty() && !fw->getInactive()) ||
-           (!onlySelected && !reqFirewalls.empty() && reqFirewalls.find(fw)!=reqFirewalls.end() ||
-           (onlySelected && fw->needsCompile() && !fw->getInactive()) );
+    return (fw->needsCompile() && !fw->getInactive());
 }
 
 bool instDialog::checkIfNeedToInstall(Firewall *fw)
 {
-    return ((fw->needsInstall() && reqFirewalls.empty() && !fw->getInactive()) ||
-            (!reqFirewalls.empty() && reqFirewalls.find(fw)!=reqFirewalls.end()));
+    return (fw->needsInstall() && !fw->getInactive());
 }
 
 QTreeWidgetItem* instDialog::createTreeItem(QTreeWidgetItem* parent,
@@ -169,6 +169,21 @@ void instDialog::setFlags(QTreeWidgetItem* item)
     time_t li = fw->getInt("lastInstalled");
     QDateTime dt;
 
+    if (fwbdebug)
+    {
+        qDebug() << "instDialog::setFlags"
+                 << item->text(0)
+                 << "parent=" << parent
+                 << "fw=" << fw
+                 << "Firewall::isA(fw)=" << Firewall::isA(fw)
+                 << "lm=" << lm
+                 << "lc=" << lc
+                 << "li=" << li
+                 << "compile_only=" << compile_only;
+        qDebug() << "fw->needsCompile()" << fw->needsCompile()
+                 << "checkIfNeedToCompile(fw)=" << checkIfNeedToCompile(fw);
+    }
+
     // need to skip the secondary cluster members if platform only
     // allows installations on the primary (e.g. PIX).  Note that
     // platform attribute must be the same in the cluster and member
@@ -269,15 +284,6 @@ void instDialog::setFlags(QTreeWidgetItem* item)
         if (num_members)
         {
             bool checked = checkIfNeedToCompile(fw);
-            // if any of the member firewalls are in reqFirewalls, re-check
-            // if we need to compile the cluster. checkIfNeedToCompile()
-            // uses different condition if reqFirewalls is not empty.
-            for (list<Firewall*>::iterator it=members.begin(); it!=members.end(); ++it)
-            {
-                if (reqFirewalls.find(*it)!=reqFirewalls.end() &&
-                    fw->needsCompile() && !fw->getInactive())
-                    checked = true;
-            }
             item->setCheckState(COMPILE_CHECKBOX_COLUMN,
                                 checked?Qt::Checked:Qt::Unchecked);
         }
@@ -353,35 +359,99 @@ void instDialog::setInProcessState(QTreeWidgetItem *item)
 
 void instDialog::opSuccess(Firewall *fw)
 {
-    opListMapping[(fw)->getId()]->setText(1,tr("Success"));
-    setSuccessState(opListMapping[(fw)->getId()]);
+    QTreeWidgetItem* itm = opListMapping[(fw)->getId()];
+    if (itm)
+    {
+        itm->setText(1,tr("Success"));
+        setSuccessState(itm);
+    }
     currentLabel->setText("");
+
+    if (installer)
+        wfl->registerFlag(UserWorkflow::INSTALL_SUCCESS, true);
 }
 
 void instDialog::opError(Firewall *fw)
 {
-    opListMapping[(fw)->getId()]->setText(1, tr("Error"));
-    setErrorState(opListMapping[(fw)->getId()]);
+    QTreeWidgetItem* itm = opListMapping[(fw)->getId()];
+    if (itm)
+    {
+        itm->setText(1, tr("Error"));
+        setErrorState(itm);
+    }
     currentLabel->setText("");
 }
 
 void instDialog::opCancelled(Firewall *fw)
 {
-    opListMapping[(fw)->getId()]->setText(1, tr("Cancelled"));
-    setErrorState(opListMapping[(fw)->getId()]);
+    QTreeWidgetItem* itm = opListMapping[(fw)->getId()];
+    // itm can be NULL, for example when we install to PIX cluster
+    // where we skip one of the members
+    if (itm)
+    {
+        itm ->setText(1, tr("Cancelled"));
+        setErrorState(itm);
+    }
     currentLabel->setText("");
 }
 
 void instDialog::nextClicked()
 {
-    if (nextRelevant( currentPage() ) > -1)
-        showPage(nextRelevant( currentPage() ));
+    if (currentPage() == CHOOSE_OBJECTS)
+    {
+        page_1_op = INST_DLG_COMPILE;
+        showPage(COMPILE_INSTALL);
+        return;
+    }
+
+    if (currentPage() == COMPILE_INSTALL &&
+        (page_1_op == INST_DLG_COMPILE || page_1_op == INST_DLG_INSPECT))
+    {
+        // clicking "Next" on page 1 (compile/install) changes
+        // contents of the same page
+        page_1_op = INST_DLG_INSTALL;
+        showPage(COMPILE_INSTALL);
+        return;
+    }
 }
 
 void instDialog::backClicked()
 {
-    if (previousRelevant( currentPage() ) > -1)
-        showPage(previousRelevant( currentPage() ));
+    if (currentPage() == COMPILE_INSTALL && page_1_op == INST_DLG_COMPILE)
+    {
+        // clicking "Back" on page 1 in mode "compile" returns to page 0
+        page_1_op = INST_DLG_COMPILE;
+        showPage(CHOOSE_OBJECTS);
+        return;
+    } 
+
+    if (currentPage() == COMPILE_INSTALL && page_1_op == INST_DLG_INSTALL)
+    {
+        // clicking "Back" on page 1 in mode "install" changes
+        // contents of the same page.  Ideally, I would like to be
+        // able to move back from "install" mode to "compile" mode
+        // without recompiling everything. This is impossible in the
+        // current implementation because we reuse the same widgets on
+        // the page.  This will be possible when "install" becomes its
+        // own page of the wizard.
+
+        // page_1_op = INST_DLG_COMPILE;
+        // showPage(COMPILE_INSTALL);
+        return;
+    } 
+
+    if (currentPage() == COMPILE_INSTALL && page_1_op == INST_DLG_INSPECT)
+    {
+        page_1_op = INST_DLG_COMPILE;
+        showPage(COMPILE_INSTALL);
+        return;
+    }
+}
+
+void instDialog::inspectFiles()
+{
+    page_1_op = INST_DLG_INSPECT;
+    showPage(COMPILE_INSTALL);
 }
 
 void instDialog::prepareInstConf(Firewall *)
@@ -435,7 +505,7 @@ void instDialog::summary()
 
     str.append("");
 
-    QTextCursor cursor = currentLog->textCursor();
+    QTextCursor cursor = m_dialog->procLogDisplay->textCursor();
     cursor.insertBlock();
     cursor.insertText(str.join("\n"), highlight_format);
 }
@@ -448,10 +518,8 @@ void instDialog::fillCompileSelectList()
     Cluster *cl;
     QDateTime dt;
 
-    if (fwbdebug && reqFirewalls.empty())
-        qDebug("instDialog::fillCompileSelectList reqFirewalls is empty");
-
     creatingTable = true;
+    m_dialog->selectTable->clear();
 
     list<Firewall*> working_list_of_firewalls = firewalls;
 
@@ -522,8 +590,8 @@ void instDialog::fillCompileSelectList()
                     {
                         warn2 <<
                             QString(tr("Firewall '%1' is member of cluster '%2'")
-                                    .arg(fw->getName().c_str())
-                                    .arg(cluster->getPath().c_str()));
+                                    .arg(QString::fromUtf8(fw->getName().c_str()))
+                                    .arg(QString::fromUtf8(cluster->getPath().c_str())));
                     }
                 }
             }
@@ -543,7 +611,6 @@ void instDialog::fillCompileSelectList()
         m_dialog->selectTable->resizeColumnToContents(i);
 
     setNextEnabled(0, tableHasCheckedItems());
-
     //m_dialog->selectTable->resizeRowsToContents();
 }
 
@@ -588,6 +655,8 @@ void instDialog::cancelClicked()
 
     if (proc.state() == QProcess::Running)
     {
+        if (fwbdebug)
+            qDebug() << "instDialog::cancelClicked  killing background process";
         rejectDialogFlag = true;
         proc.kill();
     }
@@ -620,7 +689,7 @@ void instDialog::hideEvent( QHideEvent *ev)
 void instDialog::saveLog()
 {
     QString dir;
-    if (currentLog==NULL) return;
+    //if (m_dialog->procLogDisplay==NULL) return;
     dir=st->getWDir();
     if (dir.isEmpty())  dir=st->getOpenFileDir();
     if (dir.isEmpty())  dir="~";
@@ -632,8 +701,7 @@ void instDialog::saveLog()
      adding text from each paragraph separately.
      */
     QString logText;
-    logText = currentLog->toPlainText();
-    //logText = currentLog->toHtml();
+    logText = m_dialog->procLogDisplay->toPlainText();
 
     QString s = QFileDialog::getSaveFileName(
                     this,
@@ -665,23 +733,22 @@ void instDialog::saveLog()
  * Adds one line of text to the log
  *
  */
-void instDialog::addToLog(const QString &line)
+void instDialog::addToLog(const QString &buf)
 {
-    // if (fwbdebug)
-    //     qDebug("instDialog::addToLog: '%s'", line.toLatin1().constData());
+//     if (fwbdebug)
+//         qDebug() << "instDialog::addToLog" << QTime::currentTime().toString()
+//                  << "buf.size()=" << buf.size();
 
-    if (line.isEmpty()) return;
+    if (buf.isEmpty()) return;
 
-    if (currentLog)
+    foreach(QString line, buf.trimmed().split("\n"))
     {
-        QString txt = line.trimmed();
-
         QTextCharFormat format = normal_format;
 
         list<QRegExp>::const_iterator it;
         for (it=error_re.begin(); it!=error_re.end(); ++it)
         {
-            if ((*it).indexIn(txt) != -1)
+            if ((*it).indexIn(line) != -1)
             {
                 format = error_format;
                 break;
@@ -690,13 +757,17 @@ void instDialog::addToLog(const QString &line)
 
         for (it=warning_re.begin(); it!=warning_re.end(); ++it)
         {
-            if ((*it).indexIn(txt) != -1)
+            if ((*it).indexIn(line) != -1)
             {
                 format = warning_format;
                 break;
             }
         }
 
+//         if (fwbdebug)
+//             qDebug() << "instDialog::addToLog" << QTime::currentTime().toString()
+//                      << "errors and warnings scan done";
+
         /* See sourceforge bug https://sourceforge.net/tracker/?func=detail&aid=2847263&group_id=5314&atid=1070394
          *
          * QTextEditor::insertHtml() becomes incrementally slow as the
@@ -706,23 +777,25 @@ void instDialog::addToLog(const QString &line)
          * line in a separate block makes it much faster.
          */
 
-        txt = line;
+        QString txt = line;
         while (!txt.isEmpty() && (txt.endsWith("\n") || txt.endsWith("\r")))
             txt.chop(1);
 
         if (format == error_format || format == warning_format )
             format.setAnchorHref(txt);
 
-        QTextCursor cursor = currentLog->textCursor();
+        QTextCursor cursor = m_dialog->procLogDisplay->textCursor();
+
         cursor.insertBlock();
+
         cursor.insertText(txt, format);
-
-        //m_dialog->procLogDisplayList->addItem(txt);
-
-        currentLog->ensureCursorVisible();
-
-        qApp->processEvents();
     }
+
+    //m_dialog->procLogDisplayList->addItem(txt);
+
+    m_dialog->procLogDisplay->ensureCursorVisible();
+
+    //qApp->processEvents();
 }
 
 void instDialog::interpretLogLine(const QString &line)
@@ -969,20 +1042,10 @@ bool instDialog::tableHasCheckedItems()
     return false;
 }
 
-void instDialog::clearReqFirewalls()
-{
-    reqFirewalls.clear();
-}
-
-void instDialog::addReqFirewall(Firewall *f)
-{
-    reqFirewalls.insert(f);
-}
-
 /*
  * getInstOptions() fills attributes of the cnf object
  */
-bool instDialog::getInstOptions(Firewall *fw)
+bool instDialog::getInstOptions(Firewall *fw, bool cancelAllVisible)
 {
     cnf.fwobj = fw;
 
@@ -998,13 +1061,25 @@ bool instDialog::getInstOptions(Firewall *fw)
     {
         // In non-batch mode installer options from the dialog
         // overwrite options set in the fw object itself.
-        instOptionsDialog *inst_opt_dlg = new instOptionsDialog(this, &cnf);
-        if (inst_opt_dlg->exec()==QDialog::Rejected)
+        instOptionsDialog *inst_opt_dlg = new instOptionsDialog(this, &cnf, cancelAllVisible);
+        int resultCode = inst_opt_dlg->exec();
+        // 0 - rejected
+        // 1 - accepted
+        // -1 - cancell all clicked
+        if (resultCode == -1)
+        {
+            canceledAll = true;
+            delete inst_opt_dlg;
+            return false;
+        }
+        if (resultCode == QDialog::Rejected)
         {
             delete inst_opt_dlg;
             return false;
         }
         readInstallerOptionsFromDialog(fw, inst_opt_dlg);
+        inst_opt_dlg->close();
+        inst_opt_dlg->deleteLater();
     }
 
     return verifyManagementAddress();
