@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: instOptionsDialog.cpp 2639 2010-03-01 04:39:27Z vadim $
+  $Id: instOptionsDialog.cpp 3074 2010-07-14 13:43:18Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -52,13 +52,15 @@
 using namespace std;
 using namespace libfwbuilder;
 
-instOptionsDialog::instOptionsDialog(QWidget *parent, instConf *_cnf) :
+instOptionsDialog::instOptionsDialog(QWidget *parent, instConf *_cnf, bool cancelAllVisible) :
     QDialog(parent)
 {
     m_dialog = new Ui::instOptionsDialog_q;
     m_dialog->setupUi(this);
     cnf = _cnf;
 
+    this->m_dialog->cancelAllButton->setVisible(cancelAllVisible);
+
     int fw_id = -1;
     if (cnf->fwobj)
     {
@@ -230,3 +232,8 @@ QString instOptionsDialog::getUName() { return m_dialog->uname->text(); }
 QString instOptionsDialog::getPWD()   { return m_dialog->pwd->text();   }
 QString instOptionsDialog::getEPWD()  { return m_dialog->epwd->text();  }
 
+
+void instOptionsDialog::cancelAll()
+{
+    this->done(-1);
+}
