@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: instOptionsDialog.h 1667 2009-10-30 21:39:54Z a2k $
+  $Id: instOptionsDialog.h 3074 2010-07-14 13:43:18Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -40,7 +40,7 @@ class instOptionsDialog : public QDialog
     instConf *cnf;
 
  public:
-    instOptionsDialog(QWidget *parent, instConf *_cnf);
+    instOptionsDialog(QWidget *parent, instConf *_cnf, bool cancelAllVisible = true);
     ~instOptionsDialog();
 
     void savePassword();
@@ -51,6 +51,8 @@ class instOptionsDialog : public QDialog
     
     Ui::instOptionsDialog_q *m_dialog;
 
+public slots:
+    void cancelAll();
    
 };
 
