@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: iosAdvancedDialog.cpp 332 2008-07-06 20:11:03Z vadim $
+  $Id: iosAdvancedDialog.cpp 1932 2009-11-26 03:26:24Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -31,10 +31,13 @@
 
 #include "iosAdvancedDialog.h"
 #include "FWWindow.h"
+#include "FWCmdChange.h"
 
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Management.h"
 
+#include <memory>
+
 #include <qcheckbox.h>
 #include <qspinbox.h>
 #include <qcombobox.h>
@@ -70,6 +73,8 @@ iosAdvancedDialog::iosAdvancedDialog(QWidget *parent,FWObject *o)
     data.registerOption( m_dialog->ios_ip_address  ,    fwoptions,  "ios_ip_address"    );
 
     data.loadAll();
+
+    m_dialog->tabWidget->setCurrentIndex(0);
 }
 
 /*
@@ -77,8 +82,19 @@ iosAdvancedDialog::iosAdvancedDialog(QWidget *parent,FWObject *o)
  */
 void iosAdvancedDialog::accept()
 {
-    data.saveAll();
-    mw->updateLastModifiedTimestampForAllFirewalls(obj);
+    ProjectPanel *project = mw->activeProject();
+    std::auto_ptr<FWCmdChange> cmd( new FWCmdChange(project, obj));
+
+    // new_state  is a copy of the fw object
+    FWObject* new_state = cmd->getNewState();
+    FWOptions* fwoptions = Firewall::cast(new_state)->getOptionsObject();
+    assert(fwoptions!=NULL);
+
+    data.saveAll(fwoptions);
+
+    if (!cmd->getOldState()->cmp(new_state, true))
+        project->undoStack->push(cmd.release());
+    
     QDialog::accept();
 }
 
