@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: iosaclAdvancedDialog.cpp 1051 2009-06-11 20:17:10Z vadim $
+  $Id: iosaclAdvancedDialog.cpp 2431 2010-01-25 20:36:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -34,6 +34,7 @@
 #include "SimpleTextEditor.h"
 #include "FWWindow.h"
 #include "FWBSettings.h"
+#include "FWCmdChange.h"
 
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Management.h"
@@ -41,6 +42,8 @@
 #include "fwbuilder/Interface.h"
 #include "fwbuilder/XMLTools.h"
 
+#include <memory>
+
 #include <qcheckbox.h>
 #include <qspinbox.h>
 #include <qcombobox.h>
@@ -78,36 +81,6 @@ iosaclAdvancedDialog::iosaclAdvancedDialog(QWidget *parent,FWObject *o)
 
     Firewall  *fw=Firewall::cast(obj);
     FWOptions *fwopt=fw->getOptionsObject();
-    string compiler=fwopt->getStr("compiler");
-    if (compiler=="")
-    {
-        compiler=Resources::platform_res[fw->getStr("platform")]->getCompiler();
-    }
-/*
- * On Unix compilers are installed in the standard place and are
- * accessible via PATH. On Windows and Mac they get installed in
- * unpredictable directories and need to be found
- *
- * first, check if user specified an absolute path for the compiler,
- * then check  if compiler is registsred in preferences, and if not,
- * look for it in appRootDir and if it is not there, rely on PATH
- */
-#if defined(Q_OS_WIN32) ||  defined(Q_OS_MACX)
-
-    if ( ! QFile::exists( compiler.c_str() ) )
-    {
-        string ts = string("Compilers/")+compiler;
-        QString cmppath = st->getStr( ts.c_str() );
-        if (!cmppath.isEmpty()) compiler = cmppath.toLatin1().constData();
-        else
-        {
-            /* try to find compiler in appRootDir. */
-            string ts =  getPathToBinary(compiler);
-            if ( QFile::exists( ts.c_str() ) )
-                compiler = ts;
-        }
-    }
-#endif
 
     string vers="version_"+obj->getStr("version");
     string platform = obj->getStr("platform");   // should be 'iosacl'
@@ -241,6 +214,9 @@ iosaclAdvancedDialog::iosaclAdvancedDialog(QWidget *parent,FWObject *o)
     data.registerOption( m_dialog->iosacl_acl_basic, fwoptions,
                          "iosacl_acl_basic" );
 
+    data.registerOption( m_dialog->iosacl_use_object_groups, fwoptions,
+                         "iosacl_use_object_groups" );
+
 /*
     data.registerOption( m_dialog->iosacl_acl_alwaysNew, fwoptions,
                          "iosacl_acl_always_new" );
@@ -280,6 +256,10 @@ iosaclAdvancedDialog::iosaclAdvancedDialog(QWidget *parent,FWObject *o)
     data.registerOption( m_dialog->sshArgs, fwoptions, "sshArgs");
     data.registerOption( m_dialog->scpArgs, fwoptions, "scpArgs");
 
+    data.registerOption( m_dialog->use_scp, fwoptions, "use_scp");
+    data.registerOption( m_dialog->filesystem, fwoptions, "filesystem");
+    data.registerOption( m_dialog->filesystem, fwoptions, "firewall_dir");
+
     PolicyInstallScript *pis   = mgmt->getPolicyInstallScript();
 
     m_dialog->installScript->setText(pis->getCommand().c_str() );
@@ -333,6 +313,8 @@ iosaclAdvancedDialog::iosaclAdvancedDialog(QWidget *parent,FWObject *o)
     data.loadAll();
     scriptACLModeChanged();
     toggleGenerateLogging();
+
+    m_dialog->tabWidget->setCurrentIndex(0);
 }
 
 /*
@@ -340,17 +322,18 @@ iosaclAdvancedDialog::iosaclAdvancedDialog(QWidget *parent,FWObject *o)
  */
 void iosaclAdvancedDialog::accept()
 {
-    FWOptions *options=(Firewall::cast(obj))->getOptionsObject();
+    ProjectPanel *project = mw->activeProject();
+    std::auto_ptr<FWCmdChange> cmd( new FWCmdChange(project, obj));
+
+    // new_state  is a copy of the fw object
+    FWObject* new_state = cmd->getNewState();
+    FWOptions* options = Firewall::cast(new_state)->getOptionsObject();
     assert(options!=NULL);
 
     Management *mgmt=(Firewall::cast(obj))->getManagementObject();
     assert(mgmt!=NULL);
 
-    data.saveAll();
-
-//    PolicyInstallScript *pis   = mgmt->getPolicyInstallScript();
-//    pis->setCommand( installScript->text() );
-//    pis->setArguments( installScriptArgs->text() );
+    data.saveAll(options);
 
     const InetAddr *mgmt_addr = Firewall::cast(obj)->getManagementAddress();
     if (mgmt_addr)
@@ -360,7 +343,9 @@ void iosaclAdvancedDialog::accept()
     pis->setCommand( m_dialog->installScript->text().toLatin1().constData() );
     pis->setArguments( m_dialog->installScriptArgs->text().toLatin1().constData() );
 
-    mw->updateLastModifiedTimestampForAllFirewalls(obj);
+    if (!cmd->getOldState()->cmp(new_state, true))
+        project->undoStack->push(cmd.release());
+    
     QDialog::accept();
 }
 
