@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ipfwAdvancedDialog.cpp 585 2008-10-09 05:08:41Z vadim $
+  $Id: ipfwAdvancedDialog.cpp 1932 2009-11-26 03:26:24Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -30,11 +30,14 @@
 #include "ipfwAdvancedDialog.h"
 #include "SimpleTextEditor.h"
 #include "FWWindow.h"
+#include "FWCmdChange.h"
 
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Management.h"
 #include "fwbuilder/Resources.h"
 
+#include <memory>
+
 #include <qcheckbox.h>
 #include <qspinbox.h>
 #include <qcombobox.h>
@@ -42,6 +45,7 @@
 #include <qlineedit.h>
 #include <qstackedwidget.h>
 #include <qregexp.h>
+#include <QUndoStack>
 
 
 using namespace std;
@@ -111,25 +115,23 @@ ipfwAdvancedDialog::ipfwAdvancedDialog(QWidget *parent,FWObject *o)
     data.registerOption( m_dialog->compiler, fwopt, "compiler" );
     data.registerOption( m_dialog->compilerArgs, fwopt, "cmdline");
     data.registerOption( m_dialog->outputFileName, fwopt, "output_file");
+    data.registerOption( m_dialog->fileNameOnFw, fwopt, "script_name_on_firewall");
 
     data.registerOption( m_dialog->mgmt_ssh, fwopt, "mgmt_ssh"  );
     data.registerOption( m_dialog->mgmt_addr, fwopt, "mgmt_addr" );
 
-    PolicyInstallScript *pis   = mgmt->getPolicyInstallScript();
+    PolicyInstallScript *pis = mgmt->getPolicyInstallScript();
 
-    m_dialog->installScript->setText(     pis->getCommand().c_str() );
-    m_dialog->installScriptArgs->setText( pis->getArguments().c_str() );
+    m_dialog->installScript->setText(pis->getCommand().c_str());
+    m_dialog->installScriptArgs->setText(pis->getArguments().c_str());
 
 /* page "Prolog/Epilog" */
-    data.registerOption( m_dialog->prolog_script, fwopt,
-                         "prolog_script"  );
-
-    data.registerOption( m_dialog->epilog_script, fwopt,
-                         "epilog_script"  );
-
-
+    data.registerOption( m_dialog->prolog_script, fwopt, "prolog_script"  );
+    data.registerOption( m_dialog->epilog_script, fwopt, "epilog_script"  );
 
     data.loadAll();
+
+    m_dialog->tabWidget->setCurrentIndex(0);
 }
 
 /*
@@ -137,19 +139,26 @@ ipfwAdvancedDialog::ipfwAdvancedDialog(QWidget *parent,FWObject *o)
  */
 void ipfwAdvancedDialog::accept()
 {
-    FWOptions *fwopt=(Firewall::cast(obj))->getOptionsObject();
-    assert(fwopt!=NULL);
+    ProjectPanel *project = mw->activeProject();
+    std::auto_ptr<FWCmdChange> cmd( new FWCmdChange(project, obj));
 
-    Management *mgmt=(Firewall::cast(obj))->getManagementObject();
+    // new_state  is a copy of the fw object
+    FWObject* new_state = cmd->getNewState();
+    FWOptions* fwoptions = Firewall::cast(new_state)->getOptionsObject();
+    assert(fwoptions!=NULL);
+
+    Management *mgmt = (Firewall::cast(new_state))->getManagementObject();
     assert(mgmt!=NULL);
 
-    data.saveAll();
+    data.saveAll(fwoptions);
 
     PolicyInstallScript *pis   = mgmt->getPolicyInstallScript();
     pis->setCommand( m_dialog->installScript->text().toLatin1().constData() );
     pis->setArguments( m_dialog->installScriptArgs->text().toLatin1().constData() );
 
-    mw->updateLastModifiedTimestampForAllFirewalls(obj);
+    if (!cmd->getOldState()->cmp(new_state, true))
+        project->undoStack->push(cmd.release());
+    
     QDialog::accept();
 }
 
