@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: macosxAdvancedDialog.h,v 1.1 2004/05/11 04:45:38 vkurland Exp $
+  $Id: macosxAdvancedDialog.h 304 2008-07-03 02:19:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,22 +27,25 @@
 #ifndef __MACOSXADVANCEDDIALOG_H_
 #define __MACOSXADVANCEDDIALOG_H_
 
-#include "macosxadvanceddialog_q.h"
+#include <ui_macosxadvanceddialog_q.h>
 #include "DialogData.h"
+#include <QDialog>
 
 namespace libfwbuilder {
     class FWObject;
 };
 
-class macosxAdvancedDialog : public macosxAdvancedDialog_q
+class macosxAdvancedDialog : public QDialog
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
     DialogData                       data;
+    Ui::macosxAdvancedDialog_q      *m_dialog;
 
  public:
     macosxAdvancedDialog(QWidget *parent,libfwbuilder::FWObject *o);
+    ~macosxAdvancedDialog();
 
 protected slots:
 
