@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: main.cpp 2644 2010-03-03 01:04:24Z vadim $
+  $Id: main.cpp 2968 2010-06-08 20:35:48Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -51,6 +51,7 @@
 #include <QLibraryInfo>
 #include <QtDebug>
 
+#include "FWBApplication.h"
 #include "FWBSettings.h"
 #include "RCS.h"
 #include "FWWindow.h"
@@ -61,6 +62,7 @@
 #include "findDialog.h"
 #include "ProjectPanel.h"
 #include "RCS.h"
+#include "UserWorkflow.h"
 
 #include "fwbuilder/FWObject.h"
 #include "fwbuilder/Tools.h"
@@ -87,14 +89,15 @@ using namespace std;
 static QString filename;
 static QString print_output_file_name;
 bool auto_load_from_rcs_head_revision = false;
-QApplication *app = NULL;
+FWBApplication *app = NULL;
 FWWindow *mw = NULL;
 FWBSettings *st = NULL;
+UserWorkflow *wfl = NULL;
 int fwbdebug = 0;
 bool safemode = false;
 bool cli_print = false;
 QString cli_print_fwname = "";
-
+int sig = FWB_SIG;
 
 void usage()
 {
@@ -154,7 +157,7 @@ int main( int argc, char *argv[] )
 
     Q_INIT_RESOURCE(MainRes);
 
-    app = new QApplication( argc, argv );
+    app = new FWBApplication( argc, argv );
     app->setOrganizationName(QLatin1String("NetCitadel"));
     app->setApplicationName(QLatin1String("Firewall Builder"));
 
@@ -170,6 +173,8 @@ int main( int argc, char *argv[] )
     st->init();
     if (fwbdebug) qDebug("done");
 
+    wfl = new UserWorkflow();
+
     QPixmapCache::setCacheLimit(4096);
 
     INIT2;
@@ -240,6 +245,9 @@ int main( int argc, char *argv[] )
 
     mw->show();
 
+    // it is connected to QApplication's slot, not to FWBApplication
+    app->setQuitOnLastWindowClosed(false);
+    // connecting to right slot
     app->connect(app, SIGNAL(lastWindowClosed()), app, SLOT(quit()));
 
 #if defined(Q_WS_MAC)
@@ -247,7 +255,7 @@ int main( int argc, char *argv[] )
 #endif
 
     // setup single shot timer to call startupLoad()
-    QTimer::singleShot(0.5, mw, SLOT(startupLoad()));
+    QTimer::singleShot(500, mw, SLOT(startupLoad()));
 
     app->exec();
 
