@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: newFirewallDialog.cpp 2481 2010-02-01 20:30:05Z vadim $
+  $Id: newFirewallDialog.cpp 3069 2010-07-12 17:34:36Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -35,6 +35,7 @@
 #include "FWBSettings.h"
 #include "FWBTree.h"
 #include "events.h"
+#include "UserWorkflow.h"
 
 #include "fwbuilder/Library.h"
 #include "fwbuilder/Firewall.h"
@@ -219,11 +220,11 @@ void newFirewallDialog::changed()
         f = false;
         m_dialog->use_snmp->setEnabled( f );
 #endif
-
+        m_dialog->snmpIP->setEnabled( f );
         m_dialog->snmp_community->setEnabled( f );
         m_dialog->snmpQuery->setEnabled( f );
         m_dialog->snmpProgress->setEnabled( f );
-        if (f) m_dialog->snmp_community->setFocus();
+        if ( f ) m_dialog->snmp_community->setFocus();
 
         f = m_dialog->use_manual->isChecked() || snmpPollCompleted;
         setNextEnabled( 1, f );
@@ -298,22 +299,30 @@ void newFirewallDialog::getInterfacesViaSNMP()
     getInterfacesBusy = true;
 
     InetAddr addr;
-    QString name=m_dialog->obj_name->text().toLatin1().constData();
     try
     {
-        QApplication::setOverrideCursor( QCursor( Qt::WaitCursor) );
-        QString a = getAddrByName(name, AF_INET);
-        QApplication::restoreOverrideCursor();
-        addr = InetAddr(a.toAscii().constData());
-    } catch (FWException &ex)
+        addr = InetAddr(m_dialog->snmpIP->text().toStdString());
+    }
+    catch (FWException &ex)
     {
-        QMessageBox::warning(
-            this,"Firewall Builder",
-            tr("Address of %1 could not be obtained via DNS")
-            .arg(m_dialog->obj_name->text()),
-            "&Continue", QString::null, QString::null, 0, 1 );
-        getInterfacesBusy = false;
-        return ;
+        try
+        {
+            QApplication::setOverrideCursor( QCursor( Qt::WaitCursor) );
+            QString a = getAddrByName(m_dialog->snmpIP->text(), AF_INET);
+            QApplication::restoreOverrideCursor();
+            addr = InetAddr(a.toAscii().constData());
+            getInterfacesBusy = false;
+        }
+        catch (FWException &ex)
+        {
+            QMessageBox::warning(
+                this,"Firewall Builder",
+                tr("Address of %1 could not be obtained via DNS")
+                .arg(m_dialog->snmpIP->text()),
+                "&Continue", QString::null, QString::null, 0, 1 );
+            getInterfacesBusy = false;
+            return ;
+        }
     }
 
     logger=NULL;
@@ -417,6 +426,29 @@ void newFirewallDialog::showPage(const int page)
     case 1:
     {
         changed();  // to properly enable/disable widgets
+
+        getInterfacesBusy = true;
+
+        InetAddr addr;
+        QString name=m_dialog->obj_name->text().toLatin1().constData();
+        try
+        {
+            QApplication::setOverrideCursor( QCursor( Qt::WaitCursor) );
+            QString a = getAddrByName(name, AF_INET);
+            m_dialog->snmpIP->setText(a);
+            QApplication::restoreOverrideCursor();
+            getInterfacesBusy = false;
+        } catch (FWException &ex)
+        {
+            QMessageBox::warning(
+                this,"Firewall Builder",
+                tr("Address of %1 could not be obtained via DNS")
+                .arg(m_dialog->obj_name->text()),
+                "&Continue", QString::null, QString::null, 0, 1 );
+            getInterfacesBusy = false;
+            break ;
+        }
+
         break;
     }
 
@@ -503,6 +535,22 @@ void newFirewallDialog::showPage(const int page)
         {
             FWObject *o=*m;
 
+/*
+  Ticket #1492 requested the change to only show the user templates
+  that match platform and host OS they choose on the first page of the
+  wizard.
+
+  Unfortunately this does not really work because most templates have
+  platform and host OS set to "unknown". Either we have to maintain
+  many almost identical templates to provide enough choices for all
+  possible platforms, or we should not filter by platform.
+
+            string platform = readPlatform(m_dialog->platform).toAscii().constData();
+            string host_os = readHostOS(m_dialog->hostOS).toAscii().constData();
+            if (o->getStr("platform") != platform || o->getStr("host_OS") != host_os)
+                continue;
+*/
+
             QPixmap pm;
             if ( ! QPixmapCache::find( icn, pm) )
             {
@@ -832,6 +880,12 @@ void newFirewallDialog::finishClicked()
         qDebug() << "newFirewallDialog::finishClicked()"
                  << "p=" << p;
 
+    if ((!this->m_dialog->useTemplate->isChecked()) && p == 2)
+    {
+        if ( !this->m_dialog->interfaceEditor1->isValid() )
+            return;
+    }
+
     if ( p == 5 )
         if ( !this->m_dialog->interfaceEditor2->isValid() )
             return;
@@ -852,6 +906,8 @@ void newFirewallDialog::finishClicked()
 
     } else
     {
+        wfl->registerFlag(UserWorkflow::NEW_FW_NO_TEMPLATE, true);
+
         // Create from interface list (obtained either manually or via snmp)
         if ( !this->m_dialog->interfaceEditor1->isValid() )
             return;
