@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: newFirewallDialog.h 304 2008-07-03 02:19:16Z vadim $
+  $Id: newFirewallDialog.h 1824 2009-11-19 20:32:49Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -31,6 +31,8 @@
 #include <ui_newfirewalldialog_q.h>
 
 #include "fwbuilder/InterfaceData.h"
+#include "fwbuilder/InetAddrMask.h"
+
 #include "fakeWizard.h"
 
 #include <map>
@@ -50,26 +52,52 @@ class QTextEdit;
 
 class newFirewallDialog : public QDialog, public FakeWizard
 {
-    Q_OBJECT
+    Q_OBJECT;
     
     Ui::newFirewallDialog_q            *m_dialog;
 
+    libfwbuilder::FWObject             *currentTemplate;
     libfwbuilder::Firewall             *nfw;
     bool                                snmpPollCompleted;
     libfwbuilder::Logger               *logger;
     libfwbuilder::SNMP_interface_query *q;
     QTimer                             *timer;
+    libfwbuilder::FWObjectDatabase     *db;
     libfwbuilder::FWObjectDatabase     *tmpldb;
+    libfwbuilder::FWObject             *parent;
     std::map<QListWidgetItem*, libfwbuilder::FWObject*> templates;
     bool                                unloadTemplatesLib;
     bool                                getInterfacesBusy;
+
+    std::list<std::string>              possible_inside_interface_labels;
+    std::list<std::string>              possible_outside_interface_labels;
+    std::list<std::string>              possible_dmz_interface_labels;
     
     void adjustSL(QTreeWidgetItem *itm1);
     void fillInterfaceData(libfwbuilder::Interface *intf, QTextBrowser *qte);
     void fillInterfaceSLList();
+    void createFirewallFromTemplate();
+    void changedAddressesInNewFirewall();
 
- public:
-    newFirewallDialog();
+    void replaceInterfaceAttributes(libfwbuilder::Firewall *fw,
+                                    libfwbuilder::Interface *intf,
+                                    EditedInterfaceData *new_data);
+    libfwbuilder::Address* replaceInterfaceAddressData(libfwbuilder::Firewall *fw,
+                                                       libfwbuilder::Interface *intf,
+                                                       libfwbuilder::Address *addr_obj,
+                                                       const QString &address,
+                                                       const QString &netmask,
+                                                       bool ipv4);
+    void replaceReferencesToNetworks(libfwbuilder::Firewall *fw,
+                                     libfwbuilder::Interface *intf,
+                                     libfwbuilder::InetAddrMask old_net,
+                                     libfwbuilder::InetAddrMask new_net);
+    void replaceReferencesToObject(libfwbuilder::Firewall *fw,
+                                   libfwbuilder::FWObject *old_obj,
+                                   libfwbuilder::FWObject *new_obj);
+
+public:
+    newFirewallDialog(libfwbuilder::FWObject *parent);
     virtual ~newFirewallDialog();
 
     libfwbuilder::Firewall* getNewFirewall() { return nfw; };
@@ -80,26 +108,23 @@ class newFirewallDialog : public QDialog, public FakeWizard
     bool validateAddressAndMask(const QString &addr,const QString &netm);
     
 public slots:
-    virtual void addInterface();
-    virtual void updateInterface();
-    virtual void deleteInterface();
     virtual void upInterface();
     virtual void downInterface();
     virtual void changed();
-    virtual void selectedInterface(QTreeWidgetItem*,QTreeWidgetItem*);
     virtual void getInterfacesViaSNMP();    
     virtual void monitor();
     virtual void templateSelected(QListWidgetItem *itm);
     void browseTemplate();
     void useStandartTemplate();
     void showHideTemplatePanel();
- protected slots:
+
+protected slots:
     
     void finishClicked();
     void cancelClicked();
     void nextClicked();
     void backClicked();
- 
+
 };
 
 #endif // __NEWFIREWALLDIALOG_H
