@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: newGroupDialog.h 353 2008-07-13 01:26:39Z vadim $
+  $Id: newGroupDialog.h 1487 2009-09-23 17:00:48Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -32,15 +32,17 @@
 #include <QDialog>
 
 #include "fwbuilder/FWObject.h"
+#include "fwbuilder/FWObjectDatabase.h"
 
 
 class newGroupDialog : public QDialog
 {
-    Q_OBJECT
+    Q_OBJECT;
             
-
+    libfwbuilder::FWObjectDatabase *db;
+ 
  public:
-    newGroupDialog(QWidget *parent);
+    newGroupDialog(QWidget *parent, libfwbuilder::FWObjectDatabase *_db);
     ~newGroupDialog();
     
     Ui::newGroupDialog_q *m_dialog;
