@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: newHostDialog.cpp 992 2009-06-01 14:48:12Z vadim $
+  $Id: newHostDialog.cpp 1924 2009-11-25 21:58:10Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -34,6 +34,7 @@
 #include "FWWindow.h"
 #include "ObjConflictResolutionDialog.h"
 #include "upgradePredicate.h"
+#include "events.h"
 
 #include "fwbuilder/Library.h"
 #include "fwbuilder/Host.h"
@@ -73,8 +74,11 @@ using namespace std;
 #define MANUAL_PAGE      2
 #define TEMPLATES_PAGE   3
 
-newHostDialog::newHostDialog() : QDialog()
+newHostDialog::newHostDialog(FWObject *_p) : QDialog()
 {
+    parent = _p;
+    db = parent->getRoot();
+
     m_dialog = new Ui::newHostDialog_q;
     m_dialog->setupUi(this);
 
@@ -102,10 +106,10 @@ newHostDialog::newHostDialog() : QDialog()
 
     setNextEnabled( OBJECT_NAME_PAGE, false );
 
-    m_dialog->iface_list->setAllColumnsShowFocus( true );
-
     m_dialog->obj_name->setFocus();
 
+    m_dialog->interfaceEditor->clear();
+
     showPage(0);
 }
 
@@ -192,6 +196,7 @@ void newHostDialog::changed()
 
     if (p==MANUAL_PAGE)
     {
+        /*
         if (m_dialog->iface_dyn->isChecked() || m_dialog->iface_unnum->isChecked())
         {
             m_dialog->iface_addr->clear();
@@ -202,7 +207,7 @@ void newHostDialog::changed()
         {
             m_dialog->iface_addr->setEnabled(true);
             m_dialog->iface_netmask->setEnabled(true);
-        }
+        }*/
     }
 }
 
@@ -232,24 +237,7 @@ void  newHostDialog::monitor()
         if ( idata->ostatus )
         {
             idata->guessLabel("");
-
-            QString dn;
-            if (idata->isDyn)        dn+="dyn";
-            if (idata->isUnnumbered) dn+="unn";
-
-            QStringList qsl;
-            qsl << idata->name.c_str() << idata->label.c_str();
-            // TODO: redesign the way we pass information from the
-            // snmp crawler down the line so that multiple ip
-            // addresses per interface can be processed.
-            if (idata->addr_mask.size())
-                qsl << idata->addr_mask.front()->getAddressPtr()->toString().c_str()
-                    << idata->addr_mask.front()->getNetmaskPtr()->toString().c_str();
-            else
-                qsl << "" << "";
-
-            qsl << dn << idata->mac_addr.c_str();
-            new QTreeWidgetItem(m_dialog->iface_list, qsl);
+            this->m_dialog->interfaceEditor->addInterfaceFromData(idata);
         }
     }
 
@@ -270,7 +258,6 @@ void newHostDialog::getInterfacesViaSNMP()
     if (q!=NULL || getInterfacesBusy) return;
 
     snmpPollCompleted=false;
-    m_dialog->iface_list->clear();
 
     string rcomm=m_dialog->snmp_community->text().toLatin1().constData();
 
@@ -283,6 +270,8 @@ void newHostDialog::getInterfacesViaSNMP()
         return ;
     }
 
+    m_dialog->interfaceEditor->clear();
+    m_dialog->interfaceEditor->removeTab(0);
     getInterfacesBusy = true;
 
     InetAddr addr;
@@ -369,8 +358,6 @@ void newHostDialog::showPage(const int page)
 
     case MANUAL_PAGE:
     {
-        m_dialog->iface_name->setFocus();
-
         setNextEnabled( MANUAL_PAGE, false );
         setFinishEnabled( MANUAL_PAGE, true );
         break;
@@ -557,86 +544,6 @@ bool newHostDialog::validateAddressAndMask(const QString &addr,
     return true;
 }
 
-
-void newHostDialog::addInterface()
-{
-    QString dn = "";
-    if (m_dialog->iface_dyn->isChecked())   dn += "Dyn";
-    if (m_dialog->iface_unnum->isChecked()) dn += "Unn";
-
-    QString addr;
-    QString netm;
-
-    if (!m_dialog->iface_dyn->isChecked() &&
-        !m_dialog->iface_unnum->isChecked())
-    {
-        addr = m_dialog->iface_addr->text();
-        netm = m_dialog->iface_netmask->text();
-
-        if (addr.isEmpty()) 
-            addr = QString(InetAddr::getAny().toString().c_str());
-        if (netm.isEmpty())
-            netm = QString(InetAddr::getAny().toString().c_str());
-
-        if (!validateAddressAndMask(addr, netm)) return;
-    }
-    QStringList sl;
-    sl << m_dialog->iface_name->text()
-       << m_dialog->iface_label->text()
-       << addr
-       << netm
-       << dn
-       << m_dialog->iface_physaddr->text();
-
-    new QTreeWidgetItem(m_dialog->iface_list, sl);
-}
-
-
-void newHostDialog::selectedInterface(QTreeWidgetItem*cur,QTreeWidgetItem*)
-//void newHostDialog::selectedInterface(QTreeWidgetItem *cur)
-{
-    QTreeWidgetItem *itm = cur;
-    if (itm)
-    {
-        m_dialog->iface_name->setText( itm->text(0) );
-        m_dialog->iface_label->setText( itm->text(1) );
-        m_dialog->iface_addr->setText( itm->text(2) );
-        m_dialog->iface_netmask->setText( itm->text(3) );
-        m_dialog->iface_dyn->setChecked( itm->text(4).indexOf("Dyn")!=-1 );
-        m_dialog->iface_unnum->setChecked( itm->text(4).indexOf("Unn")!=-1 );
-        m_dialog->iface_physaddr->setText( itm->text(5) );
-    }
-}
-
-void newHostDialog::updateInterface()
-{
-    QString dn = "";
-    if (m_dialog->iface_dyn->isChecked())   dn+="Dyn";
-    if (m_dialog->iface_unnum->isChecked()) dn+="Unn";
-
-    QTreeWidgetItem *itm = m_dialog->iface_list->currentItem();
-    if (itm==NULL) return;
-
-    QString addr = m_dialog->iface_addr->text();
-    QString netm = m_dialog->iface_netmask->text();
-    if (!validateAddressAndMask(addr, netm)) return;
-
-    itm->setText( 0 , m_dialog->iface_name->text() );
-    itm->setText( 1 , m_dialog->iface_label->text() );
-    itm->setText( 2 , addr );
-    itm->setText( 3 , netm );
-    itm->setText( 4 , dn );
-    itm->setText( 5 , m_dialog->iface_physaddr->text() );
-}
-
-void newHostDialog::deleteInterface()
-{
-    QTreeWidgetItem *itm = m_dialog->iface_list->currentItem();
-    if (itm==NULL) return;
-    m_dialog->iface_list->takeTopLevelItem(
-            m_dialog->iface_list->indexOfTopLevelItem(itm) );
-}
-
 void newHostDialog::cancelClicked()
 {
     QDialog::reject();
@@ -652,48 +559,44 @@ void newHostDialog::finishClicked()
         FWObject *o=templates[itm];
         assert (o!=NULL);
 
-        FWObject *no = mw->duplicateObject(mw->getCurrentLib(),
-                                           o,
-                                           m_dialog->obj_name->text(),
-                                           false );  // do not ask to autorename
+        FWObject *no = db->create(Host::TYPENAME);
+        no->duplicate(o, true);
+        no->setName(m_dialog->obj_name->text().toUtf8().constData());
+
         if (no==NULL)
         {
           QDialog::accept();
           return;
         }
-        nhst=Host::cast(no);
+        nhst = Host::cast(no);
     } else
     {
         FWObject *o;
-        o=mw->createObject(Host::TYPENAME, m_dialog->obj_name->text() );
+        o = db->create(Host::TYPENAME);
+        o->setName(m_dialog->obj_name->text().toUtf8().constData());
         if (o==NULL)
         {
           QDialog::accept();
           return;
         }
 
-        nhst=Host::cast(o);
+        nhst = Host::cast(o);
 
 /* create interfaces */
 
-        for (int i = 0; i < m_dialog->iface_list->topLevelItemCount(); i++)
+        foreach(EditedInterfaceData iface, this->m_dialog->interfaceEditor->getNewData())
         {
-            QTreeWidgetItem *itm = m_dialog->iface_list->topLevelItem(i);
-            QString name    =  itm->text(0);
-            QString label   =  itm->text(1);
-            QString addr    =  itm->text(2);
-            QString netmask =  itm->text(3);
-            bool    dyn     =  itm->text(4).indexOf("Dyn")!=-1;
-            bool    unnum   =  itm->text(4).indexOf("Unn")!=-1;
-            QString physaddr=  itm->text(5);
+            QString name     =  iface.name;
+            QString label    =  iface.label;
+            bool    dyn      =  iface.type == 1;
+            bool    unnum    =  iface.type == 2;
+            QString physaddr =  iface.mac;
 
-            Interface *oi = Interface::cast(
-                mw->createObject(nhst,Interface::TYPENAME, name)
-            );
-#ifdef USE_INTERFACE_POLICY
-            oi->add(new InterfacePolicy());
-#endif
-            oi->setLabel( label.toLatin1().constData() );
+            Interface *oi = Interface::cast(db->create(Interface::TYPENAME));
+            oi->setName( string(name.toUtf8().constData()) );
+            oi->setLabel( string(label.toUtf8().constData()) );
+            oi->setComment( string(iface.comment.toUtf8().constData()) );
+            nhst->add(oi);
 
             if (dyn)   oi->setDyn(true);
             if (unnum) oi->setUnnumbered(true);
@@ -702,60 +605,56 @@ void newHostDialog::finishClicked()
             {
                 QString addrname=QString("%1:%2:mac")
                     .arg(m_dialog->obj_name->text()).arg(name);
-                physAddress * pa =
-                    physAddress::cast(mw->createObject(oi,
-                                                       physAddress::TYPENAME,
-                                                       addrname));
+                physAddress* pa = physAddress::cast(db->create(physAddress::TYPENAME));
+                pa->setName(addrname.toUtf8().constData());
+                oi->add(pa);
                 pa->setPhysAddress(physaddr.toLatin1().constData());
             }
-            if (!dyn && !unnum && !addr.isEmpty() && addr!="0.0.0.0")
+            if (iface.type == 0)
             {
-                if (addr.indexOf(':')!=-1)
+                foreach(AddressInfo address, iface.addresses)
                 {
-                    // ipv6 address
-                    QString addrname = QString("%1:%2:ip6")
-                        .arg(m_dialog->obj_name->text()).arg(name);
-                    IPv6 *oa = IPv6::cast(
-                        mw->createObject(oi, IPv6::TYPENAME, addrname)
-                    );
-                    oa->setAddress(
-                        InetAddr(AF_INET6, addr.toLatin1().constData()) );
-                    bool ok = false ;
-                    int inetmask = netmask.toInt(&ok);
-                    if (ok)
+                    if (address.address == "0.0.0.0") continue;
+                    if (address.ipv4)
                     {
-                        oa->setNetmask( InetAddr(AF_INET6, inetmask) );
+                        string addrname = string( QString("%1:%2:ip").arg(m_dialog->obj_name->text()).arg(name).toUtf8() );
+                        IPv4 *oa = IPv4::cast(db->create(IPv4::TYPENAME));
+                        oi->add(oa);
+                        oa->setName(addrname);
+                        oa->setAddress( InetAddr(address.address.toLatin1().constData()) );
+                        bool ok = false ;
+                        int inetmask = address.netmask.toInt(&ok);
+                        if (ok)
+                        {
+                            oa->setNetmask( InetAddr(inetmask) );
+                        }
+                        else
+                        {
+                            oa->setNetmask( InetAddr(address.netmask.toLatin1().constData()) );
+                        }
                     }
                     else
                     {
-                        oa->setNetmask(
-                            InetAddr(AF_INET6, netmask.toLatin1().constData()));
-                    }
-
-                } else
-                {
-                    // ipv4 address
-                    QString addrname = QString("%1:%2:ip")
-                        .arg(m_dialog->obj_name->text()).arg(name);
-                    IPv4 *oa = IPv4::cast(
-                        mw->createObject(oi, IPv4::TYPENAME,addrname)
-                    );
-                    oa->setAddress( InetAddr(addr.toLatin1().constData()) );
-                    bool ok = false ;
-                    int inetmask = netmask.toInt(&ok);
-                    if (ok)
-                    {
-                        oa->setNetmask( InetAddr(inetmask) );
-                    }
-                    else
-                    {
-                        oa->setNetmask(
-                            InetAddr(netmask.toLatin1().constData()));
+                        string addrname = string( QString("%1:%2:ip6").arg(m_dialog->obj_name->text()).arg(name).toUtf8() );
+                        IPv6 *oa = IPv6::cast(db->create(IPv6::TYPENAME));
+                        oi->add(oa);
+                        oa->setName(addrname);
+                        oa->setAddress(InetAddr(AF_INET6, address.address.toLatin1().constData()) );
+                        bool ok = false ;
+                        int inetmask = address.netmask.toInt(&ok);
+                        if (ok)
+                        {
+                            oa->setNetmask( InetAddr(AF_INET6, inetmask) );
+                        }
+                        else
+                        {
+                            oa->setNetmask(InetAddr(AF_INET6, address.netmask.toLatin1().constData()));
+                        }
                     }
                 }
             }
         }
-        mw->reloadAllWindowsWithFile(mw->activeProject());
+        
     }
     if (unloadTemplatesLib)
     {
