@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: platforms.cpp 2647 2010-03-04 02:06:35Z vadim $
+  $Id: platforms.cpp 2919 2010-05-22 01:32:13Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -252,7 +252,7 @@ bool isDefaultPolicyRuleOptions(FWOptions *opt)
             bool ge_4_5 = XMLTools::version_compare(version, "4.5")>=0;
             if (ge_4_5)
             {
-                res = (!opt->getBool("pf_no_sync") && opt->getBool("pf_pflow"));
+                res = (!opt->getBool("pf_no_sync") && !opt->getBool("pf_pflow"));
             }
 
             if (ge_4_0)
@@ -265,7 +265,9 @@ bool isDefaultPolicyRuleOptions(FWOptions *opt)
                       opt->getInt("pf_max_src_conn_rate_num")<=0       &&
                       opt->getInt("pf_max_src_conn_rate_seconds")<=0 &&
                       ! opt->getBool("pf_keep_state") &&
-                      ! opt->getBool("pf_sloppy_tracker")
+                      ! opt->getBool("pf_sloppy_tracker") &&
+                      ! opt->getBool("pf_synproxy")    &&
+                      ! opt->getBool("pf_modulate_state")
                 );
             }else
             {
@@ -277,7 +279,9 @@ bool isDefaultPolicyRuleOptions(FWOptions *opt)
                       opt->getInt("pf_max_src_conn_rate_num")<=0       &&
                         opt->getInt("pf_max_src_conn_rate_seconds")<=0 &&
                       ! opt->getBool("pf_keep_state") &&
-                      ! opt->getBool("pf_sloppy_tracker")
+                      ! opt->getBool("pf_sloppy_tracker") &&
+                      ! opt->getBool("pf_synproxy")    &&
+                      ! opt->getBool("pf_modulate_state")
                 );
             }
 	}
@@ -311,10 +315,11 @@ bool isDefaultPolicyRuleOptions(FWOptions *opt)
         }
 
         // all rules are stateless for IOS ACL
-	if (platform=="iosacl")
+	if (platform=="iosacl" || platform=="procurve_acl")
         {
             res = !opt->getBool("iosacl_add_mirror_rule");
         }
+
     }
     return res;
 }
@@ -402,7 +407,12 @@ void getVersionsForPlatform(const QString &platform, std::list<QStringPair> &res
         res.push_back(QStringPair("1.4.3", QObject::tr("1.4.3 or later")));
     } else
     {
-        if (platform=="pix" || platform=="fwsm" || platform=="iosacl")
+        // we list supported versions for the following platforms in
+        // corresponding resource .xml file
+        if (platform=="pix" ||
+            platform=="fwsm" ||
+            platform=="iosacl" ||
+            platform=="procurve_acl")
         {
             QString lst = Resources::platform_res[
                 platform.toAscii().constData()]->getResourceStr(
@@ -422,7 +432,8 @@ void getVersionsForPlatform(const QString &platform, std::list<QStringPair> &res
                 res.push_back(QStringPair("4.0", QObject::tr("4.0 to 4.2")));
                 res.push_back(QStringPair("4.3", QObject::tr("4.3")));
                 res.push_back(QStringPair("4.5", QObject::tr("4.5")));
-                res.push_back(QStringPair("4.6", QObject::tr("4.6 and later")));
+                res.push_back(QStringPair("4.6", QObject::tr("4.6")));
+                res.push_back(QStringPair("4.7", QObject::tr("4.7 and later")));
 /* add pf versions here */
             } else
             {
