@@ -4,9 +4,9 @@
 
                  Copyright (C) 2009 NetCitadel, LLC
 
-  Author:  Roman Bovsunivkiy     a2k0001@gmail.com
+  Author:  Roman Bovsunivskiy     a2k0001@gmail.com
 
-  $Id: main.cpp 2039 2009-12-05 20:16:44Z a2k $
+  $Id: main_ImporterTest.cpp 2707 2010-03-10 18:22:19Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
