@@ -4,9 +4,9 @@
 
                  Copyright (C) 2009 NetCitadel, LLC
 
-  Author:  Roman Bovsunivkiy     a2k0001@gmail.com
+  Author:  Roman Bovsunivskiy     a2k0001@gmail.com
 
-  $Id: UsageResolverTest.h 2161 2009-12-16 11:41:47Z a2k $
+  $Id: RCSTest.h 2752 2010-03-24 03:07:54Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -26,23 +26,17 @@
 #ifndef RCSTEST_H
 #define RCSTEST_H
 
-#include <cppunit/TestCase.h>
-#include <cppunit/TestSuite.h>
-#include <cppunit/TestCaller.h>
+#include <cppunit/extensions/HelperMacros.h>
 
-class RCSTest : public CppUnit::TestCase
+class RCSTest : public CppUnit::TestFixture
 {
 public:
     void verifyRevisions();
 
-    static CppUnit::Test *suite()
-    {
-      CppUnit::TestSuite *suiteOfTests = new CppUnit::TestSuite( "RCSTest" );
-      suiteOfTests->addTest( new CppUnit::TestCaller<RCSTest>(
-                                   "verifyRevisions",
-                                   &RCSTest::verifyRevisions ) );
-      return suiteOfTests;
-    }
+    CPPUNIT_TEST_SUITE(RCSTest);
+    CPPUNIT_TEST(verifyRevisions);
+    CPPUNIT_TEST_SUITE_END();
+
 };
 
 #endif // RCSTEST_H
