@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: utils.h 2174 2009-12-17 01:12:32Z vadim $
+  $Id: utils.h 3038 2010-06-28 23:14:56Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -117,10 +117,13 @@ extern QString getAddrByName(const QString &name, int af_type);
 extern QString getNameByAddr(const QString &addr);
 extern QString wordWrap(const QString& ,int);
 
-extern void LoadPixmap(const QString path, QPixmap &where);
-extern QPixmap LoadPixmap(const QString path);
+extern void LoadPixmap(const QString &path, QPixmap &where);
+extern QPixmap LoadPixmap(const QString &path);
 extern QString calculateIconName(const QString &_icn, bool negation);
 
+extern void parseCommandLine(const QString &cmd, QStringList &argv);
+
+
 /*
  * @icon_size:  0 - small (16x16) , 1 - medium (25x25), 2 - big (64x64)
  */
