@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: CompilerDriver_ipt_run.cpp 2585 2010-02-19 18:54:14Z rueegsegger $
+  $Id: CompilerDriver_ipt_run.cpp 3079 2010-07-14 17:31:28Z a2k $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -172,7 +172,11 @@ QString CompilerDriver_ipt::run(const std::string &cluster_id,
                 new OSConfigurator_ipcop(objdb , fw, false));
         }
 
-        if (os_family == "linux24" || os_family == "openwrt" || os_family == "sveasoft")
+        if (os_family == "linux24" ||
+            os_family == "openwrt" ||
+            os_family == "dd-wrt-nvram" ||
+            os_family == "dd-wrt-jffs" ||
+            os_family == "sveasoft")
             oscnf = std::auto_ptr<OSConfigurator_linux24>(
                 new OSConfigurator_linux24(objdb , fw, false));
 
@@ -284,6 +288,7 @@ QString CompilerDriver_ipt::run(const std::string &cluster_id,
             }
 
             ostringstream automaitc_rules_stream;
+            ostringstream automaitc_mangle_stream;
             ostringstream filter_rules_stream;
             ostringstream mangle_rules_stream;
             ostringstream nat_rules_stream;
@@ -323,6 +328,7 @@ QString CompilerDriver_ipt::run(const std::string &cluster_id,
                     policy_af,
                     minus_n_commands_nat)) empty_output = false;
 
+            // first process all non-top rule sets, then all top rule sets
             for (int all_top = 0; all_top < 2; ++all_top)
             {
                 for (list<FWObject*>::iterator p=all_policies.begin();
@@ -341,6 +347,7 @@ QString CompilerDriver_ipt::run(const std::string &cluster_id,
                             filter_rules_stream,
                             mangle_rules_stream,
                             automaitc_rules_stream,
+                            automaitc_mangle_stream,
                             oscnf.get(),
                             policy_af,
                             minus_n_commands_filter,
@@ -366,6 +373,7 @@ QString CompilerDriver_ipt::run(const std::string &cluster_id,
 
             generated_script += dumpScript(fw,
                                            automaitc_rules_stream.str(),
+                                           automaitc_mangle_stream.str(),
                                            nat_rules_stream.str(),
                                            mangle_rules_stream.str(),
                                            filter_rules_stream.str(),
@@ -479,7 +487,7 @@ QString CompilerDriver_ipt::run(const std::string &cluster_id,
         script_skeleton.setVariable("tools",
                                     oscnf->printPathForAllTools(os_variant).c_str());
         script_skeleton.setVariable("shell_functions",
-                                    oscnf->printShellFunctions().c_str());
+                                    oscnf->printShellFunctions(have_ipv6).c_str());
         if (supports_prolog_epilog)
         {
             //script_skeleton.setVariable("prolog_epilog",
@@ -506,8 +514,17 @@ QString CompilerDriver_ipt::run(const std::string &cluster_id,
         if ( options->getBool("configure_bridge_interfaces") ) 
             ostr << oscnf->printBridgeInterfaceConfigurationCommands();
 
-        if ( options->getBool("configure_interfaces") ) 
-            ostr << oscnf->printInterfaceConfigurationCommands();
+
+        if ( options->getBool("configure_interfaces") ||
+             options->getBool("manage_virtual_addr"))
+        {
+            if ( options->getBool("configure_interfaces"))
+                ostr << oscnf->printInterfaceConfigurationCommands();
+            else
+                ostr << oscnf->printVirtualAddressesForNatCommands();
+        }
+
+        ostr << oscnf->printCommandsToClearKnownInterfaces();
 
         ostr << oscnf->printDynamicAddressesConfigurationCommands();
 
@@ -598,6 +615,7 @@ QString CompilerDriver_ipt::run(const std::string &cluster_id,
         script_skeleton.setVariable("timestamp", timestr);
         script_skeleton.setVariable("tz", tzname[stm->tm_isdst]);
         script_skeleton.setVariable("user", user_name);
+        script_skeleton.setVariable("database", objdb->getFileName().c_str());
 
         /*
          * Call reset_all function to flush and reset iptables, but only
@@ -642,12 +660,13 @@ QString CompilerDriver_ipt::run(const std::string &cluster_id,
         top_comment.setVariable("timestamp", timestr);
         top_comment.setVariable("tz", tzname[stm->tm_isdst]);
         top_comment.setVariable("user", user_name);
+        top_comment.setVariable("database", objdb->getFileName().c_str());
 
         QFileInfo fw_file_info(fw_file_name);
         script_buffer = "";
-        script << MANIFEST_MARKER << "* " << fw_file_info.fileName();
+        script << MANIFEST_MARKER << "* " << this->escapeFileName(fw_file_info.fileName());
         string remote_name = fw->getOptionsObject()->getStr("script_name_on_firewall");
-        if (!remote_name.empty()) script << " " << remote_name;
+        if (!remote_name.empty()) script << " " << this->escapeFileName(remote_name.c_str());
         script << "\n";
 
         /* Add additional files to manifest if specified.  Currently there
@@ -664,7 +683,7 @@ QString CompilerDriver_ipt::run(const std::string &cluster_id,
             {
                 string name = c_iter->first;
                 string dest = c_iter->second;
-                script << MANIFEST_MARKER << name;
+                script << MANIFEST_MARKER << this->escapeFileName(name.c_str());
                 if (!dest.empty()) script << " " << dest;
                 script << "\n";
             }
