@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipt.cpp 2555 2010-02-17 05:37:55Z vadim $
+  $Id: NATCompiler_ipt.cpp 3022 2010-06-25 03:38:24Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -220,11 +220,12 @@ int NATCompiler_ipt::prolog()
 
 void NATCompiler_ipt::_expand_interface(Rule *rule,
                                         Interface *iface,
-                                        std::list<FWObject*> &ol)
+                                        std::list<FWObject*> &ol,
+                                        bool expand_cluster_interfaces_fully)
 {
     std::list<FWObject*> nol;
 
-    Compiler::_expand_interface(rule, iface, ol);
+    Compiler::_expand_interface(rule, iface, ol, expand_cluster_interfaces_fully);
 
     physAddress *pa=iface->getPhysicalAddress();
 /*
@@ -843,14 +844,9 @@ bool NATCompiler_ipt::addVirtualAddress::processNext()
         else
             a=compiler->getFirstODst(rule);
 
-        // TODO: should always issue the warning that adding virtual
-        // addresses for NAT is not supported with address ranges,
-        // regardless of the result of complexMatch()
-
         if ( ! a->isAny() &&
              ! compiler->complexMatch(a, compiler->fw) &&
-             ! compiler->complexMatch(a, cluster) && 
-             options->getBool("manage_virtual_addr"))
+             ! compiler->complexMatch(a, cluster))
         {
             if (AddressRange::cast(a)!=NULL)
             {
@@ -2379,65 +2375,6 @@ bool NATCompiler_ipt::AssignInterface::processNext()
  * has no interfaces at all.  I wonder if I really have to do this,
  * but I do it anyway.
  */
-        ObjectMatcher om_exact;
-        om_exact.setRecognizeBroadcasts(true);
-        om_exact.setRecognizeMulticasts(true);
-        om_exact.setIPV6(ipt_comp->ipv6);
-        om_exact.setMatchSubnets(true);
-        om_exact.setAddressRangeMatchMode(ObjectMatcher::EXACT);
-
-        ObjectMatcher om_partial;
-        om_partial.setRecognizeBroadcasts(true);
-        om_partial.setRecognizeMulticasts(true);
-        om_partial.setIPV6(ipt_comp->ipv6);
-        om_partial.setMatchSubnets(true);
-        om_partial.setAddressRangeMatchMode(ObjectMatcher::PARTIAL);
-
-        bool found_interface = false;
-        foreach(FWObject* i, all_interfaces)
-        {
-            Interface *iface = Interface::cast(i);
-            assert(iface);
-
-            if (iface->isLoopback() ||
-                iface->isUnnumbered() ||
-                iface->isBridgePort()
-            ) continue;
-
-            if (om_partial.complexMatch(tsrc, iface))
-            {
-                found_interface = true;
-                NATRule *r = compiler->dbcopy->createNATRule();
-                r->duplicate(rule);
-                compiler->temp_ruleset->add(r);
-                r->setInterfaceId(iface->getId());
-                tmp_queue.push_back(r);
-
-                if (AddressRange::isA(tsrc) && !om_exact.complexMatch(tsrc, iface))
-                {
-                    // We have only partial match of this address range and subnet
-                    // defined by the interface
-                    QString err(
-                        "Object '%1' used in TSrc of the NAT rule defines "
-                        "address range that only partially matches subnet "
-                        "defined by the configuration of interface '%2'");
-                    compiler->warning(
-                        r,
-                        err
-                        .arg(tsrc->getName().c_str())
-                        .arg(iface->getName().c_str()).toStdString());
-                }
-            }
-
-    // TODO: add check for non-aligned boundaries of the range
-    // defined by TSrc. Example: interface is configured as
-    // 33.33.33.33//255.255.255.248 (subnet 33.33.33.32 .. 47)
-    // but address range used in TSrc is 33.33.33.20 .. 35.
-    // Both define 15 addresses but boundaries are different.
-
-        }
-        if (found_interface) return true;
-
         int n = 0;
         foreach(QString intf_name, regular_interfaces)
         {
@@ -2693,21 +2630,6 @@ void NATCompiler_ipt::compile()
         add( new classifyNATRule( "reclassify rules" ));
         add( new ConvertLoadBalancingRules( "convert load balancing rules"));
         add( new VerifyRules( "verify rules" ));
-#if 0
-// ----------- 10/18/2008
-        add( new splitODstForSNAT(
-                 "split rule if objects in ODst belong to different subnets") );
-        add( new ReplaceFirewallObjectsODst("replace firewall in ODst" ) );
-	add( new ReplaceFirewallObjectsTSrc("replace firewall in TSrc" ) );
-        add( new splitOnDynamicInterfaceInODst(
-                 "split rule if ODst is dynamic interface" ) );
-        add( new splitOnDynamicInterfaceInTSrc(
-                 "split rule if TSrc is dynamic interface" ) );
-
-        add( new ExpandMultipleAddresses("expand multiple addresses") );
-        add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
-// ----------- 
-#endif
 
         add( new singleObjectNegationOSrc(
                  "negation in OSrc if it holds single object"));
