@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipt.h 2395 2010-01-20 08:09:15Z vadim $
+  $Id: NATCompiler_ipt.h 2800 2010-04-09 02:29:27Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -86,8 +86,8 @@ namespace fwcompiler {
          */
         virtual void _expand_interface(libfwbuilder::Rule *rule,
                                        libfwbuilder::Interface *iface,
-                                       std::list<libfwbuilder::FWObject*> &ol);
-
+                                       std::list<libfwbuilder::FWObject*> &ol,
+                                       bool expand_cluster_interfaces_fully);
 
 
         virtual std::string debugPrintRule(libfwbuilder::Rule *rule);
