@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipt.h 2555 2010-02-17 05:37:55Z vadim $
+  $Id: PolicyCompiler_ipt.h 2844 2010-04-26 16:27:57Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -120,9 +120,19 @@ protected:
          */
         virtual void _expand_interface(libfwbuilder::Rule *rule,
                                        libfwbuilder::Interface *iface,
-                                       std::list<libfwbuilder::FWObject*> &ol);
+                                       std::list<libfwbuilder::FWObject*> &ol,
+                                       bool expand_cluster_interfaces_fully);
 
 
+        /**
+         * virtual method to let policy compiler check rules using
+         * options specific for the given fw platform. Base class
+         * PolicyCompiler has no visibility into platform-specific
+         * options and can not do this.
+         */
+        virtual bool checkForShadowingPlatformSpecific(libfwbuilder::PolicyRule *r1,
+                                                       libfwbuilder::PolicyRule *r2);
+
         /**
          * prints rule in some universal format (close to that visible
          * to user in the GUI). Used for debugging purposes. This method
@@ -699,12 +709,6 @@ protected:
 	 */
         DECLARE_POLICY_RULE_PROCESSOR(checkUserServiceInWrongChains);
 
-
-	/**
-	 * expand groups in Srv
-	 */
-        DECLARE_POLICY_RULE_PROCESSOR(expandGroupsInSrv);
-
 	/**
          * split a rule if action Reject is used in a rule with
          * Service 'any' and rule options do not specify what should
