@@ -24,7 +24,7 @@
 class IPTImporter;
 
 #line 27 "IPTCfgLexer.hpp"
-#line 62 "iptables.g"
+#line 64 "iptables.g"
 
     // gets inserted after generated namespace specifications in the
     // header file. But outside the generated class.
@@ -63,26 +63,35 @@ public:
 	public: void mWORD(bool _createToken);
 	public: void mSTRING(bool _createToken);
 	protected: void mUNSUPPORTED_OPTION(bool _createToken);
-	public: void mSECONDS(bool _createToken);
-	public: void mSET(bool _createToken);
 	public: void mRSOURCE(bool _createToken);
 	public: void mADD_RULE(bool _createToken);
 	public: void mMATCH_STATE(bool _createToken);
 	public: void mMATCH_SRC_MULTIPORT(bool _createToken);
 	public: void mMATCH_DST_MULTIPORT(bool _createToken);
-	public: void mMATCH_SRC_MULTIPORT_SHORT(bool _createToken);
-	public: void mMATCH_DST_MULTIPORT_SHORT(bool _createToken);
+	public: void mMATCH_BOTH_MULTIPORT(bool _createToken);
 	public: void mMATCH_SRC_PORT(bool _createToken);
 	public: void mMATCH_DST_PORT(bool _createToken);
+	public: void mMATCH_SRC_PORT_SHORT(bool _createToken);
+	public: void mMATCH_DST_PORT_SHORT(bool _createToken);
 	public: void mMATCH_SYN(bool _createToken);
 	public: void mMATCH_TCP_FLAGS(bool _createToken);
 	public: void mMATCH_TCP_OPTION(bool _createToken);
-	public: void mMATCH_SRC_PORT_SHORT(bool _createToken);
-	public: void mMATCH_DST_PORT_SHORT(bool _createToken);
 	public: void mMATCH_ICMP_TYPE(bool _createToken);
 	public: void mMATCH_MARK(bool _createToken);
+	public: void mMATCH_LENGTH(bool _createToken);
 	public: void mMATCH_LIMIT(bool _createToken);
 	public: void mMATCH_LIMIT_BURST(bool _createToken);
+	public: void mMATCH_RECENT_NAME(bool _createToken);
+	public: void mMATCH_RECENT_RCHECK(bool _createToken);
+	public: void mMATCH_RECENT_UPDATE(bool _createToken);
+	public: void mMATCH_RECENT_REMOVE(bool _createToken);
+	public: void mMATCH_RECENT_SECONDS(bool _createToken);
+	public: void mMATCH_RECENT_HITCOUNT(bool _createToken);
+	public: void mMATCH_RECENT_RTTL(bool _createToken);
+	public: void mMATCH_RECENT_RDEST(bool _createToken);
+	public: void mMATCH_RECENT_SET(bool _createToken);
+	public: void mMATCH_IPRANGE_SRC(bool _createToken);
+	public: void mMATCH_IPRANGE_DST(bool _createToken);
 	public: void mMATCH_COMMENT(bool _createToken);
 	public: void mREJECT_WITH(bool _createToken);
 	public: void mSET_MARK(bool _createToken);
