@@ -24,7 +24,7 @@
 class IPTImporter;
 
 #line 27 "IPTCfgParser.hpp"
-#line 62 "iptables.g"
+#line 64 "iptables.g"
 
     // gets inserted after generated namespace specifications in the
     // header file. But outside the generated class.
@@ -32,7 +32,7 @@ class IPTImporter;
 #line 33 "IPTCfgParser.hpp"
 class CUSTOM_API IPTCfgParser : public ANTLR_USE_NAMESPACE(antlr)LLkParser, public IPTCfgParserTokenTypes
 {
-#line 79 "iptables.g"
+#line 81 "iptables.g"
 
 // additional methods and members
 
@@ -74,6 +74,8 @@ public:
 	public: void chain_def();
 	public: void ipt_option();
 	public: void module();
+	public: void match_mark();
+	public: void match_recent();
 	public: void src();
 	public: void dst();
 	public: void i_intf();
@@ -85,9 +87,11 @@ public:
 	public: void basic_tcp_udp_port_spec();
 	public: void multiport_tcp_udp_port_spec();
 	public: void tcp_options();
-	public: void match_mark();
 	public: void match_limit();
 	public: void match_limit_burst();
+	public: void match_length();
+	public: void match_iprange_src();
+	public: void match_iprange_dst();
 	public: void unknown_option();
 	public: void unknown_parameter();
 	public: void m_state();
@@ -95,8 +99,9 @@ public:
 	public: void m_icmp();
 	public: void m_tcp();
 	public: void m_udp();
-	public: void m_mark();
 	public: void m_limit();
+	public: void m_length();
+	public: void m_iprange();
 	public: void m_comment();
 	public: void m_unknown_module();
 	public: void protocol_word();
@@ -106,7 +111,13 @@ public:
 	public: void nat_addr_range();
 	public: void nat_port_def_with_range();
 	public: void state_word();
+	public: void m_mark();
 	public: void limit_rate();
+	public: void m_recent();
+	public: void recent_opts();
+	public: void recent_args_no_param();
+	public: void recent_args_param();
+	public: void length_spec();
 	public: void port_def_no_range();
 	public: void port_def_with_range();
 	public: void port_def_with_incomplete_range();
@@ -126,10 +137,10 @@ protected:
 private:
 	static const char* tokenNames[];
 #ifndef NO_STATIC_CONSTS
-	static const int NUM_TOKENS = 127;
+	static const int NUM_TOKENS = 139;
 #else
 	enum {
-		NUM_TOKENS = 127
+		NUM_TOKENS = 139
 	};
 #endif
 	
@@ -155,6 +166,14 @@ private:
 	static const ANTLR_USE_NAMESPACE(antlr)BitSet _tokenSet_9;
 	static const unsigned long _tokenSet_10_data_[];
 	static const ANTLR_USE_NAMESPACE(antlr)BitSet _tokenSet_10;
+	static const unsigned long _tokenSet_11_data_[];
+	static const ANTLR_USE_NAMESPACE(antlr)BitSet _tokenSet_11;
+	static const unsigned long _tokenSet_12_data_[];
+	static const ANTLR_USE_NAMESPACE(antlr)BitSet _tokenSet_12;
+	static const unsigned long _tokenSet_13_data_[];
+	static const ANTLR_USE_NAMESPACE(antlr)BitSet _tokenSet_13;
+	static const unsigned long _tokenSet_14_data_[];
+	static const ANTLR_USE_NAMESPACE(antlr)BitSet _tokenSet_14;
 };
 
 #endif /*INC_IPTCfgParser_hpp_*/
