@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: CompilerDriver_ipfw.cpp 1861 2009-11-21 22:12:01Z vadim $
+  $Id: CompilerDriver_ipfw.cpp 2779 2010-03-29 18:07:03Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -43,6 +43,8 @@ CompilerDriver_ipfw::CompilerDriver_ipfw(FWObjectDatabase *db) :
 // create a copy of itself, including objdb
 CompilerDriver* CompilerDriver_ipfw::clone()
 {
-    return new CompilerDriver_ipfw(objdb);
+    CompilerDriver_ipfw* new_cd = new CompilerDriver_ipfw(objdb);
+    if (inEmbeddedMode()) new_cd->setEmbeddedMode();
+    return new_cd;
 }
 
