@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipf.cpp 709 2008-12-25 20:38:53Z vadim $
+  $Id: NATCompiler_ipf.cpp 2353 2010-01-16 00:26:01Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -74,59 +74,53 @@ bool NATCompiler_ipf::VerifyRules::processNext()
     RuleElementTSrv  *tsrv=rule->getTSrv();  assert(tsrv);
 
     if (rule->getRuleType()==NATRule::DNAT && odst->size()!=1)
-	throw FWException(_("There should be no more than one object in original destination in the rule ")+rule->getLabel());
+	compiler->abort(rule,
+                        "There should be no more than one object in "
+                        "original destination");
 
 //    if (rule->getRuleType()==NATRule::SNAT && tsrc->size()!=1)
-//	throw FWException(_("There should be no more than one object in translated source in the rule ")+rule->getLabel());
+//	compiler->abort(rule, "There should be no more than one object in translated source in the rule "+rule->getLabel());
 
     if (rule->getRuleType()==NATRule::DNAT && osrv->isAny()) 
-	throw FWException(_("Service must be specified for destination translation rule. Rule ")+rule->getLabel());
+	compiler->abort(rule,
+                        "Service must be specified for destination translation rule");
 
     if (tsrv->size()!=1) 
-	throw FWException(_("Translated service should be 'Original' or should contain single object. Rule: ")+rule->getLabel());
+	compiler->abort(rule,
+                        "Translated service should be 'Original' or should "
+                        "contain single object");
 
     FWObject *o=tsrv->front();
     if (FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
 
     if ( Group::cast(o)!=NULL)
-	throw FWException(_("Can not use group in translated service. Rule ")+rule->getLabel());
+	compiler->abort(rule,
+                        "Can not use group in translated service");
 
-#if 0
-    if (rule->getRuleType()==NATRule::SNAT ) 
+    if (rule->getRuleType()==NATRule::SNetnat && !tsrc->isAny() )
     {
-        if ( tsrc->size()!=1)
-            throw FWException(_("There should be no more than one object in translated source in the rule ")+rule->getLabel());
-
-//        Address* o1=tsrc->getFirst(true);
-//        if ( ! tsrc->isAny() && Network::cast(o1)!=NULL)
-//            throw FWException(_("Can not use network object in translated source. Rule ")+rule->getLabel());
-    }
-#endif
-
-    if (rule->getRuleType()==NATRule::SNetnat && !tsrc->isAny() ) {
         Network *a1=Network::cast(compiler->getFirstOSrc(rule));
         Network *a2=Network::cast(compiler->getFirstTSrc(rule));
         if ( a1==NULL || a2==NULL ||
              a1->getNetmaskPtr()->getLength()!=a2->getNetmaskPtr()->getLength() )
-            throw FWException(_("Original and translated source should both be networks of the same size . Rule ")+rule->getLabel());
+            compiler->abort(rule,
+                            "Original and translated source should both "
+                            "be networks of the same size");
     }
 
-    if (rule->getRuleType()==NATRule::DNetnat && !tsrc->isAny() ) {
+    if (rule->getRuleType()==NATRule::DNetnat && !tsrc->isAny() )
+    {
         Network *a1=Network::cast(compiler->getFirstODst(rule));
         Network *a2=Network::cast(compiler->getFirstTDst(rule));
         if ( a1==NULL || a2==NULL ||
              a1->getNetmaskPtr()->getLength()!=a2->getNetmaskPtr()->getLength() )
-            throw FWException(_("Original and translated destination should both be networks of the same size . Rule ")+rule->getLabel());
+            compiler->abort(rule,
+                            "Original and translated destination should "
+                            "both be networks of the same size");
     }
 
-
-
-
     if (osrc->getNeg() || odst->getNeg() || osrv->getNeg())
-        throw FWException(_("Negation in NAT rules is not supported. Rule ")+rule->getLabel());
-
-//    if (rule->getRuleType()==NATRule::NONAT)
-//        throw FWException(_("Unsupported translation. Rule ")+rule->getLabel());
+        compiler->abort(rule, "Negation in NAT rules is not supported");
 
     return true;
 }
@@ -152,10 +146,9 @@ bool NATCompiler_ipf::ExpandPortRange::processNext()
         if (numPorts > 20)
         {
             ostringstream ostr;
-            ostr << string("Rule ") << rule->getLabel() << " : "
-                 << string("Expanding port range ") << osrv->getName()
+            ostr << string("Expanding port range ") << osrv->getName()
                  << " creates " << numPorts << " rules";
-            compiler->warning(ostr.str());
+            compiler->warning(rule, ostr.str());
         }
 
         string newSrvType = TCPService::TYPENAME;
@@ -172,7 +165,6 @@ bool NATCompiler_ipf::ExpandPortRange::processNext()
             TCPUDPService::cast(newSrv)->setDstRangeEnd(p);
             compiler->dbcopy->add(newSrv,false);
             compiler->dbcopy->addToIndex(newSrv);
-            compiler->cacheObj(newSrv);
 
             RuleElementOSrv *nosrv = r->getOSrv();
             nosrv->clearChildren();
@@ -304,9 +296,10 @@ bool NATCompiler_ipf::AssignInterface::processNext()
     default: ;
     }
 
-    throw FWException(_("Could not assign NAT rule to the interface. Perhaps one of the \n\
- objects has address which does not belong to any subnet the firewall has interface on. \n\
- Rule: ")+rule->getLabel());
+    compiler->abort(rule,
+                    "Could not assign NAT rule to the interface. "
+                    "Perhaps one of the objects has address which does not "
+                    "belong to any subnet the firewall has interface on");
     
     return true;
 }
@@ -508,7 +501,9 @@ bool NATCompiler_ipf::processMultiAddressObjectsInRE::processNext()
         if (FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
         MultiAddressRunTime *atrt = MultiAddressRunTime::cast(o);
         if (atrt!=NULL && atrt->getSubstitutionTypeName()==AddressTable::TYPENAME)
-            compiler->abort("Run-time AddressTable objects are not supported. Rule " + rule->getLabel());
+            compiler->abort(
+                    rule, 
+                    "Run-time AddressTable objects are not supported.");
     }
 
     tmp_queue.push_back(rule);
@@ -520,7 +515,7 @@ void NATCompiler_ipf::compile()
 {
     bool manage_virtual_addr=getCachedFwOpt()->getBool("manage_virtual_addr");
 
-    cout << _(" Compiling NAT rules for ") << fw->getName() << " ..." << endl << flush;
+    info(" Compiling NAT rules for " + fw->getName());
 
     try {
 
@@ -529,6 +524,8 @@ void NATCompiler_ipf::compile()
         add( new Begin());
         add( new printTotalNumberOfRules() );
 
+        add( new singleRuleFilter());
+
         add( new recursiveGroupsInOSrc(      "check for recursive groups in OSRC"     ) );
         add( new recursiveGroupsInODst(      "check for recursive groups in ODST"     ) );
         add( new recursiveGroupsInOSrv(      "check for recursive groups in OSRV"     ) );
@@ -581,13 +578,18 @@ void NATCompiler_ipf::compile()
         add( new AssignInterface( "assign rules to interfaces" ) );
         add( new RedirectRules( "replace objects in TDst for 'Redirect' rules" ) );
         add( new convertInterfaceIdToStr(    "prepare interface assignments"         ) );
+
+        add( new checkForObjectsWithErrors(
+                 "check if we have objects with errors in rule elements"));
+
         add( new PrintRule("generate ipfilter code") );
         add( new simplePrintProgress() );
 
         runRuleProcessors();
 
 
-    } catch (FWException &ex) {
+    } catch (FWException &ex)
+    {
 	error(ex.toString());
 	exit(1);
     }
