@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipf_writers.cpp 714 2008-12-28 21:06:00Z vadim $
+  $Id: NATCompiler_ipf_writers.cpp 2342 2010-01-13 21:21:07Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -229,25 +229,10 @@ bool NATCompiler_ipf::PrintRule::processNext()
 
     tmp_queue.push_back(rule);
 
-    string rl=rule->getLabel();
-    if (rl!=current_rule_label) {
-
-        compiler->output << "# " << endl;
-        compiler->output << "# Rule  " << rl << endl;
-
-        string    comm=rule->getComment();
-        string::size_type c1,c2;
-        c1=0;
-        while ( (c2=comm.find('\n',c1))!=string::npos ) {
-            compiler->output << "# " << comm.substr(c1,c2-c1) << endl;
-            c1=c2+1;
-        }
-        compiler->output << "# " << comm.substr(c1) << endl;
-        compiler->output << "# " << endl;
-
-        current_rule_label=rl;
-    }
+    compiler->output << compiler->printComment(rule, current_rule_label, "#");
 
+    // string err = rule->getStr(".error_msg");
+    // if (!err.empty()) compiler->output << "# " << err << endl;
 
     Address  *osrc=compiler->getFirstOSrc(rule);  assert(osrc);
     Address  *odst=compiler->getFirstODst(rule);  assert(odst);
