@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipfw.cpp 312 2008-07-05 17:40:12Z vadim $
+  $Id: NATCompiler_ipfw.cpp 1487 2009-09-23 17:00:48Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -61,7 +61,7 @@ int NATCompiler_ipfw::prolog()
 
 void NATCompiler_ipfw::compile()
 {
-    cout << _(" Compiling NAT rules for ") << fw->getName() << " ..." << endl << flush;
+    info(" Compiling NAT rules for " + fw->getName());
 
     try {
 
@@ -74,7 +74,8 @@ void NATCompiler_ipfw::compile()
 
         runRuleProcessors();
 
-    } catch (FWException &ex) {
+    } catch (FWException &ex)
+    {
 	error(ex.toString());
 	exit(1);
     }
