@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_pf.cpp 2554 2010-02-17 02:43:23Z vadim $
+  $Id: NATCompiler_pf.cpp 2828 2010-04-23 04:38:51Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -155,9 +155,9 @@ bool NATCompiler_pf::NATRuleType::processNext()
         return true;
     }
 
-
-
-    if (tsrc->isAny() && tdst->isAny() && tsrv->isAny())
+    if (tsrc->isAny() && tdst->isAny() && 
+        (tsrv->isAny() || (tsrv->getId() == osrv->getId()))
+    )
     {
 	rule->setRuleType(NATRule::NONAT);
 	return true;
@@ -342,6 +342,8 @@ bool NATCompiler_pf::VerifyRules::processNext()
 {
     NATRule *rule=getNext(); if (rule==NULL) return false;
 
+    string version = compiler->fw->getStr("version");
+
     RuleElementOSrc  *osrc=rule->getOSrc();  assert(osrc);
     RuleElementODst  *odst=rule->getODst();  assert(odst);
     RuleElementOSrv  *osrv=rule->getOSrv();  assert(osrv);
@@ -350,6 +352,28 @@ bool NATCompiler_pf::VerifyRules::processNext()
     RuleElementTDst  *tdst=rule->getTDst();  assert(tdst);
     RuleElementTSrv  *tsrv=rule->getTSrv();  assert(tsrv);
 
+    /*
+     * because of the change in the nat and rdr rules syntax in
+     * 4.7, I can no longer implement no-nat rules correctly for
+     * this version. They dropped the "no" keyword and their
+     * examples suggest using "pass" to implement exclusions for
+     * the nat rules. I need no-nat rule to just not translate but
+     * not make a decision whether the packet should be passed or
+     * dropped. In the new PF model, translation rules are just
+     * options on the matching policy rules and they do not offer
+     * any keyword or option to not translate.
+     */
+    if (rule->getRuleType()==NATRule::NONAT &&
+        XMLTools::version_compare(version, "4.7")>=0)
+    {
+        compiler->abort(
+            rule,
+            "No translation rules are not supported for PF 4.7, "
+            "use negation to implement exclusions");
+        return true;
+    }
+
+
     if (rule->getRuleType()==NATRule::DNAT && odst->size()!=1)
     {
 	compiler->abort(
@@ -695,6 +719,12 @@ bool NATCompiler_pf::AssignInterface::processNext()
     NATCompiler_pf *pf_comp=dynamic_cast<NATCompiler_pf*>(compiler);
     NATRule *rule=getNext(); if (rule==NULL) return false;
 
+    if (rule->getInterfaceStr() != "")
+    {
+        tmp_queue.push_back(rule);
+        return true;
+    }
+
     switch ( rule->getRuleType() )
     {
     case NATRule::SNAT:
@@ -747,13 +777,13 @@ bool NATCompiler_pf::ReplaceFirewallObjectsODst::processNext()
 
     list<FWObject*> cl;
     RuleElementODst *rel;
-    Address         *obj=NULL;
-
-    rel=rule->getODst();      assert(rel);
-    obj=compiler->getFirstODst(rule);  assert(obj);
-
-    if (obj->getId()==compiler->getFwId() ) {
+    Address *obj=NULL;
 
+    rel = rule->getODst();      assert(rel);
+    obj =compiler->getFirstODst(rule);  assert(obj);
+ 
+    if (obj->getId()==compiler->getFwId() )
+    {
 	list<FWObject*> l2=compiler->fw->getByType(Interface::TYPENAME);
 	for (list<FWObject*>::iterator i=l2.begin(); i!=l2.end(); ++i) {
 	    Interface *interface_=Interface::cast(*i);
@@ -768,14 +798,19 @@ bool NATCompiler_pf::ReplaceFirewallObjectsODst::processNext()
             if (! interface_->isLoopback() ) cl.push_back(interface_);
 
 	}
-	if ( ! cl.empty() ) {
+	if ( ! cl.empty() )
+        {
 	    rel->clearChildren();
-
 	    for (FWObject::iterator i1=cl.begin(); i1!=cl.end(); ++i1) 
 	    {
 		rel->addRef( *i1 );
 	    }
 	}
+/*
+ * update for ticket 1397
+ * If firewall object is in ODst, do not assign the rule to any interface
+ */
+        rule->setInterfaceStr("nil");
     }
 
     return true;
