@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_pf.h 1048 2009-06-09 22:36:41Z vadim $
+  $Id: NATCompiler_pf.h 1626 2009-10-21 00:51:10Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -78,7 +78,17 @@ namespace fwcompiler {
 
         virtual std::string debugPrintRule(libfwbuilder::Rule *rule);
 
-
+        /**
+         * analyse given address and decide which interface this NAT
+         * rule should be tied to. If interface is found, use
+         * rule->setInterfaceId() to save its ID and return
+         * true. Otherwise, return false. Most importantly, this
+         * function checks if @obj is cluster interface and then
+         * uses corresponding real interface instead of it.
+         */
+        bool assignInterfaceToNATRule(libfwbuilder::Rule *rule,
+                                      libfwbuilder::Address *obj);
+        
 	/**
 	 *  determines type of the NAT rule
 	 */
@@ -338,7 +348,12 @@ namespace fwcompiler {
 	 */
         class PrintRule : public NATRuleProcessor
         {
-            protected:
+            void _printAnchorRule(const std::string &anchor_command,
+                                  const std::string &ruleset_name,
+                                  const std::string &interface_name,
+                                  libfwbuilder::NATRule *rule);
+                
+    protected:
             bool                             init;
             std::string                      current_rule_label;
 
@@ -368,11 +383,11 @@ namespace fwcompiler {
 	public:
 
 	NATCompiler_pf(libfwbuilder::FWObjectDatabase *_db,
-		       const std::string &fwname,
+		       libfwbuilder::Firewall *fw,
                        bool ipv6_policy,
 		       fwcompiler::OSConfigurator *_oscnf,
                        TableFactory *tbf = NULL) :
-        NATCompiler(_db, fwname, ipv6_policy, _oscnf)
+        NATCompiler(_db, fw, ipv6_policy, _oscnf)
         {
             tables = tbf;
         }
