@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSConfigurator_solaris.h 312 2008-07-05 17:40:12Z vadim $
+  $Id: OSConfigurator_solaris.h 1568 2009-10-09 18:23:54Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,16 +28,24 @@
 
 #include "config.h"
 
-#include "fwcompiler/OSConfigurator.h"
 #include "fwbuilder/InetAddr.h"
 
 #include <vector>
 
+#include "OSConfigurator_bsd.h"
 #include "OSData.h"
 
+/*
+ * Of course Solaris has nothing to do with BSD. Class
+ * OSConfigurator_solaris inherits OSConfigurator_bsd only because the
+ * latter is the base class for all OSConfigurator classes for the
+ * pf-ipf-ipfw family. TODO: rename OSConfigurator_bsd to use more
+ * generic name, something like OSConfigurator_generic_pf_ipf_family
+ */
+
 namespace fwcompiler {
 
-    class OSConfigurator_solaris : public OSConfigurator {
+    class OSConfigurator_solaris : public OSConfigurator_bsd {
 
         OSData   os_data;
 
@@ -47,18 +55,19 @@ namespace fwcompiler {
 
 	virtual ~OSConfigurator_solaris() {};
 	OSConfigurator_solaris(libfwbuilder::FWObjectDatabase *_db,
-                               const std::string &fwname,
+                               libfwbuilder::Firewall *fw,
                                bool ipv6_policy) : 
-        OSConfigurator(_db, fwname, ipv6_policy) , os_data() {}
+        OSConfigurator_bsd(_db, fw, ipv6_policy) , os_data() {}
 
         virtual int prolog();
 
 	virtual std::string myPlatformName();
-	virtual void processFirewallOptions();
+	virtual std::string printKernelVarsCommands();
+        
 	virtual void addVirtualAddressForNAT(const libfwbuilder::Address *addr);
 	virtual void addVirtualAddressForNAT(const libfwbuilder::Network   *nw);
-        void         printPathForAllTools(const std::string &os);
-        void         configureInterfaces();
+
+        virtual std::string configureInterfaces();
     };
 };
 
