@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipf.cpp 709 2008-12-25 20:38:53Z vadim $
+  $Id: PolicyCompiler_ipf.cpp 2353 2010-01-16 00:26:01Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -55,17 +55,14 @@ int PolicyCompiler_ipf::prolog()
     anytcp = dbcopy->createTCPService();
     anytcp->setId(FWObjectDatabase::generateUniqueId()); //ANY_TCP_OBJ_ID);
     dbcopy->add(anytcp,false);
-    cacheObj(anytcp); // to keep cache consistent
 
     anyudp=dbcopy->createUDPService();
     anyudp->setId(FWObjectDatabase::generateUniqueId()); //ANY_UDP_OBJ_ID);
     dbcopy->add(anyudp,false);
-    cacheObj(anyudp); // to keep cache consistent
 
     anyicmp=dbcopy->createICMPService();
     anyicmp->setId(FWObjectDatabase::generateUniqueId()); //ANY_ICMP_OBJ_ID);
     dbcopy->add(anyicmp,false);
-    cacheObj(anyicmp); // to keep cache consistent
 
     return n;
 }
@@ -205,8 +202,9 @@ bool PolicyCompiler_ipf::doSrvNegation::processNext()
 
     RuleElementSrv *srv=rule->getSrv();
 
-    if (srv->getNeg()) {
-	throw FWException(_("Negation in Srv is not implemented. Rule: ")+rule->getLabel());
+    if (srv->getNeg())
+    {
+	compiler->abort(rule, "Negation in Srv is not implemented");
 	return false;
     }
     tmp_queue.push_back(rule);
@@ -332,19 +330,29 @@ bool PolicyCompiler_ipf::checkForKeepState::processNext()
 
 bool PolicyCompiler_ipf::eliminateDuplicateRules::processNext()
 {
-    PolicyCompiler *pcomp=dynamic_cast<PolicyCompiler*>(compiler);
-    PolicyRule *rule=getNext(); if (rule==NULL) return false;
+    PolicyCompiler *pcomp = dynamic_cast<PolicyCompiler*>(compiler);
+    PolicyRule *rule = getNext(); if (rule==NULL) return false;
+
+    // Note that if rule has "any" in Interface column, it is
+    // implemented as reference to the AnyNetwork object. In this case
+    // Compiler::getFirstItf() returns NULL.
+    Interface *intf_rule = compiler->getFirstItf(rule);
+    int intf_id_rule = (intf_rule) ? intf_rule->getId() : -1;
 
     if ( ! rule->getBool("skip_check_for_duplicates"))
     {
         for (deque<PolicyRule*>::iterator i=rules_seen_so_far.begin(); i!=rules_seen_so_far.end(); ++i)
         {
             PolicyRule *r=(*i);
-            if ( r->getBool("skip_check_for_duplicates") ) continue;
-            if (r->getInterfaceId()==rule->getInterfaceId() &&
+            if (r->getBool("skip_check_for_duplicates") ) continue;
+            if (r->getAction()==PolicyRule::Continue ||
+                r->getAction()==PolicyRule::Skip) continue;
+
+            Interface *intf_r = compiler->getFirstItf(r);
+            int intf_id_r = (intf_r) ? intf_r->getId() : -1;
+
+            if (intf_id_r==intf_id_rule &&
                 r->getAction()==rule->getAction()           &&
-                r->getAction()!=PolicyRule::Continue        &&
-                r->getAction()!=PolicyRule::Skip            &&
                 r->getLogging()==rule->getLogging()         &&
                 pcomp->cmpRules(*r,*rule) ) 
             {
@@ -372,17 +380,45 @@ bool PolicyCompiler_ipf::processMultiAddressObjectsInRE::processNext()
         if (FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
         MultiAddressRunTime *atrt = MultiAddressRunTime::cast(o);
         if (atrt!=NULL && atrt->getSubstitutionTypeName()==AddressTable::TYPENAME)
-            compiler->abort("Run-time AddressTable objects are not supported. Rule " + rule->getLabel());
+            compiler->abort(
+                
+                    rule, 
+                    "Run-time AddressTable objects are not supported.");
     }
 
     tmp_queue.push_back(rule);
     return true;
 }
 
+bool PolicyCompiler_ipf::SplitDirectionIpfilter::processNext()
+{
+    PolicyRule *rule=getNext(); if (rule==NULL) return false;
+
+    if (rule->getDirection()==PolicyRule::Both)
+    {
+	PolicyRule *r= compiler->dbcopy->createPolicyRule();
+	compiler->temp_ruleset->add(r);
+	r->duplicate(rule);
+	r->setDirection(PolicyRule::Inbound);
+	tmp_queue.push_back(r);
+
+	r= compiler->dbcopy->createPolicyRule();
+	compiler->temp_ruleset->add(r);
+	r->duplicate(rule);
+	r->setDirection(PolicyRule::Outbound);
+	tmp_queue.push_back(r);
+
+    } else 
+	tmp_queue.push_back(rule);
+
+    return true;
+}
+
+
 
 void PolicyCompiler_ipf::compile()
 {
-    cout << " Compiling policy for " << fw->getName() << " ..." <<  endl << flush;
+    info(" Compiling policy for " + fw->getName());
 
     try {
 
@@ -391,7 +427,8 @@ void PolicyCompiler_ipf::compile()
 	addDefaultPolicyRule();
         bool check_for_recursive_groups=true;
 
-        if ( fw->getOptionsObject()->getBool ("check_shading") ) 
+        if ( fw->getOptionsObject()->getBool ("check_shading") &&
+             ! inSingleRuleCompileMode())
         {
             add( new Begin ("Detecting rule shadowing"              ) );
             add( new printTotalNumberOfRules( ) );
@@ -415,11 +452,15 @@ void PolicyCompiler_ipf::compile()
             add( new swapMultiAddressObjectsInDst(
                      " swap MultiAddress -> MultiAddressRunTime in Dst") );
 
-            add( new ExpandMultipleAddressesInSRC(
+            add( new ExpandMultipleAddressesInSrc(
                      "expand objects with multiple addresses in SRC" ) );
-            add( new ExpandMultipleAddressesInDST(
+            add( new ExpandMultipleAddressesInDst(
                      "expand objects with multiple addresses in DST" ) );
             add( new ConvertToAtomic("convert to atomic rules" ) );
+
+            add( new checkForObjectsWithErrors(
+                     "check if we have objects with errors in rule elements"));
+
             add( new DetectShadowing("Detect shadowing" ) );
             add( new simplePrintProgress() );
 
@@ -430,6 +471,9 @@ void PolicyCompiler_ipf::compile()
 
         add( new Begin());
         add( new printTotalNumberOfRules() );
+
+        add( new singleRuleFilter());
+
 //        add( new MACFiltering(                "verify for MAC address filtering"                ) );
         add( new setQuickFlag("set 'quick' flag") );
 
@@ -474,7 +518,7 @@ void PolicyCompiler_ipf::compile()
         add( new splitIfFirewallInSrc("split rule if firewall is in Src") );
         add( new splitIfFirewallInDst("split rule if firewall is in Dst") );
         add( new fillDirection("determine directions") );
-        add( new SplitDirection("split rules with direction 'both'" ) );
+        add( new SplitDirectionIpfilter("split rules with direction 'both'" ) );
         add( new ExpandMultipleAddresses(
                  "expand objects with multiple addresses") );
         add( new checkForDynamicInterfacesOfOtherObjects(
@@ -511,13 +555,18 @@ void PolicyCompiler_ipf::compile()
 	add( new calculateSkip("calculate argument for skip") );
         add( new checkForKeepState("check for 'keep state'") );
         add( new convertInterfaceIdToStr("prepare interface assignments") );
+
+        add( new checkForObjectsWithErrors(
+                 "check if we have objects with errors in rule elements"));
+
         add( new PrintRule("generate ipf code") );
         add( new simplePrintProgress() );
 
         runRuleProcessors();
 
 
-    } catch (FWException &ex) {
+    } catch (FWException &ex)
+    {
 	error(ex.toString());
 	exit(1);
     }
@@ -531,13 +580,33 @@ string PolicyCompiler_ipf::debugPrintRule(Rule *r)
     ostringstream s;
     s << PolicyCompiler::debugPrintRule(rule) << " ";
 
-    int iface_id = rule->getInterfaceId();
-    if (iface_id > -1)
+    RuleElementItf *intf_re = rule->getItf();
+    string rule_interfaces;
+    int intf_count = 0;
+    for (FWObject::iterator it=intf_re->begin(); it!=intf_re->end(); ++it)
     {
-	Interface *rule_iface = getCachedFwInterface( iface_id );
-        s << " intf: "+rule_iface->getName();
-    } else
-        s << iface_id;
+        FWObject *o   = *it;
+        if (FWReference::cast(o)!=NULL) o = FWReference::cast(o)->getPointer();
+        rule_interfaces += " " + o->getName();
+        intf_count++;
+    }
+    if (intf_count > 0)
+    {
+        s << " intf: ";
+        if (intf_count > 1) s << "{ ";
+        s << rule_interfaces;
+        if (intf_count > 1) s << " }";
+    }
+    else
+        s << " intf: ?";
+
+    // int iface_id = rule->getInterfaceId();
+    // if (iface_id > -1)
+    // {
+    //     FWObject *rule_iface = dbcopy->findInIndex( iface_id );
+    //     s << " intf: "+rule_iface->getName();
+    // } else
+    //     s << iface_id;
 
     s << " ";
 
@@ -545,6 +614,9 @@ string PolicyCompiler_ipf::debugPrintRule(Rule *r)
     if (r->getStr("skip_label")!="")             s << "skip_label: " << r->getStr("skip_label") << " ";
     if (r->getStr("skip_to")!="")                s << "skip_to: "    << r->getStr("skip_to")    << " ";
     if (r->getInt("no_to_skip")!=-1)             s << "no_to_skip: " << r->getInt("no_to_skip");
+
+    s << " " << FWObjectDatabase::getStringId(r->getId()) << " (" << r->getId() << ")";
+
     return s.str();
 }
 
