@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipfw.h 1487 2009-09-23 17:00:48Z vadim $
+  $Id: PolicyCompiler_ipfw.h 2800 2010-04-09 02:29:27Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -57,7 +57,9 @@ namespace fwcompiler {
 
 	virtual std::string myPlatformName();
 
-	virtual void _expandAddr(libfwbuilder::Rule *rule,libfwbuilder::FWObject *s);
+	virtual void _expand_addr(libfwbuilder::Rule *rule,
+                                  libfwbuilder::FWObject *s,
+                                  bool expand_cluster_interfaces_fully);
 
         /**
          * prints rule in some universal format (close to that visible
