@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipfw_writers.cpp 751 2009-01-25 06:35:06Z vadim $
+  $Id: PolicyCompiler_ipfw_writers.cpp 2640 2010-03-01 04:44:02Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -42,6 +42,7 @@
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Resources.h"
 #include "fwbuilder/DNSName.h"
+#include "fwbuilder/FWObjectDatabase.h"
 
 #include <iostream>
 
@@ -58,6 +59,9 @@
 
 #include <assert.h>
 
+#include <QStringList>
+
+
 using namespace libfwbuilder;
 using namespace fwcompiler;
 using namespace std;
@@ -248,9 +252,9 @@ void PolicyCompiler_ipfw::PrintRule::_printAction(PolicyRule *rule)
 
     default:
         compiler->abort(
-            string("Unknown action ") + rule->getActionAsString()
-            + " in rule " + rule->getLabel()
-        );
+            
+                rule, 
+                string("Unknown action ") + rule->getActionAsString());
 
 //   compiler->output << rule->getActionAsString() << " ";
     }
@@ -329,8 +333,8 @@ void PolicyCompiler_ipfw::PrintRule::_printDirection(libfwbuilder::PolicyRule *r
 
 void PolicyCompiler_ipfw::PrintRule::_printInterface(PolicyRule *r)
 {
-    int iface_id = r->getInterfaceId();
-    if (iface_id > -1) 
+    Interface *intf = compiler->getFirstItf(r);
+    if (intf)
     {
         switch (r->getDirection())
         {
@@ -339,10 +343,23 @@ void PolicyCompiler_ipfw::PrintRule::_printInterface(PolicyRule *r)
         case PolicyRule::Both:     compiler->output << "via  "; break;
         default: break;
         }
-
-	Interface *rule_iface = compiler->getCachedFwInterface( iface_id );
-	compiler->output << rule_iface->getName() << " ";
+	compiler->output << intf->getName() << " ";
     }
+
+    // int iface_id = r->getInterfaceId();
+    // if (iface_id > -1) 
+    // {
+    //     switch (r->getDirection())
+    //     {
+    //     case PolicyRule::Outbound: compiler->output << "xmit "; break;
+    //     case PolicyRule::Inbound:  compiler->output << "recv "; break;
+    //     case PolicyRule::Both:     compiler->output << "via  "; break;
+    //     default: break;
+    //     }
+
+    //     FWObject *rule_iface = compiler->dbcopy->findInIndex( iface_id );
+    //     compiler->output << rule_iface->getName() << " ";
+    // }
 }
 
 void PolicyCompiler_ipfw::PrintRule::_printSrcService(RuleElementSrv  *rel)
@@ -440,8 +457,34 @@ void PolicyCompiler_ipfw::PrintRule::_printDstService(RuleElementSrv  *rel)
         string str=_printTCPFlags(TCPService::cast(s1));
         if (!str.empty()) compiler->output << str << " ";
     }
-    if (IPService::isA(s1) && (s1->getBool("fragm") || s1->getBool("short_fragm")) )
-        compiler->output << " frag ";
+
+    const IPService *ip_srv = IPService::constcast(s1);
+    if (ip_srv)
+    {
+        Rule *rule = Rule::cast(rel->getParent());
+
+        if ((ip_srv->getBool("fragm") || ip_srv->getBool("short_fragm")) )
+            compiler->output << " frag ";
+
+        if (ip_srv->hasIpOptions())
+        {
+            QStringList options;
+
+            if (ip_srv->getBool("any_opt"))
+                compiler->warning(rule, "ipfw can not match \"any IP option\" ");
+            else
+            {
+                const char *option_names[] = {"lsrr", "ssrr", "rr", "ts", NULL};
+                for (const char* *cptr=option_names; *cptr; cptr++)
+                    if  (ip_srv->getBool(*cptr)) options.push_back(*cptr);
+            }
+
+            if (!options.empty())
+                compiler->output << " ipoptions "
+                                 << options.join(",").toStdString()
+                                 << " ";
+        }
+    }
 }
 
 string PolicyCompiler_ipfw::PrintRule::_printDstService(Service *srv,bool neg)
@@ -476,7 +519,6 @@ PolicyCompiler_ipfw::PrintRule::PrintRule(const std::string &name) :
 bool PolicyCompiler_ipfw::PrintRule::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
-    FWOptions*  options = compiler->fw->getOptionsObject();
     FWOptions  *ruleopt = rule->getOptionsObject();
 
     tmp_queue.push_back(rule);
@@ -486,26 +528,10 @@ bool PolicyCompiler_ipfw::PrintRule::processNext()
 
     string quote = "\"";
 
-    string rl=rule->getLabel();
-    if (rl!=current_rule_label) 
-    {
-        compiler->output << "# " << endl;
-        compiler->output << "# Rule " << rl << endl;
-
-        string    comm=rule->getComment();
-        string::size_type c1,c2;
-        c1=0;
-        while ( (c2=comm.find('\n',c1))!=string::npos ) 
-        {
-            compiler->output << "# " << comm.substr(c1,c2-c1) << endl;
-            c1=c2+1;
-        }
-        compiler->output << "# " << comm.substr(c1) << endl;
-        compiler->output << "# " << endl;
-
-        current_rule_label=rl;
-    }
+    compiler->output << compiler->printComment(rule, current_rule_label, "#");
 
+    // string err = rule->getStr(".error_msg");
+    // if (!err.empty()) compiler->output << "# " << err << endl;
 
     RuleElementSrc *srcrel=rule->getSrc();
     Address        *src   =compiler->getFirstSrc(rule);  assert(src);
@@ -585,7 +611,7 @@ bool PolicyCompiler_ipfw::PrintRule::processNext()
     }
 
     compiler->output << " || exit 1" << endl;
-    compiler->output << endl;
+    //compiler->output << endl;
 
     return true;
 }
