@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf.cpp 2438 2010-01-26 03:45:14Z vadim $
+  $Id: PolicyCompiler_pf.cpp 2783 2010-03-29 20:01:10Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -1090,6 +1090,10 @@ void PolicyCompiler_pf::compile()
 
         add(new replaceFailoverInterfaceInItf("replace carp interfaces"));
 
+
+        add(new expandGroupsInItf("expand groups in Interface"));
+        add(new replaceClusterInterfaceInItf(
+                "replace cluster interfaces with member interfaces in the Interface rule element"));
         add(new ItfNegation("process negation in Itf"));
 
         //add(new InterfacePolicyRules(
