@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf_writers.cpp 2504 2010-02-07 05:24:21Z vadim $
+  $Id: PolicyCompiler_pf_writers.cpp 2827 2010-04-23 04:10:59Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -72,11 +72,22 @@ void PolicyCompiler_pf::PrintRule::_printAction(PolicyRule *rule)
 {
     FWOptions *ruleopt =rule->getOptionsObject();
     Service *srv=compiler->getFirstSrv(rule);    assert(srv);
+    string version = compiler->fw->getStr("version");
 
     switch (rule->getAction())
     {
-    case PolicyRule::Accept:  
     case PolicyRule::Tag:
+    {
+        if (XMLTools::version_compare(version, "4.6")>=0)
+        {
+            compiler->output << "match ";
+        }else
+        {
+            compiler->output << "pass ";
+        }
+        break;
+    }
+    case PolicyRule::Accept:  
     case PolicyRule::Classify:
     case PolicyRule::Accounting:
     case PolicyRule::Route:
@@ -115,8 +126,17 @@ void PolicyCompiler_pf::PrintRule::_printAction(PolicyRule *rule)
 	}
 	break;
     case PolicyRule::Scrub:
-        compiler->output << "scrub   ";
+    {
+        string version = compiler->fw->getStr("version");
+        if (XMLTools::version_compare(version, "4.7")>=0)
+        {
+            compiler->output << "match in all scrub   ";
+        } else
+        {
+            compiler->output << "scrub   ";
+        }
         break;
+    }
     case PolicyRule::Custom:
         compiler->output << ruleopt->getStr("custom_str") << " ";
         break;
@@ -1011,7 +1031,7 @@ bool PolicyCompiler_pf::PrintRule::processNext()
          * First, set explicit state tracking parameter, then add
          * stateful tracking options. 
          */
-	if (compiler->getCachedFwOpt()->getBool("pf_synproxy") && tcpsrv!=NULL)
+	if (ruleopt->getBool("pf_synproxy") && tcpsrv!=NULL)
         {
 	    compiler->output << "synproxy state ";
             have_state_option = true;
