@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Preprocessor_pf.h 312 2008-07-05 17:40:12Z vadim $
+  $Id: Preprocessor_pf.h 1487 2009-09-23 17:00:48Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -41,9 +41,9 @@ namespace fwcompiler {
 	public:
 
 	Preprocessor_pf(libfwbuilder::FWObjectDatabase *_db,
-                        const std::string &fwname,
+                        libfwbuilder::Firewall *fw,
                         bool ipv6_policy) :
-        Preprocessor(_db, fwname, ipv6_policy)
+        Preprocessor(_db, fw, ipv6_policy)
         { }
 
         virtual void convertObject(libfwbuilder::FWObject *obj);
