@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: TableFactory.h 312 2008-07-05 17:40:12Z vadim $
+  $Id: TableFactory.h 1675 2009-11-03 06:41:29Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,8 +27,10 @@
 #define __TABLEFACTORY_HH
 
 #include <fwbuilder/libfwbuilder-config.h>
-#include "fwcompiler/PolicyCompiler.h"
 #include <fwbuilder/FWException.h>
+#include <fwbuilder/RuleElement.h>
+
+#include <fwcompiler/BaseCompiler.h>
 
 #include <list>
 #include <map>
@@ -41,16 +43,17 @@ namespace libfwbuilder {
 namespace fwcompiler {
 
     class TableFactory {
+        BaseCompiler *compiler;
         libfwbuilder::FWObjectDatabase *dbroot;
-        libfwbuilder::FWObject         *persistent_tables;
+        libfwbuilder::FWObject *persistent_tables;
 
         std::map<std::string,libfwbuilder::FWObject*> tables;
-        std::map<std::string,std::string>             tblnames;
+        std::map<std::string,std::string> tblnames;
         std::string generateTblID(libfwbuilder::RuleElement *re);
         std::string ruleSetName;
 
 public:
-        TableFactory();
+        TableFactory(BaseCompiler *comp);
 
         void init(libfwbuilder::FWObjectDatabase *_dbroot);
 
